=== modified file 'NEWS'
--- NEWS	2011-02-19 12:27:30 +0000
+++ NEWS	2011-04-06 14:00:46 +0000
@@ -1,4 +1,20 @@
-0.100.0	UNRELEASED
+0.101.0	UNRELEASED
+
+ FEATURES
+
+  * Internationalization support has been added. (David Planella, #621680)
+
+  * Show avatars for committers and authors in "bzr viz". (Guillaume Hain)
+
+  * gannotate now supports interactive substring search in the file content.
+    interactive search for line numbers has been removed, use Ctrl-G instead.
+    (Sergei Golubchik)
+
+  * visualise now supports interactive changeset comment search.
+    interactive search for revision numbers continues to work.
+    (Sergei Golubchik)
+
+0.100.0	2011-03-02
 
  BUG FIXES
 
@@ -16,6 +32,11 @@
 
   * "bzr viz" now shows authors instead of committers. (Jelmer Vernooij, #693949)
 
+  * Don't use markup for secondary text in error dialogs.
+    (Edward Ari Bichetero, #656641)
+
+  * Generate pickles file when running 'setup.py sdist'. (Jelmer Vernooij, #397526)
+
  FEATURES
  
   * Add lock dialog. (Daniel Schierbeck, #93652)

=== modified file '__init__.py'
--- __init__.py	2011-01-31 10:19:52 +0000
+++ __init__.py	2011-03-06 09:47:57 +0000
@@ -62,6 +62,21 @@
     bzr_plugin_version as version_info,
     bzr_compatible_versions,
     )
+from gettext import (
+    gettext,
+    textdomain,
+    bindtextdomain,
+    bind_textdomain_codeset,
+    )
+
+# FIXME: We should find out LOCALEDIR at compile or run time. The current
+# hardcoded path will work for most distributions, but not for e.g. Solaris and
+# Windows
+GETTEXT_PACKAGE = 'bzr-gtk'
+LOCALEDIR = '/usr/share/locale'
+bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR)
+bind_textdomain_codeset(GETTEXT_PACKAGE, 'UTF-8')
+textdomain(GETTEXT_PACKAGE)
 
 if version_info[3] == 'final':
     version_string = '%d.%d.%d' % version_info[:3]
@@ -181,5 +196,4 @@
 
 
 def _i18n(text):
-    # Stub until we support proper i18n
-    return text
+    return gettext(text)

=== modified file 'about.py'
--- about.py	2010-12-17 22:48:28 +0000
+++ about.py	2011-03-14 20:12:19 +0000
@@ -20,11 +20,15 @@
 except:
     pass
 
-import bzrlib
 import gtk
 import os
 
-from bzrlib.plugins.gtk import data_path, icon_path
+import bzrlib
+
+from bzrlib.plugins.gtk import (
+    data_path,
+    icon_path,
+    )
 
 
 def read_license():

=== modified file 'annotate/colormap.py'
--- annotate/colormap.py	2011-02-18 13:01:03 +0000
+++ annotate/colormap.py	2011-03-14 20:12:19 +0000
@@ -16,7 +16,7 @@
 
 import sys
 
-class AnnotateColorMap:
+class AnnotateColorMap(object):
 
     really_old_color = "#0046FF"
 
@@ -89,7 +89,7 @@
 
     def saturate_v(self, saturation, hv):
         return int(255 - (saturation/3*(1-hv)))
-    
+
     def committer_angle(self, committer):
         return float(abs(hash(committer))) / sys.maxint * 360.0
 

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2011-02-18 13:01:03 +0000
+++ annotate/gannotate.py	2011-03-23 09:49:44 +0000
@@ -27,7 +27,7 @@
 from bzrlib.errors import NoSuchRevision
 from bzrlib.revision import NULL_REVISION, CURRENT_REVISION
 
-from colormap import AnnotateColorSaturation
+from bzrlib.plugins.gtk.annotate.colormap import AnnotateColorSaturation
 from bzrlib.plugins.gtk.revisionview import RevisionView
 from bzrlib.plugins.gtk.window import Window
 
@@ -318,9 +318,12 @@
         col.add_attribute(cell, "text", TEXT_LINE_COL)
         tv.append_column(col)
 
-        # FIXME: Now that C-f is now used for search by text we
-        # may as well disable the auto search.
-        tv.set_search_column(LINE_NUM_COL)
+        # interactive substring search
+        def search_equal_func(model, column, key, iter):
+            return model.get_value(iter, TEXT_LINE_COL).lower().find(key.lower()) == -1
+
+        tv.set_enable_search(True)
+        tv.set_search_equal_func(search_equal_func)
 
         return tv
 

=== modified file 'annotate/spanselector.py'
--- annotate/spanselector.py	2006-05-19 16:56:46 +0000
+++ annotate/spanselector.py	2011-03-14 20:12:19 +0000
@@ -32,10 +32,10 @@
 class SpanSelector(gtk.HBox):
     """Encapsulates creation and functionality of widgets used for changing
     highlight spans.
-    
+
     Note that calling any activate_* methods will emit "span-changed".
     """
-    
+
     max_custom_spans = 4
     custom_spans = []
     last_selected = None
@@ -104,7 +104,7 @@
         self.combo.show()
 
         span = float(w.get_text())
-        
+
         if span == 0:
             # FIXME this works as "cancel", returning to the previous span,
             # but it emits "span-changed", which isn't necessary.
@@ -121,11 +121,11 @@
             self.custom_iter = self.model.insert_after(self.custom_iter,
                                                        self.separator)
             self.custom_iter_top = self.custom_iter.copy()
-        
+
         if len(self.custom_spans) == self.max_custom_spans:
             self.custom_spans.pop(0)
             self.model.remove(self.model.iter_next(self.custom_iter_top))
-        
+
         self.custom_spans.append(span)
         self.custom_iter = self.model.insert_after(
             self.custom_iter, [span, "%.2f Days" % span, False, False])
@@ -143,7 +143,7 @@
                           gobject.TYPE_BOOLEAN)
 
         self.separator = [0., "", True, False]
-        
+
         self.oldest_iter = m.append([0., "to Oldest Revision", False, False])
         self.newest_iter = m.append([0., "Newest to Oldest", False, False])
         m.append(self.separator)
@@ -170,7 +170,7 @@
 
     def _create_custom_entry(self):
         entry = gtk.HBox(False, 6)
-        
+
         spin = gtk.SpinButton(digits=2)
         spin.set_numeric(True)
         spin.set_increments(1., 10.)

=== added file 'avatarproviders.py'
--- avatarproviders.py	1970-01-01 00:00:00 +0000
+++ avatarproviders.py	2011-03-15 16:50:15 +0000
@@ -0,0 +1,110 @@
+# Copyright (C) 2011 by Guillaume Hain (zedtux) <zedtux@zedroot.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+import Queue
+import urllib
+import urllib2
+import hashlib
+import threading
+
+class AvatarProvider(object):
+    """
+    Master class for Avatar providers.
+    
+    All AvatarProviderXxxx classes should inherite from this one
+    and override at least get_base_url.
+    """
+    def __init__(self, size=80):
+        """ Constructor """
+        self.size = size
+    
+    def get_base_url(self):
+        """
+        Override this methode in your provider class in order to return
+        base url of your provider.
+        """
+        raise NotImplementedError("You must implement the get_base_url method.")
+
+
+class AvatarDownloaderWorker(threading.Thread):
+    """
+    Threaded worker to retrieve avatar from a provider.
+    
+    It create a persitante connection to the provider in order
+    to get avatars quickly through the same socket (urllib3).
+    """
+    
+    def __init__(self, provider_method):
+        """
+        Constructor
+        
+        provider_method: Provider method that return fields
+                         to send with the request.
+        """
+        threading.Thread.__init__(self)
+        self.__stop = threading.Event()
+        self.__queue = Queue.Queue()
+        
+        self.__provider_method = provider_method
+        self.__end_thread = False
+    
+    def stop(self):
+        """ Stop this worker """
+        self.__end_thread = True
+        self.__stop.set()
+    
+    def set_callback_method(self, method):
+        """ Fire the given callback method when treatment is finished """
+        self.__callback_method = method
+    
+    def queue(self, id_field):
+        """
+        Put in Queue the id_field to treat in the thread.
+        This id_field is for example with Gravatar the email address.
+        """
+        self.__queue.put(id_field)
+    
+    def run(self):
+        """ Worker core code. """
+        while not self.__end_thread:
+            id_field = self.__queue.get()
+            # Call provider method to get fields to pass in the request
+            url = self.__provider_method(id_field)
+            # Execute the request
+            response = urllib2.urlopen(url)
+            # Fire the callback method
+            if not self.__callback_method is None:
+                self.__callback_method(response, id_field)
+            self.__queue.task_done()
+
+
+class AvatarProviderGravatar(AvatarProvider):
+    """ Gravatar provider """
+    
+    def __init__(self):
+        """ Constructor """
+        super(AvatarProviderGravatar, self).__init__()
+    
+    def get_base_url(self):
+        return "http://www.gravatar.com/avatar.php?"
+    
+    def gravatar_id_for_email(self, email):
+        """ Return a converted email address to a gravatar_id """
+        return self.get_base_url() + \
+                urllib.urlencode({
+                    'gravatar_id':hashlib.md5(email.lower()).hexdigest(),
+                    'size':str(self.size)
+                })

=== added file 'avatarsbox.py'
--- avatarsbox.py	1970-01-01 00:00:00 +0000
+++ avatarsbox.py	2011-03-15 23:05:04 +0000
@@ -0,0 +1,250 @@
+# Copyright (C) 2011 by Guillaume Hain (zedtux) <zedtux@zedroot.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+import gtk
+
+from bzrlib.config import parse_username
+
+from bzrlib.plugins.gtk import _i18n
+from bzrlib.plugins.gtk.avatarproviders import AvatarProviderGravatar, AvatarDownloaderWorker
+
+
+class Avatar(gtk.Box):
+    """ Author or committer avatar """
+    
+    def __init__(self, apparent_username):
+        """ Constructor """
+        gtk.Box.__init__(self)
+        
+        self.apparent_username = apparent_username
+        self.username, self.email = parse_username(apparent_username)
+        self.image = None
+    
+    def __eq__(self, other):
+        """
+        Return True if attributes of the given avatar
+        match to current object attributes otherwise return False
+        """
+        return self.apparent_username == other.apparent_username and \
+               self.name == other.name and \
+               self.email == other.email
+    
+    # ~~~~~ Public methods ~~~~~
+    def show_spinner(self):
+        """
+        Replace the current content of the Avatar with a gtk.Spinner
+        if an email address has been parsed. If not, show an gtk.Label with
+        the translatable 'No email' text.
+        """
+        if not self.email is "":
+            spinner = gtk.Spinner()
+            spinner.start()
+            self.pack_start(spinner, False)
+            spinner.set_tooltip_text(_i18n("Retrieving avatar for %s...") % self.email)
+            spinner.set_size_request(20, 20)
+            spinner.show()
+        else:
+            no_email = gtk.Label(_i18n("No email"))
+            self.pack_start(no_email)
+            self.set_tooltip_text(self.apparent_username)
+            no_email.show()
+    
+    def show_image(self):
+        """ Replace the current content of the Avatar with the gtk.Image """
+        if not self.email is "" and self.image:
+            self.remove(self.get_children()[0])
+            self.pack_start(self.image)
+            self.image.set_tooltip_text(self.apparent_username)
+            self.image.show()
+
+
+class AvatarBox(gtk.HBox):
+    """ Improved gtk.HBox """
+    
+    def __init__(self, homogeneous=False, spacing=0):
+        """ Constructor """
+        gtk.HBox.__init__(self, homogeneous, spacing)
+        self.__avatars = {}
+        self.avatar = None
+        self.__displaying = None
+    
+    
+    # ~~~~~ Public methods ~~~~~
+    def reset_view(self):
+        """ Remove current avatars from the gtk box """
+        for child in self.get_children():
+            self.remove(child)
+        self.__displaying = None
+    
+    def have_avatar(self, avatar):
+        """
+        Return True if this box has registered given avatar,
+        otherwise return False
+        """
+        return avatar.email in self.__avatars
+    
+    def showing(self, avatar):
+        """
+        Return True if the displaying avatar is the same
+        as the given one otherwise return False
+        """
+        return self.__displaying and self.__displaying == avatar
+    
+    def append_avatars_with(self, avatar):
+        """
+        Append avatars collection with the given one if not already registed
+        otherwise render it back.
+        When an avatar is added this method True, otherwise, if the avatar
+        was in the collection, return False.
+        """
+        if not avatar.email is "" and not avatar.email in self.__avatars:
+            self.__avatars[avatar.email] = avatar
+            self._new_cell_for_avatar(avatar)
+            return True
+        else:
+            self.and_avatar_email(avatar.email).come_back_to_gui()
+        return False
+    
+    def and_avatar_email(self, email):
+        """
+        Select the avatar from avatars collection
+        in order to apply future actions
+        """
+        self.avatar = None
+        if not email is "" and email in self.__avatars:
+            self.avatar = self.__avatars[email]
+        else:
+            self.avatar = None
+        return self
+    
+    def update_avatar_image_from_pixbuf_loader(self, loader):
+        """ Replace the gtk.Spinner with the given loader """
+        if self.avatar:
+            self.avatar.image = gtk.Image()
+            self.avatar.image.set_from_pixbuf(loader.get_pixbuf())
+            self.avatar.show_image()
+            self.__displaying = self.avatar
+    
+    def come_back_to_gui(self):
+        """ Render back avatar in the GUI """
+        if self.avatar:
+            self.pack_start(self.avatar)
+            self.__displaying = self.avatar
+        else:
+            self._show_no_email()
+    
+    
+    # ~~~~~ Private methods ~~~~~~
+    def _new_cell_for_avatar(self, avatar):
+        """ Create a new cell in this box with a gtk.Spinner """
+        avatar.show_spinner()
+        self.pack_start(avatar)
+        avatar.show()
+        self.__displaying = avatar
+    
+    def _show_no_email(self):
+        """ Show a gtk.Label with test 'No email' """
+        no_email = gtk.Label(_i18n("No email"))
+        self.pack_start(no_email)
+        no_email.show()
+
+
+class AvatarsBox(gtk.HBox):
+    """ GTK container for authors and committers avatars """
+    
+    def __init__(self):
+        """ Constructor """
+        gtk.HBox.__init__(self, False, 10)
+        
+        self.__committer_box = None
+        self.__authors_box = None
+        self._init_gui()
+        
+        # If more later you want to implement more avatar providers, to it like this:
+        # Create a new class named AvatarProvider + provider_name that inherit from
+        # the AvatarProvider class.
+        # Implement a method that return url to use in the request.
+        # For example, with Gravatar, the method return the complete url
+        # with MD5 hash of the email address and put the value in a gravatar_id field.
+        # Then create a new worker (manage them in a python dictionnary).
+        provider = AvatarProviderGravatar()
+        self.__worker = AvatarDownloaderWorker(
+            provider.gravatar_id_for_email
+        )
+        # This callback method should be fired bt all workers when a request is done.
+        self.__worker.set_callback_method(self._update_avatar_from_response)
+        self.__worker.start()
+    
+    
+    # ~~~~~ Public methods ~~~~~
+    def add(self, username, role):
+        """
+        Add the given username in the right role box and add in the worker queue.
+        Here again: If you want to implement more providers, you should add the
+        avatar request in all workers queue.
+        """
+        avatar = Avatar(username)
+        if role is "author" and not self._role_box_for("committer").showing(avatar) or role is "committer":
+            if self._role_box_for(role).append_avatars_with(avatar):
+                self.__worker.queue(avatar.email)
+    
+    def merge(self, usernames, role):
+        """ Add avatars from a list """
+        for username in usernames:
+            self.add(username, role)
+    
+    def reset(self):
+        """
+        Request a reset view for all boxes in order to show only avatars
+        of the selected line in the revision view screen.
+        """
+        [self._role_box_for(role).reset_view() for role in ["committer", "author"]]
+    
+    
+    # ~~~~~ Private methods ~~~~~
+    def _init_gui(self):
+        """ Create boxes where avatars will be displayed """
+        # 2 gtk.HBox: One for the committer and one for authors
+        # Committer
+        self.__committer_box = AvatarBox()
+        self.__committer_box.set_size_request(80, 80)
+        self.pack_end(self.__committer_box, False)
+        self.__committer_box.show()
+        # Authors
+        self.__authors_box = AvatarBox()
+        self.pack_end(self.__authors_box, False)
+        self.__authors_box.set_spacing(10)
+        self.__authors_box.show()
+    
+    def _update_avatar_from_response(self, response, email):
+        """
+        Callback method fired by avatar worker when finished.
+        
+        response is a urllib2.urlopen() return value.
+        email is used to identify item from self.__avatars.
+        """
+        if not email is "":
+            # Convert downloaded image from provider to gtk.Image
+            loader = gtk.gdk.PixbufLoader()
+            loader.write(response.read())
+            loader.close()
+            
+            for role in ["committer", "author"]:
+                self._role_box_for(role).and_avatar_email(email).update_avatar_image_from_pixbuf_loader(loader)
+    
+    def _role_box_for(self, role):
+        """ Return the gtk.HBox for the given role """
+        return self.__committer_box if role is "committer" else self.__authors_box

=== added file 'bazaar-properties.desktop'
--- bazaar-properties.desktop	1970-01-01 00:00:00 +0000
+++ bazaar-properties.desktop	2011-03-06 08:24:07 +0000
@@ -0,0 +1,9 @@
+[Desktop Entry]
+Name=Bazaar Preferences
+Comment=Configure Bazaar settings
+Icon=bzr-icon-64
+Exec=bzr gpreferences
+Terminal=false
+Type=Application
+Categories=Settings;
+OnlyShowIn=GNOME;

=== renamed file 'bazaar-properties.desktop' => 'bazaar-properties.desktop.in'
--- bazaar-properties.desktop	2009-10-06 13:57:12 +0000
+++ bazaar-properties.desktop.in	2010-08-21 09:32:13 +0000
@@ -1,6 +1,6 @@
 [Desktop Entry]
-Name=Bazaar Preferences
-Comment=Configure Bazaar settings
+_Name=Bazaar Preferences
+_Comment=Configure Bazaar settings
 Icon=bzr-icon-64
 Exec=bzr gpreferences
 Terminal=false

=== modified file 'branch.py'
--- branch.py	2008-05-05 18:16:46 +0000
+++ branch.py	2011-03-14 20:12:19 +0000
@@ -24,16 +24,19 @@
 
 import gtk
 
-from errors import show_bzr_error
-
+from bzrlib import (
+    errors,
+    )
 from bzrlib.branch import Branch
-import bzrlib.errors as errors
+from bzrlib.transport import get_transport
+
 
 from bzrlib.plugins.gtk import _i18n
 
-from dialog import error_dialog, info_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog, info_dialog
+from bzrlib.plugins.gtk.errors import show_bzr_error
+from bzrlib.plugins.gtk.branchbox import BranchSelectionBox
 
-from branchbox import BranchSelectionBox
 
 class BranchDialog(gtk.Dialog):
     """ New implementation of the Branch dialog. """
@@ -44,10 +47,10 @@
                                   parent=parent,
                                   flags=0,
                                   buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
-        
+
         # Get arguments
         self.path = path
-        
+
         # Create the widgets
         self._button_branch = gtk.Button(_i18n("_Branch"), use_underline=True)
         self._remote_branch = BranchSelectionBox()
@@ -62,7 +65,7 @@
         self._hbox_revision = gtk.HBox()
         self._entry_revision = gtk.Entry()
         self._entry_nick = gtk.Entry()
-        
+
         # Set callbacks
         self._button_branch.connect('clicked', self._on_branch_clicked)
         self._button_revision.connect('clicked', self._on_revision_clicked)
@@ -78,7 +81,7 @@
         self._table.attach(self._filechooser, 1, 2, 1, 2)
         self._table.attach(self._entry_nick, 1, 2, 2, 3)
         self._table.attach(self._hbox_revision, 1, 2, 3, 4)
-        
+
         # Set properties
         self._image_browse = gtk.Image()
         self._image_browse.set_from_stock(gtk.STOCK_OPEN, gtk.ICON_SIZE_BUTTON)
@@ -94,16 +97,16 @@
             self._remote_branch.set_url(remote_path)
         if self.path is not None:
             self._filechooser.set_filename(self.path)
-        
+
         # Pack some widgets
         self._hbox_revision.pack_start(self._entry_revision, True, True)
         self._hbox_revision.pack_start(self._button_revision, False, False)
         self.vbox.add(self._table)
         self.action_area.pack_end(self._button_branch)
-        
+
         # Show the dialog
         self.vbox.show_all()
-    
+
     def _get_last_revno(self):
         """ Get the revno of the last revision (if any). """
         try:
@@ -111,12 +114,12 @@
             return br.revno()
         except:
             pass
-    
+
     def _on_revision_clicked(self, button):
         """ Browse for revision button clicked handler. """
         from revbrowser import RevisionBrowser
-        
-        
+
+
         try:
             br = self._remote_branch.get_branch()
         except:
@@ -125,13 +128,13 @@
         response = revb.run()
         if response != gtk.RESPONSE_NONE:
             revb.hide()
-    
+
             if response == gtk.RESPONSE_OK:
                 if revb.selected_revno is not None:
                     self._entry_revision.set_text(revb.selected_revno)
-        
+
             revb.destroy()
-    
+
     @show_bzr_error
     def _on_branch_clicked(self, button):
         """ Branch button clicked handler. """
@@ -140,32 +143,30 @@
             error_dialog(_i18n('Missing branch location'),
                          _i18n('You must specify a branch location.'))
             return
-        
+
         destination = self._filechooser.get_filename()
         try:
             revno = int(self._entry_revision.get_text())
         except:
             revno = None
-        
+
         nick = self._entry_nick.get_text()
         if nick is '':
             nick = os.path.basename(location.rstrip("/\\"))
-        
+
         br_from = Branch.open(location)
-        
+
         br_from.lock_read()
         try:
-            from bzrlib.transport import get_transport
-
             revision_id = br_from.get_rev_id(revno)
 
             basis_dir = None
-            
+
             to_location = destination + os.sep + nick
             to_transport = get_transport(to_location)
-            
+
             to_transport.mkdir('.')
-            
+
             try:
                 # preserve whatever source format we have.
                 dir = br_from.bzrdir.sprout(to_transport.base,
@@ -178,12 +179,12 @@
                 raise
         finally:
             br_from.unlock()
-                
+
         info_dialog(_i18n('Branching successful'),
                     _i18n('%d revision(s) branched.') % revs)
-        
+
         self.response(gtk.RESPONSE_OK)
-    
+
     def _on_branch_changed(self, widget, event):
         """ We try to get the last revision if focus lost. """
         rev = self._get_last_revno()

=== modified file 'branchbox.py'
--- branchbox.py	2010-05-29 23:42:20 +0000
+++ branchbox.py	2011-03-14 20:12:19 +0000
@@ -20,18 +20,21 @@
 except:
     pass
 
+import gtk
+import gobject
+
 from bzrlib.branch import Branch
 from bzrlib.config import GlobalConfig
-import gtk
-from history import UrlHistory
-import gobject
+
+from bzrlib.plugins.gtk.history import UrlHistory
 
 class BranchSelectionBox(gtk.HBox):
+
     def __init__(self, path=None):
         gobject.GObject.__init__(self)
         self._combo = gtk.ComboBoxEntry()
         self._combo.child.connect('focus-out-event', self._on_combo_changed)
-        
+
         # Build branch history
         self._history = UrlHistory(GlobalConfig(), 'branch_history')
         self._build_history()
@@ -53,17 +56,17 @@
     def _build_history(self):
         """ Build up the branch history. """
         self._combo_model = gtk.ListStore(str)
-        
+
         for item in self._history.get_entries():
             self._combo_model.append([ item ])
-        
+
         self._combo.set_model(self._combo_model)
         self._combo.set_text_column(0)
 
     def _on_combo_changed(self, widget, event):
         self.emit('branch-changed', widget)
 
-gobject.signal_new('branch-changed', BranchSelectionBox, 
+gobject.signal_new('branch-changed', BranchSelectionBox,
                    gobject.SIGNAL_RUN_LAST,
                    gobject.TYPE_NONE, (gobject.TYPE_OBJECT,))
 gobject.type_register(BranchSelectionBox)

=== modified file 'branchview/graphcell.py'
--- branchview/graphcell.py	2008-04-02 23:21:11 +0000
+++ branchview/graphcell.py	2011-03-14 20:12:19 +0000
@@ -30,7 +30,7 @@
       in_lines          (start, end, colour) tuple list to draw inward lines,
       out_lines         (start, end, colour) tuple list to draw outward lines.
     """
-    
+
     columns_len = 0
 
     __gproperties__ = {
@@ -51,7 +51,7 @@
                           gobject.PARAM_WRITABLE
                         ),
         }
-    
+
     def do_set_property(self, property, value):
         """Set properties from GObject properties."""
         if property.name == "node":
@@ -181,7 +181,7 @@
         ctx.fill()
 
         self.render_tags(ctx, widget.create_pango_context(), cell_area, box_size)
-    
+
     def render_line(self, ctx, cell_area, box_size, mid, height, start, end, colour, flags):
         if start is None:
             ctx.set_line_cap(cairo.LINE_CAP_ROUND)
@@ -190,7 +190,7 @@
             ctx.line_to(x, mid + height / 3)
             ctx.move_to(x, mid + height / 6)
             ctx.line_to(x, mid + height / 6)
-            
+
         elif end is None:
             ctx.set_line_cap(cairo.LINE_CAP_ROUND)
             x = cell_area.x + box_size * start + box_size / 2
@@ -203,9 +203,9 @@
             ctx.set_line_cap(cairo.LINE_CAP_BUTT)
             startx = cell_area.x + box_size * start + box_size / 2
             endx = cell_area.x + box_size * end + box_size / 2
-            
+
             ctx.move_to(startx, mid - height / 2)
-            
+
             if start - end == 0 :
                 ctx.line_to(endx, mid + height / 2 + 1)
             else:

=== modified file 'branchview/linegraph.py'
--- branchview/linegraph.py	2009-12-10 16:13:32 +0000
+++ branchview/linegraph.py	2011-03-14 20:12:19 +0000
@@ -12,6 +12,7 @@
 from bzrlib.tsort import merge_sort
 from bzrlib import ui
 
+
 def linegraph(graph, start_revs, maxnum=None, broken_line_length=None,
               graph_data=True, mainline_only=False, root_progress=None):
     """Produce a directed graph of a bzr repository.
@@ -26,7 +27,7 @@
     * revid_index is a dict of each revision with the key being the revid, and
       the value the row index, and
     * columns_len is the number of columns need to draw the line graph.
-    
+
 
     Node is a tuple of (column, colour) with column being a zero-indexed
     column number of the graph that this revision represents and colour
@@ -92,17 +93,17 @@
             generate_revno=True)
     else:
         merge_sorted_revisions = ()
-    
+
     if mainline_only:
         merge_sorted_revisions = [elem for elem in merge_sorted_revisions \
                                   if len(elem[3])==1 ]
 
     assert merge_sorted_revisions[0][1] == "top:"
     merge_sorted_revisions = merge_sorted_revisions[1:]
-    
+
     revid_index = {}
     revno_index = {}
-    
+
     # This will hold an item for each "branch". For a revisions, the revsion
     # number less the least significant digit is the branch_id, and used as the
     # key for the dict. Hence revision with the same revsion number less the
@@ -111,9 +112,9 @@
     # and these two revisions will be in the same branch line. Each value is
     # a list of rev_indexes in the branch.
     branch_lines = {}
-    
-    linegraph = []    
-    
+
+    linegraph = []
+
     update_root_progress(3)
     progress_bar = ui.ui_factory.nested_progress_bar()
     try:
@@ -129,7 +130,7 @@
             if maxnum and rev_index >= maxnum:
                 break
             revid_index[revid] = rev_index
-            
+
             parents = graph_parents[revid]
             linegraph.append([revid,
                               None,
@@ -137,26 +138,26 @@
                               parents,
                               None,
                               revno_sequence])
-            
+
             if graph_data:
                 revno_index[revno_sequence] = rev_index
-                
+
                 branch_id = revno_sequence[0:-1]
-                
+
                 branch_line = None
                 if branch_id not in branch_lines:
                     branch_line = []
                     branch_lines[branch_id] = branch_line
                 else:
                     branch_line = branch_lines[branch_id]
-                
-                branch_line.append(rev_index)        
+
+                branch_line.append(rev_index)
     finally:
         progress_bar.finished()
 
     if graph_data:
         branch_ids = branch_lines.keys()
-    
+
         def branch_id_cmp(x, y):
             """Compaire branch_id's first by the number of digits, then reversed
             by their value"""
@@ -165,7 +166,7 @@
             if len_x == len_y:
                 return -cmp(x, y)
             return cmp(len_x, len_y)
-        
+
         branch_ids.sort(branch_id_cmp)
         # This will hold a tuple of (child_index, parent_index, col_index) for each
         # line that needs to be drawn. If col_index is not none, then the line is
@@ -178,8 +179,8 @@
         # cell allready contains a node or line. This use when deciding what column
         # to place a branch line or line in, without it overlaping something else.
         columns = [list(empty_column)]
-        
-        
+
+
         update_root_progress(4)
         progress_bar = ui.ui_factory.nested_progress_bar()
         try:
@@ -188,7 +189,7 @@
                 if i % 25 == 0:
                     progress_bar.update(None, i)
                 branch_line = branch_lines[branch_id]
-                
+
                 # Find the col_index for the direct parent branch. This will be the
                 # starting point when looking for a free column.
                 parent_col_index = 0
@@ -200,13 +201,13 @@
                         parent_node = linegraph[parent_index][1]
                         if parent_node:
                             parent_col_index = parent_node[0]
-                        
-                
+
+
                 col_search_order = _branch_line_col_search_order(columns,
                                                                  parent_col_index)
                 color = reduce(lambda x, y: x+y, branch_id, 0)
                 cur_cont_line = []
-                
+
                 line_range = []
                 last_rev_index = None
                 for rev_index in branch_line:
@@ -217,17 +218,17 @@
                             line_range.append(rev_index-1)
                         else:
                             line_range.extend(range(last_rev_index+1, rev_index))
-                    
+
                     line_range.append(rev_index)
                     last_rev_index = rev_index
-                
+
                 if parent_index:
                     if broken_line_length and \
                        parent_index - last_rev_index > broken_line_length:
                         line_range.append(last_rev_index+1)
                     else:
                         line_range.extend(range(last_rev_index+1, parent_index))
-                
+
                 col_index = _find_free_column(columns,
                                               empty_column,
                                               col_search_order,
@@ -236,21 +237,21 @@
                 for rev_index in branch_line:
                     linegraph[rev_index][1] = node
                     columns[col_index][rev_index] = True
-                
+
                 for rev_index in branch_line:
                     (sequence_number,
                          revid,
                          merge_depth,
                          revno_sequence,
                          end_of_merge) = merge_sorted_revisions[rev_index]
-                    
+
                     linegraph[rev_index][4] = graph_children[revid]
                     col_index = linegraph[rev_index][1][0]
-                    
+
                     for parent_revid in graph_parents[revid]:
                         if parent_revid in revid_index:
-                            
-                            parent_index = revid_index[parent_revid]                            
+
+                            parent_index = revid_index[parent_revid]
                             parent_node = linegraph[parent_index][1]
                             if parent_node:
                                 parent_col_index = parent_node[0]
@@ -260,7 +261,7 @@
                                     _line_col_search_order(columns,
                                                            parent_col_index,
                                                            col_index)
-                                
+
                             # If this line is really long, break it.
                             if len(branch_id) > 0 and \
                                broken_line_length and \
@@ -273,7 +274,7 @@
                                 _mark_column_as_used(columns,
                                                      child_line_col_index,
                                                      (rev_index + 1,))
-                                
+
                                 # Recall _line_col_search_order to reset it back to
                                 # the beging.
                                 col_search_order = \
@@ -309,7 +310,7 @@
                                               (line_col_index,)))
         finally:
             progress_bar.finished()
-        
+
         update_root_progress(5)
         progress_bar = ui.ui_factory.nested_progress_bar()
         try:
@@ -319,7 +320,7 @@
                     progress_bar.update(None, i)
                 (child_col_index, child_color) = linegraph[child_index][1]
                 (parent_col_index, parent_color) = linegraph[parent_index][1]
-                
+
                 if len(line_col_indexes) == 1:
                     if parent_index - child_index == 1:
                         linegraph[child_index][2].append(
@@ -335,7 +336,7 @@
                         # lines down the line's column
                         for line_part_index in range(child_index+1, parent_index-1):
                             linegraph[line_part_index][2].append(
-                                (line_col_indexes[0],   
+                                (line_col_indexes[0], 
                                  line_col_indexes[0],
                                  parent_color))
                         # line from the line's column to the parent's column
@@ -355,7 +356,7 @@
                         (line_col_indexes[0],
                          None,
                          parent_color))
-                    
+
                     # Broken line end 
                     linegraph[parent_index-2][2].append(
                         (None,
@@ -371,7 +372,7 @@
         return (linegraph, revid_index, len(columns))
     else:
         return (linegraph, revid_index, 0)
-    
+
 
 def _branch_line_col_search_order(columns, parent_col_index):
     for col_index in range(parent_col_index, len(columns)):
@@ -417,7 +418,7 @@
 def _mark_column_as_used(columns, col_index, line_range):
     column = columns[col_index]
     for row_index in line_range:
-        column[row_index] = True    
+        column[row_index] = True
 
 def same_branch(a, b):
     """Return whether we think revisions a and b are on the same branch."""

=== modified file 'branchview/treemodel.py'
--- branchview/treemodel.py	2011-02-18 13:16:37 +0000
+++ branchview/treemodel.py	2011-03-14 20:12:19 +0000
@@ -9,13 +9,15 @@
 
 import gtk
 import gobject
-import re
 from xml.sax.saxutils import escape
 
 from bzrlib.config import parse_username
 from bzrlib.revision import NULL_REVISION
 
-from time import (strftime, localtime)
+from time import (
+    strftime,
+    localtime,
+    )
 
 REVID = 0
 NODE = 1

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2011-02-19 12:27:30 +0000
+++ branchview/treeview.py	2011-04-06 14:00:46 +0000
@@ -9,15 +9,15 @@
 import gtk
 import gobject
 import pango
-import treemodel
+
 from bzrlib import ui
-
-from bzrlib.plugins.gtk.ui import ProgressPanel
-from linegraph import linegraph, same_branch
-from graphcell import CellRendererGraph
-from treemodel import TreeModel
 from bzrlib.revision import NULL_REVISION
+
 from bzrlib.plugins.gtk import lock
+from bzrlib.plugins.gtk.ui import ProgressPanel
+from bzrlib.plugins.gtk.branchview import treemodel
+from bzrlib.plugins.gtk.branchview.linegraph import linegraph, same_branch
+from bzrlib.plugins.gtk.branchview.graphcell import CellRendererGraph
 
 
 class TreeView(gtk.VBox):
@@ -232,7 +232,7 @@
             lock.acquire(self.branch, lock.READ)
 
             self.emit('tag-added', tag, revid)
-        
+
     def refresh(self):
         gobject.idle_add(self.populate, self.get_revision())
 
@@ -298,7 +298,7 @@
                 broken_line_length = 32
             else:
                 broken_line_length = None
-            
+
             show_graph = self.graph_column.get_visible()
 
             self.branch.lock_read()
@@ -310,7 +310,7 @@
                                                             self.mainline_only,
                                                             self.progress_bar)
 
-            self.model = TreeModel(self.branch, linegraphdata)
+            self.model = treemodel.TreeModel(self.branch, linegraphdata)
             self.graph_cell.columns_len = columns_len
             width = self.graph_cell.get_size(self.treeview)[2]
             if width > 500:
@@ -334,8 +334,19 @@
         self.treeview = gtk.TreeView()
 
         self.treeview.set_rules_hint(True)
-        self.treeview.set_search_column(treemodel.REVNO)
-        
+        # combined revno/summary interactive search
+        #
+        # the row in a treemodel is considered "matched" if a REVNO *starts*
+        # from the key (that is the key is found in a REVNO at the offset 0)
+        # or if a MESSAGE *contains* the key anywhere (that is, the key is
+        # found case insensitively in a MESSAGE at any offset)
+        def search_equal_func(model, column, key, iter):
+            return (model.get_value(iter, treemodel.REVNO).find(key) != 0
+                and model.get_value(iter, treemodel.MESSAGE).lower().find(key.lower()) == -1)
+
+        self.treeview.set_search_equal_func(search_equal_func)
+        self.treeview.set_enable_search(True)
+
         # Fix old PyGTK bug - by JAM
         set_tooltip = getattr(self.treeview, 'set_tooltip_column', None)
         if set_tooltip is not None:
@@ -411,9 +422,9 @@
         self.date_column.pack_start(cell, expand=True)
         self.date_column.add_attribute(cell, "text", treemodel.TIMESTAMP)
         self.treeview.append_column(self.date_column)
-        
+
         return self.treeview
-    
+
     def _on_selection_changed(self, treeview):
         """callback for when the treeview changes."""
         (path, focus) = treeview.get_cursor()

=== modified file 'bzr-handle-patch'
--- bzr-handle-patch	2010-04-13 15:06:17 +0000
+++ bzr-handle-patch	2011-04-04 17:52:28 +0000
@@ -2,7 +2,8 @@
 
 from bzrlib import errors, merge_directive
 from bzrlib.plugin import load_plugins
-from bzrlib.plugins.gtk import open_display
+from bzrlib.plugins.gtk.commands import open_display
+
 load_plugins()
 
 import sys

=== added file 'bzr-handle-patch.desktop'
--- bzr-handle-patch.desktop	1970-01-01 00:00:00 +0000
+++ bzr-handle-patch.desktop	2011-03-06 08:24:07 +0000
@@ -0,0 +1,10 @@
+[Desktop Entry]
+Name=Bazaar
+Comment=Apply Bazaar Bundle
+Icon=bzr-icon-64
+Exec=bzr-handle-patch %f
+NoDisplay=true
+Terminal=false
+Type=Application
+Categories=Application;Development;RevisionControl;
+MimeType=text/x-diff;text/x-patch;application/x-bazaar-merge-directive;

=== renamed file 'bzr-handle-patch.desktop' => 'bzr-handle-patch.desktop.in'
--- bzr-handle-patch.desktop	2008-10-14 19:49:27 +0000
+++ bzr-handle-patch.desktop.in	2010-08-21 09:32:13 +0000
@@ -1,6 +1,6 @@
 [Desktop Entry]
-Name=Bazaar
-Comment=Apply Bazaar Bundle
+_Name=Bazaar
+_Comment=Apply Bazaar Bundle
 Icon=bzr-icon-64
 Exec=bzr-handle-patch %f
 NoDisplay=true

=== modified file 'bzr-notify'
--- bzr-notify	2011-02-15 00:15:40 +0000
+++ bzr-notify	2011-04-02 12:42:35 +0000
@@ -9,7 +9,7 @@
 from bzrlib.plugin import load_plugins
 load_plugins()
 
-from bzrlib.plugins.gtk import open_display, icon_path
+from bzrlib.plugins.gtk.commands import open_display
 
 from bzrlib.plugins.gtk.notify import NotifyPopupMenu
 gtk = open_display()

=== added file 'bzr-notify.desktop'
--- bzr-notify.desktop	1970-01-01 00:00:00 +0000
+++ bzr-notify.desktop	2011-03-06 08:24:07 +0000
@@ -0,0 +1,10 @@
+[Desktop Entry]
+Type=Application
+Version=0.1
+Name=Bazaar Notification
+GenericName=Bazaar Notification
+Comment=Notification Area Icon for Bazaar
+Icon=bzr-icon-64
+Exec=bzr-notify
+Categories=Application;Development;RevisionControl;
+Terminal=false

=== renamed file 'bzr-notify.desktop' => 'bzr-notify.desktop.in'
--- bzr-notify.desktop	2009-10-06 13:57:12 +0000
+++ bzr-notify.desktop.in	2010-08-21 09:32:13 +0000
@@ -1,9 +1,9 @@
 [Desktop Entry]
 Type=Application
 Version=0.1
-Name=Bazaar Notification
-GenericName=
-Comment=Notification Area Icon for Bazaar
+_Name=Bazaar Notification
+_GenericName=Bazaar Notification
+_Comment=Notification Area Icon for Bazaar
 Icon=bzr-icon-64
 Exec=bzr-notify
 Categories=Application;Development;RevisionControl;

=== modified file 'checkout.py'
--- checkout.py	2010-05-29 23:42:20 +0000
+++ checkout.py	2011-03-14 20:12:19 +0000
@@ -25,27 +25,28 @@
 import gtk
 
 from bzrlib.plugins.gtk import _i18n
-from errors import show_bzr_error
 
 from bzrlib.branch import Branch
 from bzrlib.config import GlobalConfig
 
-from dialog import error_dialog
+from bzrlib.plugins.gtk.dialog import error_dialog
+from bzrlib.plugins.gtk.errors import show_bzr_error
+from bzrlib.plugins.gtk.history import UrlHistory
 
-from history import UrlHistory
 
 class CheckoutDialog(gtk.Dialog):
     """ New implementation of the Checkout dialog. """
+
     def __init__(self, path=None, parent=None, remote_path=None):
         """ Initialize the Checkout dialog. """
         gtk.Dialog.__init__(self, title="Checkout - Olive",
                                   parent=parent,
                                   flags=0,
                                   buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
-        
+
         # Get arguments
         self.path = path
-        
+
         # Create the widgets
         self._button_checkout = gtk.Button(_i18n("Check_out"), use_underline=True)
         self._button_revision = gtk.Button('')
@@ -61,12 +62,12 @@
         self._entry_nick = gtk.Entry()
         self._check_lightweight = gtk.CheckButton(_i18n("_Lightweight checkout"),
                                                   use_underline=True)
-        
+
         # Set callbacks
         self._button_checkout.connect('clicked', self._on_checkout_clicked)
         self._button_revision.connect('clicked', self._on_revision_clicked)
         self._combo.child.connect('focus-out-event', self._on_combo_changed)
-        
+
         # Create the table and pack the widgets into it
         self._table = gtk.Table(rows=3, columns=2)
         self._table.attach(self._label_location, 0, 1, 0, 1)
@@ -78,7 +79,7 @@
         self._table.attach(self._entry_nick, 1, 2, 2, 3)
         self._table.attach(self._hbox_revision, 1, 2, 3, 4)
         self._table.attach(self._check_lightweight, 1, 2, 4, 5)
-        
+
         # Set properties
         self._image_browse.set_from_stock(gtk.STOCK_OPEN, gtk.ICON_SIZE_BUTTON)
         self._button_revision.set_image(self._image_browse)
@@ -95,30 +96,30 @@
             self._filechooser.set_filename(self.path)
         if remote_path is not None:
             self._combo.child.set_text(remote_path)
-        
+
         # Pack some widgets
         self._hbox_revision.pack_start(self._entry_revision, True, True)
         self._hbox_revision.pack_start(self._button_revision, False, False)
         self.vbox.add(self._table)
         self.action_area.pack_end(self._button_checkout)
-        
+
         # Show the dialog
         self.vbox.show_all()
-        
+
         # Build checkout history
         self._history = UrlHistory(GlobalConfig(), 'branch_history')
         self._build_history()
-    
+
     def _build_history(self):
         """ Build up the checkout history. """
         self._combo_model = gtk.ListStore(str)
-        
+
         for item in self._history.get_entries():
             self._combo_model.append([ item ])
-        
+
         self._combo.set_model(self._combo_model)
         self._combo.set_text_column(0)
-    
+
     def _get_last_revno(self):
         """ Get the revno of the last revision (if any). """
         location = self._combo.get_child().get_text()
@@ -128,13 +129,13 @@
             return None
         else:
             return br.revno()
-    
+
     def _on_revision_clicked(self, button):
         """ Browse for revision button clicked handler. """
         from revbrowser import RevisionBrowser
-        
+
         location = self._combo.get_child().get_text()
-        
+
         try:
             br = Branch.open(location)
         except:
@@ -144,13 +145,13 @@
             response = revb.run()
             if response != gtk.RESPONSE_NONE:
                 revb.hide()
-        
+
                 if response == gtk.RESPONSE_OK:
                     if revb.selected_revno is not None:
                         self._entry_revision.set_text(revb.selected_revno)
-            
+
                 revb.destroy()
-    
+
     @show_bzr_error
     def _on_checkout_clicked(self, button):
         """ Checkout button clicked handler. """
@@ -159,31 +160,31 @@
             error_dialog(_i18n('Missing branch location'),
                          _i18n('You must specify a branch location.'))
             return
-        
+
         destination = self._filechooser.get_filename()
         try:
             revno = int(self._entry_revision.get_text())
         except:
             revno = None
-        
+
         nick = self._entry_nick.get_text()
         if nick is '':
             nick = os.path.basename(location.rstrip("/\\"))
-        
+
         br_from = Branch.open(location)
-        
+
         revision_id = br_from.get_rev_id(revno)
         lightweight = self._check_lightweight.get_active()
         to_location = destination + os.sep + nick
-        
+
         os.mkdir(to_location)
-        
+
         br_from.create_checkout(to_location, revision_id, lightweight)
-        
+
         self._history.add_entry(location)
-        
+
         self.response(gtk.RESPONSE_OK)
-    
+
     def _on_combo_changed(self, widget, event):
         """ We try to get the last revision if focus lost. """
         rev = self._get_last_revno()

=== modified file 'conflicts.py'
--- conflicts.py	2011-02-18 13:01:03 +0000
+++ conflicts.py	2011-03-14 20:12:19 +0000
@@ -27,8 +27,10 @@
 
 from bzrlib.config import GlobalConfig
 from bzrlib.plugins.gtk import _i18n
-
-from dialog import error_dialog, warning_dialog
+from bzrlib.plugins.gtk.dialog import (
+    error_dialog,
+    warning_dialog,
+    )
 
 
 class ConflictsDialog(gtk.Dialog):
@@ -40,10 +42,10 @@
                                   parent=parent,
                                   flags=0,
                                   buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CANCEL))
-        
+
         # Get arguments
         self.wt = wt
-        
+
         # Create the widgets
         self._scrolledwindow = gtk.ScrolledWindow()
         self._treeview = gtk.TreeView()
@@ -52,10 +54,10 @@
         self._image_diff3 = gtk.Image()
         self._button_diff3 = gtk.Button()
         self._hbox_diff3 = gtk.HBox()
-        
+
         # Set callbacks
         self._button_diff3.connect('clicked', self._on_diff3_clicked)
-        
+
         # Set properties
         self._scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC,
                                         gtk.POLICY_AUTOMATIC)
@@ -65,7 +67,7 @@
         self._hbox_diff3.set_spacing(3)
         self.vbox.set_spacing(3)
         self.set_default_size(400, 300)
-        
+
         # Construct dialog
         self._hbox_diff3.pack_start(self._label_diff3, False, False)
         self._hbox_diff3.pack_start(self._entry_diff3, True, True)
@@ -73,13 +75,13 @@
         self._scrolledwindow.add(self._treeview)
         self.vbox.pack_start(self._scrolledwindow, True, True)
         self.vbox.pack_start(self._hbox_diff3, False, False)
-        
+
         # Create the conflict list
         self._create_conflicts()
-        
+
         # Show the dialog
         self.vbox.show_all()
-    
+
     def _get_diff3(self):
         """ Get the specified diff3 utility. Default is meld. """
         config = GlobalConfig()
@@ -87,12 +89,12 @@
         if diff3 is None:
             diff3 = 'meld'
         return diff3
-    
+
     def _set_diff3(self, cmd):
         """ Set the default diff3 utility to cmd. """
         config = GlobalConfig()
         config.set_user_option('gconflicts_diff3', cmd)
-    
+
     def _create_conflicts(self):
         """ Construct the list of conflicts. """
         if len(self.wt.conflicts()) == 0:
@@ -100,7 +102,7 @@
             self._treeview.set_model(self.model)
             self._treeview.append_column(gtk.TreeViewColumn(_i18n('Conflicts'),
                                          gtk.CellRendererText(), text=0))
-            self._treeview.set_headers_visible(False)            
+            self._treeview.set_headers_visible(False)
             self.model.append([ _i18n("No conflicts in working tree.") ])
             self._button_diff3.set_sensitive(False)
         else:
@@ -134,29 +136,29 @@
                     t = _i18n("deleting parent")
                 else:
                     t = _i18n("unknown type of conflict")
-                
-                self.model.append([ conflict.path, t, conflict.typestring ]) 
-    
+
+                self.model.append([ conflict.path, t, conflict.typestring ])
+
     def _get_selected_file(self):
         """ Return the selected conflict's filename. """
         treeselection = self._treeview.get_selection()
         (model, iter) = treeselection.get_selected()
-        
+
         if iter is None:
             return None
         else:
             return model.get_value(iter, 0)
-    
+
     def _get_selected_type(self):
         """ Return the type of the selected conflict. """
         treeselection = self._treeview.get_selection()
         (model, iter) = treeselection.get_selected()
-        
+
         if iter is None:
             return None
         else:
             return model.get_value(iter, 2)
-    
+
     def _on_diff3_clicked(self, widget):
         """ Launch external utility to resolve conflicts. """
         self._set_diff3(self._entry_diff3.get_text())

=== modified file 'dialog.py'
--- dialog.py	2008-07-27 07:59:23 +0000
+++ dialog.py	2011-03-14 20:12:19 +0000
@@ -25,15 +25,15 @@
 
 def _message_dialog(type, primary, secondary, parent=None, buttons=gtk.BUTTONS_OK):
     """ Display a given type of MessageDialog with the given message.
-    
+
     :param type: message dialog type
-    
+
     :param message: the message you want to display.
     """
     dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL, type=type, parent=parent,
                                buttons=buttons)
     dialog.set_markup('<big><b>' + primary + '</b></big>')
-    dialog.format_secondary_markup(secondary)
+    dialog.format_secondary_text(secondary)
     response = dialog.run()
     dialog.destroy()
     return response

=== modified file 'diff.py'
--- diff.py	2010-10-08 14:26:56 +0000
+++ diff.py	2011-03-14 20:12:19 +0000
@@ -41,12 +41,16 @@
     urlutils,
     workingtree,
 )
-from bzrlib.diff import show_diff_trees, internal_diff
+from bzrlib.diff import show_diff_trees
 from bzrlib.patches import parse_patches
 from bzrlib.trace import warning
 from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.window import Window
-from dialog import error_dialog, info_dialog, warning_dialog
+from bzrlib.plugins.gtk.dialog import (
+    error_dialog,
+    info_dialog,
+    warning_dialog,
+    )
 
 
 def fallback_guess_language(slm, content_type):

=== modified file 'errors.py'
--- errors.py	2011-02-18 13:01:03 +0000
+++ errors.py	2011-03-14 20:12:19 +0000
@@ -14,9 +14,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import bzrlib.errors as errors
+from bzrlib import errors
 from bzrlib.plugins.gtk import _i18n
-from dialog import error_dialog, info_dialog
+from bzrlib.plugins.gtk.dialog import (
+    error_dialog,
+    info_dialog,
+    )
 
 
 def show_bzr_error(unbound):

=== modified file 'info.py'
--- info.py	2011-01-17 03:38:49 +0000
+++ info.py	2011-03-02 15:24:46 +0000
@@ -20,7 +20,7 @@
 # versions ending in 'exp' mean experimental mappings
 # versions ending in 'dev' mean development version
 # versions ending in 'final' mean release (well tested, etc)
-bzr_plugin_version = (0, 99, 1, 'final', 0)
+bzr_plugin_version = (0, 101, 0, 'dev', 0)
 
 #FIXME: fill this in automatically somehow
 bzr_commands = []

=== modified file 'initialize.py'
--- initialize.py	2008-05-05 18:16:46 +0000
+++ initialize.py	2011-03-14 20:12:19 +0000
@@ -24,16 +24,20 @@
 
 import os
 
-from dialog import error_dialog
-from errors import show_bzr_error
+from bzrlib import (
+    bzrdir,
+    errors,
+    transport,
+    )
 
-from bzrlib import bzrdir
-from bzrlib import transport
-import bzrlib.errors as errors
 from bzrlib.plugins.gtk import _i18n
+from bzrlib.plugins.gtk.dialog import error_dialog
+from bzrlib.plugins.gtk.errors import show_bzr_error
+
 
 class InitDialog(gtk.Dialog):
     """ Initialize dialog. """
+
     def __init__(self, path, parent=None):
         """ Initialize the Initialize dialog. """
         gtk.Dialog.__init__(self, title="Initialize - Olive",

=== modified file 'lock.py'
--- lock.py	2011-02-18 11:53:18 +0000
+++ lock.py	2011-03-14 20:12:19 +0000
@@ -1,4 +1,3 @@
-
 import gtk
 
 

=== modified file 'loom.py'
--- loom.py	2008-07-31 01:55:07 +0000
+++ loom.py	2011-03-14 20:12:19 +0000
@@ -26,8 +26,11 @@
 from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.diff import DiffWidget
 from bzrlib.plugins.gtk.dialog import question_dialog
-from bzrlib.plugins.loom import branch as loom_branch
-from bzrlib.plugins.loom import tree as loom_tree
+from bzrlib.plugins.loom import (
+    branch as loom_branch,
+    tree as loom_tree,
+    )
+
 
 class LoomDialog(gtk.Dialog):
     """Simple Loom browse dialog."""

=== modified file 'merge.py'
--- merge.py	2008-07-27 11:37:31 +0000
+++ merge.py	2011-03-14 20:12:19 +0000
@@ -28,7 +28,11 @@
 import bzrlib.errors as errors
 
 from bzrlib.plugins.gtk import _i18n, icon_path
-from bzrlib.plugins.gtk.dialog import error_dialog, info_dialog, warning_dialog
+from bzrlib.plugins.gtk.dialog import (
+    error_dialog,
+    info_dialog,
+    warning_dialog,
+    )
 from bzrlib.plugins.gtk.errors import show_bzr_error
 
 

=== modified file 'mergedirective.py'
--- mergedirective.py	2011-02-18 13:01:03 +0000
+++ mergedirective.py	2011-03-14 20:12:19 +0000
@@ -20,7 +20,6 @@
 except:
     pass
 
-import bzrlib
 import gtk
 
 from bzrlib.plugins.gtk.branchbox import BranchSelectionBox
@@ -37,7 +36,7 @@
         # submittted
 
         # TODO: Create a frame with a the ability to select a branch
-        
+
         # TODO: Create a frame with a button for selecting a file name 
         # for the bundle
         pass

=== modified file 'nautilus-bzr.py'
--- nautilus-bzr.py	2011-02-18 13:01:03 +0000
+++ nautilus-bzr.py	2011-03-14 20:12:19 +0000
@@ -8,22 +8,29 @@
 
 import gtk
 import nautilus
-import bzrlib
 from bzrlib.branch import Branch
 from bzrlib.bzrdir import BzrDir
-from bzrlib.errors import NotBranchError, NoWorkingTree, UnsupportedProtocol
+from bzrlib.errors import (
+    NotBranchError,
+    NoWorkingTree,
+    UnsupportedProtocol,
+    )
 from bzrlib.workingtree import WorkingTree
 from bzrlib.config import GlobalConfig
 
 from bzrlib.plugin import load_plugins
 load_plugins()
 
-from bzrlib.plugins.gtk.commands import cmd_gannotate, start_viz_window
+from bzrlib.plugins.gtk.commands import (
+    cmd_gannotate,
+    start_viz_window,
+    )
 
 print "Bazaar nautilus module initialized"
 
 
 class BzrExtension(nautilus.MenuProvider, nautilus.ColumnProvider, nautilus.InfoProvider):
+
     def __init__(self):
         pass
 

=== added file 'po/Makevars'
--- po/Makevars	1970-01-01 00:00:00 +0000
+++ po/Makevars	2010-08-21 09:38:06 +0000
@@ -0,0 +1,2 @@
+top_builddir=../
+XGETTEXT_OPTIONS =  --keyword=_i18n --keyword=_ --keyword=N_ --keyword=U_

=== added file 'po/POTFILES.in'
--- po/POTFILES.in	1970-01-01 00:00:00 +0000
+++ po/POTFILES.in	2011-03-06 08:24:07 +0000
@@ -0,0 +1,20 @@
+bazaar-properties.desktop.in
+bzr-handle-patch.desktop.in
+bzr-notify.desktop.in
+branch.py
+branchview/treeview.py
+checkout.py
+commands.py
+commit.py
+conflicts.py
+diff.py
+errors.py
+initialize.py
+loom.py
+merge.py
+nautilus-bzr.py
+push.py
+revbrowser.py
+search.py
+status.py
+tags.py

=== added file 'po/POTFILES.skip'
--- po/POTFILES.skip	1970-01-01 00:00:00 +0000
+++ po/POTFILES.skip	2011-03-06 08:24:07 +0000
@@ -0,0 +1,2 @@
+setup.cfg
+setup.py

=== added file 'po/bzr-gtk.pot'
--- po/bzr-gtk.pot	1970-01-01 00:00:00 +0000
+++ po/bzr-gtk.pot	2011-03-06 08:24:07 +0000
@@ -0,0 +1,696 @@
+# SOME DESCRIPTIVE TITLE.
+# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
+# This file is distributed under the same license as the PACKAGE package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
+#
+#, fuzzy
+msgid ""
+msgstr ""
+"Project-Id-Version: PACKAGE VERSION\n"
+"Report-Msgid-Bugs-To: \n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
+"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
+"Language-Team: LANGUAGE <LL@li.org>\n"
+"Language: \n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=CHARSET\n"
+"Content-Transfer-Encoding: 8bit\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr ""
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr ""
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr ""
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr ""
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr ""
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr ""
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr ""
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr ""
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr ""
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr ""
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr ""
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr ""
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr ""
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr ""
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr ""
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr ""
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr ""
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr ""
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr ""
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr ""
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid "There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr ""
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr ""
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr ""
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr ""
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr ""
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr ""
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr ""
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr ""
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr ""
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr ""
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr ""
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr ""
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr ""
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr ""
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr ""
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr ""
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr ""
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr ""
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr ""
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr ""
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr ""
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr ""
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr ""
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr ""
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr ""
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr ""
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr ""
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr ""
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr ""
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr ""
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr ""
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr ""
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr ""
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr ""
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr ""
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr ""
+
+#: ../status.py:100
+msgid "Removed"
+msgstr ""
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr ""
+
+#: ../status.py:113
+msgid "Modified"
+msgstr ""
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr ""
+
+#: ../status.py:126
+msgid "No changes."
+msgstr ""
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr ""
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr ""
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr ""
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr ""
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr ""
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr ""
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr ""
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr ""
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr ""
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr ""
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""

=== modified file 'po/ca.po'
--- po/ca.po	2008-03-11 17:01:27 +0000
+++ po/ca.po	2011-03-08 04:41:48 +0000
@@ -7,245 +7,336 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2007-10-01 20:42+0000\n"
-"Last-Translator: David Planella <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-07 18:37+0000\n"
+"Last-Translator: David Planella <david.planella@ubuntu.com>\n"
 "Language-Team: Ubuntu Catalan Translators <ubuntu-l10n-ca@lists.ubuntu.com>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr "Preferències del Bazaar"
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr "Configureu els paràmetres del Bazaar"
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr "Bazaar"
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr "Notificacions del Bazaar"
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr "Icona a l'àrea de notificació per al Bazaar"
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "Crea una _branca"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Seleccioneu una carpeta"
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Ubicació de la branca:"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destinació:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Sobrenom de la branca:"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisió"
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Seleccioneu una carpeta"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Manca la ubicació de la branca"
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Heu d'especificar la ubicació de la branca."
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "S'ha creat la branca satisfactòriament"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "S'ha creat una branca de %d revisions."
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/A"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "_Obté"
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr "Sobrenom de la branca:"
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Obtenció _lleugera"
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "El directori no té cap arbre de treball"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "S'ha interromput l'operació"
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "El directori no és una branca"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr "No podeu dur a terme aquesta acció en una branca."
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Hi ha modificacions locals a la branca"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "Heu de publicar o desfer els canvis abans de poder fer la fusió."
+
+#: ../commit.py:182
+msgid "added"
+msgstr "afegit"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "suprimit"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "canviat de nom"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "nom canviat i modificat"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "modificat"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "_Només publica localment"
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Pu_blica"
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr "Fitxers a publicar"
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr "Missatge de publicació"
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr "Fusions pendents"
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr "_Només publica localment"
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr "Voleu publicar-ho amb un missatge buit?"
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr "Podeu descriure el vostre intent de publicació en el missatge"
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr "Voleu publicar-ho tot i haver-hi fitxers desconeguts?"
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-"Hi ha fitxers desconeguts en l'arbre de treball. Voleu publicar de totes "
-"maneres?"
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr "Voleu publicar sense canvis?"
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr "No hi ha cap canvi en l'arbre de treball."
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr "Fitxers"
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Publica"
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Camí"
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Tipus"
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr "afegit"
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr "suprimit"
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr "nom canviat i modificat"
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr "canviat de nom"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr "modificat"
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr "Data"
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Publicador"
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Resum"
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Voleu publicar-ho amb un missatge buit?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "Podeu descriure el vostre intent de publicació en el missatge"
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "Voleu publicar-ho tot i haver-hi fitxers desconeguts?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+"Hi ha fitxers desconeguts en l'arbre de treball. Voleu publicar de totes "
+"maneres?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "Voleu publicar sense canvis?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Eina externa:"
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflictes"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "No hi ha cap conflicte en l'arbre de treball."
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflicte de camí"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflicte de contingut"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflicte de text"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "identificador duplicat"
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicat"
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "bucle del pare"
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "pare sense versionar"
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "manca el pare"
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "supressió del pare"
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "tipus de conflicte desconegut"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "No s'ha seleccionat cap fitxer"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Seleccioneu un fitxer de la llista."
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Ha fallat l'execució de l'eina externa"
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "No es pot resoldre el conflicta"
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -255,36 +346,79 @@
 "Els conflictes de contingut, de l'estructura de l'arbre, s'han de resoldre a "
 "la línia d'ordres."
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Visualització"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "S'ha fusionat correctament"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "S'han aplicat tots els canvis correctament."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "S'han trobat conflictes."
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "Heu de resoldre els conflictes manualment abans de poder publicar."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "El directori no és una branca"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "No podeu dur a terme aquesta acció en una branca."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "El directori no és una obtenció"
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Només podeu fer publicacions locals en obtencions."
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "No hi ha cap canvi per a publicar"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 "Intenteu una publicació forçada si és que voleu publicar de totes maneres."
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Hi ha conflictes en l'arbre"
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "Heu de resoldre els conflictes abans de publicar."
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "La publicació estricta ha fallat"
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -292,28 +426,29 @@
 "Hi ha fitxers desconeguts a l'arbre de treball.\n"
 "Hauríeu d'afegir-los o suprimir-los."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "La branca lligada no està actualitzada"
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Fitxer no versionat"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "El fitxer seleccionat no és versionat"
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "S'han divergit les branques"
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -322,35 +457,35 @@
 "Utilitzeu la opció de sobreescriptura si voleu\n"
 "empènyer de totes maneres."
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Sense sortida diff"
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "El fitxer seleccionat no ha estat modificat."
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "No existeix tal revisió"
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "La revisió que heu especificat no existeix."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "La destinació ja existeix"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "El directori objectiu ja existeix. Seleccioneu-ne un altre."
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "El directori ja és una branca"
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -359,11 +494,11 @@
 "El directori actual (%s) ja és una branca.\n"
 "Podeu començar a utilitzar-lo o bé inicialitzar un altre directori."
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Branca sense un arbre de treball"
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -372,97 +507,94 @@
 "El directori actual (%s)\n"
 "és una branca sense cap arbre de treball."
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Error desconegut del bzr"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Se us ha denegat el permís"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "se us ha denegat el permís"
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Error desconegut"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inicialitza"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Quin directori voleu inicialitzar?"
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "El directori actual"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr "Crea un directori nou amb el nom següent:"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "No s'ha especificat cap nom de directori"
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Heu d'especificar un nom per al directori"
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr "Directori"
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr "Ubicació personalitzada"
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Fusiona"
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "No s'ha especificat cap branca"
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 "Heu d'especificar el nom de la branca a partir de la qual es fusionarà"
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Error en l'ordre del Bazaar"
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr "S'ha fusionat correctament"
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr "S'han aplicat tots els canvis correctament."
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr "S'han trobat conflictes."
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr "Heu de resoldre els conflictes manualment abans de poder publicar."
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr "Ubicació:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr "E_mpeny"
 
-#: push.py:97
-msgid "Set default push location"
-msgstr "Establiu la ubicació predeterminada per a empènyer"
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-"No hi ha cap ubicació predeterminada per a empènyer.\n"
-"Voleu establir %r com a tal?"
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -470,20 +602,20 @@
 "No podeu empènyer branques que hagin divergit.\n"
 "Voleu sobreescriure-la?"
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr "S'ha empès satisfactòriament"
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "S'han empès %d revisions."
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "El directori pare no existeix"
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -492,831 +624,665 @@
 "El directori pare %s\n"
 "no existeix. El voleu crear?"
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr "S'estan carregant les revisions. Espereu un moment..."
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Selecciona"
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr "NúmRev"
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr "Hora"
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr "Cerca:"
+
+#: ../search.py:56
+msgid "Document"
+msgstr "Document"
+
+#: ../status.py:94
 msgid "Added"
 msgstr "Afegit"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr "Suprimit"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Nom canviat"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificat"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Desconegut"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "Sense canvis."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Etiquetes"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr "Nom de l'etiqueta"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr "Identificador de la revisió"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Les etiquetes no estan implementades en aquest format de branca. Hauríeu "
 "d'actualitzar-lo."
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "No hi ha cap revisió etiquetada a la branca."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Suprimeix l'etiqueta"
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Voleu suprimir l'etiqueta?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Esteu segur de voler suprimir l'etiqueta: <b>%s</b>?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Afegeix una etiqueta"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nom de l'etiqueta:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Identificador de la revisió:"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "No s'ha especificat cap nom per a l'etiqueta"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Heu d'especificar un nom per a l'etiqueta."
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr "Hi ha modificacions locals a la branca"
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr "Heu de publicar o desfer els canvis abans de poder fer la fusió."
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr "Es desconeix la ubicació pare"
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-"No es poden determinar les revisions que manquen si la ubicació pare és "
-"desconeguda."
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr "Manquen revisions"
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr "Manquen %d revisions."
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr "Branca local actualitzada"
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr "No manquen revisions."
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr "No podeu estirar sense una ubicació pare."
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr "L'estirada s'ha completat satisfactòriament"
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr "S'han estirat %d revisions."
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr "S'han detectat conflictes"
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr "Comproveu l'arbre de treball abans de continuar."
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr "S'ha desfet correctament"
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr "S'han tornat tots els fitxers a la darrera revisió."
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Adreces d'interès"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Adreça d'interès"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr "sense canvis"
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr "ignorat"
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr "desconegut"
-
-#: __init__.py:964
-msgid "Filename"
-msgstr "Nom del fitxer"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "Estat"
-
-#: __init__.py:966
-msgid "Size"
-msgstr "Mida"
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr "Darrera modificació"
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-"Seleccioneu un fitxer de la llista\n"
-"o bé escolliu l'altra opció."
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Títol:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr "No s'ha especificat cap títol"
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr "Hauríeu d'especificar un títol per a continuar."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr "No s'ha trobat el fitxer del Glade."
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr "El fitxer de descripció de la IU no s'ha trobat"
-
-#: menu.py:63
-msgid "Add"
-msgstr "Afegeix"
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr "Afegeix el fitxer seleccionat"
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr "Suprimeix"
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr "Suprimeix el fitxer seleccionat"
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr "Suprimeix"
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr "Suprimeix el fitxer o directori del disc"
-
-#: menu.py:75
-msgid "Rename"
-msgstr "Torna a anomenar"
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr "Torna a anomenar el fitxer seleccionat"
-
-#: menu.py:79
-msgid "Open"
-msgstr "Obre"
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr "Obre el fitxer seleccionat"
-
-#: menu.py:83
-msgid "Revert"
-msgstr "Torna a l'estat anterior"
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr "Desfés els canvis"
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr "Publica els canvis"
-
-#: menu.py:91
-msgid "Annotate"
-msgstr "Anota"
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr "Anota el fitxer seleccionat"
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Diferencia"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr "Mostra les diferències del fitxer"
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr "Afegeix la ubicació actual a les adreces d'interès"
-
-#: menu.py:103
-msgid "Edit"
-msgstr "Edita"
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr "Edita l'adreça d'interès seleccionada"
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr "Suprimeix l'adreça d'interès seleccionada"
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr "Obre una carpeta"
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr "Obre una carpeta de les adreces d'interès en el Nautilus"
-
-#: menu.py:115
-msgid "Selected..."
-msgstr "Seleccionat..."
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr "Mostra les diferències del fitxer seleccionat"
-
-#: menu.py:119
-msgid "All..."
-msgstr "Tots..."
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr "Mostra les diferències de tots els fitxers"
-
-#: menu.py:123
-msgid "View contents"
-msgstr "Visualitza el contingut"
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr "Visualitza el contingut del fitxer en un visualitzador integrat"
-
-#: menu.py:127
-msgid "Show differences"
-msgstr "Mostra les diferències"
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr "Mostra les diferències entre dues revisions del fitxer"
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr "Torna a aquesta revisió"
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr "Torna el fitxer seleccionar a la revisió seleccionada"
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr "Voleu suprimir el directori i tots els seus subdirectoris?"
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr "S'ha afegit l'adreça d'interès amb èxit"
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-"El directori actual s'ha afegit a les adreces d'interès.\n"
-"Hi podeu accedir des de quadre de l'esquerra."
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr "La ubicació ja és una adreça d'interès"
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-"El directori actual ja s'ha afegit a les adreces \n"
-"d'interès. Vegeu el quadre de l'esquerra."
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr "No s'ha especificat cap nom de directori"
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr "Hauríeu d'especificar un nom per al directori nou"
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr "El directori ja existeix"
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr "Hauríeu d'especificar un altre nom per a continuar."
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr "Hauríeu de seleccionar un fitxer de la llista per a continuar."
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr "No és la mateixa branca"
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr "La destinació no és a la mateixa branca."
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr "No hi ha fitxers coincidents"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr "No s'ha trobat cap fitxer afegit en l'arbre de treball."
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "Quins fitxers voleu suprimir?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Només els seleccionats"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "Tots els fitxers amb l'estat «added» (afegits)"
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Suprimeix"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr "No s'ha especificat el nom del fitxer"
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr "Hauríeu d'especificar un nom nou per al fitxer."
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - IU del Bazaar"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Fitxer"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Afegeix fitxers..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Suprimeix fitxers..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Crea un _directori..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "Canvia el _nom..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Mou..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr "_Anota..."
-
-#: olive.glade:118
-msgid "_View"
-msgstr "_Visualització"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Mostra els fit_xers ocults"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Refresca"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr "_Inicialitza..."
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Aconsegueix..."
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr "O_bté..."
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr "E_stira"
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr "E_mpeny..."
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr "_Desfés tots els canvis"
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr "_Fusiona..."
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr "_Publica..."
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr "E_tiquetes..."
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "Es_tat..."
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr "_Revisions que manquen"
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr "Con_flictes..."
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "E_stadístiques"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Diferències..."
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "Re_gistre..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr "_Informació..."
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "A_juda"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr "gtk-jump-to"
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr "Mode d'h_istorial"
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  David Planella https://launchpad.net/~dpm"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - addició de fitxers"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Quins fitxers voleu afegir?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr "Tots els desconeguts de manera recursiva"
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Afegeix"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - supressió de fitxers"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - creació d'un directori"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr "Directori _versionat"
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Crea un directori"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - moviment"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Mou a"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Seleccioneu un directori"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Mou"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - canvi de nom"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Canvia el nom a"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "Canvia el _nom"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr "Olive - informació"
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(cap)"
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr "Arrel de l'obtenció: "
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr "Arrel de la branca: "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Obtenció del repositori: "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr "Obtenció de la branca: "
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr "Branca del dipòsit: "
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr "Dipòsit compartit: "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr "Arrel de l'obtenció lleugera: "
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr "<b>Ubicació:</b>"
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr "Publica a la branca: "
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr "Branca pare: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr "<b>Branques relacionades:</b>"
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr "Format del dipòsit: "
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr "Format de la branca: "
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr "Format de l'arbre de treball: "
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr "Format del control: "
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr "<b>Format:</b>"
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr "Estat del blocatge del dipòsit: "
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr "Estat del blocatge de la branca: "
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr "Estat del blocatge de l'arbre de treball: "
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr "<b>Estat del blocatge:</b>"
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr "Revisions que manquen a la branca: "
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr "Revisions que manquen en l'arbre de treball: "
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr "<b>Revisions que manquen:</b>"
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr "Subdirectoris versionats: "
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "Fitxers ignorats: "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Fitxers desconeguts: "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Fitxers amb el nom canviat: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Fitxers suprimits: "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Fitxers afegits: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Fitxers modificats: "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Fitxers no modificats: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr "<b>En l'arbre de treball:</b>"
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr "Data de la darrera revisió "
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Data de la primera revisió: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr "Edat de la branca en dies: "
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr "Nombre de publicadors: "
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr "Revisions en la branca: "
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr "<b>Historial de branca:</b>"
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr "Mida del dipòsit: "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr "Revisions al dipòsit: "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr "<b>Dipòsit de revisions:</b>"
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr "Fusió - Olive"
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr "Fusiona des de:"
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr "_Fusiona"
+#~ msgid "_Rename..."
+#~ msgstr "Canvia el _nom..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Mou..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Crea un _directori..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Suprimeix fitxers..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - IU del Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Afegeix fitxers..."
+
+#~ msgid "_File"
+#~ msgstr "_Fitxer"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Refresca"
+
+#~ msgid "_Get..."
+#~ msgstr "_Aconsegueix..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Mostra els fit_xers ocults"
+
+#~ msgid "C_heckout..."
+#~ msgstr "O_bté..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "E_stira"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Es_tat..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Publica..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "E_mpeny..."
+
+#~ msgid "_Log..."
+#~ msgstr "Re_gistre..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferències..."
+
+#~ msgid "_Statistics"
+#~ msgstr "E_stadístiques"
+
+#~ msgid "_Help"
+#~ msgstr "A_juda"
+
+#~ msgid "Diff"
+#~ msgstr "Diferencia"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Quins fitxers voleu afegir?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - addició de fitxers"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Tots els fitxers amb l'estat «added» (afegits)"
+
+#~ msgid "_Remove"
+#~ msgstr "_Suprimeix"
+
+#~ msgid "Selected only"
+#~ msgstr "Només els seleccionats"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - supressió de fitxers"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Quins fitxers voleu suprimir?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Tots els desconeguts de manera recursiva"
+
+#~ msgid "_Add"
+#~ msgstr "_Afegeix"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - creació d'un directori"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Directori _versionat"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Crea un directori"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - moviment"
+
+#~ msgid "Move to"
+#~ msgstr "Mou a"
+
+#~ msgid "Rename to"
+#~ msgstr "Canvia el nom a"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - canvi de nom"
+
+#~ msgid "_Move"
+#~ msgstr "_Mou"
+
+#~ msgid "Select a directory"
+#~ msgstr "Seleccioneu un directori"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publica a la branca: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Branca pare: "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Arrel de l'obtenció: "
+
+#~ msgid "(none)"
+#~ msgstr "(cap)"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Obtenció del repositori: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Arrel de la branca: "
+
+#~ msgid "Control format: "
+#~ msgstr "Format del control: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Format de l'arbre de treball: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Fitxers amb el nom canviat: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Fitxers desconeguts: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Fitxers ignorats: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Fitxers no modificats: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Fitxers modificats: "
+
+#~ msgid "Added files: "
+#~ msgstr "Fitxers afegits: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Fitxers suprimits: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Revisions que manquen en l'arbre de treball: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Revisions que manquen a la branca: "
+
+#~ msgid "Title:"
+#~ msgstr "Títol:"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Data de la darrera revisió "
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Seleccioneu un fitxer de la llista\n"
+#~ "o bé escolliu l'altra opció."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Mida del dipòsit: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisions al dipòsit: "
+
+#~ msgid "Pull successful"
+#~ msgstr "L'estirada s'ha completat satisfactòriament"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "S'han estirat %d revisions."
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Manquen revisions"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "No es poden determinar les revisions que manquen si la ubicació pare és "
+#~ "desconeguda."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Branca local actualitzada"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "Manquen %d revisions."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "No manquen revisions."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Afegeix el fitxer seleccionat"
+
+#~ msgid "unchanged"
+#~ msgstr "sense canvis"
+
+#~ msgid "Bookmark"
+#~ msgstr "Adreça d'interès"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Adreces d'interès"
+
+#~ msgid "Status"
+#~ msgstr "Estat"
+
+#~ msgid "Filename"
+#~ msgstr "Nom del fitxer"
+
+#~ msgid "unknown"
+#~ msgstr "desconegut"
+
+#~ msgid "Add"
+#~ msgstr "Afegeix"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "El fitxer de descripció de la IU no s'ha trobat"
+
+#~ msgid "Remove"
+#~ msgstr "Suprimeix"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "El directori actual s'ha afegit a les adreces d'interès.\n"
+#~ "Hi podeu accedir des de quadre de l'esquerra."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "S'ha afegit l'adreça d'interès amb èxit"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "El directori actual ja s'ha afegit a les adreces \n"
+#~ "d'interès. Vegeu el quadre de l'esquerra."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "La ubicació ja és una adreça d'interès"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostra les diferències de tots els fitxers"
+
+#~ msgid "All..."
+#~ msgstr "Tots..."
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Hauríeu d'especificar un nom per al directori nou"
+
+#~ msgid "No directory name given"
+#~ msgstr "No s'ha especificat cap nom de directori"
+
+#~ msgid "Not the same branch"
+#~ msgstr "No és la mateixa branca"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "La destinació no és a la mateixa branca."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Hauríeu d'especificar un nom nou per al fitxer."
+
+#~ msgid "Filename not given"
+#~ msgstr "No s'ha especificat el nom del fitxer"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Obtenció de la branca: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Branca del dipòsit: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Dipòsit compartit: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Arrel de l'obtenció lleugera: "
+
+#~ msgid "_Rename"
+#~ msgstr "Canvia el _nom"
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisions en la branca: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Subdirectoris versionats: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Data de la primera revisió: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Edat de la branca en dies: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Nombre de publicadors: "
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "No s'ha trobat el fitxer del Glade."
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Hauríeu de seleccionar un fitxer de la llista per a continuar."
+
+#~ msgid "Directory already exists"
+#~ msgstr "El directori ja existeix"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Hauríeu d'especificar un altre nom per a continuar."
+
+#~ msgid "Repository format: "
+#~ msgstr "Format del dipòsit: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Estat del blocatge del dipòsit: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Estat del blocatge de la branca: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format de la branca: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Estat del blocatge de l'arbre de treball: "
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Es desconeix la ubicació pare"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Suprimeix el fitxer seleccionat"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "No s'ha trobat cap fitxer afegit en l'arbre de treball."
+
+#~ msgid "No matching files"
+#~ msgstr "No hi ha fitxers coincidents"
+
+#~ msgid "Selected..."
+#~ msgstr "Seleccionat..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostra les diferències del fitxer seleccionat"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Afegeix la ubicació actual a les adreces d'interès"
+
+#~ msgid "Edit"
+#~ msgstr "Edita"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Edita l'adreça d'interès seleccionada"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Suprimeix l'adreça d'interès seleccionada"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Publica els canvis"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostra les diferències del fitxer"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Hauríeu d'especificar un títol per a continuar."
+
+#~ msgid "No title given"
+#~ msgstr "No s'ha especificat cap títol"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Fitxers a publicar"
+
+#~ msgid "Commit message:"
+#~ msgstr "Missatge de publicació"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "No hi ha cap canvi en l'arbre de treball."
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "No hi ha cap ubicació predeterminada per a empènyer.\n"
+#~ "Voleu establir %r com a tal?"
+
+#~ msgid "Set default push location"
+#~ msgstr "Establiu la ubicació predeterminada per a empènyer"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "S'estan carregant les revisions. Espereu un moment..."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "S'han detectat conflictes"
+
+#~ msgid "Last modified"
+#~ msgstr "Darrera modificació"
+
+#~ msgid "Revert successful"
+#~ msgstr "S'ha desfet correctament"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "S'han tornat tots els fitxers a la darrera revisió."
+
+#~ msgid "ignored"
+#~ msgstr "ignorat"
+
+#~ msgid "Size"
+#~ msgstr "Mida"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Comproveu l'arbre de treball abans de continuar."
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "No podeu estirar sense una ubicació pare."
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostra les diferències entre dues revisions del fitxer"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Visualitza el contingut del fitxer en un visualitzador integrat"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostra les diferències"
+
+#~ msgid "Revert"
+#~ msgstr "Torna a l'estat anterior"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Anota el fitxer seleccionat"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Desfés els canvis"
+
+#~ msgid "Annotate"
+#~ msgstr "Anota"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Obre una carpeta de les adreces d'interès en el Nautilus"
+
+#~ msgid "Open Folder"
+#~ msgstr "Obre una carpeta"
+
+#~ msgid "View contents"
+#~ msgstr "Visualitza el contingut"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Mode d'h_istorial"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Branques relacionades:</b>"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Revisions que manquen"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flictes..."
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Ubicació:</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - informació"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Estat del blocatge:</b>"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informació..."
+
+#~ msgid "Pending merges"
+#~ msgstr "Fusions pendents"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Torna a aquesta revisió"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inicialitza..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Anota..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Fusiona..."
+
+#~ msgid "Ta_gs..."
+#~ msgstr "E_tiquetes..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Desfés tots els canvis"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Torna el fitxer seleccionar a la revisió seleccionada"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Voleu suprimir el directori i tots els seus subdirectoris?"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Torna a anomenar el fitxer seleccionat"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Suprimeix"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Suprimeix el fitxer o directori del disc"
+
+#~ msgid "Rename"
+#~ msgstr "Torna a anomenar"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Obre el fitxer seleccionat"
+
+#~ msgid "Open"
+#~ msgstr "Obre"
+
+#~ msgid "Time"
+#~ msgstr "Hora"
+
+#~ msgid "Revno"
+#~ msgstr "NúmRev"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Historial de branca:</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>En l'arbre de treball:</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revisions que manquen:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Dipòsit de revisions:</b>"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusió - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Fusiona des de:"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  David Planella https://launchpad.net/~dpm"

=== modified file 'po/cs.po'
--- po/cs.po	2008-03-11 17:01:27 +0000
+++ po/cs.po	2011-03-10 04:41:02 +0000
@@ -7,1312 +7,806 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2007-08-17 14:17+0000\n"
-"Last-Translator: DarkenCZ <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-09 10:28+0000\n"
+"Last-Translator: Daniel Milde <info@milde.cz>\n"
 "Language-Team: Czech <cs@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
-#, fuzzy
+"X-Launchpad-Export-Date: 2011-03-10 04:40+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Větev"
 
-#: branch.py:55 checkout.py:53
-#, fuzzy
-msgid "Please select a folder"
-msgstr "Prosím vyberte složku"
-
-#: branch.py:57 checkout.py:55
-#, fuzzy
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Umístění větve:"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Cíl:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
-msgstr ""
+msgstr "Označení větve:"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
-msgstr ""
-
-#: branch.py:162 checkout.py:163
+msgstr "Revize:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Zvolte adresář"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr ""
+msgstr "Chybí umístění větve"
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr ""
+msgstr "Musíte zadat umístění větve."
 
-#: branch.py:205
-#, fuzzy
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Větvení bylo úspěšné"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
-msgstr ""
+msgstr "%d revize byla rozvětvena."
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
-msgstr ""
+msgstr "N / A"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr ""
+msgstr "Adresář nemá pracovní strom"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
-msgstr ""
-
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-#, fuzzy
-msgid "Directory is not a branch"
-msgstr "Adresář není větví"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-#, fuzzy
-msgid "You can perform this action only in a branch."
-msgstr "Tento úkon lze provést pouze ve větvi."
-
-#: commit.py:88
+msgstr "Operace byla přerušena."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr "přidáno"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "odstraněno"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "přejmenováno"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "přejmenováno a změněno"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "změněno"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: commit.py:325 conflicts.py:108
-#, fuzzy
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Cesta"
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Typ"
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr "přidáno"
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr ""
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr ""
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr ""
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
-msgstr ""
+msgstr "Datum"
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
-msgstr ""
-
-#: conflicts.py:48
+msgstr "Souhrn"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr ""
+msgstr "Vnější nástroj:"
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
-msgstr ""
+msgstr "Konflikty"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
-msgstr ""
+msgstr "V pracovním stromě nejsou žádné konflikty."
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
-msgstr ""
+msgstr "konflikt cesty"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
-msgstr ""
+msgstr "konflikt obsahu"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
-msgstr ""
+msgstr "konflikt textu"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
-msgstr ""
+msgstr "duplikát"
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
-msgstr ""
+msgstr "neznámý typ konfliktu"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Nebyl zvolen žádný soubor"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
-msgstr ""
+msgstr "Vyberte prosím soubor ze seznamu."
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
-msgstr ""
+msgstr "Konflikt nelze vyřešit"
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Náhled"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Sloučení úspěšné"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Všechny změny byly úspěsně uplatněny."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Adresář není větví"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
-msgstr ""
+msgstr "Konflikty ve stromu"
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
-msgstr ""
+msgstr "Vybraný soubor se nezměnil."
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
-msgstr ""
+msgstr "Revize, kterou jste zadali, neexistuje."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
-msgstr ""
+msgstr "Cíl již existuje"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
-msgstr ""
+msgstr "Cílový adresář již existuje. Vyberte prosím jiný cíl."
 
-#: errors.py:59
-#, fuzzy
+#: ../errors.py:65
 msgid "Directory is already a branch"
-msgstr "Adresář již je větví"
+msgstr ""
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
-msgstr ""
+msgstr "Větev bez pracovního stromu"
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
-msgstr ""
+msgstr "Neznámá chyba bzr"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
-msgstr ""
+msgstr "Přístup odepřen"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
-msgstr ""
+msgstr "Přístup byl odepřen."
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
-msgstr ""
+msgstr "Neznámá chyba"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
-msgstr ""
+msgstr "_Inicializovat"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
-msgstr ""
+msgstr "Současný adresář"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
-msgstr ""
+msgstr "Vytvořit nový adresář se jménem:"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Sloučit"
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
-msgstr ""
+msgstr "Umístění:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
-msgstr ""
-
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+msgstr "_Vybrat"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
-msgstr ""
+msgstr "Přidáno"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
-msgstr ""
+msgstr "Odstraněno"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
-msgstr ""
+msgstr "Přejmenováno"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
-msgstr ""
+msgstr "Upraveno"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
-msgstr ""
+msgstr "Neznámý"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
-msgstr ""
+msgstr "Žádné změny."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
-msgstr ""
+msgstr "ID revize"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-#, fuzzy
-msgid "Local branch up to date"
-msgstr "Lokální větev je aktuální"
-
-#: __init__.py:541
-#, fuzzy
-msgid "There are no missing revisions."
-msgstr "Nechybějí žádné revize"
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Záložky"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Záložka"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Titul:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr ""
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-#, fuzzy
-msgid "Which file(s) do you want to remove?"
-msgstr "Který(é) soubor(y) chcete vyjmout?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-#, fuzzy
-msgid "Selected only"
-msgstr "Pouze vybrané"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Vyjmout"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-#, fuzzy
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - grafické rozhraní pro Bazaar"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Soubor"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Přidat soubor(y)..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Vyjmout soubor(y)..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Vytvořit _adresář..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Přejmenovat..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Přesunout..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr ""
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Zobrazit _skryté soubory"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Obnovit"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Statistika"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Rozdíly..."
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Záznam..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Nápověda"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  DarkenCZ https://launchpad.net/~darkencz\n"
-"  Fred https://launchpad.net/~fredrooks"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Přidat soubor(y)"
-
-#: olive.glade:705
-#, fuzzy
-msgid "Which file(s) do you want to add?"
-msgstr "Který(é) soubor(y) chete přidat?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Přidat"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Vyjmout soubor(y)"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Vytvořit adresář"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Přesunout"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Zvolte adresář"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Přesunout"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Přejmenovat"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Přejmenovat na"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "_Přejmenovat"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-#, fuzzy
-msgid "Branch root: "
-msgstr "Kořen větve: "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-#, fuzzy
-msgid "Repository branch: "
-msgstr "Větev repozitáře: "
-
-#: olive.glade:1428
-#, fuzzy
-msgid "Shared repository: "
-msgstr "Sdílený repozitář: "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-#, fuzzy
-msgid "Publish to branch: "
-msgstr "Publikovat do větve: "
-
-#: olive.glade:1520
-#, fuzzy
-msgid "Parent branch: "
-msgstr "Mateřská větev: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-#, fuzzy
-msgid "Repository format: "
-msgstr "Formát repozitáře: "
-
-#: olive.glade:1626
-#, fuzzy
-msgid "Branch format: "
-msgstr "Formát větve: "
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-#, fuzzy
-msgid "Missing revisions in branch: "
-msgstr "Chybějící revize ve větvi: "
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-#, fuzzy
-msgid "Ignored files: "
-msgstr "Ignorované soubory: "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Neznámé soubory: "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Přejmenované soubory: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Vyjmuté soubory: "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Přidané soubory: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Pozměněné soubory: "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Nepozměněné soubory: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-#, fuzzy
-msgid "Time of last revision: "
-msgstr "Čas poslední revize: "
-
-#: olive.glade:2184
-#, fuzzy
-msgid "Time of first revision: "
-msgstr "Čas první revize: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr "Stáří větve ve dnech: "
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr "Revize ve větvi: "
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-#, fuzzy
-msgid "Size of repository: "
-msgstr "Velikost repozitáře: "
-
-#: olive.glade:2300
-#, fuzzy
-msgid "Revisions in repository: "
-msgstr "Revize v repozitáři: "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "_Make directory"
+#~ msgstr "_Vytvořit adresář"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Přesunout"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Přejmenovat"
+
+#~ msgid "_Move"
+#~ msgstr "_Přesunout"
+
+#~ msgid "Select a directory"
+#~ msgstr "Zvolte adresář"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Přejmenovat..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Vytvořit _adresář..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Vyjmout soubor(y)..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Přidat soubor(y)..."
+
+#~ msgid "_File"
+#~ msgstr "_Soubor"
+
+#~ msgid "_Move..."
+#~ msgstr "_Přesunout..."
+
+#~ msgid "_Refresh"
+#~ msgstr "_Obnovit"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Zobrazit _skryté soubory"
+
+#~ msgid "_Log..."
+#~ msgstr "_Záznam..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Rozdíly..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistika"
+
+#~ msgid "_Help"
+#~ msgstr "_Nápověda"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Přidat soubor(y)"
+
+#~ msgid "_Remove"
+#~ msgstr "_Vyjmout"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Vyjmout soubor(y)"
+
+#~ msgid "_Add"
+#~ msgstr "_Přidat"
+
+#~ msgid "_Rename"
+#~ msgstr "_Přejmenovat"
+
+#~ msgid "Rename to"
+#~ msgstr "Přejmenovat na"
+
+#~ msgid "Modified files: "
+#~ msgstr "Pozměněné soubory: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Nepozměněné soubory: "
+
+#~ msgid "Added files: "
+#~ msgstr "Přidané soubory: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Přejmenované soubory: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Neznámé soubory: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Vyjmuté soubory: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revize ve větvi: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Stáří větve ve dnech: "
+
+#~ msgid "Title:"
+#~ msgstr "Titul:"
+
+#~ msgid "Bookmark"
+#~ msgstr "Záložka"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Záložky"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Daniel Milde https://launchpad.net/~daniel-milde\n"
+#~ "  DarkenCZ https://launchpad.net/~darkencz\n"
+#~ "  Fred https://launchpad.net/~fredrooks\n"
+#~ "  Jan Tojnar https://launchpad.net/~jtojnar\n"
+#~ "  Jan Vlnas https://launchpad.net/~jnv\n"
+#~ "  Konki https://launchpad.net/~pavel-konkol"

=== added file 'po/da.po'
--- po/da.po	1970-01-01 00:00:00 +0000
+++ po/da.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,703 @@
+# Danish translation for bzr-gtk
+# Copyright (c) 2009 Rosetta Contributors and Canonical Ltd 2009
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2009.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-12-06 12:55+0000\n"
+"Last-Translator: Launchpad Translations Administrators "
+"<rosetta@launchpad.net>\n"
+"Language-Team: Danish <da@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr ""
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr ""
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr ""
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr ""
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr ""
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr ""
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr ""
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr ""
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr ""
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr ""
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr ""
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr ""
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr ""
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr ""
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr ""
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr ""
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr ""
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr ""
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr ""
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr ""
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr ""
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr ""
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr ""
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr ""
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr ""
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr ""
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr ""
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr ""
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr ""
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr ""
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr ""
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr ""
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr ""
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr ""
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr ""
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr ""
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr ""
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr ""
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr ""
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr ""
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr ""
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr ""
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr ""
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr ""
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr ""
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr ""
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr ""
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr ""
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr ""
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr ""
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr ""
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr ""
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr ""
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr ""
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr ""
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr ""
+
+#: ../status.py:100
+msgid "Removed"
+msgstr ""
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr ""
+
+#: ../status.py:113
+msgid "Modified"
+msgstr ""
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr ""
+
+#: ../status.py:126
+msgid "No changes."
+msgstr ""
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr ""
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr ""
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr ""
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr ""
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr ""
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr ""
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr ""
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr ""
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr ""
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr ""
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  nanker https://launchpad.net/~nanker"

=== modified file 'po/de.po'
--- po/de.po	2008-03-11 17:01:27 +0000
+++ po/de.po	2011-03-08 04:41:48 +0000
@@ -7,248 +7,336 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-02-04 12:17+0000\n"
-"Last-Translator: Augustus Kling <augustus.kling@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:41+0000\n"
+"Last-Translator: welterde <dev@welterde.de>\n"
 "Language-Team: German <de@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
-#, fuzzy
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Zweig"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Bitte wählen sie ein Verzeichniss"
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Zweig Position:"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Zielort:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Zweig Spitzname:"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revision:"
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Bitte wählen Sie ein Verzeichniss"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Fehlender Zweigpfad"
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Sie müssen einen Zweigpfad angeben."
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Abzweigung erfolgreich"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d Revision(en) abgezweigt."
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "Nicht Verfügbar"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "_Checkout"
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "_Lightweight checkout"
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Verzeichnis hat keine aktive Verzeichnisstruktur"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Aktion abgebrochen."
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "Verzeichnis ist kein Zweig"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr "Sie können diese Aktion nur in einem Zweig ausführen."
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Es gibt lokale Änderungen im dem Zweig"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "Bitte führen sie commit oder revert aus bevor sie mergen."
+
+#: ../commit.py:182
+msgid "added"
+msgstr "hinzugefügt"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "entfernt"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "umbenannt"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "umbenannt und verändert"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "verändert"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "Nur l_okal abschicken"
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Absch_icken"
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr "Datei(en) zu hinzufügen"
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr "Nachricht abschicken"
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr "Wartende Merges"
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr "Nur l_okal abschicken"
-
-#: commit.py:215
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Festlegen"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Pfad"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Typ"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "Datum"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr "Festleger"
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "Zusammenfassung"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Hinzufügen mit Leerer Kommentar?"
 
-#: commit.py:216
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "Du kannst Grund für deine Übermittlung in der Nachricht beschreiben."
 
-#: commit.py:228
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Abschicken mit Unbekannten?"
 
-#: commit.py:229
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Unbekannte Dateien bestehen im aktiven Verzeichnisstruktur. Definitiv "
 "festlegen?"
 
-#: commit.py:240
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Festlegen ohne Änderungen im Arbeitsbaum?"
 
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr "Es gibt keine Änderungen im Arbeitsbaum."
-
-#: commit.py:323 menu.py:87
-msgid "Commit"
-msgstr "Festlegen"
-
-#: commit.py:325 conflicts.py:108
-msgid "Path"
-msgstr "Pfad"
-
-#: commit.py:327 conflicts.py:110
-msgid "Type"
-msgstr "Typ"
-
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr "hinzugefügt"
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr "entfernt"
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr "umbenannt und verändert"
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr "umbenannt"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr "verändert"
-
-#: commit.py:395
-msgid "Date"
-msgstr "Datum"
-
-#: commit.py:397 revbrowser.py:68
-msgid "Committer"
-msgstr "Festleger"
-
-#: commit.py:399 revbrowser.py:66
-msgid "Summary"
-msgstr "Zusammenfassung"
-
-#: conflicts.py:48
-#, fuzzy
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr "Externe Dienste:"
+msgstr ""
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Konflikte"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Kein konflikte im aktiven Verzeichnisstruktur"
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "Pfad konflikt"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "Inhaltskonflikt"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "Text konflikt"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "Doppelte ID"
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "Duplikat"
 
-#: conflicts.py:125
-#, fuzzy
+#: ../conflicts.py:128
 msgid "parent loop"
-msgstr "parent loop"
+msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "unversionierter parent"
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "fehlender parent"
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "lösche parent"
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "Unbekannte type des Konflikts"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Keine Datei wurde ausgewählt"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Wählen Sie bitte eine Datei von der Liste."
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Keine Verbindung mit externem Dienstprogramm möglich"
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Konflikt kann nicht aufgelöst werden"
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -258,37 +346,80 @@
 "Konflikte, im Verzeichnisstruktur des Arbeitsbaum, müssen Sie manuell "
 "beheben in der Kommando Linie."
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "Anzeigen"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Merge erfolgreich"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Alle Änderungen erfolgreich angewendet."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Konflikte gefunden"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "Bitte löse die Konflikte vor der Übermittlung manuell auf."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Verzeichnis ist kein Zweig"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "Sie können diese Aktion nur in einem Zweig ausführen."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Verzeichnis ist kein Austrag"
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Sie können eine lokale Festlegung nur an Austrägen ausführen."
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Keine Änderungen festzulegen"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 "Versuchen Sie eine Zwangsfestlegung, falls Sie trotzdem festlegen wollen."
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Konflikte in der Verzeichnisstruktur"
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 "Sie müssen erst die Konflikte beseitigen, bevor Sie festlegen können."
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Striktes festlegen misslingt"
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -296,28 +427,29 @@
 "Es befinden sich unbekannte Dateien in dem aktiven Verzeichnisstruktur.\n"
 "Fügen Sie bitte diese hinzu oder löschen Sie sie."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "Gebundener Zweig ist veraltet"
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Datei nicht versioniert"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Die ausgewählte Datei ist nicht versioniert."
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Zweige sind geschieden"
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -325,38 +457,37 @@
 "Getrennte Zweige koennen nicht hochgeladen werden. Benutzen\n"
 "Sie die Überschreibungsoption um trotzdem hochzuladen."
 
-#: errors.py:50
-#, fuzzy
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Kein Unterschied gefunden"
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Die gewählte Datei hat sich nicht geändert"
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "keine solche Revision"
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "Die angegebene Revision existiert nicth."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Ziel existiert bereits"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 "Zielverzeichnis existiert schon. Bitte wählen Sie einen anderen "
 "Zielverzeichnis."
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Verzeichnis ist schon ein Zweig"
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -365,11 +496,11 @@
 "Das aktuelle Verzeichnis (%s) ist schon ein Zweig.\n"
 "Sie können es benutzen, oder ein anderes Verzeichnis initialisieren."
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Zweig ohne aktives Verzeichnisstruktur"
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -378,96 +509,93 @@
 "Das aktuelle Verzeichnis (%s)\n"
 "ist ein Zweig ohne funktionsfähige Verzeichnisstruktur."
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Unbekannte bzr Fehler"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Zugriff verboten"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "Zugriff verboten"
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Unbekannte Fehler"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initializieren"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Welches Verzeichnis möchten Sie initialisieren?"
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Aktuelles Verzeichnis"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr "Erzeugen Sie ein neues Verzeichnis mit dem Namen:"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Verzeichnis Name ist nicht spezifiziert"
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Sie solten ein neues Verzeichnis Name spezifizieren"
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Merge"
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Zweig nicht angegeben"
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Bitte geben Sie einen Zweig an von dem gemerged werden soll."
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Bazaar Befehl Fehler"
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr "Merge erfolgreich"
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr "Alle Änderungen erfolgreich angewendet."
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr "Konflikte gefunden"
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr "Bitte löse die Konflikte vor der Übermittlung manuell auf."
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr "Ort:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Drücken"
 
-#: push.py:97
-msgid "Set default push location"
-msgstr "Standard-Push-Ziel einstellen"
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-"Es wurde kein Standard-Push-Ziel eingestellt.\n"
-"Willst du %r als Standard einstellen?"
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -475,20 +603,20 @@
 "Du kannst nicht pushen, wenn die Branches sich unterscheiden.\n"
 "Überschreiben?"
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Hochladen erfolgreich"
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d Revision(en) hochgeladen."
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Nicht-existierendes Überverzeichnis."
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -497,850 +625,675 @@
 "Das Überverzeichnis (%s)\n"
 "existiert nicht. Erzeugen?"
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr "Warten Sie bitte, Revisionen werden geladen..."
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "Aus_wahl"
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr "Revno"
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr "Datum"
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr "Hinzugefügt"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr "Entfernt"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Umbenannt"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Geändert"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Unbekannt"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "Keine Änderungen."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Tags"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr "Tagname"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr "Revision ID"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Tags werden in diesem Branch-Format nicht unterstützt. Bitte upgraden."
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Keine markierten Überarbeitungen im Branch."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Entferne tag"
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Entferne Tag?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Sind sie sicher das Sie das Tag <b>%s</b> entfernen möchten?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "T_ag hinzufügen"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Tag Name:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Revision ID:"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Kein Tag Name angegeben"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Sie müssen den gewünschten Tag Namen angeben."
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr "Es gibt lokale Änderungen im dem Zweig"
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr "Bitte führen sie commit oder revert aus bevor sie mergen."
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr "Vorläuferpfad ist unbekannt"
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-"Kann fehlende Revisionen nicht ermitteln falls Vorläuferpfad unbekannt ist."
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr "Es fehlen Revisionen"
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr "%d fehlende Revision(en)"
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr "Lokaler Zweig ist aktuell"
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr "Es fehlen keine Revisionen."
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr "Herunterladen ist nicht möglich bis es ein Vorläuferpfad existiert."
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr "Herunterladen erfolgreich"
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr "%d Revision(en) heruntergeladen."
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr "Konflikte gefunden"
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-"Schauen Sie bitte das aktive Verzeichnisstruktur an, bevor Sie fortfahren."
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr "Revert erfolgreich"
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-"Sämtliche Dateien wurden zur letzten Revision zurückgesetzt (revert)."
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Lesezeichen"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Lesezeichen"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr "unverändert"
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr "ignoriert"
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr "unbekennt"
-
-#: __init__.py:964
-msgid "Filename"
-msgstr "Dateiname"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "Status"
-
-#: __init__.py:966
-msgid "Size"
-msgstr "Gr&ouml;&szlig;e"
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr "Zuletzt verändert"
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-"Bitte wählen Sie eine Datei aus der Liste,\n"
-"oder wählen Sie eine andere Option."
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Titel:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr "Kein Titel angegeben."
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr "Bitte geben Sie einen Titel an, um fortzufahren."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr "Glade Datei konnte nicht gefunden werden."
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr "UI Beschreibungsdatei konnte nicht gefunden werden."
-
-#: menu.py:63
-msgid "Add"
-msgstr "Hinzufügen"
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr "Ausgewählte Datei hinzufügen"
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr "Entfernen"
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr "Ausgewählte Datei entfernen"
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr "Entfernen und löschen"
-
-#: menu.py:72
-#, fuzzy
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-"Entferne die gewählte(n) Datei(en)/Verzeichnis(se) und lösche sie von der "
-"Festplatte"
-
-#: menu.py:75
-msgid "Rename"
-msgstr "Umbenenen"
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr "Die ausgewählte Datei umbenennen"
-
-#: menu.py:79
-#, fuzzy
-msgid "Open"
-msgstr "Öffnen..."
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr "Öffne die ausgewählte Datei"
-
-#: menu.py:83
-msgid "Revert"
-msgstr "Rückgängig"
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr "Änderung verwerfen"
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr "Änderungen festlegen"
-
-#: menu.py:91
-msgid "Annotate"
-msgstr "Beschreibe"
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr "Breschreibe die gewählte Datei"
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Diff"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr "Dateiendifferenzen anzeigen"
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr "Aktueller Pfad als Lesezeichen abspeichern"
-
-#: menu.py:103
-msgid "Edit"
-msgstr "Bearbeiten"
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr "Ausgewähltes Lesezeichen bearbeiten"
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr "Auswähltes Lesezeichen entfernen"
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr "Öffne Verzeichnis"
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr "Öffne Lesezeichen in Nautilus"
-
-#: menu.py:115
-msgid "Selected..."
-msgstr "Ausgewählt..."
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr "Unterschiede der ausgewählten Dateien anzeigen"
-
-#: menu.py:119
-msgid "All..."
-msgstr "Alles..."
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr "Unterschiede aller Dateien anzeigen"
-
-#: menu.py:123
-msgid "View contents"
-msgstr "Zeige Inhalt an"
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr "Zeige Dateiinhalt an in einem built-in viewer"
-
-#: menu.py:127
-msgid "Show differences"
-msgstr "Zeige differenz ain"
-
-#: menu.py:128
-#, fuzzy
-msgid "Show the differences between two revisions of the file"
-msgstr "Zeige die Unterschiede zwischen zwei Revisionen der Datei"
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr "Bis zu dieser Überarbeitung rückgängig machen"
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr "Die gewählte Datei bis zur gewählten Überarbeitung zurücksetzen."
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr "Lösche Verzeichnis und alle Unterverzeichnisse?"
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr "Lesezeichen erfolgreich hinzugefügt."
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-"Das aktuelle Verzeichnis wurde as Lesezeichen abgespeichert. Sie können\n"
-"es im linken Panel auswählen."
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr "Pfad ist schon als Lesezeichen abgespeichert"
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-"Das aktuelle Verzeichnis wurde schon als Lesezeichen abgespeichert.\n"
-"Bitte berufen Sie sich auf das linke Panel."
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr "Kein Verzeichnisnamen angegeben"
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-"Bitte geben Sie den gewünschten Verzeichnisnamen für das neue Verzeichnis an."
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr "Verzeichnis existiert bereits"
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr "Bitte geben Sie einen anderen Namen an, um fortzufahren."
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr "Bitte wählen Sie eine Datei aus der List aus um fortzufahren."
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr "Nicht dasselbe Zweig"
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr "Das Zielort ist nicht in demselben Zweig."
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr "Keine übereinstimmende Dateien"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-"Keine hinzugefuegten Dateien konnten in der aktiven Verzeichnisstruktur "
-"gefunden werden."
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "Welche Datei(en) wollen Sie entfernen?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Nur ausgewältes"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "Alle Dateien mit Status 'hinzugefügt'"
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Entfernen"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr "Dateienname nicht angegeben"
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr "Bitte geben Sie einen neuen Dateiennamen an."
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - Bazaar GUI"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Datei"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Datei(en) hinzufügen..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Datei(en) entfernen..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Verzeichniss erstellen..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Umbenennen..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Verschieben..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr "_Beschreibe..."
-
-#: olive.glade:118
-msgid "_View"
-msgstr "Anzeigen"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Versteckte Dateien zeigen"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "Aktualisie_ren"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr "_Initialisiere..."
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "Holen..."
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr "Auschecken..."
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr "Herunter_laden"
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr "Hochloaden..."
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr "Alle Änderungen _rückgängig machen"
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr "_Merge..."
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr "Festlegen..."
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr "Ta_gs..."
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "S_tatus..."
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr "Fehlende Übe_rarbeitungen"
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr "Kon_flikte..."
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Statistik"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Unterschiede"
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Logbuch..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr "_Information..."
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Hilfe"
-
-#: olive.glade:548
-#, fuzzy
-msgid "gtk-jump-to"
-msgstr "gtk-jump-to"
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr "H_istory Modus"
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Augustus Kling https://launchpad.net/~augustus-kling\n"
-"  Benjamin Jochheim https://launchpad.net/~benjamin-jochheim\n"
-"  Blackout https://launchpad.net/~coolx67\n"
-"  Mike Bronner https://launchpad.net/~mike.bronner\n"
-"  Philipp Wolfer https://launchpad.net/~phw\n"
-"  Pierre Vorhagen https://launchpad.net/~pep.\n"
-"  Sebastian Wallroth https://launchpad.net/~sebastian-wallroth\n"
-"  Simon Pascal Klein https://launchpad.net/~klepas\n"
-"  welterde https://launchpad.net/~welterde"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Datei(en) hinzufügen"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Welche Datei(en) möchten Sie hinzufügen?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr "Alle unbekannten rekursiv"
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Hinzufügen"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Datei(en) entfernen"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - Verzeichnis erstellen"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr "_Versioniertes Verzeichnis"
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "Verzeichnis erstellen"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Versetzen"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Versetzen nach"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Wählen Sie ein Verzeichnis aus"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Verschieben"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Umbennen"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Umbenennen zu"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "_Umbenennen"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr "Olive - Informationen"
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(nichts)"
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr "Austragsstammpfad: "
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr "Zweigstammpfad: "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Quellenaustrag: "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr "Zweigaustrag: "
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr "Quellenzweig: "
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr "Beteiligte Quelle: "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr "Leichtaustragsstammpfad: "
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr "<b>Ort:</b>"
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr "Zu Zweig veröffentlichen: "
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr "Zweigvorläufer: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr "<b>Verbindende Zweige</b>"
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr "Quellenformat: "
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr "Branch Format "
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr "Aktive Verzeichnisstrukturformat: "
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr "Kontroll Format "
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr "<b>Format:</b>"
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr "Quellen Festlegungsstatus: "
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr "Zweig Festlegungsstatus: "
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr "Arbeitsverzeichnisstruktur SperrFetatus: "
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr "<b>Sperrstatus:</b>"
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr "Fehlende Revisionen in Zweig: "
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr "Fehlende Revisionen in der Arbeitsverzeichnisstruktur: "
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr "<b>Fehlende Revisionen:</b>"
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr "Versionierte Unterverzeichnisse: "
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "Ignorierte Dateien: "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Unbekannte Dateien: "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Umbennante Dateien: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Entfernte Dateien: "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Hinzugefügte Dateien: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Geänderte Dateien: "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Unveränderte Dateien: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr "<b>Im aktiven Verzeichnisstruktur:</b>"
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr "Zeit der letzten Revision: "
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Zeit der ersten Revision: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr "Zweigalter in Tagen: "
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr "Anzahl Festleger: "
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr "Revisionen in Zweig: "
-
-#: olive.glade:2234
-#, fuzzy
-msgid "<b>Branch history:</b>"
-msgstr "<b>Zweig history:</b>"
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr "Quellengrösse: "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr "Revisionen in der Quelle: "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr "<b>Revisions Speicher:</b>"
-
-#: olive.glade:2356
-#, fuzzy
-msgid "Merge - Olive"
-msgstr "Merge - Olive"
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr "Mergen aus:"
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr "_Merge"
+#~ msgid "_Rename..."
+#~ msgstr "_Umbenennen..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Verschieben..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Verzeichniss erstellen..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Datei(en) entfernen..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Datei(en) hinzufügen..."
+
+#~ msgid "_File"
+#~ msgstr "_Datei"
+
+#~ msgid "_Refresh"
+#~ msgstr "Aktualisie_ren"
+
+#~ msgid "_Get..."
+#~ msgstr "Holen..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Versteckte Dateien zeigen"
+
+#~ msgid "C_heckout..."
+#~ msgstr "Auschecken..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Herunter_laden"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Commit..."
+#~ msgstr "Festlegen..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Hochloaden..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Logbuch..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Unterschiede"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistik"
+
+#~ msgid "_Help"
+#~ msgstr "_Hilfe"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Welche Datei(en) möchten Sie hinzufügen?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Datei(en) hinzufügen"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Alle Dateien mit Status 'hinzugefügt'"
+
+#~ msgid "_Remove"
+#~ msgstr "_Entfernen"
+
+#~ msgid "Selected only"
+#~ msgstr "Nur ausgewältes"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Datei(en) entfernen"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Welche Datei(en) wollen Sie entfernen?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Alle unbekannten rekursiv"
+
+#~ msgid "_Add"
+#~ msgstr "_Hinzufügen"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Verzeichnis erstellen"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Versioniertes Verzeichnis"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Versetzen"
+
+#~ msgid "Move to"
+#~ msgstr "Versetzen nach"
+
+#~ msgid "_Make directory"
+#~ msgstr "Verzeichnis erstellen"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Umbennen"
+
+#~ msgid "_Move"
+#~ msgstr "_Verschieben"
+
+#~ msgid "Select a directory"
+#~ msgstr "Wählen Sie ein Verzeichnis aus"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Austragsstammpfad: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Quellenaustrag: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Zweigstammpfad: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Zweigaustrag: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Quellenzweig: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Beteiligte Quelle: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Leichtaustragsstammpfad: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Umbenennen"
+
+#~ msgid "Rename to"
+#~ msgstr "Umbenennen zu"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Zu Zweig veröffentlichen: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Zweigvorläufer: "
+
+#~ msgid "(none)"
+#~ msgstr "(nichts)"
+
+#~ msgid "Control format: "
+#~ msgstr "Kontroll Format "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Aktive Verzeichnisstrukturformat: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Quellenformat: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Branch Format "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Quellen Festlegungsstatus: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Zweig Festlegungsstatus: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Arbeitsverzeichnisstruktur SperrFetatus: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Umbennante Dateien: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Unbekannte Dateien: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ignorierte Dateien: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Versionierte Unterverzeichnisse: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Unveränderte Dateien: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Geänderte Dateien: "
+
+#~ msgid "Added files: "
+#~ msgstr "Hinzugefügte Dateien: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Entfernte Dateien: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Fehlende Revisionen in Zweig: "
+
+#~ msgid "Title:"
+#~ msgstr "Titel:"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Bitte wählen Sie eine Datei aus der Liste,\n"
+#~ "oder wählen Sie eine andere Option."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Quellengrösse: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisionen in der Quelle: "
+
+#~ msgid "No title given"
+#~ msgstr "Kein Titel angegeben."
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisionen in Zweig: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Fehlende Revisionen in der Arbeitsverzeichnisstruktur: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Anzahl Festleger: "
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Bitte geben Sie einen Titel an, um fortzufahren."
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Vorläuferpfad ist unbekannt"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Es fehlen Revisionen"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Kann fehlende Revisionen nicht ermitteln falls Vorläuferpfad unbekannt ist."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Lokaler Zweig ist aktuell"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d fehlende Revision(en)"
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Es fehlen keine Revisionen."
+
+#~ msgid "unchanged"
+#~ msgstr "unverändert"
+
+#~ msgid "Bookmark"
+#~ msgstr "Lesezeichen"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Lesezeichen"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade Datei konnte nicht gefunden werden."
+
+#~ msgid "unknown"
+#~ msgstr "unbekennt"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Lesezeichen erfolgreich hinzugefügt."
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Unterschiede aller Dateien anzeigen"
+
+#~ msgid "All..."
+#~ msgstr "Alles..."
+
+#~ msgid "Selected..."
+#~ msgstr "Ausgewählt..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Unterschiede der ausgewählten Dateien anzeigen"
+
+#~ msgid "Edit"
+#~ msgstr "Bearbeiten"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Ausgewähltes Lesezeichen bearbeiten"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Auswähltes Lesezeichen entfernen"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Nicht dasselbe Zweig"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "Das Zielort ist nicht in demselben Zweig."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Bitte geben Sie einen neuen Dateiennamen an."
+
+#~ msgid "Filename not given"
+#~ msgstr "Dateienname nicht angegeben"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr ""
+#~ "Keine hinzugefuegten Dateien konnten in der aktiven Verzeichnisstruktur "
+#~ "gefunden werden."
+
+#~ msgid "No matching files"
+#~ msgstr "Keine übereinstimmende Dateien"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Zeit der letzten Revision: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Zeit der ersten Revision: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Zweigalter in Tagen: "
+
+#~ msgid "Pull successful"
+#~ msgstr "Herunterladen erfolgreich"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d Revision(en) heruntergeladen."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Pfad ist schon als Lesezeichen abgespeichert"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Das aktuelle Verzeichnis wurde as Lesezeichen abgespeichert. Sie können\n"
+#~ "es im linken Panel auswählen."
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Das aktuelle Verzeichnis wurde schon als Lesezeichen abgespeichert.\n"
+#~ "Bitte berufen Sie sich auf das linke Panel."
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr ""
+#~ "Bitte geben Sie den gewünschten Verzeichnisnamen für das neue Verzeichnis an."
+
+#~ msgid "No directory name given"
+#~ msgstr "Kein Verzeichnisnamen angegeben"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Verzeichnis existiert bereits"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Bitte geben Sie einen anderen Namen an, um fortzufahren."
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Aktueller Pfad als Lesezeichen abspeichern"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Bitte wählen Sie eine Datei aus der List aus um fortzufahren."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Ausgewählte Datei hinzufügen"
+
+#~ msgid "Add"
+#~ msgstr "Hinzufügen"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "UI Beschreibungsdatei konnte nicht gefunden werden."
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Dateiname"
+
+#~ msgid "Remove"
+#~ msgstr "Entfernen"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Ausgewählte Datei entfernen"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Änderungen festlegen"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Dateiendifferenzen anzeigen"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Datei(en) zu hinzufügen"
+
+#~ msgid "Commit message:"
+#~ msgstr "Nachricht abschicken"
+
+#~ msgid "Pending merges"
+#~ msgstr "Wartende Merges"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Es gibt keine Änderungen im Arbeitsbaum."
+
+#~ msgid "Set default push location"
+#~ msgstr "Standard-Push-Ziel einstellen"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Es wurde kein Standard-Push-Ziel eingestellt.\n"
+#~ "Willst du %r als Standard einstellen?"
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Warten Sie bitte, Revisionen werden geladen..."
+
+#~ msgid "Time"
+#~ msgstr "Datum"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Herunterladen ist nicht möglich bis es ein Vorläuferpfad existiert."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Konflikte gefunden"
+
+#~ msgid "ignored"
+#~ msgstr "ignoriert"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr ""
+#~ "Schauen Sie bitte das aktive Verzeichnisstruktur an, bevor Sie fortfahren."
+
+#~ msgid "Last modified"
+#~ msgstr "Zuletzt verändert"
+
+#~ msgid "Size"
+#~ msgstr "Gr&ouml;&szlig;e"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Die ausgewählte Datei umbenennen"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Entfernen und löschen"
+
+#~ msgid "Rename"
+#~ msgstr "Umbenenen"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Öffne die ausgewählte Datei"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Zeige Dateiinhalt an in einem built-in viewer"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Öffne Lesezeichen in Nautilus"
+
+#~ msgid "Show differences"
+#~ msgstr "Zeige differenz ain"
+
+#~ msgid "View contents"
+#~ msgstr "Zeige Inhalt an"
+
+#~ msgid "Open Folder"
+#~ msgstr "Öffne Verzeichnis"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Bis zu dieser Überarbeitung rückgängig machen"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Die gewählte Datei bis zur gewählten Überarbeitung zurücksetzen."
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Lösche Verzeichnis und alle Unterverzeichnisse?"
+
+#~ msgid "Revert"
+#~ msgstr "Rückgängig"
+
+#~ msgid "Annotate"
+#~ msgstr "Beschreibe"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Änderung verwerfen"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initialisiere..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Beschreibe..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Alle Änderungen _rückgängig machen"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Fehlende Übe_rarbeitungen"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_gs..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Kon_flikte..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Merge..."
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Verbindende Zweige</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Informationen"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>Im aktiven Verzeichnisstruktur:</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Fehlende Revisionen:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Sperrstatus:</b>"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Breschreibe die gewählte Datei"
+
+#~ msgid "Merge from:"
+#~ msgstr "Mergen aus:"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Ort:</b>"
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert erfolgreich"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr ""
+#~ "Sämtliche Dateien wurden zur letzten Revision zurückgesetzt (revert)."
+
+#~ msgid "_Information..."
+#~ msgstr "_Information..."
+
+#~ msgid "H_istory Mode"
+#~ msgstr "H_istory Modus"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Zweig history:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Revisions Speicher:</b>"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr ""
+#~ "Entferne die gewählte(n) Datei(en)/Verzeichnis(se) und lösche sie von der "
+#~ "Festplatte"
+
+#~ msgid "Open"
+#~ msgstr "Öffnen..."
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Zeige die Unterschiede zwischen zwei Revisionen der Datei"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Augustus Kling https://launchpad.net/~augustus-kling\n"
+#~ "  Benjamin Jochheim https://launchpad.net/~benjamin-jochheim\n"
+#~ "  C-S https://launchpad.net/~c-s\n"
+#~ "  Christian Faulhammer https://launchpad.net/~fauli\n"
+#~ "  Mike Bronner https://launchpad.net/~mike.bronner\n"
+#~ "  Philipp Wolfer https://launchpad.net/~phw\n"
+#~ "  Pierre Vorhagen https://launchpad.net/~pep.\n"
+#~ "  Roman Stingler https://launchpad.net/~coolx67\n"
+#~ "  Sebastian Wallroth https://launchpad.net/~sebastian-wallroth\n"
+#~ "  Simon Pascal Klein https://launchpad.net/~klepas\n"
+#~ "  Xandi https://launchpad.net/~launchpad-net-20-taube\n"
+#~ "  welterde https://launchpad.net/~welterde"

=== modified file 'po/en_GB.po'
--- po/en_GB.po	2008-03-11 17:01:27 +0000
+++ po/en_GB.po	2011-03-08 04:41:48 +0000
@@ -7,243 +7,334 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-01-14 17:07+0000\n"
-"Last-Translator: John Drinkwater <john@nextraweb.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:08+0000\n"
+"Last-Translator: Bruce Cowan <Unknown>\n"
 "Language-Team: English (United Kingdom) <en_GB@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Branch"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Please select a folder"
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Branch location:"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destination:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Branch nick:"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revision:"
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Please select a folder"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Missing branch location"
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "You must specify a branch location."
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Branching successful"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d revision(s) branched."
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/A"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Check_out"
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "_Light-weight checkout"
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Directory does not have a working tree"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operation aborted."
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "Directory is not a branch"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr "You can perform this action only in a branch."
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "There are local changes in the branch"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "Please commit or revert the changes before merging."
+
+#: ../commit.py:182
+msgid "added"
+msgstr "added"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "removed"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "renamed"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "renamed and modified"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "modified"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "_Only commit locally"
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Comm_it"
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr "File(s) to commit"
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr "Commit message:"
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr "Pending merges"
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr "_Only commit locally"
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr "Commit with an empty message?"
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr "You can describe your commit intent in the message."
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr "Commit with unknowns?"
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr "Unknown files exist in the working tree. Commit anyway?"
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr "Commit with no changes?"
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr "There are no changes in the working tree."
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Commit"
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Path"
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Type"
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr "added"
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr "removed"
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr "renamed and modified"
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr "renamed"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr "modified"
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr "Date"
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Committer"
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Summary"
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Commit with an empty message?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "You can describe your commit intent in the message."
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "Commit with unknowns?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr "Unknown files exist in the working tree. Commit anyway?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "Commit with no changes?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "External utility:"
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflicts"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "No conflicts in working tree."
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "path conflict"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "contents conflict"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "text conflict"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "duplicate id"
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicate"
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "parent loop"
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "unversioned parent"
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "missing parent"
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "deleting parent"
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "unknown type of conflict"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "No file was selected"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Please select a file from the list."
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Call to external utility failed"
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Cannot resolve conflict"
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -253,35 +344,78 @@
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_View"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Merge successful"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "All changes applied successfully."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Conflicts encountered"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "Please resolve the conflicts manually before committing."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Directory is not a branch"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "You can perform this action only in a branch."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Directory is not a checkout"
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "You can perform local commit only on checkouts."
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "No changes to commit"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Try force commit if you want to commit anyway."
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflicts in tree"
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "You need to resolve the conflicts before committing."
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Strict commit failed"
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -289,28 +423,29 @@
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "Bound branch is out of date"
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "File not versioned"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "The selected file is not versioned."
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Branches have been diverged"
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -318,35 +453,35 @@
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "No diff output"
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "The selected file hasn't changed."
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "No such revision"
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "The revision you specified doesn't exist."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Target already exists"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "Target directory already exists. Please select another target."
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Directory is already a branch"
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -355,11 +490,11 @@
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialise another directory."
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Branch without a working tree"
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -368,117 +503,114 @@
 "The current directory (%s)\n"
 "is a branch without a working tree."
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Unknown bzr error"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permission denied"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "permission denied."
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Unknown error"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initialise"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Which directory do you want to initialise?"
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Current directory"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr "Create a new directory with the name:"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Directory name not specified"
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "You should specify a new directory name."
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Merge"
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Branch not given"
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Please specify a branch to merge from."
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Bazaar command error"
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr "Merge successful"
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr "All changes applied successfully."
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr "Conflicts encountered"
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr "Please resolve the conflicts manually before committing."
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr "Location:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Push"
 
-#: push.py:97
-msgid "Set default push location"
-msgstr "Set default push location"
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-
-#: push.py:106
-msgid ""
-"You cannot push if branches have diverged.\n"
-"Overwrite?"
-msgstr ""
-"You cannot push if branches have diverged.\n"
-"Overwrite?"
-
-#: push.py:112
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Push successful"
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d revision(s) pushed."
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Non existing parent directory"
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -487,828 +619,662 @@
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr "Please wait, revisions are being loaded..."
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Select"
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr "Revno"
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr "Time"
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr "Added"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr "Removed"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renamed"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modified"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Unknown"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "No changes."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Tags"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr "Tag Name"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr "Revision ID"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr "Tags are not supported by this branch format. Please upgrade."
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "No tagged revisions in the branch."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Remove tag"
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Remove tag?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Are you sure you want to remove the tag: <b>%s</b>?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Add tag"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Tag Name:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Revision ID:"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "No tag name specified"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "You have to specify the tag's desired name."
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr "There are local changes in the branch"
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr "Please commit or revert the changes before merging."
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr "Parent location is unknown"
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr "Cannot determine missing revisions if no parent location is known."
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr "There are missing revisions"
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr "%d revision(s) missing."
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr "Local branch up to date"
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr "There are no missing revisions."
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr "Pulling is not possible until there is a parent location."
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr "Pull successful"
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr "%d revision(s) pulled."
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr "Conflicts detected"
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr "Please have a look at the working tree before continuing."
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr "Revert successful"
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr "All files reverted to last revision."
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Bookmarks"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Bookmark"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr "unchanged"
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr "ignored"
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr "unknown"
-
-#: __init__.py:964
-msgid "Filename"
-msgstr "Filename"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "Status"
-
-#: __init__.py:966
-msgid "Size"
-msgstr "Size"
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr "Last modified"
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-"Please select a file from the list,\n"
-"or choose the other option."
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Title:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr "No title given"
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr "Please specify a title to continue."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr "Glade file cannot be found."
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr "UI description file cannot be found."
-
-#: menu.py:63
-msgid "Add"
-msgstr "Add"
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr "Add the selected file"
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr "Remove"
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr "Remove the selected file"
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr "Remove and delete"
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr "Remove the selected file/directory and permanently delete"
-
-#: menu.py:75
-msgid "Rename"
-msgstr "Rename"
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr "Rename the selected file"
-
-#: menu.py:79
-msgid "Open"
-msgstr "Open"
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr "Open the selected file"
-
-#: menu.py:83
-msgid "Revert"
-msgstr "Revert"
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr "Revert the changes"
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr "Commit the changes"
-
-#: menu.py:91
-msgid "Annotate"
-msgstr "Annotate"
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr "Annotate the selected file"
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Diff"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr "Show the diff of the file"
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr "Bookmark current location"
-
-#: menu.py:103
-msgid "Edit"
-msgstr "Edit"
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr "Edit the selected bookmark"
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr "Remove the selected bookmark"
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr "Open Directory"
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr "Open bookmark directory in Nautilus"
-
-#: menu.py:115
-msgid "Selected..."
-msgstr "Selected..."
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr "Show the differences of the selected file"
-
-#: menu.py:119
-msgid "All..."
-msgstr "All..."
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr "Show the differences of all files"
-
-#: menu.py:123
-msgid "View contents"
-msgstr "View contents"
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr "View the contents of the file in a built-in viewer"
-
-#: menu.py:127
-msgid "Show differences"
-msgstr "Show differences"
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr "Show the differences between two revisions of the file"
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr "Revert to this revision"
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr "Revert the selected file to the selected revision"
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr "Delete directory with all directories below ?"
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr "Bookmark successfully added"
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr "Location already bookmarked"
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr "No directory name given"
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr "Please specify a desired name for the new directory."
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr "Directory already exists"
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr "Please specify another name to continue."
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr "Please select a file from the list to proceed."
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr "Not the same branch"
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr "The destination is not in the same branch."
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr "No matching files"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr "No added files were found in the working tree."
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "Which file(s) do you want to remove?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Selected only"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "All files with status 'added'"
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Remove"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr "Filename not given"
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr "Please specify a new name for the file."
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - Bazaar GUI"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_File"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Add file(s)..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Remove file(s)..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Make _directory..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Rename..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Move..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr "_Annotate..."
-
-#: olive.glade:118
-msgid "_View"
-msgstr "_View"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Show _hidden files"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Refresh"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr "_Initialise..."
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Get..."
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr "C_heckout..."
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr "Pu_ll"
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr "Pu_sh..."
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr "_Revert all changes"
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr "_Merge..."
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr "_Commit..."
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr "Ta_gs..."
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "S_tatus..."
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr "Missing _revisions"
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr "Con_flicts..."
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Statistics"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Differences..."
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Log..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr "_Information..."
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Help"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr "gtk-jump-to"
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr "H_istory Mode"
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Bruce Cowan https://launchpad.net/~bruce89\n"
-"  John Drinkwater https://launchpad.net/~johndrinkwater"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Add file(s)"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Which file(s) do you want to add?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr "All unknowns recursively"
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Add"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Remove file(s)"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - Make directory"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr "_Versioned directory"
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Make directory"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Move"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Move to"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Select a directory"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Move"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Rename"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Rename to"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "_Rename"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr "Olive - Information"
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(none)"
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr "Checkout root: "
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr "Branch root: "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Repository checkout: "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr "Checkout of branch: "
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr "Repository branch: "
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr "Shared repository: "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr "Light checkout root: "
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr "<b>Location:</b>"
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr "Publish to branch: "
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr "Parent branch: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr "<b>Related branches:</b>"
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr "Repository format: "
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr "Branch format: "
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr "Working tree format: "
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr "Control format: "
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr "<b>Format:</b>"
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr "Repository lock status: "
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr "Branch lock status: "
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr "Working tree lock status: "
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr "<b>Lock status:</b>"
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr "Missing revisions in branch: "
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr "Missing revisions in working tree: "
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr "<b>Missing revisions:</b>"
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr "Versioned subdirectories: "
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "Ignored files: "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Unknown files: "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Renamed files: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Removed files: "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Added files: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Modified files: "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Unchanged files: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr "<b>In the working tree:</b>"
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr "Time of last revision: "
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Time of first revision: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr "Age of branch in days: "
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr "Number of commiters: "
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr "Revisions in branch: "
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr "<b>Branch history:</b>"
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr "Size of repository: "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr "Revisions in repository: "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr "<b>Revision store:</b>"
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr "Merge - Olive"
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr "Merge from:"
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr "_Merge"
+#~ msgid "_Rename..."
+#~ msgstr "_Rename..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Move..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Make _directory..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Remove file(s)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Add file(s)..."
+
+#~ msgid "_File"
+#~ msgstr "_File"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Refresh"
+
+#~ msgid "_Get..."
+#~ msgstr "_Get..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Show _hidden files"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Differences..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistics"
+
+#~ msgid "_Help"
+#~ msgstr "_Help"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Which file(s) do you want to add?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Add file(s)"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "All files with status 'added'"
+
+#~ msgid "_Remove"
+#~ msgstr "_Remove"
+
+#~ msgid "Selected only"
+#~ msgstr "Selected only"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Remove file(s)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Which file(s) do you want to remove?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "All unknowns recursively"
+
+#~ msgid "_Add"
+#~ msgstr "_Add"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Make directory"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Versioned directory"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Move"
+
+#~ msgid "Move to"
+#~ msgstr "Move to"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Make directory"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Rename"
+
+#~ msgid "_Move"
+#~ msgstr "_Move"
+
+#~ msgid "Select a directory"
+#~ msgstr "Select a directory"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Checkout root: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Repository checkout: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Branch root: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout of branch: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Repository branch: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Shared repository: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Light checkout root: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Rename"
+
+#~ msgid "Rename to"
+#~ msgstr "Rename to"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publish to branch: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Parent branch: "
+
+#~ msgid "(none)"
+#~ msgstr "(none)"
+
+#~ msgid "Working tree format: "
+#~ msgstr "Working tree format: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Repository format: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Branch format: "
+
+#~ msgid "Control format: "
+#~ msgstr "Control format: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Unchanged files: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Modified files: "
+
+#~ msgid "Added files: "
+#~ msgstr "Added files: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Repository lock status: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Branch lock status: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Missing revisions in working tree: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Working tree lock status: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Missing revisions in branch: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisions in branch: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Renamed files: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Unknown files: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ignored files: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Versioned subdirectories: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Removed files: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Time of first revision: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Age of branch in days: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Number of commiters: "
+
+#~ msgid "Title:"
+#~ msgstr "Title:"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Time of last revision: "
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Size of repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisions in repository: "
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Please specify a title to continue."
+
+#~ msgid "No title given"
+#~ msgstr "No title given"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull successful"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d revision(s) pulled."
+
+#~ msgid "There are missing revisions"
+#~ msgstr "There are missing revisions"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Parent location is unknown"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr "Cannot determine missing revisions if no parent location is known."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Local branch up to date"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revision(s) missing."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "There are no missing revisions."
+
+#~ msgid "Bookmarks"
+#~ msgstr "Bookmarks"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade file cannot be found."
+
+#~ msgid "Bookmark"
+#~ msgstr "Bookmark"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Add the selected file"
+
+#~ msgid "Add"
+#~ msgstr "Add"
+
+#~ msgid "unchanged"
+#~ msgstr "unchanged"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "UI description file cannot be found."
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Filename"
+
+#~ msgid "unknown"
+#~ msgstr "unknown"
+
+#~ msgid "Remove"
+#~ msgstr "Remove"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Remove the selected file"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Commit the changes"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Show the diff of the file"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Show the differences of all files"
+
+#~ msgid "All..."
+#~ msgstr "All..."
+
+#~ msgid "Selected..."
+#~ msgstr "Selected..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Show the differences of the selected file"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Bookmark current location"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Edit the selected bookmark"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Remove the selected bookmark"
+
+#~ msgid "Edit"
+#~ msgstr "Edit"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Bookmark successfully added"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Location already bookmarked"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Please specify a desired name for the new directory."
+
+#~ msgid "No directory name given"
+#~ msgstr "No directory name given"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Directory already exists"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Please specify another name to continue."
+
+#~ msgid "Not the same branch"
+#~ msgstr "Not the same branch"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Please select a file from the list to proceed."
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "The destination is not in the same branch."
+
+#~ msgid "No matching files"
+#~ msgstr "No matching files"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Please specify a new name for the file."
+
+#~ msgid "Filename not given"
+#~ msgstr "Filename not given"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "No added files were found in the working tree."
+
+#~ msgid "File(s) to commit"
+#~ msgstr "File(s) to commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Commit message:"
+
+#~ msgid "Pending merges"
+#~ msgstr "Pending merges"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "There are no changes in the working tree."
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert successful"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Pulling is not possible until there is a parent location."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflicts detected"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "View the contents of the file in a built-in viewer"
+
+#~ msgid "Show differences"
+#~ msgstr "Show differences"
+
+#~ msgid "Revert"
+#~ msgstr "Revert"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Annotate the selected file"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Revert the changes"
+
+#~ msgid "Annotate"
+#~ msgstr "Annotate"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Open the selected file"
+
+#~ msgid "View contents"
+#~ msgstr "View contents"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "H_istory Mode"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Related branches:</b>"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Missing _revisions"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_gs..."
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flicts..."
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Location:</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Information"
+
+#~ msgid "_Information..."
+#~ msgstr "_Information..."
+
+#~ msgid "Time"
+#~ msgstr "Time"
+
+#~ msgid "Set default push location"
+#~ msgstr "Set default push location"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Please wait, revisions are being loaded..."
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Open bookmark directory in Nautilus"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Annotate..."
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Rename the selected file"
+
+#~ msgid "Rename"
+#~ msgstr "Rename"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Revert the selected file to the selected revision"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Delete directory with all directories below ?"
+
+#~ msgid "Open"
+#~ msgstr "Open"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Show the differences between two revisions of the file"
+
+#~ msgid "Open Folder"
+#~ msgstr "Open Directory"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Revert to this revision"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Merge - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Merge from:"
+
+#~ msgid "Last modified"
+#~ msgstr "Last modified"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Remove and delete"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "All files reverted to last revision."
+
+#~ msgid "ignored"
+#~ msgstr "ignored"
+
+#~ msgid "Size"
+#~ msgstr "Size"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Please have a look at the working tree before continuing."
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Branch history:</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Missing revisions:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Revision store:</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>In the working tree:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Lock status:</b>"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initialise..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Revert all changes"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "_Merge..."
+#~ msgstr "_Merge..."
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Remove the selected file/directory and permanently delete"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Bruce Cowan https://launchpad.net/~bruce89\n"
+#~ "  John Drinkwater https://launchpad.net/~johndrinkwater"

=== added file 'po/eo.po'
--- po/eo.po	1970-01-01 00:00:00 +0000
+++ po/eo.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,704 @@
+# Esperanto translation for bzr-gtk
+# Copyright (c) 2009 Rosetta Contributors and Canonical Ltd 2009
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2009.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-12-23 20:48+0000\n"
+"Last-Translator: Launchpad Translations Administrators "
+"<rosetta@launchpad.net>\n"
+"Language-Team: Esperanto <eo@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr ""
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr ""
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "Celo:"
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr ""
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Bonvolu elekti leterujon"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr ""
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr ""
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr ""
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr ""
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr "N/A"
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr ""
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr ""
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "Operacio haltigita."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr ""
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr ""
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr ""
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr ""
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "Dato"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr ""
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr ""
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr ""
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "Konfliktoj"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr ""
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr ""
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr ""
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr ""
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr ""
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr ""
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr ""
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr ""
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr ""
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr ""
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr ""
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr ""
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr ""
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr ""
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr ""
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr ""
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr ""
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr ""
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr ""
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr ""
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr ""
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr ""
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr ""
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr ""
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr ""
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr ""
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr ""
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr ""
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr ""
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr ""
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr ""
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr ""
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr ""
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr ""
+
+#: ../status.py:100
+msgid "Removed"
+msgstr ""
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr ""
+
+#: ../status.py:113
+msgid "Modified"
+msgstr ""
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr ""
+
+#: ../status.py:126
+msgid "No changes."
+msgstr ""
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr ""
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr ""
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr ""
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr ""
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr ""
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr ""
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr ""
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr ""
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr ""
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr ""
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Colin Dean https://launchpad.net/~colindean\n"
+#~ "  Larry Gilbert https://launchpad.net/~l2g"

=== modified file 'po/es.po'
--- po/es.po	2008-03-11 17:01:27 +0000
+++ po/es.po	2011-03-08 04:41:48 +0000
@@ -7,379 +7,498 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-01-23 23:24+0000\n"
-"Last-Translator: VRZ <vruiz.desarrollo@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:27+0000\n"
+"Last-Translator: BigSus <bigsus@gmail.com>\n"
 "Language-Team: Spanish <es@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
-msgstr "_Branch"
-
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Por favor seleccione una carpeta"
-
-#: branch.py:57 checkout.py:55
+msgstr "_Rama"
+
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Ubicación de la rama:"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destino:"
 
-#: branch.py:59 checkout.py:57
-#, fuzzy
+#: ../branch.py:58
 msgid "Branck nick:"
-msgstr "Nombre de la rama:"
+msgstr "Apodo de la rama:"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisión:"
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Por favor, seleccione una carpeta"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Localización de la rama no encontrada"
+msgstr "No se ha encontrado la ubicación de la rama"
 
-#: branch.py:163 checkout.py:164
-#, fuzzy
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "Debes especificar la localización de la rama"
+msgstr "Debe especificar la ubicación de una rama"
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Rama creada con éxito"
 
-#: branch.py:206
-#, fuzzy, python-format
+#: ../branch.py:183
+#, python-format
 msgid "%d revision(s) branched."
-msgstr "%d revision(es) ramificadas."
+msgstr "%d revision(es) ramificada(s)."
 
-#: branch.py:214 checkout.py:195
-#, fuzzy
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/D"
 
-#: checkout.py:50
-#, fuzzy
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
-msgstr "Check_out"
-
-#: checkout.py:62
+msgstr "Comprobación"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
-msgstr ""
+msgstr "Comprobación _ligera"
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr "El directorio no tiene un árbol de trabajo"
+msgstr "El directorio no contiene un árbol de trabajo"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operación interrumpida."
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "El directorio no es una rama"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr "Esta acción sólo puede realizarse sobre una rama."
-
-#: commit.py:88
-msgid "Comm_it"
-msgstr "Publ_icar"
-
-#: commit.py:89
-#, fuzzy
-msgid "File(s) to commit"
-msgstr "Archivos a entregar"
-
-#: commit.py:95
-#, fuzzy
-msgid "Commit message:"
-msgstr "Mensaje de entraga:"
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr "Fusiones pendientes"
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr "_Solo publicar localmente"
-
-#: commit.py:215
-#, fuzzy
-msgid "Commit with an empty message?"
-msgstr "¿Entregar con un mensaje vacío?"
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr "Puedes describir tu intento de commit en el mensaje"
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr "¿Publicar con desconocidos?"
-
-#: commit.py:229
-#, fuzzy
-msgid "Unknown files exist in the working tree. Commit anyway?"
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Hay cambios locales en la rama"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
 msgstr ""
-"Existen archivos desconocidos en el directorio de trabajo. ¿Entregar de "
-"todos modos?"
-
-#: commit.py:240
-#, fuzzy
-msgid "Commit with no changes?"
-msgstr "¿Entregar sin cambios?"
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr "No hay cambios pendientes en el árbol de trabajo."
-
-#: commit.py:323 menu.py:87
-#, fuzzy
-msgid "Commit"
-msgstr "Entregar"
-
-#: commit.py:325 conflicts.py:108
-msgid "Path"
-msgstr "Ruta"
-
-#: commit.py:327 conflicts.py:110
-msgid "Type"
-msgstr "Tipo"
-
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
+"Por favor, haga un commit o un revert de los cambios antes de fusionar."
+
+#: ../commit.py:182
 msgid "added"
 msgstr "añadido"
 
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
+#: ../commit.py:183
 msgid "removed"
 msgstr "quitado"
 
-#: commit.py:353
+#: ../commit.py:184
+msgid "renamed"
+msgstr "renombrado"
+
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "renombrado y modificado"
 
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr "renombrado"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
+#: ../commit.py:186
 msgid "modified"
 msgstr "modificado"
 
-#: commit.py:395
-#, fuzzy
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "Hacer commit sólo localmente"
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "Comm_it"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Commit"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Ruta"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Tipo"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr "Fecha"
 
-#: commit.py:397 revbrowser.py:68
-#, fuzzy
+#: ../commit.py:509
 msgid "Committer"
-msgstr "Entregador"
+msgstr "Committer"
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Resumen"
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "¿Hacer commit con un mensaje vacío?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "Puede describir en el mensaje el motivo del commit."
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "¿Hacer commit con desconocidos?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+"Existen archivos desconocidos en el árbol de trabajo. ¿Hacer commit de todos "
+"modos?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "¿Hacer commit sin cambios?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr "Utilidad externa"
+msgstr "Utilidad externa:"
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflictos"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "No hay conflictos en el árbol de trabajo."
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflicto en la ruta"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflicto de contenidos"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
-msgstr "texto en conflicto"
+msgstr "conflicto de texto"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id duplicado"
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicado"
 
-#: conflicts.py:125
-#, fuzzy
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "bucle padre"
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
-msgstr "versión sin padre"
+msgstr "padre sin versionar"
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "no se encuentra el padre"
 
-#: conflicts.py:131
-#, fuzzy
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "borrando padre"
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "tipo de conflicto desconocido"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
-#, fuzzy
+#: ../conflicts.py:165
 msgid "No file was selected"
-msgstr "Ningún archivo fue seleccionado"
+msgstr "No se ha seleccionado ningún archivo"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
-msgstr "Por favor selecciona un archivo de la lista"
+msgstr "Por favor, seleccione un archivo de la lista."
 
-#: conflicts.py:173
-#, fuzzy
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Falló la llamada a una utilidad externa"
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "No se puede resolver el conflicto"
 
-#: conflicts.py:176
-#, fuzzy
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
-"Por el momento, Olive únicamente puede resolver conflictos en el texto de "
-"los archivos. Los conflictos de contenido, en la estructura del archivo, "
-"deben ser resueltos usando la línea de comandos."
-
-#: errors.py:29
+"Por el momento, Olive sólo puede resolver conflictos en el texto de los "
+"archivos. Los conflictos de contenido o en la estructura del árbol deberán "
+"resolverse usando la línea de comandos."
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Ver"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Fusión realizada con éxito"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Cambios aplicados con éxito."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Se encontraron conflictos"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+"Por favor, resuelva los conflictos manualmente antes de hacer commit."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "El directorio no es una rama"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "Esta acción sólo puede realizarse sobre una rama."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
-msgstr ""
+msgstr "El directorio no es un checkout"
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
-msgstr ""
+msgstr "Sólo puede realizar commits locales sobre checkouts."
 
-#: errors.py:32
-#, fuzzy
+#: ../errors.py:34
 msgid "No changes to commit"
-msgstr "No hay cambios a entregar"
+msgstr "No hay cambios a los que hacer commit"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
-msgstr ""
-
-#: errors.py:35
+msgstr "Intente forzar el commit si desea hacerlo de todas formas."
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflictos en el árbol"
 
-#: errors.py:36
-#, fuzzy
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
-msgstr "Es necesaio resolver los conflictos antes de entregar."
+msgstr "Es necesario resolver los conflictos antes de hacer un commit."
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
-msgstr "Publicación estricta fallada"
+msgstr "Ha fallado el commit estricto"
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 "Hay archivos desconocidos en el árbol de trabajo.\n"
-"Por favor, añádelos o quítalos."
+"Por favor, añádalos o quítelos."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
-msgstr ""
+msgstr "La rama ligada está obsoleta"
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
-msgstr ""
+msgstr "Archivo no versionado"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "El archivo seleccionado no está versionado."
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
-msgstr ""
+msgstr "Las ramas se han dividido"
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
+"No se puede hacer un push si las ramas se han dividido. Use\n"
+"la opción de sobreescribir si desea hacer push de todos modos."
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
-msgstr ""
+msgstr "No hay salida de diff"
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
-msgstr "El archivo seleccionado no ha cambiado"
+msgstr "El archivo seleccionado no ha cambiado."
 
-#: errors.py:53
-#, fuzzy
+#: ../errors.py:59
 msgid "No such revision"
-msgstr "No existe tal revisión"
+msgstr "No existe esa revisión"
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "La revisión especificada no existe."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "El destino ya existe"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
-msgstr "El destino ya existe. Por favor, selecciona otro."
+msgstr "El destino ya existe. Por favor, seleccione otro."
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "El directorio ya es una rama"
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 "El directorio actual (%s) ya es una rama.\n"
-"Ya puedes usarlo, o inicializar otro directorio."
+"Puede empezar a usarlo, o bien inicializar otro directorio."
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Rama sin árbol de trabajo."
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -388,982 +507,793 @@
 "El directorio actual (%s)\n"
 "es una rama sin árbol de trabajo."
 
-#: errors.py:65
-#, fuzzy
+#: ../errors.py:71
 msgid "Unknown bzr error"
-msgstr "Error bzr desconocido"
+msgstr "Error desconocido de bzr"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permiso denegado"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "permiso denegado."
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Error desconocido"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
-msgstr "_Iniciar"
+msgstr "_Inicializar"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
-msgstr "¿Qué directorio quieres inicializar?"
+msgstr "¿Qué directorio desea inicializar?"
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Directorio actual"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr "Crear un nuevo directorio con el nombre:"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Nombre del directorio no especificado"
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Deberías especificar un nuevo nombre de directorio."
 
-#: merge.py:66
-#, fuzzy
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Fusionar"
+
+#: ../merge.py:132
 msgid "Branch not given"
-msgstr "No se ha proporcionado una rama"
+msgstr "No se ha indicado ninguna rama"
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
-msgstr "Por favor, especifica una rama desde la que fusiones."
+msgstr "Por favor, especifique una rama desde la que fusionar."
 
-#: merge.py:75
-#, fuzzy
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Error en el comando Bazaar"
 
-#: merge.py:81
-#, fuzzy
-msgid "Merge successful"
-msgstr "Fusión exitosa"
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr "Cambios aplicados con éxito."
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr "Se encontraron conflictos"
-
-#: merge.py:86
-#, fuzzy
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-"Por favor, resuelve los conflictos manualmente antes de hacer commit."
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
-msgstr "Localización:"
+msgstr "Ubicación:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
-msgstr "_Subir"
-
-#: push.py:97
-msgid "Set default push location"
-msgstr "Establecer la localizacion de subida por defecto"
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+msgstr "_Push"
+
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
+"No se puede hacer push si las ramas se han dividido.\n"
+"¿Sobreescribir?"
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
-msgstr "Subido satisfactoriamente"
+msgstr "Push realizado con éxito"
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
-msgstr "%d revisión(es) subida."
+msgstr "Se ha realizado un push a %d revision(es)."
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Directorio padre no existente"
 
-#: push.py:147
-#, fuzzy, python-format
+#: ../push.py:143
+#, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 "El directorio padre (%s)\n"
-"no existe. ¿Quieres crearlo?"
-
-#: revbrowser.py:45
-#, fuzzy
-msgid "Please wait, revisions are being loaded..."
-msgstr "Por favor, espera. Se están cargando las revisiones."
-
-#: revbrowser.py:48
+"no existe. ¿Desea crearlo?"
+
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Seleccionar"
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr "Revno"
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr "Hora"
-
-#: status.py:78
-#, fuzzy
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
-msgstr "Agregado"
+msgstr "Añadido"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
-msgstr "Removido"
+msgstr "Eliminado"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renombrado"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificado"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
-msgstr "Descanocido"
+msgstr "Desconocido"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "No hay cambios."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Etiquetas"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr "Nombre de etiqueta"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr "ID de la revisión"
 
-#: tags.py:151
-#, fuzzy
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
-msgstr "Esta versión no soporta etiquetas. Actualízate a la última versión."
+msgstr ""
+"Este formato de rama no soporta etiquetas. Por favor, haga un upgrade."
 
-#: tags.py:157
-#, fuzzy
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "No hay revisiones con etiqueta en la rama."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Eliminar etiqueta"
 
-#: tags.py:242
-#, fuzzy
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>¿Quitar etiqueta?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "¿Seguro que quiere quitar la etiqueta <b>%s</b>?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Añadir etiqueta"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nombre de la etiqueta:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID de la revisión:"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "No se ha especificado un nombre de etiqueta"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
-msgstr "Debes especificar el nombre de la etiqueta que quieres."
-
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr "Hay cambios locales en la rama"
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr "La localización padre es desconocida"
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr "%d revisiones no encontradas."
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr "Subida satisfactoriamente"
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr "Detectados conflictos"
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr "Por favor, echa un vistazo al árbol de trabajo antes de continuar."
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr "Deshecho satisfactoriamente"
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr "Todos los archivos han vuelto a la última versión."
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Marcadores"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Marcador"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr "no hay cambios"
-
-#: __init__.py:946 __init__.py:1233
-#, fuzzy
-msgid "ignored"
-msgstr "ignorada"
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr "desconocido"
-
-#: __init__.py:964
-msgid "Filename"
-msgstr "Nombre de Archivo"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "Estado"
-
-#: __init__.py:966
-msgid "Size"
-msgstr "Tamaño"
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr "Última modificación"
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-"Por favor seleccione un archivo de la lista,\n"
-"o seleccione la otra opción."
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Título"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr "Sin título"
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr "Por favor especifica un título para continuar."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr "el archivo de Glade no puede ser encontrado."
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr "Agregar"
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr "Agregar el archivo seleccionado"
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr "Remover"
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr "Remover el archivo seleccionado"
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr "Quitar y borrar"
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr "Quitar el archivo/directorio seleccionado y borrarlo del disco"
-
-#: menu.py:75
-msgid "Rename"
-msgstr "Renombrar"
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr "Renombrar el archivo seleccionado"
-
-#: menu.py:79
-msgid "Open"
-msgstr "Abrir"
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr "Abrir el archivo seleccionado"
-
-#: menu.py:83
-msgid "Revert"
-msgstr "Revertir"
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr "Deshacer los cambios"
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr "Confirmar los cambios"
-
-#: menu.py:91
-msgid "Annotate"
-msgstr "Anotar"
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr "Anotar el archivo seleccionado"
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Comparar"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr "Mostrar las diferencias del archivo"
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr "Añadir a marcadores la localización actual"
-
-#: menu.py:103
-msgid "Edit"
-msgstr "Editar"
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr "Editar el marcador seleccionado"
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr "Quitar el marcador seleccionado"
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr "Abrir Directorio"
-
-#: menu.py:112
-#, fuzzy
-msgid "Open bookmark folder in Nautilus"
-msgstr "Abrir carpeta de marcadores de Nautilus"
-
-#: menu.py:115
-msgid "Selected..."
-msgstr "Seleccionado..."
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr "Mostrar las diferencias del archivo seleccionado"
-
-#: menu.py:119
-msgid "All..."
-msgstr "Todos..."
-
-#: menu.py:120
-#, fuzzy
-msgid "Show the differences of all files"
-msgstr "Mostrar las diferencias de todos los archivos"
-
-#: menu.py:123
-msgid "View contents"
-msgstr "Mostrar los contenidos"
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr "Mostrar las diferencias"
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr "Mostrar las diferencias entre dos reviciones de un archivo"
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-#, fuzzy
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-"Se ha añadido el directorio actual a marcadores. Puedes \n"
-"llegar a él eligiéndolo desde el panel de la izquierda."
-
-#: menu.py:319
-#, fuzzy
-msgid "Location already bookmarked"
-msgstr "Esta localización ya está en marcadores"
-
-#: menu.py:320
-#, fuzzy
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-"El directorio actual ya está en marcadores. Mira\n"
-"el panel de la izquierda para ver referencias."
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr "No se dio nombre para el directorio"
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr "Por favor especifíca el nombre deseado para el nuevo directorio."
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr "El directorio ya existe"
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr "Por favor especifique otro nombre para continuar."
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr "Por favor selecciona un archivo de la lista para continuar."
-
-#: move.py:89 rename.py:87
-#, fuzzy
-msgid "Not the same branch"
-msgstr "No están en la misma rama"
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr "El destino no está en la misma rama."
-
-#: remove.py:79 remove.py:139
-#, fuzzy
-msgid "No matching files"
-msgstr "No hay archivos coincidentes"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr "No se encontraron archivos adicionados en el arbol de trabajo."
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "¿Cual(es) archivo(s) quiere remover?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Sólo seleccionados"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "Estatus de todos los archivos  'Adicionado'"
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Quitar"
-
-#: rename.py:75
-#, fuzzy
-msgid "Filename not given"
-msgstr "No se ha proporcionado un nombre de archivo"
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr "Por favor, especifique un nuevo nombre para el archivo"
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - Bazaar GUI"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Archivo"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Añadir fichero(s)..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Remover archivo(s)..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Crear _directorio..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Renombrar..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Mover..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr "_Anotar"
-
-#: olive.glade:118
-msgid "_View"
-msgstr "_Ver"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Mostrar _ficheros ocultos"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Refrescar"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr "_Inicializar..."
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Obtener..."
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr "Compro_bar"
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr "_Halar"
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr "_Empujar"
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr "_Revertir todos los cambios"
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr "_Fusionar"
-
-#: olive.glade:236
-#, fuzzy
-msgid "_Commit..."
-msgstr "En_viar"
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "Es_tado..."
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr "Con_flictos..."
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Estadisticas"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Diferencias..."
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Registro..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr "_Información..."
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Ayuda"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr "gtk-jump-to"
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr "Modo H_istorial"
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  BigSus https://launchpad.net/~bigsus\n"
-"  David Arnoldo Ortiz Lozano https://launchpad.net/~tyoc\n"
-"  Joseph https://launchpad.net/~josephmail7\n"
-"  Mario del Pozo https://launchpad.net/~mariodpros\n"
-"  Omar Olarte https://launchpad.net/~oeolartep\n"
-"  Rodrigo Garcia Gonzalez https://launchpad.net/~nibblesmx\n"
-"  VRZ https://launchpad.net/~vruiz-desarrollo\n"
-"  Virusurbano https://launchpad.net/~lucianofacchinelli13\n"
-"  kilik https://launchpad.net/~kilik\n"
-"  Álvaro del Olmo Alonso https://launchpad.net/~dllum"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Adicionar archivos"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "¿Cual(es) archivo(s) quiere adicionar?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr "Todos los desconocidos recursivamente"
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Añadir"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Remover archivo(s)"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - Crear directorio"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Crear directorio"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Mover"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Mover a"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Seleccionar un directorio"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Mover"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Renombrar"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Renombrar a"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "Renombrar"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr "Olive - Información"
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(nada)"
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr "Comprobar directorio raíz: "
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr "Directorio raíz de la rama: "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Comprobar repositorio: "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr "Comprobar la rama: "
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr "Rama del repositorio: "
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr "Repositorio compartido: "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr "<b>Localización:</b>"
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr "Publicar en la rama: "
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr "Rama padre: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr "<b>Ramas relacionadas:</b>"
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr "Formato de repositorio: "
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr "Formato de la rama: "
-
-#: olive.glade:1638
-#, fuzzy
-msgid "Working tree format: "
-msgstr "Formato del árbol de trabajo: "
-
-#: olive.glade:1650
-#, fuzzy
-msgid "Control format: "
-msgstr "Formato de control: "
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr "<b>Formato:</b>"
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr "Revisiones faltantes en la rama: "
-
-#: olive.glade:1835
-#, fuzzy
-msgid "Missing revisions in working tree: "
-msgstr "No se han encontrado revisiones en el directorio de trabajo: "
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr "Directorios subversionados: "
-
-#: olive.glade:1993
-#, fuzzy
-msgid "Ignored files: "
-msgstr "Archivos ignorados "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Arvhivos desconocidos: "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Archivos renombrados: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Archivos removidos: "
-
-#: olive.glade:2041
-#, fuzzy
-msgid "Added files: "
-msgstr "Archivos agregados: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Arcchivos modificados "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Archivos sin cambios: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr "<b>En el directorio de trabajo:</b>"
-
-#: olive.glade:2172
-#, fuzzy
-msgid "Time of last revision: "
-msgstr "Hora de la última revisión: "
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Momento de la primera revisión: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr "Edad de la rama en días: "
-
-#: olive.glade:2208
-#, fuzzy
-msgid "Number of commiters: "
-msgstr "Número de confirmadores: "
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr "Revisiones en la rama: "
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr "<b>Historial de ramas:</b>"
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr "Tamaño del repositorio: "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr "Revisiones en el repositorio: "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-#, fuzzy
-msgid "Merge - Olive"
-msgstr "Fusionar - Olive"
-
-#: olive.glade:2370
-#, fuzzy
-msgid "Merge from:"
-msgstr "Fusionar desde:"
-
-#: olive.glade:2454
-#, fuzzy
-msgid "_Merge"
-msgstr "_Fusionar"
+msgstr "Debe especificar el nombre que desea para la etiqueta."
+
+#~ msgid "_Move..."
+#~ msgstr "_Mover..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Crear _directorio..."
+
+#~ msgid "_File"
+#~ msgstr "_Archivo"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Refrescar"
+
+#~ msgid "_Get..."
+#~ msgstr "_Obtener..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "Es_tado..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Registro..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferencias..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Estadisticas"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Crear directorio"
+
+#~ msgid "Repository branch: "
+#~ msgstr "Rama del repositorio: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Repositorio compartido: "
+
+#~ msgid "_Move"
+#~ msgstr "_Mover"
+
+#~ msgid "Parent branch: "
+#~ msgstr "Rama padre: "
+
+#~ msgid "Control format: "
+#~ msgstr "Formato de control: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Archivos renombrados: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Archivos sin cambios: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Arcchivos modificados "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Arvhivos desconocidos: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisiones en la rama: "
+
+#~ msgid "No title given"
+#~ msgstr "Sin título"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Por favor seleccione un archivo de la lista,\n"
+#~ "o seleccione la otra opción."
+
+#~ msgid "Edit"
+#~ msgstr "Editar"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Confirmar los cambios"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostrar las diferencias del archivo"
+
+#~ msgid "Directory already exists"
+#~ msgstr "El directorio ya existe"
+
+#~ msgid "Pending merges"
+#~ msgstr "Fusiones pendientes"
+
+#~ msgid "Last modified"
+#~ msgstr "Última modificación"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Quitar y borrar"
+
+#~ msgid "Status"
+#~ msgstr "Estado"
+
+#~ msgid "Size"
+#~ msgstr "Tamaño"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Editar el marcador seleccionado"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Quitar el marcador seleccionado"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostrar las diferencias"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostrar las diferencias de todos los archivos"
+
+#~ msgid "All..."
+#~ msgstr "Todos..."
+
+#~ msgid "Selected..."
+#~ msgstr "Seleccionado..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostrar las diferencias del archivo seleccionado"
+
+#~ msgid "No matching files"
+#~ msgstr "No hay archivos coincidentes"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "El destino no está en la misma rama."
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Crear directorio"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Mover"
+
+#~ msgid "Move to"
+#~ msgstr "Mover a"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Información"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formato:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Hora de la última revisión: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusionar - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Fusionar desde:"
+
+#~ msgid "Time"
+#~ msgstr "Hora"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Anotar el archivo seleccionado"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inicializar..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Revertir todos los cambios"
+
+#~ msgid "Not the same branch"
+#~ msgstr "No están en la misma rama"
+
+#~ msgid "Working tree format: "
+#~ msgstr "Formato del árbol de trabajo: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Ramas relacionadas:</b>"
+
+#~ msgid "Branch format: "
+#~ msgstr "Formato de la rama: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisiones en el repositorio: "
+
+#~ msgid "Bookmark"
+#~ msgstr "Marcador"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Marcadores"
+
+#~ msgid "unknown"
+#~ msgstr "desconocido"
+
+#~ msgid "Open"
+#~ msgstr "Abrir"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Abrir el archivo seleccionado"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flictos..."
+
+#~ msgid "_Information..."
+#~ msgstr "_Información..."
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Todos los desconocidos recursivamente"
+
+#~ msgid "_Add"
+#~ msgstr "_Añadir"
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Edad de la rama en días: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Tamaño del repositorio: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Historial de ramas:</b>"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Archivo(s) para el commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Mensaje del commit:"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "No hay cambios en el árbol de trabajo."
+
+#~ msgid "Revno"
+#~ msgstr "Numrev"
+
+#~ msgid "Set default push location"
+#~ msgstr "Establecer la ubicación predeterminada para el push"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull realizado con éxito"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revision(es) no encontrada(s)."
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "La ubicación del padre es desconocida"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Por favor, compruebe el árbol de trabajo antes de continuar."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Se han detectado conflictos"
+
+#~ msgid "unchanged"
+#~ msgstr "sin cambios"
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert realizado con éxito"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Todos los archivos han sido revertidos a la última versión."
+
+#~ msgid "Filename"
+#~ msgstr "Nombre de archivo"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Añadir el archivo seleccionado"
+
+#~ msgid "Add"
+#~ msgstr "Add"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "No se ha podido encontrar el archivo de Glade."
+
+#~ msgid "Title:"
+#~ msgstr "Título:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Por favor, especifique un título para continuar."
+
+#~ msgid "Remove"
+#~ msgstr "Remove"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Quitar el archivo seleccionado"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Cambiar el nombre al archivo seleccionado"
+
+#~ msgid "Revert"
+#~ msgstr "Revert"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Quitar el archivo o directorio seleccionado y borrarlo del disco"
+
+#~ msgid "Rename"
+#~ msgstr "Rename"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Revertir los cambios"
+
+#~ msgid "Annotate"
+#~ msgstr "Annotate"
+
+#~ msgid "Open Folder"
+#~ msgstr "Abrir carpeta"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Añadir a marcadores la ubicación actual"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Por favor, especifique el nombre deseado para el nuevo directorio."
+
+#~ msgid "No directory name given"
+#~ msgstr "No se ha indicado un nombre de directorio"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "No se encontraron archivos añadidos en el árbol de trabajo."
+
+#~ msgid "View contents"
+#~ msgstr "Ver contenidos"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostrar las diferencias entre dos revisiones del archivo"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Por favor, seleccione un archivo de la lista para continuar."
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Por favor, especifique otro nombre para continuar."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Por favor, especifique un nuevo nombre para el archivo."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Añadir archivo(s)..."
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Todos los archivos con estado «añadido»"
+
+#~ msgid "_Remove"
+#~ msgstr "_Remove"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Quitar archivo(s)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI para Bazaar"
+
+#~ msgid "Selected only"
+#~ msgstr "Sólo los seleccionados"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "¿Qué archivo(s) desea quitar?"
+
+#~ msgid "_Rename..."
+#~ msgstr "Cambiar _nombre..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Mostrar _archivos ocultos"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Anotar..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Help"
+#~ msgstr "Ay_uda"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Modo h_istorial"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "¿Qué archivo(s) desea añadir?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Añadir archivo(s)"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Quitar archivo(s)"
+
+#~ msgid "(none)"
+#~ msgstr "(ninguno)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Renombrar"
+
+#~ msgid "Rename to"
+#~ msgstr "Cambiar nombre a"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Cambiar nombre"
+
+#~ msgid "Select a directory"
+#~ msgstr "Seleccione un directorio"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publish to branch: "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Raíz del checkout: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Checkout del repositorio: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Raíz de la rama: "
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Ubicación:</b>"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout de la rama: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Subdirectorios versionados: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Archivos quitados: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Formato del repositorio: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Revisiones que faltan en la rama: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>En el árbol de trabajo:</b>"
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Hora de la primera revisión: "
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "No se ha establecido ninguna ubicación predeterminada para el push.\n"
+#~ "¿Desea establecer %r como predeterminada ahora?"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Faltan revisiones"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "No se pueden determinar las revisiones que faltan si no se conoce la "
+#~ "ubicación del padre."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Rama local actualizada"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Por favor, espere. Se están cargando las revisiones..."
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "Se ha realizado un pull a %d revision(es)."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "No se ha podido encontrar el archivo de descripción de la IU"
+
+#~ msgid "ignored"
+#~ msgstr "ignorado"
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "No faltan revisiones."
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Revertir el archivo seleccionado a la revisión indicada"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr ""
+#~ "No es posible hacer pull hasta que no haya una ubicación para el padre."
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Abrir carpeta de marcadores en Nautilus"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Ver el contenido del archivo en un visor interno"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Revertir a esta revisión"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Se ha añadido el directorio actual a los marcadores. Puede\n"
+#~ "llegar a él seleccionándolo en el panel de la izquierda."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "El marcador se ha añadido con éxito"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "El directorio actual ya está en marcadores.\n"
+#~ "Consulte el panel de la izquierda como referencia."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Esta ubicación ya está en marcadores"
+
+#~ msgid "Filename not given"
+#~ msgstr "No se ha indicado ningún nombre de archivo"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "¿Borrar el directorio con todos los directorios que contiene?"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Directorio _versionado"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Revisiones que faltan"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "E_tiquetas..."
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Raíz del checkout ligero: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Estado de bloqueo del repositorio: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Estado de bloqueo de la rama: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Estado de bloqueo del árbol de trabajo: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Archivos ignorados: "
+
+#~ msgid "Added files: "
+#~ msgstr "Archivos añadidos: "
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Estado de bloqueo:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Almacén de revisiones:</b>"
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Revisiones que faltan en el árbol de trabajo: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revisiones que faltan:</b>"
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Número de commiters: "
+
+#~ msgid "_Merge..."
+#~ msgstr "_Fusionar..."
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  BigSus https://launchpad.net/~bigsus\n"
+#~ "  David Arnoldo Ortiz Lozano https://launchpad.net/~tyoc\n"
+#~ "  Joseph https://launchpad.net/~josephmail7\n"
+#~ "  Lightbuster https://launchpad.net/~herramienta-vx2\n"
+#~ "  Mario del Pozo https://launchpad.net/~mariodpros\n"
+#~ "  Omar Olarte https://launchpad.net/~oeolartep\n"
+#~ "  Paco Molinero https://launchpad.net/~franciscomol\n"
+#~ "  Ricardo Pérez López https://launchpad.net/~ricardo\n"
+#~ "  Rodrigo Garcia Gonzalez https://launchpad.net/~nibblesmx\n"
+#~ "  Virusurbano https://launchpad.net/~lfacchinelli\n"
+#~ "  kilik https://launchpad.net/~kilik\n"
+#~ "  uve https://launchpad.net/~uve\n"
+#~ "  Álvaro del Olmo Alonso https://launchpad.net/~dllum"

=== added file 'po/fi.po'
--- po/fi.po	1970-01-01 00:00:00 +0000
+++ po/fi.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,702 @@
+# Finnish translation for bzr-gtk
+# Copyright (c) 2010 Rosetta Contributors and Canonical Ltd 2010
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2010.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-06-08 13:43+0000\n"
+"Last-Translator: Otto Kekäläinen <otto@sange.fi>\n"
+"Language-Team: Finnish <fi@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr ""
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr ""
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "Kohde:"
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr ""
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Valitse kansio"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr ""
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr ""
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr ""
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr ""
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr ""
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr ""
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr ""
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "Toimenpide keskeytetty."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr ""
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr ""
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr ""
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr ""
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr ""
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr ""
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr ""
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr ""
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr ""
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr ""
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr ""
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr ""
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr ""
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr ""
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr ""
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr ""
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr ""
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr ""
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr ""
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr ""
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr ""
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr ""
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr ""
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr ""
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr ""
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr ""
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr ""
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr ""
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr ""
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr ""
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr ""
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr ""
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr ""
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr ""
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr ""
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr ""
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr ""
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr ""
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr ""
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr ""
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr ""
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr ""
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr ""
+
+#: ../status.py:100
+msgid "Removed"
+msgstr ""
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr ""
+
+#: ../status.py:113
+msgid "Modified"
+msgstr ""
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr ""
+
+#: ../status.py:126
+msgid "No changes."
+msgstr ""
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr ""
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr ""
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr ""
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr ""
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr ""
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr ""
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr ""
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr ""
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr ""
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr ""
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Otto Kekäläinen https://launchpad.net/~otto"

=== modified file 'po/fr.po'
--- po/fr.po	2008-03-11 17:01:27 +0000
+++ po/fr.po	2011-03-08 04:41:48 +0000
@@ -8,251 +8,334 @@
 msgstr ""
 "Project-Id-Version: Olive 0.11\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-01-04 22:08+0000\n"
-"Last-Translator: Yoan Blanc <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:06+0000\n"
+"Last-Translator: Pierre Slamich <pierre.slamich@gmail.com>\n"
 "Language-Team: GNOME French Team <gnomefr@traduc.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=utf-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Branche"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Veuillez sélectionner un dossier"
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Emplacement de la branche :"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destination :"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Pseudo de la branche :"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Révision :"
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Veuillez choisir un dossier"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Emplacement de la branche manquant"
+msgstr "Emplacement de la branche manquante"
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "Il est nécessaire de renseigner l'emplacement de la branche."
+msgstr "Vous devez préciser l'emplacement de la branche."
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Succès de la création de la branche"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d révision(s) ont été branchées."
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/D"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
-msgstr "Checkout"
-
-#: checkout.py:62
+msgstr "Check_out"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Checkout _léger"
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Le répertoire ne contient pas de répertoire de travail"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Opération annulée."
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "Le répertoire n'est pas une branche"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr "Cette action ne peut effectuée que sur une branche."
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Cette branche contient des modifications locales."
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "Veuillez commiter ou annuler les modifications avant la fusion."
+
+#: ../commit.py:182
+msgid "added"
+msgstr "ajouté"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "supprimé"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "renommé"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "renommé et modifié"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "modifié"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "Ne valider que l_ocalement"
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Comm_it"
 
-#: commit.py:89
-#, fuzzy
-msgid "File(s) to commit"
-msgstr "Fichier(s) à valider"
-
-#: commit.py:95
-#, fuzzy
-msgid "Commit message:"
-msgstr "Message de validation :"
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr "Fusions en attente"
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr "_Ne valider que localement"
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr "Commiter avec un message vide ?"
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr "Vous pouvez donner la raison de cette validation dans ce message"
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr "Valider avec des inconnus ?"
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-"Des fichiers inconnus sont présents dans le répertoire de travail. Valider "
-"malgré tout ?"
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr "Validerer sans aucun changement ?"
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr "Aucun changement n'a été effectué dans le répertoire de travail."
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Valider"
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Chemin"
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Type"
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr "ajouté"
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr "supprimé"
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr "renommé et modifié"
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr "renommé"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr "modifié"
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr "Date"
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Commiteur"
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Résumé"
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Valider avec un message vide ?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "Vous pouvez donner la raison de cette validation dans ce message"
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "Valider avec des inconnus ?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr "Fichiers inconnus dans le répertoire de travail. Poursuivre  ?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "Validerer sans aucun changement ?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr "Utilitaire externe"
+msgstr "Utilitaire externe :"
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflits"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Aucun conflit dans l'arbre de travail."
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflit sur le chemin"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflit sur le contenu"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflit sur le texte"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id en doublon"
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "doublon"
 
-#: conflicts.py:125
-#, fuzzy
+#: ../conflicts.py:128
 msgid "parent loop"
-msgstr "boucle avec le parent"
+msgstr ""
 
-#: conflicts.py:127
-#, fuzzy
+#: ../conflicts.py:130
 msgid "unversioned parent"
-msgstr "parent non versionné"
+msgstr ""
 
-#: conflicts.py:129
-#, fuzzy
+#: ../conflicts.py:132
 msgid "missing parent"
-msgstr "parent manquant"
+msgstr ""
 
-#: conflicts.py:131
-#, fuzzy
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "suppression du parent"
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "type de conflit inconnu"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Aucun fichier n'a été selectionné"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Veuillez sélectionner un fichier parmi la liste."
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "L'appel à utilitaire externe a échoué"
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Impossible de résoudre le conflit"
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -262,36 +345,79 @@
 "résolus par Olive. Les conflits de contenu ou sur la structure de "
 "l'arborescence doivent êtres résolus en utilisant la ligne de commande."
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "Afficha_ge"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Succès de la fusion"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Tous les changements ont été appliqués avec succès."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Conflits rencontrés."
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "Veuillez résoudre les conflits manuellement avant de valider."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Le répertoire n'est pas une branche"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "Cette action ne peut effectuée que sur une branche."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Le répertoire n'est pas un checkout"
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 "Les validations locales ne peuvent être effectués que sur des checkouts."
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Aucun changement à valider"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Il est malgré tout possible de forcer la validation."
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflits dans l'arbre"
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "Il est nécessaire de résoudre les conflits avant de valider."
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "La validation stricte a échoué."
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -299,28 +425,29 @@
 "L'arbre de travail contient des fichiers inconnus.\n"
 "Veuillez les ajouter ou les supprimer."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "La branche associée n'est pas à jour"
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Fichier non versionné"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Le fichier sélectionné n'est pas versionné."
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Les branches ont divergées"
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -329,36 +456,35 @@
 "ont divergées. Utilisez l'option d'écrasement si vous souhaitez malgré tout\n"
 "effectuer un « push »."
 
-#: errors.py:50
-#, fuzzy
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Pas de différences à afficher"
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Le fichier sélectionné n'a pas été modifié."
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "Pas de telle révision"
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "La révision que vous avez renseigné n'existe pas."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "La cible existe déjà"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "Le répertoire cible existe déjà. Veuillez choisir une autre cible."
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Le répertoire est déjà une branche"
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -367,11 +493,11 @@
 "Le répertoire courant (%s) est déjà une branche.\n"
 "Vous avez la possibilité de l'utiliser ou d'initialiser un autre répertoire."
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Branche sans répertoire de travail"
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -380,97 +506,93 @@
 "Le répertoire courant (%s)\n"
 "est une branche sans arbre de travail."
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Erreur bzr inconnue"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permission refusée"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "permission refusée."
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Erreur inconnue"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initialiser"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Quel répertoire voulez-vous intialiser ?"
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Répertoire actuel"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr "Créer un nouveau répertoire nommé :"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Le nom du répertoire n'est pas indiqué"
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Vous devez indiquer un nouveau nom de répertoire."
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Fusionner"
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Branche non indiquée"
 
-#: merge.py:67
-#, fuzzy
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Veuillez indiquer une branche depuis laquelle fusionner."
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Erreur de commande Bazaar"
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr "Succès de la fusion"
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr "Tous les changements ont été appliqués avec succès."
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr "Conflits rencontrés."
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr "Veuillez résoudre les conflits manuellement avant de valider."
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr "Emplacement :"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Push"
 
-#: push.py:97
-msgid "Set default push location"
-msgstr "Définition de l'emplacement par défaut du push"
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-"Il n'y a pas d'emplacement défini par défaut pour le push.\n"
-"Voulez-vous maintenant définir « %r » par défaut ?"
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -478,20 +600,20 @@
 "Vous ne pouvez pas effectuer un push si les branches ont divergées.\n"
 "Voulez-vous écraser ?"
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Succès du push."
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d révisions exportées."
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Aucun répertoire parent existant"
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -500,855 +622,670 @@
 "Le répertoire parent (%s) n'existe pas.\n"
 "Voulez-vous le créer ?"
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr "Veuillez patienter, les révisions sont en cours de chargement..."
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Sélectionner"
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr "Renvo"
-
-#: revbrowser.py:70
-#, fuzzy
-msgid "Time"
-msgstr "Temps"
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr "Ajouté"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr "Supprimé"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renommé"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modifié"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Inconnu"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "Aucun changement."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Étiquettes"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr "Nom de l'étiquette"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr "ID de la révision"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Les étiquettes ne sont pas prises en charge par le format de cette branche. "
 "Effectuez une mise à niveau."
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Aucune révision étiquettée dans cette branche."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Supprimer l'étiquette"
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Supprimer l'étiquette ?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Voulez-vous vraiment supprimer l'étiquette : <b>%s</b> ?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Ajouter une étiquette"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nom de l'étiquette :"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID de révision :"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Aucun nom d'étiquette indiqué"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Vous devez renseigner le nom d'étiquette souhaité."
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr "Cette branche contient des modifications locales."
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr "Veuillez commiter ou annuler les modifications avant la fusion."
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr "L'emplacement parent est inconnu"
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-"Impossible de trouver les révisions manquantes si l'emplacement parent n'est "
-"pas connu."
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr "Il y a des révisions manquantes"
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr "%d révision(s) manquante(s)."
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr "La branche locale est à jour"
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr "Il n'y a pas de révisions manquantes."
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-"Impossible d'effectuer un « pull » tant que l'emplacement parent est absent."
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr "Pull réussi"
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr "%d révision(s) importée(s)."
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr "Conflits détectés"
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr "Vérifiez le répertoire de travail avant de poursuivre."
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr "Rétablissement réussi"
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr "Tous les fichiers ont été rétablis à la dernière révision."
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Marque-pages"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Marque-page"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr "inchangé"
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr "ignoré"
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr "inconnu"
-
-#: __init__.py:964
-msgid "Filename"
-msgstr "Nom de fichier"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "État"
-
-#: __init__.py:966
-msgid "Size"
-msgstr "Taille"
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr "Dernière modification"
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-"Veuillez sélectionner un fichier de la liste\n"
-"ou choisir l'autre option."
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Titre :"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr "Aucun titre renseigné"
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr "Veuillez renseigner un titre pour poursuivre."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr "Impossible de trouver le fichier Glade."
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr "Impossible de trouver le fichier de description UI."
-
-#: menu.py:63
-msgid "Add"
-msgstr "Ajouter"
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr "Ajoute le fichier sélectionné"
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr "Supprimer"
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr "Supprime le fichier sélectionné"
-
-#: menu.py:71
-#, fuzzy
-msgid "Remove and delete"
-msgstr "Enlève et efface"
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr "Enlève les fichiers/répertoires sélectionnés et les efface"
-
-#: menu.py:75
-#, fuzzy
-msgid "Rename"
-msgstr "Renommer"
-
-#: menu.py:76
-#, fuzzy
-msgid "Rename the selected file"
-msgstr "Renommer le fichier sélectionné"
-
-#: menu.py:79
-msgid "Open"
-msgstr "Ouvrir"
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr "Ouvrir le fichier sélectionné"
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr "Commit les changements"
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Analyse des différences"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr "Affiche les différences du fichier"
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr "Marque l'emplacement courant"
-
-#: menu.py:103
-msgid "Edit"
-msgstr "Éditer"
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr "Édite le marque-page sélectionné"
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr "Supprime le marque-page sélectionné"
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr "Ouvrir le dossier"
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr "Ouvrir le dossier en marque-page dans Nautilus"
-
-#: menu.py:115
-msgid "Selected..."
-msgstr "Sélectionné..."
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr "Affiche les différences du fichier sélectionné"
-
-#: menu.py:119
-msgid "All..."
-msgstr "Toutes..."
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr "Affiche les différences de tous les fichiers"
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-#, fuzzy
-msgid "Delete directory with all directories below ?"
-msgstr "Supprimer le répertoire et tous ses sous-répertoires ?"
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr "Marque-page ajouté avec succès"
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-"Le répertoire courant a été marqué. Il est dorénavant\n"
-"possible de l'atteindre en le sélectionnant depuis le\n"
-"panneau gauche."
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr "Emplacement déjà marqué"
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-"Le répertoire courant est déjà marqué.\n"
-"Consultez le panneau de gauche pour référence."
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr "Aucun nom de répertoire renseigné"
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr "Veuillez indiquer le nom souhaité pour le nouveau répertoire."
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr "Le répertoire existe déjà"
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr "Veuillez indiquer un nom différent pour poursuivre."
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr "Veuillez choisir un fichier de la liste pour opérer."
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr "Ce n'est pas la même branche"
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr "La destination ne se trouve pas dans la même branche."
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr "Aucun fichier correspondant"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr "Aucun fichier ajouté n'a été trouvé dans le répertoire de travail."
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "Quel(s) fichier(s) souhaitez-vous supprimer ?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Uniquement sélectionné(s)"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "Tous les fichiers avec le statut « added »"
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Supprimer"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr "Nom de fichier non fourni"
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr "Veuillez indiquer un nouveau nom pour le fichier."
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - Interface graphique de Bazaar"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Fichier"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Ajouter des fichiers..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Supprimer des fichiers..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Créer un _répertoire..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Renommer..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Déplacer..."
-
-#: olive.glade:92
-#, fuzzy
-msgid "_Annotate..."
-msgstr "_Annoter..."
-
-#: olive.glade:118
-msgid "_View"
-msgstr "Afficha_ge"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Afficher les fichiers _cachés"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Rafraîchir"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr "_Initialiser..."
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Obtenir..."
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr "C_heckout..."
-
-#: olive.glade:187
-#, fuzzy
-msgid "Pu_ll"
-msgstr "Pu_ll"
-
-#: olive.glade:201
-#, fuzzy
-msgid "Pu_sh..."
-msgstr "Pu_sh..."
-
-#: olive.glade:220
-#, fuzzy
-msgid "_Revert all changes"
-msgstr "Annule_r les modifications"
-
-#: olive.glade:228
-#, fuzzy
-msgid "_Merge..."
-msgstr "_Fusionner..."
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr "_Commit..."
-
-#: olive.glade:255
-#, fuzzy
-msgid "Ta_gs..."
-msgstr "Ta_gs..."
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "S_tatus"
-
-#: olive.glade:271
-#, fuzzy
-msgid "Missing _revisions"
-msgstr "_Révisions manquantes"
-
-#: olive.glade:279
-#, fuzzy
-msgid "Con_flicts..."
-msgstr "Con_flicts..."
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Statistiques"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Différences..."
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Historique..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr "_Information..."
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "Aid_e"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-#, fuzzy
-msgid "H_istory Mode"
-msgstr "Mode H_istorique"
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Bastien Jaillot https://launchpad.net/~bastnic\n"
-"  Bruno Bord https://launchpad.net/~brunobord\n"
-"  Hanusz leszek https://launchpad.net/~leszek-skynet\n"
-"  Nicolas Velin https://launchpad.net/~nsv\n"
-"  Pierre Slamich https://launchpad.net/~pierre-slamich\n"
-"  Shrat https://launchpad.net/~dyonisiaque\n"
-"  Stéphane Raimbault https://launchpad.net/~sra\n"
-"  Yoan Blanc https://launchpad.net/~greut-lists\n"
-"  codL https://launchpad.net/~codlgaez"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Ajouter des fichiers"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Quel(s) fichier(s) souhaitez-vous ajouter ?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr "Tous les inconnus récursivement"
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Ajouter"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Suppression de fichiers"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - Créer un répertoire"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr "Répertoire sous ré_vision"
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Créer un répertoire"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Move"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Déplacer vers"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Sélectionnez un répertoire"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Déplacer"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Renommer"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Renommer en"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "_Renommer"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr "Olive - Information"
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(aucun)"
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr "Checkout racine : "
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr "Branche racine : "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Dépôt du checkout : "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr "Checkout de la branche : "
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr "Branche du dépôt : "
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr "Dépôt partagé : "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr "Racine du checkout léger : "
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr "<b>Emplacement :</b>"
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr "Publier vers la branche : "
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr "Branche parente : "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr "<b>Relatifs aux branches :</b>"
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr "Format du dépôt : "
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr "Format de la branche : "
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr "Format du répertoire de travail : "
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr "Format de contrôle : "
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr "<b>Format :</b>"
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr "Statut du verrou du dépôt : "
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr "Statut du verrou de la branche : "
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr "Statut du verrou du répertoire de travail : "
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr "<b>État du verrou :</b>"
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr "Révisions manquantes dans la branche : "
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr "Révisions manquantes dans le répertoire de travail : "
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr "<b>Révisions manquantes :</b>"
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr "Sous-répertoires avec révisions : "
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "Fichiers ignorés : "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Fichiers inconnus : "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Fichiers renommés : "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Fichiers supprimés : "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Fichiers ajoutés : "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Fichiers modifiés : "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Fichiers inchangés : "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr "<b>Dans le répertoire de travail :</b>"
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr "Date de la dernière révision : "
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Date de la première révision : "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr "Age de la branche en jours : "
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr "Nombre de commiteurs : "
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr "Révisions dans la branche : "
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr "<b>Historique de la branche :</b>"
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr "Taille du dépôt : "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr "Révisions dans le dépôt : "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr "<b>Stockage des révisions :</b>"
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "_Rename..."
+#~ msgstr "_Renommer..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Déplacer..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Créer un _répertoire..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Supprimer des fichiers..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Interface graphique de Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Ajouter des fichiers..."
+
+#~ msgid "_File"
+#~ msgstr "_Fichier"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Rafraîchir"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Afficher les fichiers _cachés"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Historique..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Différences..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistiques"
+
+#~ msgid "_Help"
+#~ msgstr "Aid_e"
+
+#~ msgid "Diff"
+#~ msgstr "Analyse des différences"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Quel(s) fichier(s) souhaitez-vous ajouter ?"
+
+#~ msgid "Selected only"
+#~ msgstr "Uniquement sélectionné(s)"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Ajouter des fichiers"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Suppression de fichiers"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Quel(s) fichier(s) souhaitez-vous supprimer ?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Tous les inconnus récursivement"
+
+#~ msgid "_Add"
+#~ msgstr "_Ajouter"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Tous les fichiers avec le statut « added »"
+
+#~ msgid "_Remove"
+#~ msgstr "_Supprimer"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Créer un répertoire"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Répertoire sous ré_vision"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Créer un répertoire"
+
+#~ msgid "_Get..."
+#~ msgstr "_Obtenir..."
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Move"
+
+#~ msgid "Move to"
+#~ msgstr "Déplacer vers"
+
+#~ msgid "Shared repository: "
+#~ msgstr "Dépôt partagé : "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Racine du checkout léger : "
+
+#~ msgid "_Rename"
+#~ msgstr "_Renommer"
+
+#~ msgid "Rename to"
+#~ msgstr "Renommer en"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Renommer"
+
+#~ msgid "_Move"
+#~ msgstr "_Déplacer"
+
+#~ msgid "Select a directory"
+#~ msgstr "Sélectionnez un répertoire"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publier vers la branche : "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Branche parente : "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Checkout racine : "
+
+#~ msgid "(none)"
+#~ msgstr "(aucun)"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Dépôt du checkout : "
+
+#~ msgid "Branch root: "
+#~ msgstr "Branche racine : "
+
+#~ msgid "Control format: "
+#~ msgstr "Format de contrôle : "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Format du répertoire de travail : "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Statut du verrou du dépôt : "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Statut du verrou de la branche : "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Révisions manquantes dans le répertoire de travail : "
+
+#~ msgid "Repository format: "
+#~ msgstr "Format du dépôt : "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format de la branche : "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Statut du verrou du répertoire de travail : "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Révisions manquantes dans la branche : "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Révisions dans la branche : "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Fichiers renommés : "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Fichiers inconnus : "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Sous-répertoires avec révisions : "
+
+#~ msgid "Removed files: "
+#~ msgstr "Fichiers supprimés : "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Fichiers ignorés : "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Date de la première révision : "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Age de la branche en jours : "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Nombre de commiteurs : "
+
+#~ msgid "Title:"
+#~ msgstr "Titre :"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Veuillez sélectionner un fichier de la liste\n"
+#~ "ou choisir l'autre option."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Taille du dépôt : "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Révisions dans le dépôt : "
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Veuillez renseigner un titre pour poursuivre."
+
+#~ msgid "No title given"
+#~ msgstr "Aucun titre renseigné"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "L'emplacement parent est inconnu"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull réussi"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d révision(s) importée(s)."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Ajoute le fichier sélectionné"
+
+#~ msgid "Add"
+#~ msgstr "Ajouter"
+
+#~ msgid "unchanged"
+#~ msgstr "inchangé"
+
+#~ msgid "Bookmark"
+#~ msgstr "Marque-page"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Marque-pages"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Impossible de trouver le fichier de description UI."
+
+#~ msgid "Status"
+#~ msgstr "État"
+
+#~ msgid "Filename"
+#~ msgstr "Nom de fichier"
+
+#~ msgid "unknown"
+#~ msgstr "inconnu"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Impossible de trouver le fichier Glade."
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Affiche les différences de tous les fichiers"
+
+#~ msgid "All..."
+#~ msgstr "Toutes..."
+
+#~ msgid "Selected..."
+#~ msgstr "Sélectionné..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Affiche les différences du fichier sélectionné"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Marque l'emplacement courant"
+
+#~ msgid "Edit"
+#~ msgstr "Éditer"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Édite le marque-page sélectionné"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Supprime le marque-page sélectionné"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Commit les changements"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Affiche les différences du fichier"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Le répertoire courant a été marqué. Il est dorénavant\n"
+#~ "possible de l'atteindre en le sélectionnant depuis le\n"
+#~ "panneau gauche."
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Le répertoire courant est déjà marqué.\n"
+#~ "Consultez le panneau de gauche pour référence."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Emplacement déjà marqué"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Veuillez indiquer le nom souhaité pour le nouveau répertoire."
+
+#~ msgid "No directory name given"
+#~ msgstr "Aucun nom de répertoire renseigné"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Marque-page ajouté avec succès"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Le répertoire existe déjà"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Veuillez indiquer un nom différent pour poursuivre."
+
+#~ msgid "Not the same branch"
+#~ msgstr "Ce n'est pas la même branche"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Veuillez choisir un fichier de la liste pour opérer."
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "La destination ne se trouve pas dans la même branche."
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Aucun fichier ajouté n'a été trouvé dans le répertoire de travail."
+
+#~ msgid "No matching files"
+#~ msgstr "Aucun fichier correspondant"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout de la branche : "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Branche du dépôt : "
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Veuillez indiquer un nouveau nom pour le fichier."
+
+#~ msgid "Filename not given"
+#~ msgstr "Nom de fichier non fourni"
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Fichiers inchangés : "
+
+#~ msgid "Modified files: "
+#~ msgstr "Fichiers modifiés : "
+
+#~ msgid "Added files: "
+#~ msgstr "Fichiers ajoutés : "
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Date de la dernière révision : "
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Il y a des révisions manquantes"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Impossible de trouver les révisions manquantes si l'emplacement parent n'est "
+#~ "pas connu."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "La branche locale est à jour"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d révision(s) manquante(s)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Il n'y a pas de révisions manquantes."
+
+#~ msgid "_Information..."
+#~ msgstr "_Information..."
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Information"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Emplacement :</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Relatifs aux branches :</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format :</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>État du verrou :</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Révisions manquantes :</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>Dans le répertoire de travail :</b>"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Historique de la branche :</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Stockage des révisions :</b>"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr ""
+#~ "Impossible d'effectuer un « pull » tant que l'emplacement parent est absent."
+
+#~ msgid "Remove"
+#~ msgstr "Supprimer"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Supprime le fichier sélectionné"
+
+#~ msgid "Open"
+#~ msgstr "Ouvrir"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Ouvrir le fichier sélectionné"
+
+#~ msgid "Open Folder"
+#~ msgstr "Ouvrir le dossier"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Ouvrir le dossier en marque-page dans Nautilus"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Aucun changement n'a été effectué dans le répertoire de travail."
+
+#~ msgid "Pending merges"
+#~ msgstr "Fusions en attente"
+
+#~ msgid "Revno"
+#~ msgstr "Renvo"
+
+#~ msgid "Set default push location"
+#~ msgstr "Définition de l'emplacement par défaut du push"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Il n'y a pas d'emplacement défini par défaut pour le push.\n"
+#~ "Voulez-vous maintenant définir « %r » par défaut ?"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Veuillez patienter, les révisions sont en cours de chargement..."
+
+#~ msgid "Revert successful"
+#~ msgstr "Rétablissement réussi"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Tous les fichiers ont été rétablis à la dernière révision."
+
+#~ msgid "ignored"
+#~ msgstr "ignoré"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Vérifiez le répertoire de travail avant de poursuivre."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflits détectés"
+
+#~ msgid "Last modified"
+#~ msgstr "Dernière modification"
+
+#~ msgid "Size"
+#~ msgstr "Taille"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Renommer le fichier sélectionné"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Enlève les fichiers/répertoires sélectionnés et les efface"
+
+#~ msgid "Rename"
+#~ msgstr "Renommer"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Mode H_istorique"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initialiser..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Annoter..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Fusionner..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Révisions manquantes"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Annule_r les modifications"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Supprimer le répertoire et tous ses sous-répertoires ?"
+
+#~ msgid "Revert"
+#~ msgstr "Rétablir"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Annoter le fichier sélectionné"
+
+#~ msgid "View contents"
+#~ msgstr "Voir le contenu"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Annuler les changements"
+
+#~ msgid "Annotate"
+#~ msgstr "Annoter"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Afficher les différences entre deux révisions du fichier"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Voir le contenu du fichier dans le visualiseur intégré"
+
+#~ msgid "Show differences"
+#~ msgstr "Montrer les différences"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusion - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Fusionner à partir de :"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Supprimer et effacer"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Rétablir le fichier sélectionné vers la révision sélectionnée"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Rétablir à cette révision"
+
+#~ msgid "Commit message:"
+#~ msgstr "Message de validation :"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flits"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Bastien Jaillot https://launchpad.net/~bastnic\n"
+#~ "  Bruno Bord https://launchpad.net/~brunobord\n"
+#~ "  DarkRedman https://launchpad.net/~darkredman\n"
+#~ "  Francois Audirac https://launchpad.net/~francois-audirac\n"
+#~ "  Hanusz leszek https://launchpad.net/~leszek-skynet\n"
+#~ "  Jean-François Fortin Tam https://launchpad.net/~kiddo\n"
+#~ "  NSV https://launchpad.net/~nsv\n"
+#~ "  Pierre Slamich https://launchpad.net/~pierre-slamich\n"
+#~ "  Shrat https://launchpad.net/~dyonisiaque\n"
+#~ "  Stéphane Raimbault https://launchpad.net/~sra\n"
+#~ "  Wilfried Kopp https://launchpad.net/~chevdor\n"
+#~ "  Yoan Blanc https://launchpad.net/~greut\n"
+#~ "  codL https://launchpad.net/~codlgaez"

=== modified file 'po/hu.po'
--- po/hu.po	2008-03-11 17:01:27 +0000
+++ po/hu.po	2011-03-08 04:41:48 +0000
@@ -7,1284 +7,700 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2006-09-16 23:21+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 07:57+0000\n"
 "Last-Translator: Szilveszter Farkas <Szilveszter.Farkas@gmail.com>\n"
 "Language-Team: Hungarian <hu@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr ""
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr ""
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr ""
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr ""
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr ""
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr ""
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr ""
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr ""
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr ""
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr ""
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr ""
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr ""
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr ""
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - Bazaar grafikus felület"
-
-#: olive.glade:21
-msgid "_File"
-msgstr ""
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr ""
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr ""
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr ""
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr ""
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr ""
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr ""
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Szilveszter Farkas https://launchpad.net/~phanatic"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar grafikus felület"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Csörföly Dániel https://launchpad.net/~csorfolydaniel\n"
+#~ "  Szilveszter Farkas https://launchpad.net/~phanatic"

=== modified file 'po/id.po'
--- po/id.po	2008-03-11 17:01:27 +0000
+++ po/id.po	2011-03-08 04:41:48 +0000
@@ -7,1284 +7,876 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2007-07-24 14:41+0000\n"
-"Last-Translator: Mahyuddin Susanto <udienz@debian-id.org>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-13 20:04+0000\n"
+"Last-Translator: Mahyuddin Susanto <mahyuddin.susanto@gmail.com>\n"
 "Language-Team: Indonesian <id@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Cabang"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Pilijh Folder"
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Lokasi Cabang:"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Tujuan:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Pilijh Folder"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr ""
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Pegang"
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr ""
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr ""
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr ""
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr ""
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Lihat"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inisialisasi"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr ""
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr "Lokasi"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Tekan"
 
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr ""
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr ""
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Beda"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "berkas mana yang akan di buang?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Hanya yang dipilih"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "Semua berkas dengan status 'dimasukkan'"
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "Hapus"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - GUI Bazaar"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Berkas"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Masukkan Berkas(berkas)..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Buang Berkas(berkas)..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Buat _Direktori"
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Ubah Nama..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Pindah..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr "_Lihat"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Perlihatkan berkas _tersembunyi"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Penyegaran"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Dapatkan"
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr "C_heckout..."
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr "Te_kan"
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "S_tatus..."
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Statistika"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Perbedaan..."
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Log..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Bantuan..."
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Mahyuddin Susanto https://launchpad.net/~udienz"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Tambahkan berkas(berkas)"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Dimana berkas(berkas) yang akan anda tambahkan??"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Tambahkan"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Buang berkas(berkas)"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - Buat Direktori"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr "_Jenis direktory"
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Buat direktory"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Pindah"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Pindahkan ke"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Pilih direktori"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Pindahkan"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Penamaan Ulang"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Ganti nama ke"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "_Ganti nama"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(tidak ada)"
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr "Periksa root: "
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr "root Cabang: "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Periksa Repository: "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr "Periksa Cabang: "
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr "Tampilkan di cabang: "
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr "cabang diatas: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr "Format Repository: "
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr "Format Cabang: "
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr "Bekerja dengan tiga format: "
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr "Pengendali Format: "
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr "Status pengunci Repositori: "
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr "Status pengunci Cabang: "
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr "Bekerja dengan status kunci tiga: "
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr "versi anak direktori: "
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "berkas di acuhkan: "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Berkas tidak diketahui; "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Penamaan ualng  berkas: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Buang Berkas; "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Penambahan berkas: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Berkas yang diubah: "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Berkas yang tidak diubah: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Revisi pertama: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "_Rename..."
+#~ msgstr "_Ubah Nama..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Pindah..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Buat _Direktori"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Buang Berkas(berkas)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Masukkan Berkas(berkas)..."
+
+#~ msgid "_File"
+#~ msgstr "_Berkas"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Penyegaran"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Perlihatkan berkas _tersembunyi"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Te_kan"
+
+#~ msgid "_Get..."
+#~ msgstr "_Dapatkan"
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Perbedaan..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistika"
+
+#~ msgid "_Help"
+#~ msgstr "_Bantuan..."
+
+#~ msgid "Diff"
+#~ msgstr "Beda"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Dimana berkas(berkas) yang akan anda tambahkan??"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Tambahkan berkas(berkas)"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Semua berkas dengan status 'dimasukkan'"
+
+#~ msgid "_Remove"
+#~ msgstr "Hapus"
+
+#~ msgid "Selected only"
+#~ msgstr "Hanya yang dipilih"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Buang berkas(berkas)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "berkas mana yang akan di buang?"
+
+#~ msgid "_Add"
+#~ msgstr "_Tambahkan"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Buat Direktori"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Jenis direktory"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Buat direktory"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Pindah"
+
+#~ msgid "Move to"
+#~ msgstr "Pindahkan ke"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Penamaan Ulang"
+
+#~ msgid "Select a directory"
+#~ msgstr "Pilih direktori"
+
+#~ msgid "_Move"
+#~ msgstr "_Pindahkan"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Periksa Repository: "
+
+#~ msgid "Branch root: "
+#~ msgstr "root Cabang: "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Periksa root: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Periksa Cabang: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Ganti nama"
+
+#~ msgid "Rename to"
+#~ msgstr "Ganti nama ke"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Tampilkan di cabang: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "cabang diatas: "
+
+#~ msgid "(none)"
+#~ msgstr "(tidak ada)"
+
+#~ msgid "Control format: "
+#~ msgstr "Pengendali Format: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Bekerja dengan tiga format: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format Cabang: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Format Repository: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Berkas yang tidak diubah: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Berkas yang diubah: "
+
+#~ msgid "Added files: "
+#~ msgstr "Penambahan berkas: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Status pengunci Repositori: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Status pengunci Cabang: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Bekerja dengan status kunci tiga: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Penamaan ualng  berkas: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Berkas tidak diketahui; "
+
+#~ msgid "Ignored files: "
+#~ msgstr "berkas di acuhkan: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "versi anak direktori: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Buang Berkas; "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Revisi pertama: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Mahyuddin Susanto https://launchpad.net/~udienz"

=== modified file 'po/it.po'
--- po/it.po	2008-03-11 17:01:27 +0000
+++ po/it.po	2011-03-08 04:41:48 +0000
@@ -7,1394 +7,1130 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-03-11 13:25+0000\n"
-"Last-Translator: Stefano Karapetsas <stefano@karapetsas.net>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-13 20:12+0000\n"
+"Last-Translator: Luca Ferretti <elle.uca@ubuntu-it.org>\n"
 "Language-Team: Italian <it@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
-#, fuzzy
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
-msgstr "_Ramo"
-
-#: branch.py:55 checkout.py:53
-#, fuzzy
-msgid "Please select a folder"
-msgstr "Selezionare una cartella"
-
-#: branch.py:57 checkout.py:55
-#, fuzzy
+msgstr "_Branch"
+
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
-msgstr "Posizione ramo:"
+msgstr "Posizione del branch:"
 
-#: branch.py:58 checkout.py:56
-#, fuzzy
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destinazione:"
 
-#: branch.py:59 checkout.py:57
-#, fuzzy
+#: ../branch.py:58
 msgid "Branck nick:"
-msgstr "Nome ramo:"
+msgstr "Soprannome del branch:"
 
-#: branch.py:60 checkout.py:58
-#, fuzzy
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisione:"
 
-#: branch.py:162 checkout.py:163
-#, fuzzy
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Selezionare una cartella"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Posizione ramo mancante"
+msgstr "Posizione del branch mancante"
 
-#: branch.py:163 checkout.py:164
-#, fuzzy
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "È necessario specificare una posizione del ramo."
+msgstr "È necessario specificare una posizione per il branch."
 
-#: branch.py:205
-#, fuzzy
+#: ../branch.py:182
 msgid "Branching successful"
-msgstr "Ramo creato con successo"
+msgstr "Branching riuscito"
 
-#: branch.py:206
-#, fuzzy, python-format
+#: ../branch.py:183
+#, python-format
 msgid "%d revision(s) branched."
-msgstr "Creato il ramo di %d revisione/i"
+msgstr ""
 
-#: branch.py:214 checkout.py:195
-#, fuzzy
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/D"
 
-#: checkout.py:50
-#, fuzzy
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Check_out"
 
-#: checkout.py:62
-#, fuzzy
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Checkout _leggero"
 
-#: commit.py:68
-#, fuzzy
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr "La directory non ha una ramo di lavoro"
+msgstr "La directory non presenta un albero di working"
 
-#: commit.py:69
-#, fuzzy
+#: ../commands.py:308
 msgid "Operation aborted."
-msgstr "Operazione annullata."
-
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "La directory non è un ramo"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-#, fuzzy
-msgid "You can perform this action only in a branch."
-msgstr "È possibile eseguire l'azione sono in un ramo."
-
-#: commit.py:88
-#, fuzzy
-msgid "Comm_it"
-msgstr "Comm_it"
-
-#: commit.py:89
-#, fuzzy
-msgid "File(s) to commit"
-msgstr "File da inviare:"
-
-#: commit.py:95
-#, fuzzy
-msgid "Commit message:"
-msgstr "Messaggio per il commit"
-
-#: commit.py:99
-#, fuzzy
-msgid "Pending merges"
-msgstr "Unioni pendenti"
-
-#: commit.py:147
-#, fuzzy
-msgid "_Only commit locally"
-msgstr "_Eseguire commit solo localmente"
-
-#: commit.py:215
-#, fuzzy
-msgid "Commit with an empty message?"
-msgstr "Eseguire il commit senza un messaggio?"
-
-#: commit.py:216
-#, fuzzy
-msgid "You can describe your commit intent in the message."
-msgstr "È possibile descrivere il motivo del commit nel messaggio."
-
-#: commit.py:228
-#, fuzzy
-msgid "Commit with unknowns?"
-msgstr "Eseguire il commit con sconosciuti?"
-
-#: commit.py:229
-#, fuzzy
-msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr "Operazione interrotta."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Ci sono cambiamenti locali nella branca"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
 msgstr ""
-"Esistono dei file sconosciuti nell'albero di lavoro. Eseguire il commit in "
-"ogni caso?"
-
-#: commit.py:240
-#, fuzzy
-msgid "Commit with no changes?"
-msgstr "Eseguire il commint senza modifiche?"
-
-#: commit.py:241
-#, fuzzy
-msgid "There are no changes in the working tree."
-msgstr "Non ci sono modifiche nell'albero di lavoro."
-
-#: commit.py:323 menu.py:87
-#, fuzzy
-msgid "Commit"
-msgstr "Commit"
-
-#: commit.py:325 conflicts.py:108
-#, fuzzy
-msgid "Path"
-msgstr "Percoso"
-
-#: commit.py:327 conflicts.py:110
-#, fuzzy
-msgid "Type"
-msgstr "Tipo"
-
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-#, fuzzy
+
+#: ../commit.py:182
 msgid "added"
 msgstr "aggiunto"
 
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-#, fuzzy
+#: ../commit.py:183
 msgid "removed"
 msgstr "rimosso"
 
-#: commit.py:353
-#, fuzzy
+#: ../commit.py:184
+msgid "renamed"
+msgstr "rinominato"
+
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "rinominato e modificato"
 
-#: commit.py:355 __init__.py:936 __init__.py:1223
-#, fuzzy
-msgid "renamed"
-msgstr "rinominato"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-#, fuzzy
+#: ../commit.py:186
 msgid "modified"
 msgstr "modificato"
 
-#: commit.py:395
-#, fuzzy
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "_Eseguire commit solo localmente"
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "Comm_it"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Commit"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Percorso"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Tipo"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr "Data"
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
-msgstr ""
+msgstr "Committer"
 
-#: commit.py:399 revbrowser.py:66
-#, fuzzy
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Riepilogo"
 
-#: conflicts.py:48
-#, fuzzy
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Eseguire il commit con un messaggio vuoto?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "È possibile descrivere il motivo del commit nel messaggio."
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "Eseguire il commit con sconosciuti?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+"Sono presenti dei file sconosciuti nel working tree. Eseguire il commit lo "
+"stesso?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "Eseguire il commint senza cambiamenti?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Utilità esterna:"
 
-#: conflicts.py:99
-#, fuzzy
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflitti"
 
-#: conflicts.py:102
-#, fuzzy
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
-msgstr "Nessun conflitto nell'albero di lavoro."
+msgstr "Nessun conflitto nel working tree"
 
-#: conflicts.py:115
-#, fuzzy
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflitto di percorso"
 
-#: conflicts.py:117
-#, fuzzy
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflitto di contenuto"
 
-#: conflicts.py:119
-#, fuzzy
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflitto di testo"
 
-#: conflicts.py:121
-#, fuzzy
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id duplicato"
 
-#: conflicts.py:123
-#, fuzzy
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicato"
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
-#, fuzzy
+#: ../conflicts.py:132
 msgid "missing parent"
-msgstr "genitore mancante"
+msgstr ""
 
-#: conflicts.py:131
-#, fuzzy
+#: ../conflicts.py:134
 msgid "deleting parent"
-msgstr "cancellazione genitore"
+msgstr "eliminazione genitore"
 
-#: conflicts.py:133
-#, fuzzy
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "tipo di conflitto sconosciuto"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
-#, fuzzy
+#: ../conflicts.py:165
 msgid "No file was selected"
-msgstr "Nessun file selezionato"
+msgstr "Non è stato selezionato alcun file"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
-#, fuzzy
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
-msgstr "Selezionare un file dall'elenco"
+msgstr "Selezionare un file dall'elenco."
 
-#: conflicts.py:173
-#, fuzzy
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
-msgstr "Chiamata all'utilità esterna fallita"
+msgstr "Chiamata all'utilità esterna non riuscita"
 
-#: conflicts.py:175
-#, fuzzy
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Impossibile risolvere il conflitto"
 
-#: conflicts.py:176
-#, fuzzy
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
-"Al momento solo i conflitti sui file di testo possono essere risolti con "
-"Olive. Conflitti nel contenuto e nella struttura dell'albero devono essere "
-"risolti attraverso la riga di comando."
-
-#: errors.py:29
-#, fuzzy
+"Al momento è possibile risolvere con Olive solo i conflitti sui file di "
+"testo. I conflitti di contenuto, sulla struttura dell'albero, devono essere "
+"risolti usando la riga di comando."
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Mostra"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "La directory non è un branch"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "È possibile eseguire questa azione sono all'interno di un branch."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "La directory non è un checkout"
 
-#: errors.py:30
-#, fuzzy
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
-msgstr "È possibile eseguire solamente dei commit locali su checkout."
+msgstr "È possibile eseguire i commit locali solamente sui checkout."
 
-#: errors.py:32
-#, fuzzy
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Nessun cambiamento per eseguire il commit"
 
-#: errors.py:33
-#, fuzzy
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
-msgstr "Provare force commit per eseguire il commit in ogni caso."
-
-#: errors.py:35
-#, fuzzy
+msgstr "Provare «force commit« per eseguire il commit in ogni caso."
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflitti nell'albero"
 
-#: errors.py:36
-#, fuzzy
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
-msgstr "È necessario risolvere i conflitti prima di proseguire."
+msgstr "È necessario risolvere i conflitti prima di eseguire il commit."
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
-msgstr ""
+msgstr "Commit strict non riuscito"
 
-#: errors.py:39
-#, fuzzy
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
-"Sono presenti file sconosciuti nell'albero di lavoro.\n"
-"Aggiungerli o cancellarli."
+"Nell'albero di lavoro sono presenti file sconosciuti.\n"
+"Aggiungerli o eliminarli."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
-#, fuzzy
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "File non nella versione"
 
-#: errors.py:45
-#, fuzzy
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Il file selezionato non è nella versione"
 
-#: errors.py:47 push.py:105
-#, fuzzy
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
-msgstr "I rami sono stati separati"
+msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Nessun output diff"
 
-#: errors.py:51
-#, fuzzy
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
-msgstr "Il file selezionato non è cambiato"
+msgstr ""
 
-#: errors.py:53
-#, fuzzy
+#: ../errors.py:59
 msgid "No such revision"
-msgstr "Revisione inesistente"
+msgstr ""
 
-#: errors.py:54
-#, fuzzy
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
-msgstr "La revisione specificata non esiste."
+msgstr ""
 
-#: errors.py:56
-#, fuzzy
+#: ../errors.py:62
 msgid "Target already exists"
-msgstr "Obiettivo già esistente"
+msgstr ""
 
-#: errors.py:57
-#, fuzzy
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
-msgstr "La directory obiettivo esiste già. Selezionare un altro obiettivo."
+msgstr ""
 
-#: errors.py:59
-#, fuzzy
+#: ../errors.py:65
 msgid "Directory is already a branch"
-msgstr "La directory è già un ramo"
+msgstr ""
 
-#: errors.py:60
-#, fuzzy, python-format
+#: ../errors.py:66
+#, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
-"La directory corrente (%s) è già un ramo.\n"
-"È possibile utilizzarla o inizializzarne un'altra."
 
-#: errors.py:62
-#, fuzzy
+#: ../errors.py:68
 msgid "Branch without a working tree"
-msgstr "Ramo senza un albero di lavoro"
+msgstr ""
 
-#: errors.py:63
-#, fuzzy, python-format
+#: ../errors.py:69
+#, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
-"La directory corrente (%s)\n"
-"è un ramo senza un albero di lavoro."
 
-#: errors.py:65
-#, fuzzy
+#: ../errors.py:71
 msgid "Unknown bzr error"
-msgstr "Errore bzr sconosciuto"
+msgstr ""
 
-#: errors.py:67
-#, fuzzy
+#: ../errors.py:73
 msgid "Permission denied"
-msgstr "Permesso negato"
+msgstr ""
 
-#: errors.py:67
-#, fuzzy
+#: ../errors.py:73
 msgid "permission denied."
-msgstr "permesso negato."
+msgstr ""
 
-#: errors.py:69
-#, fuzzy
+#: ../errors.py:75
 msgid "Unknown error"
-msgstr "Errore sconosciuto"
+msgstr ""
 
-#: initialize.py:47
-#, fuzzy
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
-msgstr "Iniziali_zza"
+msgstr ""
 
-#: initialize.py:48
-#, fuzzy
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
-msgstr "Quale directory inizializzare?"
+msgstr ""
 
-#: initialize.py:49
-#, fuzzy
+#: ../initialize.py:50
 msgid "Current directory"
-msgstr "Directory corrente"
+msgstr ""
 
-#: initialize.py:50
-#, fuzzy
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
-msgstr "Creare una nuova directory con il nome:"
+msgstr ""
 
-#: initialize.py:85
-#, fuzzy
+#: ../initialize.py:86
 msgid "Directory name not specified"
-msgstr "Nome directory non specificato"
+msgstr ""
 
-#: initialize.py:86
-#, fuzzy
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
-msgstr "È necessario specificare un nuovo nome per la directory."
-
-#: merge.py:66
-#, fuzzy
+msgstr ""
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Unisci"
+
+#: ../merge.py:132
 msgid "Branch not given"
-msgstr "Ramo non fornito"
+msgstr ""
 
-#: merge.py:67
-#, fuzzy
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
-msgstr "Specificare un ramo da cui eseguire il merge."
+msgstr ""
 
-#: merge.py:75
-#, fuzzy
+#: ../merge.py:141
 msgid "Bazaar command error"
-msgstr "Errore comando bazaar"
-
-#: merge.py:81
-#, fuzzy
-msgid "Merge successful"
-msgstr "Merge eseguito con successo"
-
-#: merge.py:82
-#, fuzzy
-msgid "All changes applied successfully."
-msgstr "Tutti i cambiamenti applicati con successo."
-
-#: merge.py:85
-#, fuzzy
-msgid "Conflicts encountered"
-msgstr "Incontrati dei conflitti"
-
-#: merge.py:86
-#, fuzzy
-msgid "Please resolve the conflicts manually before committing."
-msgstr "Risolvere manualmente i conflitti prima di eseguire il commit."
-
-#: push.py:52 bookmark.py:45
-#, fuzzy
+msgstr ""
+
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
-msgstr "Postazione:"
+msgstr ""
 
-#: push.py:54
-#, fuzzy
+#: ../push.py:53
 msgid "_Push"
-msgstr "_Push"
-
-#: push.py:97
-#, fuzzy
-msgid "Set default push location"
-msgstr "Imposta postazione predefinita per il push"
-
-#: push.py:98
-#, fuzzy, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
 msgstr ""
-"Non esiste alcuna postazione predefinita per il push.\n"
-"Impostare %r come quella predefinita ora?"
 
-#: push.py:106
-#, fuzzy
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
-"Impossibile eseguire il push se i rami hanno diverto.\n"
-"Sovrascrivere?"
 
-#: push.py:112
-#, fuzzy
+#: ../push.py:108
 msgid "Push successful"
-msgstr "Push eseguito con successo"
+msgstr ""
 
-#: push.py:113
-#, fuzzy, python-format
+#: ../push.py:109
+#, python-format
 msgid "%d revision(s) pushed."
-msgstr "Eseguito il push di %d revisione/i."
+msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
-msgstr ""
+msgstr "Sottocartella inesistente"
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
-
-#: revbrowser.py:45
-#, fuzzy
-msgid "Please wait, revisions are being loaded..."
-msgstr "Attendere, caricamento delle revisioni..."
-
-#: revbrowser.py:48
-#, fuzzy
+"La sottocartella (%s)\n"
+"non esiste. Crearla?"
+
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
-msgstr "S_eleziona"
-
-#: revbrowser.py:64
-#, fuzzy
-msgid "Revno"
-msgstr "Rev. n°"
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+msgstr ""
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr "Aggiunto"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr "Rimosso"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Rinominato"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificato"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Sconosciuto"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "Nessuna modifica."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
-msgstr ""
+msgstr "Tag"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
-msgstr ""
+msgstr "Nome del tag"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr "ID Revisione"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
+"Le Tag non sono supportate da questo formato della branca. Per favore "
+"aggiornare."
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
-msgstr ""
+msgstr "Modifiche non taggate nella branca."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
-msgstr ""
+msgstr "_Rimuovi tag"
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
-msgstr ""
+msgstr "<b><big>Rimuovere tag?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
-msgstr ""
+msgstr "Sei sicuro di voler rimuovere la tag: <b>%s</b>?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
-msgstr ""
+msgstr "_Aggiungi tag"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
-msgstr ""
+msgstr "Nome Tag:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID Revisione:"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
-msgstr ""
+msgstr "Nessun nome tag specificato"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
-msgstr ""
-
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr "Pull eseguito con successo"
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr "Rilevati conflitti"
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Segnalibri"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Segnalibro"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr "ignorato"
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr "Nome file"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "Stato"
-
-#: __init__.py:966
-msgid "Size"
-msgstr "Dimensione"
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr "Ultima modifica"
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Titolo:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr "Specificare un titolo per continuare."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr ""
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr ""
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr ""
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:21
-msgid "_File"
-msgstr ""
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr ""
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr ""
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr ""
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr ""
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr ""
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr ""
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Milo Casagrande https://launchpad.net/~milo\n"
-"  Stefano Karapetsas https://launchpad.net/~stefano-karapetsas"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+msgstr "Devi specificare il nome della tag desiderato."
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Non ci sono modifiche nell'albero di lavoro."
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull eseguito con successo"
+
+#~ msgid "Bookmark"
+#~ msgstr "Segnalibro"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Segnalibri"
+
+#~ msgid "ignored"
+#~ msgstr "ignorato"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Rilevati conflitti"
+
+#~ msgid "Last modified"
+#~ msgstr "Ultima modifica"
+
+#~ msgid "Status"
+#~ msgstr "Stato"
+
+#~ msgid "Filename"
+#~ msgstr "Nome file"
+
+#~ msgid "Size"
+#~ msgstr "Dimensione"
+
+#~ msgid "Title:"
+#~ msgstr "Titolo:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Specificare un titolo per continuare."
+
+#~ msgid "Modified files: "
+#~ msgstr "File modificati: "
+
+#~ msgid "Added files: "
+#~ msgstr "File aggiunti: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "File rinominati: "
+
+#~ msgid "Removed files: "
+#~ msgstr "File rimossi: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "File sconosciuti: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "File ignorati: "
+
+#~ msgid "Time"
+#~ msgstr "Orario"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Ci sono modifiche mancanti"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Branca locale aggiornata"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revisione(i) mancante(i)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Non ci sono modifiche mancanti"
+
+#~ msgid "Add"
+#~ msgstr "Aggiungi"
+
+#~ msgid "unchanged"
+#~ msgstr "non modificato"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "File Glade non trovato."
+
+#~ msgid "unknown"
+#~ msgstr "sconosciuto"
+
+#~ msgid "No title given"
+#~ msgstr "Nessun titolo fornito"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Per favore selezionare un file dalla lista,\n"
+#~ "o scegliere l'altra opzione."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Aggiungi il file selezionato"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Rinomina il file selezionato"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Rimuovi ed elimina"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Rimuovi il file/cartella selezionata ed elimina dal disco"
+
+#~ msgid "Rename"
+#~ msgstr "Rinomina"
+
+#~ msgid "Revert"
+#~ msgstr "Annulla"
+
+#~ msgid "Open"
+#~ msgstr "Apri"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Apri il file selezionato"
+
+#~ msgid "Remove"
+#~ msgstr "Rimuovi"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Rimuovi il file selezionato"
+
+#~ msgid "Annotate"
+#~ msgstr "Annota"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Annota il file selezionato"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Annulla le modifiche"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Aggiungi segnalibro della posizione locale"
+
+#~ msgid "Edit"
+#~ msgstr "Modifica"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Modifica il segnalibro selezionato"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Rimuovere il segnalibro selezionato"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostra la diff del file"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Apri cartella segnalibri in Nautilus"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostra differenze"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostra le differenze di tutti i file"
+
+#~ msgid "All..."
+#~ msgstr "Tutti..."
+
+#~ msgid "View contents"
+#~ msgstr "Mostra contenuti"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostra le differenze tra due modifiche del file"
+
+#~ msgid "Open Folder"
+#~ msgstr "Apri Cartella"
+
+#~ msgid "Selected..."
+#~ msgstr "Selezionati..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostra le differenze del file selezionato"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Segnalibro aggiunto con successo"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Posizione già salvata in un segnalibro"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Per favore specificare il nome desiderato per la nuova cartella"
+
+#~ msgid "No directory name given"
+#~ msgstr "Nessun nome cartella fornito"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Riporta il file selezionato alla modifica selezionata"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Eliminare cartella e tutte le sottocartelle?"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Ritorna a questa modifica"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Cartella già esistente"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Non la stessa branca"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Tutti i file con lo status 'aggiunto'"
+
+#~ msgid "No matching files"
+#~ msgstr "File non corrispondenti"
+
+#~ msgid "Selected only"
+#~ msgstr "Selezionato solo"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Per favore selezionare un file dalla lista per continuare."
+
+#~ msgid "_Remove"
+#~ msgstr "_Rimuovi"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Per favore specificare un altro nome per continuare."
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Quali file vuoi rimuovere?"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "La destinazione non è la stessa branca"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Rinomina..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Sposta..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Annota..."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Per favore specificare un nome per il file"
+
+#~ msgid "Filename not given"
+#~ msgstr "Nome file non fornito"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Crea _cartella..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Rimuovi file..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Aggiungi file..."
+
+#~ msgid "_File"
+#~ msgstr "_File"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Aggiorna"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Mostra file _nascosti"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inizializza..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Unisci..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Annulla tutte le modifiche"
+
+#~ msgid "_Differences..."
+#~ msgstr "_Differenze..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Modifiche _mancanti"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_g..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flitti"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistiche"
+
+#~ msgid "_Help"
+#~ msgstr "_Aiuto"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informazioni..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Modalità S_toria"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Quali file vuoi aggiungere?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Aggiungi file"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Rimuovi file"
+
+#~ msgid "_Add"
+#~ msgstr "_Aggiungi"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Crea cartella"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Sposta"
+
+#~ msgid "Move to"
+#~ msgstr "Sposta in"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Crea cartella"
+
+#~ msgid "Rename to"
+#~ msgstr "Rinomina in"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Rinomina"
+
+#~ msgid "_Move"
+#~ msgstr "_Sposta"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selezionare una cartella"
+
+#~ msgid "_Rename"
+#~ msgstr "_Rinomina"
+
+#~ msgid "(none)"
+#~ msgstr "(nessuno)"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Posizione:</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Informazioni"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Pubblica su branca: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formato:</b>"
+
+#~ msgid "Unchanged files: "
+#~ msgstr "File invariati: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Modifiche mancanti:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Ora dell'ultima modifica: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Ora della prima modifica: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Modifiche mancanti nella branca: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Modifiche nella branca: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Unione - Olive"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Storia della branca:</b>"
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Età della branca in giorni: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Numero di commiter: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Dimensione del repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Modifiche nel repository: "
+
+#~ msgid "Merge from:"
+#~ msgstr "Unisci da:"
+
+#~ msgid "Revert successful"
+#~ msgstr "Annullato con successo"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Tutti i file riportati all'ultima modifica"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Impossibile trovare il file di descrizione interfaccia utente"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "File per cui eseguire il commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Messaggio del commit"
+
+#~ msgid "Pending merges"
+#~ msgstr "Merge in sospeso"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Luca Ferretti https://launchpad.net/~elle.uca\n"
+#~ "  Luca Livraghi https://launchpad.net/~luca91\n"
+#~ "  Milo Casagrande https://launchpad.net/~milo\n"
+#~ "  Stefano Karapetsas https://launchpad.net/~stefano-karapetsas\n"
+#~ "  Vale https://launchpad.net/~valetzara"

=== added file 'po/ja.po'
--- po/ja.po	1970-01-01 00:00:00 +0000
+++ po/ja.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,1021 @@
+# Japanese translation for bzr-gtk
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-04-20 14:46+0000\n"
+"Last-Translator: Fumihito YOSHIDA <hito@kugutsu.org>\n"
+"Language-Team: Japanese <ja@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr "ブランチ(_B)"
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr "ブランチの場所:"
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr ""
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr "リビジョン:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "フォルダを選択してください"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr "ブランチの場所が欠けています"
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr "ブランチの場所を入力しなければなりません。"
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr "ブランチを切るのが成功しました"
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr "%d 個のリビジョンをブランチしました。"
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr ""
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr "チェックアウト(_O)"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr "軽量チェックアウト(_L)"
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr "ディレクトリにワーキングツリーがありません"
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "操作は中止されました。"
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "マージする前に変更をコミットするかリバートしてください。"
+
+#: ../commit.py:182
+msgid "added"
+msgstr "追加された"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "削除された"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "名前が変更"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "名称変更/修正"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "変更"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "ローカルにのみコミットする (_O)"
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "コミット(_I)"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "コミット"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "パス"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr ""
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "日付"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr "コミッター"
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "概要"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "空のメッセージでコミットしますか?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr "未知のファイルがワーキングツリーに存在します。とにかくコミットしますか?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "変更無しでコミットしますか?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr "外部ユーティリティ:"
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "競合"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr "ワーキングツリー内で競合は起きませんでした。"
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr "パスの競合"
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr "内容の競合"
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr "テキストの競合"
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr "重複ID"
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr "重複"
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr ""
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr "ファイルが選択されていません"
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr "リストからファイルを選択してください"
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr "外部ユーティリティの呼び出しに失敗しました"
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr "コンフリクトを解決することができません"
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "表示(_V)"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "マージに成功しました"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "すべての変更の適用に成功しました"
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "衝突が起きました"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "コミットする前に手動で競合を解決してください"
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "ディレクトリがブランチではありません。"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "このアクションはブランチ内でしかできません。"
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr "このディレクトリはチェックアウトされたものではありません"
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr "チェックアウトされたものに対してのみローカルコミットを行うことができます。"
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr "コミットすべき変更がありません"
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr "とにかくコミットをしたいなら、強制的なコミットを行ってください"
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr "ツリー内に競合があります"
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr "コミットを行う前に競合を解決する必要があります"
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+"ワーキングツリー内に未知のファイルがあります。\n"
+"これらを add するか delete してください。"
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr "%s"
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr "ファイルはバージョン管理下に置かれていません"
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr "選択されたファイルはバージョン管理下に置かれていません。"
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr "ブランチは分岐されました"
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+"ブランチが分岐した場合にはプッシュすることはできません。\n"
+"それでもプッシュしたい場合にはオーバライトオプションを使用してください。"
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr "差分の出力はありません"
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr "選択されたファイルに変更はありません。"
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr "そのようなリビジョンはありません。"
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr "指定されたリビジョンは存在しません。"
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr "ターゲットはすでに存在しています"
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+"ターゲットのディレクトリはすでに存在しています。\r\n"
+"他のターゲットを選択してください。"
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr "そのディレクトリはすでにブランチです。"
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr "ワーキングツリーのないブランチ"
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr "現在のディレクトリ (%s) はワーキングツリーのないブランチです。"
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr "未知の bzr エラーです"
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr "権限がありません"
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr "権限がありません。"
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr "未知のエラー"
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr "初期化する(_I)"
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr "どのディレクトリを初期化しますか？"
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr "現在のディレクトリ"
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr "以下の名前で新しいディレクトリを作成する:"
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr "ディレクトリ名が指定されていません"
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr "新しいディレクトリ名を指定してください"
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "マージ(_M)"
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr "ブランチが与えられていません"
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr "マージ元のブランチを指定してください。"
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr "Bazaar コマンドのエラー"
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr "場所:"
+
+#: ../push.py:53
+msgid "_Push"
+msgstr "プッシュ (_)"
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+"ブランチが分岐した場合にはプッシュすることができません。\n"
+"上書きしますか？"
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr "プッシュに成功しました"
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr "%d リビジョンプッシュしました。"
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr "選択する(_S)"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr "追加"
+
+#: ../status.py:100
+msgid "Removed"
+msgstr "削除"
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr "名称変更"
+
+#: ../status.py:113
+msgid "Modified"
+msgstr "変更"
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr "不明"
+
+#: ../status.py:126
+msgid "No changes."
+msgstr "変更なし"
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr "タグ"
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr ""
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr "リビジョン ID"
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr "このブランチフォーマットではタグはサポートされていません。アップグレードしてください。"
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr "ブランチ内にタグ付けされたリビジョンはありません。"
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr "タグを外す (_R)"
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr "<b><big>タグを外しますか？</big></b>"
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr "タグを外してもよろしいですか: <b>%s</b>?"
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr "タグ追加 (_A)"
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr "タグ名:"
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr "リビジョン ID:"
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr "タグ名が指定されていません"
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "Commit message:"
+#~ msgstr "コミットメッセージ:"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "ワーキングツリー内に変更がありません。"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>ブランチの履歴:</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "レポジトリのサイズ: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "レポジトリ内のリビジョン: "
+
+#~ msgid "Merge from:"
+#~ msgstr "以下よりマージ:"
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "ブランチ内のリビジョン: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "変更されなかったファイル: "
+
+#~ msgid "Modified files: "
+#~ msgstr "変更されたファイル: "
+
+#~ msgid "Added files: "
+#~ msgstr "追加されたファイル: "
+
+#~ msgid "Removed files: "
+#~ msgstr "削除されたファイル: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>ワーキングツリー内:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "最後のリビジョンの時刻: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "最初のリビジョンの時刻: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "コミッターの数: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "改名されたファイル: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "未知のファイル: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "無視されたファイル: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "バージョン管理されているサブディレクトリ: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>欠けているリビジョン:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>ロックの状態:</b>"
+
+#~ msgid "Branch lock status: "
+#~ msgstr "ブランチのロックの状態: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "ワーキングツリーに欠けているリビジョン: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "ワーキングツリーのロックの状態: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "ブランチに欠けているリビジョン: "
+
+#~ msgid "Publish to branch: "
+#~ msgstr "公表するブランチ: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "親ブランチ: "
+
+#~ msgid "Control format: "
+#~ msgstr "操作形式: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "ワーキングツリーの形式: "
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>場所:</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>形式:</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>関係のあるブランチ:</b>"
+
+#~ msgid "Repository format: "
+#~ msgstr "レポジトリの形式: "
+
+#~ msgid "Branch format: "
+#~ msgstr "ブランチの形式: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "レポジトリのロックの状態: "
+
+#~ msgid "(none)"
+#~ msgstr "(なし)"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - 情報"
+
+#~ msgid "_Rename"
+#~ msgstr "名前の変更(_R)"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - ディレクトリの作成"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "バージョン管理されたディレクトリ(_V)"
+
+#~ msgid "_Make directory"
+#~ msgstr "ディレクトリの作成(_M)"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - 名前の変更"
+
+#~ msgid "_Move"
+#~ msgstr "移動(_M)"
+
+#~ msgid "Select a directory"
+#~ msgstr "ディレクトリの選択"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - 移動"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - ファイルの削除"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "履歴モード(_I)"
+
+#~ msgid "_Help"
+#~ msgstr "ヘルプ(_H)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "どのファイルを追加しますか?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - ファイルの追加"
+
+#~ msgid "_Add"
+#~ msgstr "追加(_A)"
+
+#~ msgid "_Differences..."
+#~ msgstr "差分(_D)..."
+
+#~ msgid "_Merge..."
+#~ msgstr "マージ(_M)..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "欠けているリビジョン(_R)"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "タグ(_G)..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "競合(_F)..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "ステータス(_T)..."
+
+#~ msgid "_Commit..."
+#~ msgstr "コミット(_C)..."
+
+#~ msgid "_Log..."
+#~ msgstr "ログ(_L)..."
+
+#~ msgid "_Statistics"
+#~ msgstr "統計データ(_S)"
+
+#~ msgid "_Information..."
+#~ msgstr "情報(_I)..."
+
+#~ msgid "_Refresh"
+#~ msgstr "更新(_R)"
+
+#~ msgid "_Get..."
+#~ msgstr "取得(_G)..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "隠しファイルを表示(_H)"
+
+#~ msgid "_Initialize..."
+#~ msgstr "初期化(_I)..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "注釈(_A)..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "全ての変更をリバート(_R)"
+
+#~ msgid "C_heckout..."
+#~ msgstr "チェックアウト(_H)..."
+
+#~ msgid "_Rename..."
+#~ msgstr "名前の変更(_R)..."
+
+#~ msgid "_Move..."
+#~ msgstr "移動(_M)..."
+
+#~ msgid "_Remove"
+#~ msgstr "削除(_R)"
+
+#~ msgid "Make _directory..."
+#~ msgstr "ディレクトリの作成(_D)..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "ファイルの削除..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "ファイルの追加(_A)..."
+
+#~ msgid "_File"
+#~ msgstr "ファイル(_F)"
+
+#~ msgid "Not the same branch"
+#~ msgstr "同じブランチではありません"
+
+#~ msgid "Directory already exists"
+#~ msgstr "ディレクトリは既に存在します"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "ブックマークフォルダをNautilusで開く"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "内蔵ビューアでファイルの内容を表示します"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "全てのファイルの差分を表示します"
+
+#~ msgid "All..."
+#~ msgstr "全て..."
+
+#~ msgid "View contents"
+#~ msgstr "内容を表示"
+
+#~ msgid "Open Folder"
+#~ msgstr "フォルダを開く"
+
+#~ msgid "Show differences"
+#~ msgstr "差分を表示"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "選択されているファイルの差分を表示します"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "選択されているブックマークを削除"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "このリビジョンへリバート"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "ブックマークに追加しました"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "現在のディレクトリは既にブックマークされています。\n"
+#~ "参照のために左のパネルを見てください。"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "場所は既にブックマークされています"
+
+#~ msgid "No directory name given"
+#~ msgstr "ディレクトリの名前が与えられていません"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "選択中のファイルを選択中のリビジョンへリバートします"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "ファイルの二つのリビジョン間の差分を表示します"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Fumihito YOSHIDA https://launchpad.net/~hito\n"
+#~ "  Nazo https://launchpad.net/~lovesyao\n"
+#~ "  epii https://launchpad.net/~epii"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "コミットするファイル"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "デフォルトのプッシュ先が設定されていません。\n"
+#~ "%r をデフォルトに設定しますか？"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "リビジョンが読み込まれるまでしばらくお待ちください..."
+
+#~ msgid "Time"
+#~ msgstr "時刻"
+
+#~ msgid "Revno"
+#~ msgstr "リビジョン番号"
+
+#~ msgid "Pending merges"
+#~ msgstr "マージ待ち"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "競合があります"

=== modified file 'po/ku.po'
--- po/ku.po	2008-03-11 17:01:27 +0000
+++ po/ku.po	2011-03-08 04:41:48 +0000
@@ -7,1284 +7,744 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2007-05-03 22:33+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 09:34+0000\n"
 "Last-Translator: arasname <Unknown>\n"
 "Language-Team: Kurdish <ku@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Shax"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr ""
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr ""
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr ""
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr ""
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr ""
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr ""
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr ""
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Nîşandan"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr ""
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr ""
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr ""
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Ferq"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr ""
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr ""
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Pel"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Pelekê Zêdeke(s).."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Pelê rake"
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Dosiye_chêke"
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Nav biguherîne..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr "_Nîşandan"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "PlênÊ ve shartî nîshan bide"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Nû bike"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Ka"
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr "Bikshê"
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr "Dehfde"
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr "qebul"
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "Rewsh"
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Statistîk"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Ferq"
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Alîkarî"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  arasname https://launchpad.net/~arasname"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "_Rename..."
+#~ msgstr "_Nav biguherîne..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Dosiye_chêke"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Pelê rake"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Pelekê Zêdeke(s).."
+
+#~ msgid "_File"
+#~ msgstr "_Pel"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Nû bike"
+
+#~ msgid "_Get..."
+#~ msgstr "_Ka"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "PlênÊ ve shartî nîshan bide"
+
+#~ msgid "Pu_ll"
+#~ msgstr "Bikshê"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Rewsh"
+
+#~ msgid "_Commit..."
+#~ msgstr "qebul"
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Dehfde"
+
+#~ msgid "_Differences..."
+#~ msgstr "_Ferq"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistîk"
+
+#~ msgid "_Help"
+#~ msgstr "_Alîkarî"
+
+#~ msgid "Diff"
+#~ msgstr "Ferq"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  arasname https://launchpad.net/~arasname"

=== added file 'po/nl.po'
--- po/nl.po	1970-01-01 00:00:00 +0000
+++ po/nl.po	2011-03-10 04:41:02 +0000
@@ -0,0 +1,1105 @@
+# Dutch translation for bzr-gtk
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-09 09:42+0000\n"
+"Last-Translator: Rachid <Unknown>\n"
+"Language-Team: Dutch <nl@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-10 04:40+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr "Bazaar voorkeuren"
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr "Bazaar"
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr "_Tak"
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr "Locatie aftakking"
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "Bestemming:"
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr "Alias aftakking"
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr "Revisie:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Selecteer een map alstublieft"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr "Locatie aftakking niet teruggevonden."
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr "U moet een locatie voor uw aftakking opgeven."
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr "Successvol afgetakt."
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr "%d revisie(s) afgetakt."
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr "N/B"
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr "Ophalen"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr "Folder bevat geen werkkopie!"
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "Bewerking afgebroken."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Er zijn locale wijzigingen in deze branch"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+"Gelieve uw wijzigingen vast te leggen of ongedaan te maken vooralleer samen "
+"te voegen."
+
+#: ../commit.py:182
+msgid "added"
+msgstr "toegevoegd"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "verwijderd"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "hernoemd"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "hernoemd en gewijzigd"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "gewijzigd"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "Enkel lokaal comitten"
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "Vastleggen"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Committen"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Pad"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Type"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "Datum"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr "Committer"
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "Samenvatting"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Vastleggen zonder boodschap?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "In dit bericht kan je de reden voor je commit beschrijven."
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "Vastleggen met onbekende bestanden?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+"Er bestaan onbekende bestanden in uw werkkopie. Bent U zeker dat U dit wenst "
+"vast te leggen?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "Vastleggen zonder wijzigingen?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr "Extern hulpmiddel:"
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "Conflicten"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr "Geen conflicten in de werkkopie."
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr "pad conflict"
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr "Conflicterende inhoud"
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr "Conflicterende text"
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr "dubbel id"
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr "duplicaat"
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr "ontbrekende ouder"
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr "verwijderen van de ouder"
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr "onbekend soort conflict"
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr "Geen bestand geselecteerd"
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr "Gelieve een bestand uit de lijst te selecteren."
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr ""
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr "Can conflict niet oplossen"
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+"Enkel conflicten met textbestanden kunnen, op dit moment, met Olive opgelost "
+"worden. Inhoudelijke conflicten, op de structuur, dienen via de commandolijn "
+"opgelost te worden."
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Beeld"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Succesvol samengevoegd"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Alle wijzigingen succesvol toegepast."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Conflict gedetecteerd"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+"Gelieve de conflicten manueel op te lossen vooralleer uw wijzigingen vast te "
+"leggen,"
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Folder is geen aftakking."
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "U kunt deze actie enkel op een aftakking uitvoeren."
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr "Folder werd niet uit versiecontrole opgehaald!"
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+"Lokaal vastleggen is enkel mogelijk via een werkkopie verkregen door het "
+"ophalen uit versiecontrole."
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr "Geen wijzigingen vast te leggen."
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+"Probeer prioritair vastleggen indien U uw wijzigingen toch wenst vast te "
+"leggen."
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr "Er werden conflicten in de versieboom gedetecteerd."
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr "De conflicten moeten opgelost worden voordat u kan comiten."
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr "Strikt vastleggen faalde."
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+"Er bestaan ongekende bestanden in uw werkkopie!\n"
+"Gelieve deze toe te voegen of te verwijderen."
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr "Gebonden aftakking is niet meer actueel."
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr "%s"
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr "Bestand niet onder versiecontrole"
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr "Het geselecteerde bestand staat niet onder versiebeheer."
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr "Aftakkingen werden afgeleid."
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+"U kunt geen \"push\" uitvoeren op vertakkingen die afgeleid werden. Gebruik "
+"de optie overschrijven (overwrite) indien U de \"push\" toch wenst uit te "
+"voeren."
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr "Geen verschil gevonden (diff)"
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr "Het geselecteerde bestand is ongewijzigd."
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr "Revisie onbestaande"
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr "De opgegeven revisie bestaat niet ."
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr "Het doel bestaat reeds"
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr "Doel directory bestaad reeds. Kies een ander doel."
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr "Folder is al een vertakking."
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+"De huidige folder (%s) is reeds een vertakking. U kunt deze in gebruik nemen "
+"of een andere folder instellen."
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr "Vertakking zonder werkkopie."
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr "De huidige folder (%s) is een vertakking zonder werkkopie."
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr "Onbekende bzr fout"
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr "Toegang geweigerd"
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr "toegang geweigerd"
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr "Onbekende fout"
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr "_Initializeren"
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr "Welke directory wilt u initializeren?"
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr "Huidige directory"
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr "Maak een nieuwe directory aan, genaamd:"
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr "Geen directory naam gespecificeerd"
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr "Een directory naam moet opgegeven worden."
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Samenvoegen"
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr "Vertakking niet opgegeven"
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr "Gelieve een vertakking op te geven om van samen te voegen."
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr "Fout in bazaar commando"
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr "Locatie:"
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+"De bovenliggende directory (%s) bestaat niet. Moet deze nu aangemaakt worden?"
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr "_Selecteren"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr "Toegevoegd"
+
+#: ../status.py:100
+msgid "Removed"
+msgstr "Verwijderd"
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr "Hernoemd"
+
+#: ../status.py:113
+msgid "Modified"
+msgstr "Gewijzigd"
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr "Onbekend"
+
+#: ../status.py:126
+msgid "No changes."
+msgstr "Geen wijzigingen."
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr "Tags"
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr "Tag-naam"
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr "Revisienr."
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+"Labels worden niet ondersteund door dit aftakkingsformaat. Gelieve uw versie "
+"te actualizeren."
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr "Er zijn geen gelabelde versies op de aftakking;"
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr "Tag _verwijderen"
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr "<b><big>Verwijder tag?</big></b>"
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr "Weet u zeker dat u de tag <b>%s</b> wilt verwijderen?"
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr "T_ag toevoegen"
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr "Tag-naam:"
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr "Revisienr. :"
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr "Geen tag-naam opgegeven"
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr "U moet de gewenste labelnaam opgeven."
+
+#~ msgid "Time"
+#~ msgstr "Tijd"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Er zijn ontbrekende revisies."
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d ontbrekende revisie(s)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Er zijn geen ontbrekende revisies."
+
+#~ msgid "unchanged"
+#~ msgstr "ongewijzigd"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Bladwijzers"
+
+#~ msgid "ignored"
+#~ msgstr "genegeerd"
+
+#~ msgid "unknown"
+#~ msgstr "onbekend"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflicten gedetecteerd"
+
+#~ msgid "No title given"
+#~ msgstr "Geen titel opgegeven"
+
+#~ msgid "Last modified"
+#~ msgstr "Laatst gewijzigd"
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Bestandsnaam"
+
+#~ msgid "Size"
+#~ msgstr "Grootte"
+
+#~ msgid "Title:"
+#~ msgstr "Titel:"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Selecteer een bestand uit de,\n"
+#~ "of kies een andere optie."
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Geef een titel op om verder te gaan"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Het geselecteerde bestand hernoemen"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Het geselecteerde bestand openen"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Het geselecteerde bestand toevoegen"
+
+#~ msgid "Add"
+#~ msgstr "Toevoegen"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Volledig verwijderen"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Het geselecteerde bestand/map volledig verwijderen"
+
+#~ msgid "Rename"
+#~ msgstr "Hernoemen"
+
+#~ msgid "Open"
+#~ msgstr "Openen"
+
+#~ msgid "Remove"
+#~ msgstr "Verwijderen"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Het geselecteerde bestand verwijderen"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Edit"
+#~ msgstr "Bewerken"
+
+#~ msgid "Open Folder"
+#~ msgstr "Map openen"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Te committen bestanden"
+
+#~ msgid "Commit message:"
+#~ msgstr "Commit bericht:"
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Een moment geduld alstublieft, de wijzigingen worden geladen..."
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Het geselecteerde bestand annoteren"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Directory verwijderen, inclusief alle kind-directory's?"
+
+#~ msgid "No directory name given"
+#~ msgstr "Geen directory-naam opgegeven."
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Geef een andere naam op, om verder te gaan."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Geef een nieuwe voor het bestand op."
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Alle bestanden met de status 'toegevoegd'"
+
+#~ msgid "Selected only"
+#~ msgstr "Geselecteerde"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Welke bestanden wilt u verwijderen?"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Verversen"
+
+#~ msgid "_Rename..."
+#~ msgstr "He_rnoemen..."
+
+#~ msgid "_Move..."
+#~ msgstr "Verplaatsen..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "_Verborgen bestanden weergeven"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Directory aanmaken..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Bestanden verwijderen..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "Bestanden toevoegen..."
+
+#~ msgid "_File"
+#~ msgstr "_Bestand"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initializeren..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Maak alle wijzigingen ongedaan"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Committen..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Conflicten..."
+
+#~ msgid "_Differences..."
+#~ msgstr "Verschillen..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistieken"
+
+#~ msgid "_Help"
+#~ msgstr "_Help"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informatie..."
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Welke bestanden wilt u toevoegen?"
+
+#~ msgid "_Add"
+#~ msgstr "_Toevoegen"
+
+#~ msgid "(none)"
+#~ msgstr "(geen)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Hernoemen"
+
+#~ msgid "Rename to"
+#~ msgstr "Hernoemen naar"
+
+#~ msgid "_Move"
+#~ msgstr "_Verplaatsen"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selecteer een directory"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Locatie:</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formaat:</b>"
+
+#~ msgid "Renamed files: "
+#~ msgstr "Hernoemde bestanden: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Onbekende bestanden: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Genegeerde bestanden: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Gewijzigde bestanden: "
+
+#~ msgid "Added files: "
+#~ msgstr "Toegevoegde bestanden: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Verwijderde bestanden: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Ongewijzigde bestanden: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Aantal revisies in branch: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Branch geschiedenis:</b>"
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Leeftijd van de branch, in dagen: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Aantal committers: "
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Er werden geen wijzigingen gevonden in de werkkopie."
+
+#~ msgid "Pending merges"
+#~ msgstr "Geplande samenvoegingen"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Gelieve de werkkopie te inspecteren vooralleer verder te gaan."
+
+#~ msgid "Revert"
+#~ msgstr "Ongedaan maken"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade bestand kon niet gevonden worden."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Bestand met UI bescrhijving kon niet gevonden worden."
+
+#~ msgid "Revert the changes"
+#~ msgstr "Wijzigingen ongedaan maken"
+
+#~ msgid "Annotate"
+#~ msgstr "Annoteer"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Wijzigingen vastleggen"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Toon het verschil op dit bestand."
+
+#~ msgid "Revert successful"
+#~ msgstr "Wijzigingen succesvol ongedaan gemaakt."
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Deze revisie van het geselecteerde bestand terugzetten"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Deze revisie terugzetten"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Alle bestanden werden teruggezet met hun laaste revisie."
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "ouder locatie is niet bekend"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Markeer de huideige locatie"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Open de map met markeringen in Nautilus"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Toon de verschillen van alle bestanden"
+
+#~ msgid "All..."
+#~ msgstr "Alle..."
+
+#~ msgid "View contents"
+#~ msgstr "Bekijk inhoud"
+
+#~ msgid "Show differences"
+#~ msgstr "Toon verschillen"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Toon de verschillen van de gesecteerde bestanden."
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Bewerk de geselecteerde markering"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Verwijder de geselecteerde markering"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Markering succesvol toegevoegd"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Locatie is reeds gemarkeerd"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Geef de gewenste naam op voor de nieuwe map."
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Toon de verschillen tussen twee revisies van het bestand"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Niet de zelfde aftakking"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Selecteer een bestand uit de lijst, om verder te gaan."
+
+#~ msgid "Directory already exists"
+#~ msgstr "Map bestaat al"
+
+#~ msgid "Filename not given"
+#~ msgstr "Geen bestandsnaam opgegeven"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Geen toegevoegde bestanden gevonden in de werkboom"
+
+#~ msgid "_Remove"
+#~ msgstr "_Verwijderen"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "_Geschiedenis Modus"
+
+#~ msgid "_Merge..."
+#~ msgstr "_Samenvoegen..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Ontbrekende _revisies"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "_Markeringen..."
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Ontbrekende revisies:</b>"
+
+#~ msgid "Merge from:"
+#~ msgstr "Samenvoegen vanuit:"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Samenvoegen - Olive"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>In de werkboom:</b>"
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Tijd van de eerste revisie: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Grootte van de repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisies in repository: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Lieven van der Heide https://launchpad.net/~lievenvanderheide\n"
+#~ "  Rachid https://launchpad.net/~rachidbm\n"
+#~ "  Roel Huybrechts https://launchpad.net/~rulus\n"
+#~ "  Wim Rosseel https://launchpad.net/~wim-rosseel"

=== removed file 'po/olive-gtk.pot'
--- po/olive-gtk.pot	2008-05-05 18:16:46 +0000
+++ po/olive-gtk.pot	1970-01-01 00:00:00 +0000
@@ -1,1463 +0,0 @@
-# SOME DESCRIPTIVE TITLE.
-# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
-# This file is distributed under the same license as the PACKAGE package.
-# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
-#
-#, fuzzy
-msgid ""
-msgstr ""
-"Project-Id-Version: PACKAGE VERSION\n"
-"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-05-05 20:10+0200\n"
-"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
-"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
-"Language-Team: LANGUAGE <LL@li.org>\n"
-"MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=CHARSET\n"
-"Content-Transfer-Encoding: 8bit\n"
-
-#: branch.py:52 olive.glade:151 olive.glade:167
-msgid "_Branch"
-msgstr ""
-
-#: branch.py:55 checkout.py:53 branch.py:60 checkout.py:54
-msgid "Please select a folder"
-msgstr ""
-
-#: branch.py:57 checkout.py:55 branch.py:55 checkout.py:56
-msgid "Branch location:"
-msgstr ""
-
-#: branch.py:58 checkout.py:56 branch.py:57 checkout.py:57
-msgid "Destination:"
-msgstr ""
-
-#: branch.py:59 checkout.py:57 branch.py:58 checkout.py:58
-msgid "Branck nick:"
-msgstr ""
-
-#: branch.py:60 checkout.py:58 branch.py:59 checkout.py:59
-msgid "Revision:"
-msgstr ""
-
-#: branch.py:162 checkout.py:163 branch.py:140 checkout.py:164
-msgid "Missing branch location"
-msgstr ""
-
-#: branch.py:163 checkout.py:164 branch.py:141 checkout.py:165
-msgid "You must specify a branch location."
-msgstr ""
-
-#: branch.py:205 branch.py:182
-msgid "Branching successful"
-msgstr ""
-
-#: branch.py:206 branch.py:183
-#, python-format
-msgid "%d revision(s) branched."
-msgstr ""
-
-#: branch.py:214 checkout.py:195 branch.py:191 checkout.py:196
-msgid "N/A"
-msgstr ""
-
-#: checkout.py:50 checkout.py:51
-msgid "Check_out"
-msgstr ""
-
-#: checkout.py:62 checkout.py:63
-msgid "_Lightweight checkout"
-msgstr ""
-
-#: commit.py:68 __init__.py:362
-msgid "Directory does not have a working tree"
-msgstr ""
-
-#: commit.py:69 __init__.py:363
-msgid "Operation aborted."
-msgstr ""
-
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556 olive/add.py:76
-#: olive/add.py:86 olive/info.py:556 errors.py:28 olive/add.py:77
-#: olive/add.py:87 olive/info.py:557
-msgid "Directory is not a branch"
-msgstr ""
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557 olive/add.py:77
-#: olive/add.py:87 olive/info.py:557 errors.py:29 olive/add.py:78
-#: olive/add.py:88 olive/info.py:558
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: commit.py:88 commit.py:337 commit.py:338
-msgid "Comm_it"
-msgstr ""
-
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147 commit.py:310 commit.py:311
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215 commit.py:650 commit.py:652
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216 commit.py:651 commit.py:653
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228 commit.py:670 commit.py:672
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229 commit.py:671 commit.py:673
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240 commit.py:689 commit.py:691
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87 commit.py:415 olive/menu.py:86 commit.py:416
-#: olive/menu.py:87
-msgid "Commit"
-msgstr ""
-
-#: commit.py:325 conflicts.py:108 commit.py:419 conflicts.py:109 commit.py:420
-#: conflicts.py:110
-msgid "Path"
-msgstr ""
-
-#: commit.py:327 conflicts.py:110 commit.py:421 conflicts.py:111 commit.py:422
-#: conflicts.py:112
-msgid "Type"
-msgstr ""
-
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-#: commit.py:167 olive/__init__.py:1053 olive/__init__.py:1358 commit.py:168
-#: olive/__init__.py:1054 olive/__init__.py:1359
-msgid "added"
-msgstr ""
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-#: commit.py:168 olive/__init__.py:1051 olive/__init__.py:1356 commit.py:169
-#: olive/__init__.py:1052 olive/__init__.py:1357
-msgid "removed"
-msgstr ""
-
-#: commit.py:353 commit.py:170 commit.py:171
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223 commit.py:169
-#: olive/__init__.py:1049 olive/__init__.py:1354 commit.py:170
-#: olive/__init__.py:1050 olive/__init__.py:1355
-msgid "renamed"
-msgstr ""
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-#: commit.py:171 olive/__init__.py:1055 olive/__init__.py:1360 commit.py:172
-#: olive/__init__.py:1056 olive/__init__.py:1361
-msgid "modified"
-msgstr ""
-
-#: commit.py:395 commit.py:480 commit.py:481
-msgid "Date"
-msgstr ""
-
-#: commit.py:397 revbrowser.py:68 commit.py:482 commit.py:483
-msgid "Committer"
-msgstr ""
-
-#: commit.py:399 revbrowser.py:66 commit.py:484 commit.py:485
-msgid "Summary"
-msgstr ""
-
-#: conflicts.py:48 conflicts.py:49
-msgid "External utility:"
-msgstr ""
-
-#: conflicts.py:99 conflicts.py:100
-msgid "Conflicts"
-msgstr ""
-
-#: conflicts.py:102 conflicts.py:103
-msgid "No conflicts in working tree."
-msgstr ""
-
-#: conflicts.py:115 conflicts.py:116 conflicts.py:117
-msgid "path conflict"
-msgstr ""
-
-#: conflicts.py:117 conflicts.py:118 conflicts.py:119
-msgid "contents conflict"
-msgstr ""
-
-#: conflicts.py:119 conflicts.py:120 conflicts.py:121
-msgid "text conflict"
-msgstr ""
-
-#: conflicts.py:121 conflicts.py:122 conflicts.py:123
-msgid "duplicate id"
-msgstr ""
-
-#: conflicts.py:123 conflicts.py:124 conflicts.py:125
-msgid "duplicate"
-msgstr ""
-
-#: conflicts.py:125 conflicts.py:126 conflicts.py:127
-msgid "parent loop"
-msgstr ""
-
-#: conflicts.py:127 conflicts.py:128 conflicts.py:129
-msgid "unversioned parent"
-msgstr ""
-
-#: conflicts.py:129 conflicts.py:130 conflicts.py:131
-msgid "missing parent"
-msgstr ""
-
-#: conflicts.py:131 conflicts.py:132 conflicts.py:133
-msgid "deleting parent"
-msgstr ""
-
-#: conflicts.py:133 conflicts.py:134 conflicts.py:135
-msgid "unknown type of conflict"
-msgstr ""
-
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
-#: conflicts.py:163 olive/__init__.py:687 olive/add.py:67 olive/menu.py:177
-#: olive/menu.py:190 olive/menu.py:217 olive/menu.py:253 olive/move.py:79
-#: olive/remove.py:67 olive/remove.py:129 olive/rename.py:70 conflicts.py:164
-#: olive/__init__.py:688 olive/add.py:68 olive/menu.py:178 olive/menu.py:191
-#: olive/menu.py:218 olive/menu.py:254 olive/move.py:80 olive/remove.py:68
-#: olive/remove.py:130 olive/rename.py:71
-msgid "No file was selected"
-msgstr ""
-
-#: conflicts.py:163 __init__.py:615 menu.py:192 conflicts.py:164
-#: olive/__init__.py:688 olive/menu.py:191 conflicts.py:165
-#: olive/__init__.py:689 olive/menu.py:192
-msgid "Please select a file from the list."
-msgstr ""
-
-#: conflicts.py:173 conflicts.py:174 conflicts.py:175
-msgid "Call to external utility failed"
-msgstr ""
-
-#: conflicts.py:175 conflicts.py:176 conflicts.py:177
-msgid "Cannot resolve conflict"
-msgstr ""
-
-#: conflicts.py:176 conflicts.py:177 conflicts.py:178
-msgid ""
-"Only conflicts on the text of files can be resolved with Olive at the "
-"moment. Content conflicts, on the structure of the tree, need to be resolved "
-"using the command line."
-msgstr ""
-
-#: errors.py:29 errors.py:31
-msgid "Directory is not a checkout"
-msgstr ""
-
-#: errors.py:30 errors.py:32
-msgid "You can perform local commit only on checkouts."
-msgstr ""
-
-#: errors.py:32 errors.py:34
-msgid "No changes to commit"
-msgstr ""
-
-#: errors.py:33 errors.py:35
-msgid "Try force commit if you want to commit anyway."
-msgstr ""
-
-#: errors.py:35 errors.py:37
-msgid "Conflicts in tree"
-msgstr ""
-
-#: errors.py:36 errors.py:38
-msgid "You need to resolve the conflicts before committing."
-msgstr ""
-
-#: errors.py:38 errors.py:40
-msgid "Strict commit failed"
-msgstr ""
-
-#: errors.py:39 errors.py:41
-msgid ""
-"There are unknown files in the working tree.\n"
-"Please add or delete them."
-msgstr ""
-
-#: errors.py:41 errors.py:43
-msgid "Bound branch is out of date"
-msgstr ""
-
-#: errors.py:42 errors.py:45
-#, python-format
-msgid "%s"
-msgstr ""
-
-#: errors.py:44 errors.py:47
-msgid "File not versioned"
-msgstr ""
-
-#: errors.py:45 errors.py:48
-msgid "The selected file is not versioned."
-msgstr ""
-
-#: errors.py:47 push.py:105 errors.py:50 push.py:106
-msgid "Branches have been diverged"
-msgstr ""
-
-#: errors.py:48 errors.py:51
-msgid ""
-"You cannot push if branches have diverged. Use the\n"
-"overwrite option if you want to push anyway."
-msgstr ""
-
-#: errors.py:50 errors.py:53
-msgid "No diff output"
-msgstr ""
-
-#: errors.py:51 errors.py:54
-msgid "The selected file hasn't changed."
-msgstr ""
-
-#: errors.py:53 errors.py:56
-msgid "No such revision"
-msgstr ""
-
-#: errors.py:54 errors.py:57
-msgid "The revision you specified doesn't exist."
-msgstr ""
-
-#: errors.py:56 errors.py:59
-msgid "Target already exists"
-msgstr ""
-
-#: errors.py:57 errors.py:60
-msgid "Target directory already exists. Please select another target."
-msgstr ""
-
-#: errors.py:59 errors.py:62
-msgid "Directory is already a branch"
-msgstr ""
-
-#: errors.py:60 errors.py:63
-#, python-format
-msgid ""
-"The current directory (%s) is already a branch.\n"
-"You can start using it, or initialize another directory."
-msgstr ""
-
-#: errors.py:62 errors.py:65
-msgid "Branch without a working tree"
-msgstr ""
-
-#: errors.py:63 errors.py:66
-#, python-format
-msgid ""
-"The current directory (%s)\n"
-"is a branch without a working tree."
-msgstr ""
-
-#: errors.py:65 errors.py:68
-msgid "Unknown bzr error"
-msgstr ""
-
-#: errors.py:67 errors.py:70
-msgid "Permission denied"
-msgstr ""
-
-#: errors.py:67 errors.py:70
-msgid "permission denied."
-msgstr ""
-
-#: errors.py:69 errors.py:72
-msgid "Unknown error"
-msgstr ""
-
-#: initialize.py:47 initialize.py:48
-msgid "_Initialize"
-msgstr ""
-
-#: initialize.py:48 initialize.py:49
-msgid "Which directory do you want to initialize?"
-msgstr ""
-
-#: initialize.py:49 initialize.py:50
-msgid "Current directory"
-msgstr ""
-
-#: initialize.py:50 initialize.py:51
-msgid "Create a new directory with the name:"
-msgstr ""
-
-#: initialize.py:85 initialize.py:86
-msgid "Directory name not specified"
-msgstr ""
-
-#: initialize.py:86 initialize.py:87
-msgid "You should specify a new directory name."
-msgstr ""
-
-#: merge.py:66 merge.py:68 merge.py:69
-msgid "Branch not given"
-msgstr ""
-
-#: merge.py:67 merge.py:69 merge.py:70
-msgid "Please specify a branch to merge from."
-msgstr ""
-
-#: merge.py:75 merge.py:77 merge.py:78
-msgid "Bazaar command error"
-msgstr ""
-
-#: merge.py:81 diff.py:513 merge.py:83 diff.py:514 merge.py:84
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82 diff.py:514 merge.py:84 diff.py:515 merge.py:85
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85 diff.py:517 merge.py:87 diff.py:518 merge.py:88
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86 diff.py:518 merge.py:88 diff.py:519 merge.py:89
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45 olive/bookmark.py:45 push.py:53
-#: olive/bookmark.py:46
-msgid "Location:"
-msgstr ""
-
-#: push.py:54 push.py:55
-msgid "_Push"
-msgstr ""
-
-#: push.py:97 push.py:98
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98 push.py:99
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106 push.py:107
-msgid ""
-"You cannot push if branches have diverged.\n"
-"Overwrite?"
-msgstr ""
-
-#: push.py:112 push.py:111
-msgid "Push successful"
-msgstr ""
-
-#: push.py:113 push.py:112
-#, python-format
-msgid "%d revision(s) pushed."
-msgstr ""
-
-#: push.py:146 push.py:145
-msgid "Non existing parent directory"
-msgstr ""
-
-#: push.py:147 push.py:146
-#, python-format
-msgid ""
-"The parent directory (%s)\n"
-"doesn't exist. Create?"
-msgstr ""
-
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48 revbrowser.py:44 revbrowser.py:45
-msgid "_Select"
-msgstr ""
-
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78 status.py:82 status.py:84
-msgid "Added"
-msgstr ""
-
-#: status.py:84 status.py:88 status.py:90
-msgid "Removed"
-msgstr ""
-
-#: status.py:90 status.py:94 status.py:96
-msgid "Renamed"
-msgstr ""
-
-#: status.py:97 status.py:101 status.py:103
-msgid "Modified"
-msgstr ""
-
-#: status.py:105 status.py:109 status.py:111
-msgid "Unknown"
-msgstr ""
-
-#: status.py:110 status.py:114 status.py:116
-msgid "No changes."
-msgstr ""
-
-#: tags.py:67 tags.py:65 tags.py:66
-msgid "Tags"
-msgstr ""
-
-#: tags.py:111 tags.py:109 tags.py:110
-msgid "Tag Name"
-msgstr ""
-
-#: tags.py:116 tags.py:114 tags.py:115
-msgid "Revision ID"
-msgstr ""
-
-#: tags.py:151 tags.py:149 tags.py:150
-msgid "Tags are not supported by this branch format. Please upgrade."
-msgstr ""
-
-#: tags.py:157 tags.py:155 tags.py:156
-msgid "No tagged revisions in the branch."
-msgstr ""
-
-#: tags.py:232 tags.py:230 tags.py:231
-msgid "_Remove tag"
-msgstr ""
-
-#: tags.py:242 tags.py:240 tags.py:241
-msgid "<b><big>Remove tag?</big></b>"
-msgstr ""
-
-#: tags.py:244 tags.py:242 tags.py:243
-#, python-format
-msgid "Are you sure you want to remove the tag: <b>%s</b>?"
-msgstr ""
-
-#: tags.py:289 tags.py:287 tags.py:288
-msgid "_Add tag"
-msgstr ""
-
-#: tags.py:291 tags.py:289 tags.py:290
-msgid "Tag Name:"
-msgstr ""
-
-#: tags.py:292 tags.py:290 tags.py:291
-msgid "Revision ID:"
-msgstr ""
-
-#: tags.py:323 tags.py:321 tags.py:322
-msgid "No tag name specified"
-msgstr ""
-
-#: tags.py:324 tags.py:322 tags.py:323
-msgid "You have to specify the tag's desired name."
-msgstr ""
-
-#: __init__.py:512 olive/__init__.py:539 olive/__init__.py:540
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513 olive/__init__.py:540 olive/__init__.py:541
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550 olive/__init__.py:555 olive/__init__.py:612
-#: olive/__init__.py:556 olive/__init__.py:613
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526 olive/__init__.py:556 olive/__init__.py:557
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537 olive/__init__.py:599 olive/__init__.py:600
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540 olive/__init__.py:602 olive/__init__.py:603
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541 olive/__init__.py:603 olive/__init__.py:604
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551 olive/__init__.py:613 olive/__init__.py:614
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561 olive/__init__.py:623 olive/__init__.py:624
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561 olive/__init__.py:623 olive/__init__.py:624
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275 olive/__init__.py:648 olive/menu.py:274
-#: olive/__init__.py:649 olive/menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276 olive/__init__.py:649 olive/menu.py:275
-#: olive/__init__.py:650 olive/menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278 olive/__init__.py:651 olive/menu.py:277
-#: olive/__init__.py:652 olive/menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279 olive/__init__.py:652 olive/menu.py:278
-#: olive/__init__.py:653 olive/menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117 olive/__init__.py:942
-#: olive/__init__.py:1240 olive/__init__.py:943 olive/__init__.py:1241
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:842 menu.py:99 olive/__init__.py:949 olive/menu.py:98
-#: olive/__init__.py:950 olive/menu.py:99
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:944 __init__.py:1231 olive/__init__.py:1057
-#: olive/__init__.py:1362 olive/__init__.py:1058 olive/__init__.py:1363
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233 olive/__init__.py:1059
-#: olive/__init__.py:1364 olive/__init__.py:1060 olive/__init__.py:1365
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235 olive/__init__.py:1061
-#: olive/__init__.py:1368 olive/__init__.py:1062 olive/__init__.py:1369
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964 olive/__init__.py:1083 olive/__init__.py:1084
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965 olive/__init__.py:1084 olive/__init__.py:1085
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966 olive/__init__.py:1085 olive/__init__.py:1086
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967 olive/__init__.py:1086 olive/__init__.py:1087
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-#: olive/add.py:68 olive/menu.py:178 olive/menu.py:218 olive/menu.py:254
-#: olive/remove.py:68 olive/remove.py:130 olive/add.py:69 olive/menu.py:179
-#: olive/menu.py:219 olive/menu.py:255 olive/remove.py:69 olive/remove.py:131
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46 olive/bookmark.py:46 olive/bookmark.py:47
-msgid "Title:"
-msgstr ""
-
-#: bookmark.py:81 olive/bookmark.py:81 olive/bookmark.py:82
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82 olive/bookmark.py:82 olive/bookmark.py:83
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45 olive/guifiles.py:47 olive/guifiles.py:48
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55 olive/guifiles.py:57 olive/guifiles.py:58
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63 olive/menu.py:62 olive/menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64 olive/menu.py:63 olive/menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107 olive/menu.py:66 olive/menu.py:106 olive/menu.py:67
-#: olive/menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68 olive/menu.py:67 olive/menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71 olive/menu.py:70 olive/menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72 olive/menu.py:71 olive/menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75 olive/menu.py:74 olive/menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76 olive/menu.py:75 olive/menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79 olive/menu.py:78 olive/menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80 olive/menu.py:79 olive/menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83 olive/menu.py:82 olive/menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84 olive/menu.py:83 olive/menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88 olive/menu.py:87 olive/menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91 olive/menu.py:90 olive/menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92 olive/menu.py:91 olive/menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95 olive/menu.py:94 olive/menu.py:95
-msgid "Diff"
-msgstr ""
-
-#: menu.py:96 olive/menu.py:95 olive/menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100 olive/menu.py:99 olive/menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103 olive/menu.py:102 olive/menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104 olive/menu.py:103 olive/menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108 olive/menu.py:107 olive/menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111 olive/menu.py:110 olive/menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112 olive/menu.py:111 olive/menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115 olive/menu.py:114 olive/menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116 olive/menu.py:115 olive/menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119 olive/menu.py:118 olive/menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120 olive/menu.py:119 olive/menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123 olive/menu.py:122 olive/menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124 olive/menu.py:123 olive/menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127 olive/menu.py:126 olive/menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128 olive/menu.py:127 olive/menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131 olive/menu.py:130 olive/menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132 olive/menu.py:131 olive/menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228 olive/menu.py:227 olive/menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315 olive/__init__.py:707 olive/menu.py:318 olive/__init__.py:708
-#: olive/menu.py:319
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316 olive/__init__.py:708 olive/menu.py:319 olive/__init__.py:709
-#: olive/menu.py:320
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319 olive/__init__.py:711 olive/menu.py:322 olive/__init__.py:712
-#: olive/menu.py:323
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320 olive/__init__.py:712 olive/menu.py:323 olive/__init__.py:713
-#: olive/menu.py:324
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67 olive/mkdir.py:67 olive/mkdir.py:68
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68 olive/mkdir.py:68 olive/mkdir.py:69
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89 olive/mkdir.py:79 olive/mkdir.py:89
-#: olive/mkdir.py:80 olive/mkdir.py:90
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90 olive/mkdir.py:80 olive/mkdir.py:90
-#: olive/mkdir.py:81 olive/mkdir.py:91
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71 olive/move.py:80 olive/rename.py:71
-#: olive/move.py:81 olive/rename.py:72
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87 olive/move.py:89 olive/rename.py:87
-#: olive/move.py:90 olive/rename.py:88
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88 olive/move.py:90 olive/rename.py:88
-#: olive/move.py:91 olive/rename.py:89
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139 olive/remove.py:79 olive/remove.py:139
-#: olive/remove.py:80 olive/remove.py:140
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140 olive/remove.py:80 olive/remove.py:140
-#: olive/remove.py:81 olive/remove.py:141
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825 olive.glade:878 olive/remove.py:105
-#: olive/remove.py:106
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: remove.py:106 olive.glade:717 olive.glade:837 olive.glade:766
-#: olive.glade:890 olive/remove.py:106 olive/remove.py:107
-msgid "Selected only"
-msgstr ""
-
-#: remove.py:107 olive.glade:851 olive.glade:905 olive/remove.py:107
-#: olive/remove.py:108
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905 olive.glade:962 olive/remove.py:108
-#: olive/remove.py:109
-msgid "_Remove"
-msgstr ""
-
-#: rename.py:75 olive/rename.py:75 olive/rename.py:76
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76 olive/rename.py:76 olive/rename.py:77
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:21
-msgid "_File"
-msgstr ""
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:63 olive.glade:71
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:76 olive.glade:84
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:84 olive.glade:92
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:92 olive.glade:100
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118 olive.glade:126
-msgid "_View"
-msgstr ""
-
-#: olive.glade:126 olive.glade:134
-msgid "Show _hidden files"
-msgstr ""
-
-#: olive.glade:139 olive.glade:155
-msgid "_Refresh"
-msgstr ""
-
-#: olive.glade:158 olive.glade:174
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166 olive.glade:182
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:174 olive.glade:190
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187 olive.glade:203
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201 olive.glade:217
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220 olive.glade:245
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228 olive.glade:253
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236 olive.glade:261
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255 olive.glade:280
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263 olive.glade:288
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:271 olive.glade:296
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279 olive.glade:304
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291 olive.glade:316
-msgid "_Statistics"
-msgstr ""
-
-#: olive.glade:298 olive.glade:323
-msgid "_Differences..."
-msgstr ""
-
-#: olive.glade:312 olive.glade:337
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:326 olive.glade:351
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338 olive.glade:363
-msgid "_Help"
-msgstr ""
-
-#: olive.glade:548 olive.glade:590
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575 olive.glade:618
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673 olive.glade:722
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675 olive.glade:724
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:677 olive.glade:726
-msgid "translator-credits"
-msgstr ""
-
-#: olive.glade:694 olive.glade:743
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:705 olive.glade:754
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:731 olive.glade:781
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785 olive.glade:838
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:814 olive.glade:867
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:934 olive.glade:991
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:957 olive.glade:1014
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011 olive.glade:1071
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:1041 olive.glade:1101
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:1055 olive.glade:1115
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:1066 olive.glade:1126
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:1120 olive.glade:1182
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:1148 olive.glade:1210
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:1162 olive.glade:1224
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:1227 olive.glade:1291
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:1255 olive.glade:1319
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275 olive.glade:1343 olive.glade:1356 olive.glade:1369
-#: olive.glade:1382 olive.glade:1395 olive.glade:1408 olive.glade:1421
-#: olive.glade:1548 olive.glade:1559 olive.glade:1628 olive.glade:1639
-#: olive.glade:1652 olive.glade:1665 olive.glade:1758 olive.glade:1769
-#: olive.glade:1782 olive.glade:1863 olive.glade:1874 olive.glade:1943
-#: olive.glade:1954 olive.glade:1967 olive.glade:1980 olive.glade:1993
-#: olive.glade:2006 olive.glade:2019 olive.glade:2032 olive.glade:2173
-#: olive.glade:2184 olive.glade:2197 olive.glade:2210 olive.glade:2223
-#: olive.glade:2328 olive.glade:2339
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368 olive.glade:1432
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380 olive.glade:1444
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392 olive.glade:1456
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404 olive.glade:1468
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416 olive.glade:1480
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428 olive.glade:1492
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440 olive.glade:1504
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454 olive.glade:1518
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508 olive.glade:1572
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520 olive.glade:1584
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:1534 olive.glade:1598
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614 olive.glade:1678
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:1626 olive.glade:1690
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638 olive.glade:1702
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650 olive.glade:1714
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664 olive.glade:1728
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731 olive.glade:1795
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743 olive.glade:1807
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755 olive.glade:1819
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769 olive.glade:1833
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823 olive.glade:1887
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835 olive.glade:1899
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849 olive.glade:1913
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981 olive.glade:2045
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993 olive.glade:2057
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:2005 olive.glade:2069
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:2017 olive.glade:2081
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:2029 olive.glade:2093
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:2041 olive.glade:2105
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:2053 olive.glade:2117
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:2065 olive.glade:2129
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:2079 olive.glade:2143
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172 olive.glade:2236
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184 olive.glade:2248
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:2196 olive.glade:2260
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208 olive.glade:2272
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220 olive.glade:2284
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234 olive.glade:2298
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288 olive.glade:2352
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:2300 olive.glade:2364
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314 olive.glade:2378
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356 olive.glade:2421
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370 olive.glade:2435
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454 olive.glade:2522
-msgid "_Merge"
-msgstr ""
-
-#: olive.glade:63
-msgid "_Bookmark current directory"
-msgstr ""
-
-#: olive.glade:142
-msgid "Show _ignored files"
-msgstr ""
-
-#: olive.glade:232 olive.glade:486
-msgid "Update"
-msgstr ""
-
-#: commit.py:172 commit.py:173
-msgid "kind changed"
-msgstr ""
-
-#: commit.py:260 commit.py:261
-msgid "<b>Commit Message</b>"
-msgstr ""
-
-#: commit.py:363 commit.py:364
-msgid "Files"
-msgstr ""
-
-#: commit.py:368 commit.py:369
-msgid "Commit all changes"
-msgstr ""
-
-#: commit.py:374 commit.py:375
-msgid "Only commit selected changes"
-msgstr ""
-
-#: commit.py:380 commit.py:381
-msgid "Commit all changes*"
-msgstr ""
-
-#: commit.py:413 commit.py:414
-msgid "Commit*"
-msgstr ""
-
-#: commit.py:454 commit.py:455
-msgid "<i>* Cannot select specific files when merging</i>"
-msgstr ""
-
-#: commit.py:458 commit.py:459
-msgid "Pending Revisions"
-msgstr ""
-
-#: commit.py:494 commit.py:495
-msgid "Diff for whole tree"
-msgstr ""
-
-#: commit.py:518 commit.py:599 commit.py:519 commit.py:601
-msgid "File commit message"
-msgstr ""
-
-#: commit.py:525 commit.py:526
-msgid "Global Commit Message"
-msgstr ""
-
-#: commit.py:526 commit.py:528
-msgid "<b>Global Commit Message</b>"
-msgstr ""
-
-#: commit.py:552 commit.py:554
-msgid "Diff for "
-msgstr ""
-
-#: commit.py:605 commit.py:607
-msgid "Commit message for "
-msgstr ""
-
-#: commit.py:690 commit.py:692
-msgid "There are no changes in the working tree. Do you want to commit anyway?"
-msgstr ""
-
-#: branchview/treeview.py:400 branchview/treeview.py:402
-msgid "Please wait, loading ancestral graph..."
-msgstr ""
-
-#: olive/__init__.py:71 olive/__init__.py:72
-msgid "Lead Developer:"
-msgstr ""
-
-#: olive/__init__.py:73 olive/__init__.py:74
-msgid "Contributors:"
-msgstr ""
-
-#: olive/__init__.py:578 olive/__init__.py:579
-#, python-format
-msgid "%d local extra revision(s). \n"
-msgstr ""
-
-#: olive/__init__.py:590 olive/__init__.py:591
-#, python-format
-msgid "%d local missing revision(s).\n"
-msgstr ""
-
-#: olive/__init__.py:632 olive/__init__.py:633
-msgid "Update successful but conflicts generated"
-msgstr ""
-
-#: olive/__init__.py:632 olive/__init__.py:633
-#, python-format
-msgid "Number of conflicts generated: %d."
-msgstr ""
-
-#: olive/__init__.py:634 olive/__init__.py:635
-msgid "Update successful"
-msgstr ""
-
-#: olive/__init__.py:634 olive/__init__.py:635
-msgid "No conflicts generated."
-msgstr ""

=== modified file 'po/pl.po'
--- po/pl.po	2008-03-11 17:01:27 +0000
+++ po/pl.po	2011-03-08 04:41:48 +0000
@@ -7,1286 +7,697 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-02-09 23:40+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-17 21:00+0000\n"
 "Last-Translator: Jaroslaw Zabiello <Unknown>\n"
 "Language-Team: Polish <pl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
-#, fuzzy
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
-msgstr "Gałąź"
-
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
 msgstr ""
 
-#: branch.py:57 checkout.py:55
-#, fuzzy
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
-msgstr "Położenie gałęzi"
+msgstr ""
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Cel:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr ""
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "n/d"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operacja przerwana"
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr ""
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr ""
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr ""
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr ""
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr ""
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr ""
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr ""
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr ""
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr ""
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr ""
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr ""
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:21
-msgid "_File"
-msgstr ""
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr ""
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr ""
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr ""
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr ""
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr ""
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr ""
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Jaroslaw Zabiello https://launchpad.net/~hipertracker"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Jaroslaw Zabiello https://launchpad.net/~hipertracker\n"
+#~ "  Łukasz Jernaś https://launchpad.net/~deejay1"

=== modified file 'po/pt_BR.po'
--- po/pt_BR.po	2008-03-11 17:01:27 +0000
+++ po/pt_BR.po	2011-03-10 04:41:02 +0000
@@ -7,248 +7,338 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-03-02 17:14+0000\n"
-"Last-Translator: Alexandre Sapata Carbonell <alexandrenescau@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-08 23:22+0000\n"
+"Last-Translator: Paulo Guilherme Pilotti Duarte "
+"<guilhermepilotti@gmail.com>\n"
 "Language-Team: Brazilian Portuguese <pt_BR@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-10 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr "Preferências do Bazaar"
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr "Configure as opções do Bazaar"
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr "Bazaar"
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr "Notificação do Bazaar"
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr "Ícone de Área de notificação para o Bazaar"
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Ramo(branch)"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Por favor selecione uma pasta"
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Localização do ramo(branch):"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destino:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Apelido da ramo:"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisão:"
 
-#: branch.py:162 checkout.py:163
-#, fuzzy
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Por favor selecione uma pasta"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Falta o local do ramo."
+msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "É necessário especifficar um local para o ramo."
+msgstr "Você deve especificar um local para o ramo."
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Ramificação (branching) bem sucedida"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
-msgstr "A %d revisão foi ramificada."
+msgstr "%d revisão(ões) ramificada(s)."
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "Não disponível"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
-msgstr "Verificação_geral"
-
-#: checkout.py:62
+msgstr "Verificaçã_o Geral"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
-msgstr "Verificação_leve"
+msgstr "Verificação _Leve"
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr "Diretório não tem árvore de trabalho"
+msgstr "O diretório não tem uma árvore de trabalho"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "A operação foi interrompida."
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "O diretório não é um ramo."
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr "Esta operação só pode ser executada num ramo."
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Existem modificações locais no ramo"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "Favor consolidar ou reverter as modificações antes de combinar"
+
+#: ../commit.py:182
+msgid "added"
+msgstr "Adicionado"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "removido"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "renomeado"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "renomeado e modificado"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "modificado"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "S_omente consolide localmente"
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Consol_idar"
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr "Arquivo(s) a consolidar"
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr "Mensagem da consilidação:"
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr "Combinações pendentes"
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr "S_omente consolide localmente"
-
-#: commit.py:215
+#: ../commit.py:390
+msgid "Files"
+msgstr "Arquivos"
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Enviar"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Caminho"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Tipo"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "Data"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr "Consolidador"
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "Sumário"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr "<b>Mensagem de Envio</b>"
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr "Envio cancelado"
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Consolidar com uma mensagem vazia?"
 
-#: commit.py:216
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 "Você pode descrever a sua intenção para a consolidação nesta mensagem."
 
-#: commit.py:228
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Consolidar com itens desconhecidos?"
 
-#: commit.py:229
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Há arquivos desconhecidos na árvore de trabalho. Deseja consolidar assim "
 "mesmo?"
 
-#: commit.py:240
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Consolidar sem modificaçãoes?"
 
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr "Não há mudanças na árvore de trabalho."
-
-#: commit.py:323 menu.py:87
-#, fuzzy
-msgid "Commit"
-msgstr "Consolidar"
-
-#: commit.py:325 conflicts.py:108
-msgid "Path"
-msgstr "Caminho"
-
-#: commit.py:327 conflicts.py:110
-msgid "Type"
-msgstr "Tipo"
-
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr "Adicionado"
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr "Removido"
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr "Renomeado e modificado"
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr "Renomeado"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr "Modificado"
-
-#: commit.py:395
-msgid "Date"
-msgstr "Data"
-
-#: commit.py:397 revbrowser.py:68
-msgid "Committer"
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
-msgid "Summary"
-msgstr "Sumário"
-
-#: conflicts.py:48
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr "Utilitário Externo:"
+msgstr "Utilitário externo:"
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflitos"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Sem conflitos na árvore de trabalho."
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "Conflito no caminho"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
-msgstr "Conflitos de índices"
+msgstr "conflito de conteúdos"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
-msgstr "Conflito de texto"
+msgstr "conflito de texto"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "ID duplicada"
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicar"
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
-msgstr "tipo desconhecido de conflito"
+msgstr "tipo de conflito desconhecido"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
-msgstr "nenhum arquivo foi selecionado"
+msgstr "Nenhum arquivo foi selecionado"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Por favor selecione um arquivo da lista."
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
-msgstr "A chamada a um utilitário externo falhou."
+msgstr "Falha na chamada a utilitário externo"
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Não é possível resolver o conflito"
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -258,38 +348,79 @@
 "Conflitos de conteúdo, na estrutura da árvore, têm que ser resolvidos usando "
 "a linha de comando."
 
-#: errors.py:29
-#, fuzzy
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Visualizar"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Fusão bem sucedida"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Todas as mudanças foram aplicadas com sucesso."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Encontrado conflitos"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "Por favor resolva os conflitos manualmente antes de consolidar."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "O diretório não é um ramo."
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "Esta operação só pode ser executada em um ramo."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
-msgstr "O diretório não é um checkout."
+msgstr ""
 
-#: errors.py:30
-#, fuzzy
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Você só pode executar consolidações locais em checkouts."
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Sem mudanças para consolidar"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 "Tente impor a consolidação se você quiser consolidar de qualquer maneira."
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr "Nenhuma mudança para mesclar"
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Há conflitos na árvore"
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "É necessário resolver os conflitos antes de consolidar."
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
-msgstr ""
+msgstr "Falha na consolidação estrita"
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -297,62 +428,65 @@
 "Existem arquivos desconhecidos na árvore de trabalho.\n"
 "Por favor adicione ou delete eles."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
-msgstr ""
+msgstr "Ramo vinculado está desatualizado"
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
-msgstr ""
+msgstr "Arquivo sem versão definida"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
-msgstr ""
+msgstr "O arquivo selecionado não tem versão definida."
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
-msgstr ""
+msgstr "Ramos foram divergidos"
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
+"Você não consegue enviar se os ramos tiverem divergido. Use\n"
+"a opção sobrescrever se você quiser enviar mesmo assim."
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
-msgstr ""
+msgstr "Sem saída do diff"
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "O arquivo selecionado não foi mudado."
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
-msgstr ""
+msgstr "Revisão inexistente"
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
-msgstr ""
+msgstr "A revisão especificada não existe."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "O destino já existe"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "O diretório de destino já existe. Por favor selecione outro destino."
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Esse diretório já é um ramo(branch)"
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -361,11 +495,11 @@
 "O diretório atual (%s) já é um ramo (branch).\n"
 "Você pode começar a usá-lo ou inicializar outro diretório."
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Este ramo (branch) não tem uma árvore de trabalho"
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -374,113 +508,114 @@
 "O diretório atual (%s)\n"
 "é um ramo (branch) dem uma árvore de trabalho."
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Erro desconhecido do bzr"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permissão negada"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "Permissão negada."
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Erro desconhecido"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inicializar"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Qual diretório você quer inicializar?"
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Diretório atual"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr "Criar um novo diretório com o nome:"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "O nome do diretório não foi especificado."
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Você deve especificar um novo nome para o diretório"
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr "Mesclar de"
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr "Pasta"
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr "Localização Personalizada"
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_fusão"
+
+#: ../merge.py:132
 msgid "Branch not given"
-msgstr ""
+msgstr "Ramo não fornecido"
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
-msgstr ""
+msgstr "Por favor especifique um ramo do qual mesclar."
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Erro de comando Bazaar"
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr "Fusão bem sucedida"
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr "Todas as mudanças foram aplicadas com sucesso."
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr "Encontrado conflitos"
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr "Localização:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
-msgstr ""
-
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+msgstr "_Enviar"
+
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
+"Você não pode enviar se os ramos tiverem divergido.\n"
+"Sobrescrever?"
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
-msgstr ""
+msgstr "Sucesso no envio"
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
-msgstr ""
+msgstr "%d revisões enviadas."
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Diretório pai inexistente"
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -489,835 +624,608 @@
 "O diretório pai (%s)\n"
 "não exixte. Deseja criá-lo?"
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr "Por favor aguarde, as revisões estão sendo carregadas..."
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Selecionar"
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr "nº da revisão"
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr "Tempo"
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr "Buscar por:"
+
+#: ../search.py:56
+msgid "Document"
+msgstr "Documento"
+
+#: ../status.py:94
 msgid "Added"
 msgstr "Adicionado"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr "Removido"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renomeado"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificado"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Desconhecido"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "sem mudanças"
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Etiquetas"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr "Nome da Etiqueta"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr "identificação da revisão"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Etiquetas não são suportadas por esse formato de ramo(branch). Atualize, por "
 "favor."
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Não há revisões etiquetadas no ramo (branch)."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Remover tag"
 
-#: tags.py:242
-#, fuzzy
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
-msgstr "<b><grande>Remover tag?</grande></b>"
+msgstr "<b><big>Remover tag?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Você tem certeza de que quer remover a tag: <b>%s</b>?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Adicionar tag"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nome da tag:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID de revisão:"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Nome de tag não especificado"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Você tem de especificar o nome desejado da tag."
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr "Existem revisões faltando"
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr "%d revisão(ões) faltando."
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr "Conflitos detectados"
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr "Por favor de uma olhada na árvore de trabalho antes de continuar."
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr "Sem alterações"
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr "Ignorado"
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr "Última modificação"
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-"Por favor selecione o arquivo da lista,\n"
-"ou escolha a outra opção."
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Titulo:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr "Título não foi dado"
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr "Por favor especifique um título para continuar."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr "Arquivo Glade não pôde ser encontrado."
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr "Descrição do arquivo UI não pôde ser encontrado."
-
-#: menu.py:63
-msgid "Add"
-msgstr "Adicionar"
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr "Adicionar o arquivo selecionado"
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr "Remover"
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr "Anotar"
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr "Anotar o arquivo selecionado"
-
-#: menu.py:95
-msgid "Diff"
-msgstr ""
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr "Editar"
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr "Abrir Pasta"
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr "Visualizar conteúdo"
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr "Mostrar diferenças"
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr "Mostrar as diferenças entre dois arquivos de revisão"
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr "Deletar diretório com todos os diretórios abaixo?"
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr "Por favor especifique outro nome para continuar."
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr "Por favor selecione um arquivo da lista para proceder."
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr "Arquivos não se combinam"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr "Arquivos não adicionados foram encontrados na árvore de trabalho."
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "Qual(is) arquivo(s) você deseja remover?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Somente selecionado"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "Todos arquivos com status \"adicionado\""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Remover"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:21
-msgid "_File"
-msgstr ""
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Mover..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr "_Anotar..."
-
-#: olive.glade:118
-msgid "_View"
-msgstr "_Visualizar"
-
-#: olive.glade:126
-#, fuzzy
-msgid "Show _hidden files"
-msgstr "Exibir arquivos _ocultos"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Atualizar"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr "_Inicializar"
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Pegar"
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:271
-#, fuzzy
-msgid "Missing _revisions"
-msgstr "_Revisões faltando"
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr "Con_flitos..."
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Estatísticas"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Diferenças"
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Log..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr "_Informação..."
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Ajuda"
-
-#: olive.glade:548
-#, fuzzy
-msgid "gtk-jump-to"
-msgstr "gtk-pular-para"
-
-#: olive.glade:575
-#, fuzzy
-msgid "H_istory Mode"
-msgstr "Modo de H_istória"
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Alexandre Sapata Carbonell https://launchpad.net/~alexandre-sapata-"
-"carbonell\n"
-"  Flávio Pontes https://launchpad.net/~flaviocpontes\n"
-"  Nelson do Vale https://launchpad.net/~nelsondovale"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Oliva - Adicionar arquivo(s)"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Qual(is) arquivo(s) você quer adicionar?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Adicionar"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Oliva - Remover arquivo(s)"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Oliva - Fazer diretório"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Fazer diretório"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Oliva - Mover"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Mover para"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Selecionar um diretório"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Mover"
-
-#: olive.glade:1148
-#, fuzzy
-msgid "Olive - Rename"
-msgstr "Oliva - Renomear"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Renomear para"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "_Renomear"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr "Oliva - Informação"
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(nenhum)"
-
-#: olive.glade:1368
-#, fuzzy
-msgid "Checkout root: "
-msgstr "Verificação geral do root: "
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Verificação geral do repositório: "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr "Repositório compartilhado: "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr "Verificação geral leve do root: "
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr "<b>Localização:</b>"
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr "Formato do repositório: "
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr "Formato da árvore de trabalho: "
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr "Formato do controle: "
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr "<b>Formato:</b>"
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr "<b>Revisões faltando</b>"
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "Arquivos ignorados: "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Arquivos Desconhecidos: "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Arquivos renomeados: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Arquivos removidos: "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Arquivos adicionados "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Arquivos modificados: "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Arquivos não modificados: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr "<b>Na árvore de trabalho:</b>"
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr "Tempo da última revisão: "
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Tempo da primeira revisão: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr "Tamanho do repositório: "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr "Revisões no repositório: "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr "Fusão - Oliva"
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr "_fusão"
+#~ msgid "File(s) to commit"
+#~ msgstr "Arquivo(s) a consolidar"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Não há mudanças na árvore de trabalho."
+
+#~ msgid "Time"
+#~ msgstr "Tempo"
+
+#~ msgid "Revno"
+#~ msgstr "nº da revisão"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Por favor aguarde, as revisões estão sendo carregadas..."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflitos detectados"
+
+#~ msgid "unchanged"
+#~ msgstr "Sem alterações"
+
+#~ msgid "ignored"
+#~ msgstr "Ignorado"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Por favor de uma olhada na árvore de trabalho antes de continuar."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Adicionar o arquivo selecionado"
+
+#~ msgid "Add"
+#~ msgstr "Adicionar"
+
+#~ msgid "Last modified"
+#~ msgstr "Última modificação"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Arquivo Glade não pôde ser encontrado."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Descrição do arquivo UI não pôde ser encontrado."
+
+#~ msgid "Title:"
+#~ msgstr "Titulo:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Por favor especifique um título para continuar."
+
+#~ msgid "No title given"
+#~ msgstr "Título não foi dado"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Por favor selecione o arquivo da lista,\n"
+#~ "ou escolha a outra opção."
+
+#~ msgid "Remove"
+#~ msgstr "Remover"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Anotar o arquivo selecionado"
+
+#~ msgid "Annotate"
+#~ msgstr "Anotar"
+
+#~ msgid "Open Folder"
+#~ msgstr "Abrir Pasta"
+
+#~ msgid "Edit"
+#~ msgstr "Editar"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Deletar diretório com todos os diretórios abaixo?"
+
+#~ msgid "View contents"
+#~ msgstr "Visualizar conteúdo"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostrar as diferenças entre dois arquivos de revisão"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostrar diferenças"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Todos arquivos com status \"adicionado\""
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Por favor selecione um arquivo da lista para proceder."
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Arquivos não adicionados foram encontrados na árvore de trabalho."
+
+#~ msgid "No matching files"
+#~ msgstr "Arquivos não se combinam"
+
+#~ msgid "_Remove"
+#~ msgstr "_Remover"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Por favor especifique outro nome para continuar."
+
+#~ msgid "Selected only"
+#~ msgstr "Somente selecionado"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Qual(is) arquivo(s) você deseja remover?"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Atualizar"
+
+#~ msgid "_Get..."
+#~ msgstr "_Pegar"
+
+#~ msgid "_Move..."
+#~ msgstr "_Mover..."
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inicializar"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Anotar..."
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferenças"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Estatísticas"
+
+#~ msgid "_Help"
+#~ msgstr "_Ajuda"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informação..."
+
+#~ msgid "(none)"
+#~ msgstr "(nenhum)"
+
+#~ msgid "Move to"
+#~ msgstr "Mover para"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Oliva - Informação"
+
+#~ msgid "_Rename"
+#~ msgstr "_Renomear"
+
+#~ msgid "Rename to"
+#~ msgstr "Renomear para"
+
+#~ msgid "_Move"
+#~ msgstr "_Mover"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selecionar um diretório"
+
+#~ msgid "Control format: "
+#~ msgstr "Formato do controle: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Formato da árvore de trabalho: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formato:</b>"
+
+#~ msgid "Repository format: "
+#~ msgstr "Formato do repositório: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Arquivos renomeados: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Arquivos Desconhecidos: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Arquivos ignorados: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Arquivos não modificados: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Arquivos modificados: "
+
+#~ msgid "Added files: "
+#~ msgstr "Arquivos adicionados "
+
+#~ msgid "Removed files: "
+#~ msgstr "Arquivos removidos: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>Na árvore de trabalho:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Tempo da última revisão: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Tempo da primeira revisão: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusão - Oliva"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revisões faltando</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "Tamanho do repositório: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisões no repositório: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Verificação geral do repositório: "
+
+#~ msgid "_Make directory"
+#~ msgstr "_Fazer diretório"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Oliva - Mover"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Localização:</b>"
+
+#~ msgid "Shared repository: "
+#~ msgstr "Repositório compartilhado: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Verificação geral leve do root: "
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Oliva - Fazer diretório"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flitos..."
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Oliva - Remover arquivo(s)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Qual(is) arquivo(s) você quer adicionar?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Oliva - Adicionar arquivo(s)"
+
+#~ msgid "_Add"
+#~ msgstr "_Adicionar"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Existem revisões faltando"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revisão(ões) faltando."
+
+#~ msgid "Pending merges"
+#~ msgstr "Combinações pendentes"
+
+#~ msgid "Commit message:"
+#~ msgstr "Mensagem da consolidação:"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Não existe local padrão de envio definido.\n"
+#~ "Definir %r como padrão agora?"
+
+#~ msgid "Set default push location"
+#~ msgstr "Defina o local padrão de envio"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Ramo local está atualizado"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Localização original desconhecida"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Não é possível determinar revisões que faltam se a localização original é "
+#~ "desconhecida."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Não existem revisões faltando."
+
+#~ msgid "Pull successful"
+#~ msgstr "Recebimento bem sucedido"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d revisão(ões) recebida(s)."
+
+#~ msgid "Bookmark"
+#~ msgstr "Favoritos"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Favoritos"
+
+#~ msgid "Revert successful"
+#~ msgstr "Reversão bem sucedida"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Todos os arquivos foram revertidos para a última revisão."
+
+#~ msgid "Filename"
+#~ msgstr "Nome do arquivo"
+
+#~ msgid "unknown"
+#~ msgstr "desconhecido"
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Size"
+#~ msgstr "Tamanho"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Renomear o arquivo selecionado"
+
+#~ msgid "Revert"
+#~ msgstr "Reverter"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Remover e apagar"
+
+#~ msgid "Rename"
+#~ msgstr "Renomear"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Remover o arquivo ou diretório selecionado e apagar do disco"
+
+#~ msgid "Open"
+#~ msgstr "Abrir"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Reverter as modificações"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Abrir o arquivo seleccionado"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Remover o arquivo selecionado"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Consolidar as modificações"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Abrir a pasta de favoritos no Nautilus"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostrar as diferenças de todos os arquivos"
+
+#~ msgid "Selected..."
+#~ msgstr "Selecionado..."
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostrar as diferenças dos arquivos selecionados"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Adicionar a atual localização aos favoritos"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Editar o marcador selecionado"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Remove o marcador selecionado"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostrar diff do arquivo"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Reverter para esta revisão"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "O atual diretório está nos favoritos. Você pode chegar\n"
+#~ "a ele selecionando-o no painel à esquerda."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Adicionado aos favoritos com sucesso"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "O atual diretório já está nos favoritos.\n"
+#~ "Veja o painel à esquerda para referência."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "A localização já está nos favoritos"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Favor especificar o nome desejado para o novo diretório."
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Reverter o arquivo selecionado para a selecionada revisão"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Visualizar os conteúdos do arquivo no visualizador interno"
+
+#~ msgid "Directory already exists"
+#~ msgstr "O diretório já existe"
+
+#~ msgid "No directory name given"
+#~ msgstr "Não foi dado nenhum nome ao diretório."
+
+#~ msgid "_Rename..."
+#~ msgstr "_Renomear..."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Favor especificar um novo nome para o arquivo."
+
+#~ msgid "Filename not given"
+#~ msgstr "Nome do arquivo não definido"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Não é do mesmo ramo"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Criar _diretório..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Remover arquivo(s)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Adicionar arquivo(s)..."
+
+#~ msgid "_File"
+#~ msgstr "Arquivo"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "O destino não é do mesmo ramo."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Combinar..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Reverter todas as mudanças"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Consolidar..."
+
+#~ msgid "Parent branch: "
+#~ msgstr "Ramo pai: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Sub-diretórios versionados: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Ramos relacionados:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Estado de trava:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Estado de trava do repositório: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Estado de trava do ramo: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Estado de trava da árvore de trabalho: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisões no ramo: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Quantidade de consolidadores: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Histórico do ramo:</b>"
+
+#~ msgid "Repository branch: "
+#~ msgstr "Ramo do repositório: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Formato do ramo: "
+
+#~ msgid "Merge from:"
+#~ msgstr "Combinação vinda de:"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Verificação geral do ramo: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Alexandre Sapata Carbonell https://launchpad.net/~alexandre-sapata-"
+#~ "carbonell\n"
+#~ "  Flávio Pontes https://launchpad.net/~flaviocpontes\n"
+#~ "  Leandro Pereira de Lima e Silva https://launchpad.net/~leandro-limaesilva\n"
+#~ "  Nelson do Vale https://launchpad.net/~nelsondovale\n"
+#~ "  Paulo Guilherme Pilotti Duarte https://launchpad.net/~guilhermepilotti\n"
+#~ "  Ricardo Ichizo https://launchpad.net/~n1ghtcr4wler"

=== added file 'po/ro.po'
--- po/ro.po	1970-01-01 00:00:00 +0000
+++ po/ro.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,1282 @@
+# Romanian translation for bzr-gtk
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-18 06:12+0000\n"
+"Last-Translator: Adi Roiban <adi@roiban.ro>\n"
+"Language-Team: Romanian <ro@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr "_Branch"
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr "Locaţie branch:"
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "Destinaţie:"
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr "Nume branch:"
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr "Revizie:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Vă rog să selectaţi un folder"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr "Lipseşte locaţia branch-ului"
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr "Trebuie să specificaţi o locaţie pentru branch."
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr "Branch-ul a fost creat"
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr "%d revizii au fost copiate."
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr "indisp."
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr "Check_out"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr "Checkout _lightweight"
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr "Directorul nu are working tree"
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "Operaţie anulată."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Există modificări locale în branch"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "Vă rog să executaţi un commit sau un revert înainte de merge."
+
+#: ../commit.py:182
+msgid "added"
+msgstr "adăugate"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "şterse"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "redenumite"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "redenumite şi modificate"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "modificate"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "Execută c_ommit doar local"
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "Comm_it"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Commit"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Cale"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Tip"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "Data"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr "Autor commit"
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "Rezumat"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Execut commit fără mesaj?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "Puteţi descrie conţinutul commit-ului în mesaj"
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "Execut commit cu fişiere necunoscute?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+"Există fişiere necunoscute în working tree. Doriţi să continuaţi commit-ul?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "Execut commit fără nicio schimbare?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr "Utilitar extern:"
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "Conflicte"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr "Nu există conflicte în working tree"
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr "conflict cale"
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr "conflict conţinut"
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr "conflict text"
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr "id duplicat"
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr "duplicat"
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr "bucla părinte"
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr "părinte necunoscut"
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr "părinte lipsă"
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr "şterg părinte"
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr "conflict de tip necunoscut"
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr "Nu a fost selectat niciun fisier"
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr "Vă rog selectaţi un fişier din listă"
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr "Apelarea utilitarului extern a eşuat"
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr "Nu pot rezolva conflict"
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+"Doar conflictele din fişierele text pot fi rezolvate cu Olive deocamdată. "
+"Conflictele de conţinut, de structură de directoare trebuie rezolvate "
+"folosind linia de comandă."
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Vizualizează"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Merge încheiat cu succes"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Toate modificările efectuate cu succes."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Există conflicte"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "Vă rog rezolvaţi conflictele manual înainte de commit."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Directorul nu este un branch"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "Puteţi efectua această operaţie doar pe un branch."
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr "Directorul nu este un checkout"
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr "Puteţi efectua commit-uri locale doar în checkout-uri"
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr "Nicio schimbare pentru commit"
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr "Încercaţi să forţaţi commit-ul dacă doriţi să continuaţi oricum."
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr "Conflicte în structura de directoare"
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr "Trebuie să rezolvaţi conflictele înainte de commit."
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr "Commit-ul strict a eşuat"
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+"Există fişiere necunoscute în working tree.\n"
+"Vă rog să le adăugaţi sau să le ştergeţi."
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr "Branch-ul legat este desincronizat"
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr "%s"
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr "Fişier necunoscut"
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr "Fişierul selectat nu este cunoscut"
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr "Branch-urile sunt desincronizate"
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+"Nu puteţi executa push dacă branch-urile sunt desincronizate.\n"
+"Folosiţi opţiunea de suprascriere dacă doriţi să continuaţi."
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr "Nu există diferenţe"
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr "Fişierul selectat nu a fost modificat."
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr "Revizie inexistentă"
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr "Revizia pe care aţi specificat-o nu există."
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr "Destinaţia există deja"
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+"Directorul destinaţie există deja. Vă rog să selectaţi altă destinaţie."
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr "Directorul este deja un branch"
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+"Directorul curent (%s) este deja un branch.\n"
+"Puteţi să-l folosiţi sau să iniţializaţi un alt director."
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr "Branch fără ramură curentă de lucru"
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+"Directorul curent (%s)\n"
+"este un branch fără working tree"
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr "Eroare bzr necunoscută"
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr "Acces interzis"
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr "acces interzis."
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr "Eroare necunoscută"
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr "_Iniţializează"
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr "Alegeţi directorul de iniţializat"
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr "Directorul curent"
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr "Creează un director nou cu numele:"
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr "Numele directorului nu a fost completat"
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr "Ar trebui să specificaţi un nume de director."
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Merge"
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr "Branch necompletat"
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr "Vă rog specificaţi un branch sursă"
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr "Eroare comandă Bazaar"
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr "Locaţie:"
+
+#: ../push.py:53
+msgid "_Push"
+msgstr "_Push"
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+"Nu puteţi executa push dacă branch-urile sunt desincronizate.\n"
+"Suprascriu?"
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr "Push încheiat cu succes"
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr "%d revizii copiate."
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr "Directorul părinte nu există"
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+"Directorul părinte (%s)\n"
+"nu există. Îl creez?"
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr "_Selectează"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr "Adăugat"
+
+#: ../status.py:100
+msgid "Removed"
+msgstr "Şters"
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr "Redenumit"
+
+#: ../status.py:113
+msgid "Modified"
+msgstr "Modificat"
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr "Necunoscut"
+
+#: ../status.py:126
+msgid "No changes."
+msgstr "Neschimbat."
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr "Tag-uri"
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr "Nume tag"
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr "ID revizie"
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr "Acest format de branch nu suportă tag-uri. Vă rog să-l actualizaţi."
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr "Nu există revizi cu tag-uri în branch."
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr "Şte_rge tag"
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr "<b><big>Şterg tag?</big></b>"
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr "Sigur doriţi să ştergeţi tag-ul <b>%s</b>?"
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr "Adaugă tag"
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr "Nume tag:"
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr "ID revizie:"
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr "Nume tag necompletat"
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr "Trebuie să specificaţi numele dorit pentru tag."
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Fişier(e) pentru commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Mesaj commit:"
+
+#~ msgid "Pending merges"
+#~ msgstr "Merge-uri în aşteptare"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Nu s-a schimbat nimic în working tree."
+
+#~ msgid "Revno"
+#~ msgstr "Nr. revizie"
+
+#~ msgid "Set default push location"
+#~ msgstr "Locaţia implicită pentru push"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Nu e configurată o locaţie implicită pentru push.\n"
+#~ "Salvez %r ca locaţie implicită acum?"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Vă rog aşteptaţi, încarc reviziile..."
+
+#~ msgid "Time"
+#~ msgstr "Ora"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull executat cu succes"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Există revizii lipsă"
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Nu există revizii lipsă"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Locaţia părintelui necunoscută"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr "Nu pot calcula reviziile lipsă dacă locaţia părintelui e necunoscută"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Branch local la zi"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revizii lipsă."
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Nu puteţi executa pull fără a avea locaţia branch-ului părinte"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d revizii copiate"
+
+#~ msgid "unchanged"
+#~ msgstr "nemodificat"
+
+#~ msgid "Bookmark"
+#~ msgstr "Favorit"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Favorite"
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert executat cu succes"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Toate filele restaurate conform ultimei revizii."
+
+#~ msgid "ignored"
+#~ msgstr "ignorat"
+
+#~ msgid "unknown"
+#~ msgstr "necunoscut"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Vă rog verificaţi working tree-ul înainte de a continua."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Am detectat conflicte"
+
+#~ msgid "Last modified"
+#~ msgstr "Ultima modificare"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Fişier Glade lipsă."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Fişierul care descrie interfaţa su utilizatorul nu poate fi găsit."
+
+#~ msgid "Status"
+#~ msgstr "Stare"
+
+#~ msgid "Filename"
+#~ msgstr "Nume fișier"
+
+#~ msgid "Title:"
+#~ msgstr "Titlu:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Vă rog specificaţi un titlu pentru a continua."
+
+#~ msgid "No title given"
+#~ msgstr "Titlu necompletat"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Vă rog selectaţi un fişier din listă,\n"
+#~ "sau alegeţi cealaltă opţiune."
+
+#~ msgid "Size"
+#~ msgstr "Mărime"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Deschide fişierul selectat"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Adaugă fişierul selectat"
+
+#~ msgid "Add"
+#~ msgstr "Adaugă"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Redenumeşte fişierul selectat"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Elimină şi şterge"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Elimină fişierul/directorul selectat şi şterge-l de pe disc"
+
+#~ msgid "Rename"
+#~ msgstr "Redenumește"
+
+#~ msgid "Open"
+#~ msgstr "Deschide"
+
+#~ msgid "Remove"
+#~ msgstr "Elimină"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Şterge fişierul selectat"
+
+#~ msgid "Revert"
+#~ msgstr "Revert"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Anulează modificări"
+
+#~ msgid "Annotate"
+#~ msgstr "Adnotează"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Adnotează fişierul selectat"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Adaugă locaţia curentă la favorite"
+
+#~ msgid "Edit"
+#~ msgstr "Editează"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Editează locaţia favorită selectată"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Salvează modificări"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Afişează diff pentru fişier"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Afişează conţinutul fişierului în viewer-ul inclus"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Arată modificările pentru toate fişierele"
+
+#~ msgid "All..."
+#~ msgstr "Toate..."
+
+#~ msgid "Open Folder"
+#~ msgstr "Deschide folder"
+
+#~ msgid "Show differences"
+#~ msgstr "Afişează diferenţe"
+
+#~ msgid "Selected..."
+#~ msgstr "Selectat..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Afişează modificările fişierului selectat"
+
+#~ msgid "View contents"
+#~ msgstr "Afişează conţinut"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Şterge favoritul selectat"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Restaurează la această revizie"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Directorul curent a fost adăugat la favorite. Îl puteţi accesa\n"
+#~ "selectându-l de pe panoul din stânga"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Locaţie favorită adăugată cu succes"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Directorul curent este deja prezent în favorite.\n"
+#~ "Verificaţi panoul din stânga."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Locaţie deja prezentă în favorite"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Vă rog specificaţi un nume pentru noul director"
+
+#~ msgid "No directory name given"
+#~ msgstr "Nume director necompletat"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Restaurează fişierul selectat conform reviziei selectate"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Şterg directorul şi toate directoarele din el?"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Afişează diferenţele dintre două revizii ale fişierului"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Toate fişierele cu starea 'adăugat'"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Nu am găsit fişiere proaspăt adăugate în working tree."
+
+#~ msgid "No matching files"
+#~ msgstr "Nu am găsit fişierele"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Nu e în acelaşi branch"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Vă rog selectaţi un fişier din listă pentru continuare."
+
+#~ msgid "Directory already exists"
+#~ msgstr "Directorul există deja"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Vă rog specificaţi alt nume pentru continuare."
+
+#~ msgid "Selected only"
+#~ msgstr "Doar cele selectate"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "Destinaţia nu este în acelaşi branch."
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Ce fişier(e) doriţi să ştergeţi?"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Redenumeşte..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Mută..."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Vă rog specificaţi un nume nou pentru fişier."
+
+#~ msgid "Filename not given"
+#~ msgstr "Nume fişier necompletat"
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI pentru Bazaar"
+
+#~ msgid "_Remove"
+#~ msgstr "Ște_rge"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Creează _director..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Şterge fişier(e)..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Adaugă fişier(e)..."
+
+#~ msgid "_File"
+#~ msgstr "_Fişier"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Reîncarcă"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Afişează fişierele asc_unse"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Iniţializează..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Adnotează"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Elimină toate modificările (revert)"
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferenţe..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Merge..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Revizii lipsă"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_g-uri..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flicte..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistici"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tare..."
+
+#~ msgid "_Information..."
+#~ msgstr "_Informaţii..."
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Mod _istorie"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Ce fişier(e) doriţi să adăugaţi?"
+
+#~ msgid "_Help"
+#~ msgstr "Ajutor"
+
+#~ msgid "_Add"
+#~ msgstr "_Adaugă"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Adaugă fişier(e)"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Toate fişerele necunoscute, recursiv"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Creează director"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Director c_unoscut"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Mută"
+
+#~ msgid "Move to"
+#~ msgstr "Mută în"
+
+#~ msgid "Rename to"
+#~ msgstr "Redenumeşte în"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Redenumeşte"
+
+#~ msgid "_Move"
+#~ msgstr "_Mută"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selectaţi un director"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Creează director"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Elimină fişier(e)"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Rădăcină checkout: "
+
+#~ msgid "(none)"
+#~ msgstr "(nimic)"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Checkout repository: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Rădăcină branch: "
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Informaţii"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout al branch-ului: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Branch repository: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Rădăcină checkout lightweight: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Redenumește"
+
+#~ msgid "Shared repository: "
+#~ msgstr "Repository partajat: "
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publică în branch-ul: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Branch părinte: "
+
+#~ msgid "Control format: "
+#~ msgstr "Format control: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Format working tree: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Branch-uri înrudite:</b>"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Locație:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Stare lock repository: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Format repository: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format branch: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Fişiere redenumite: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Fişiere necunoscute: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Fişiere ignorate: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revizii lipsă:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Stare lock:</b>"
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Stare lock branch: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Revizii lipsă în working tree: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Stare lock working tree: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Revizii lipsă în branch: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revizii în branch: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Fişiere nemodificate: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Fişiere modificate: "
+
+#~ msgid "Added files: "
+#~ msgstr "Fişiere adăugate: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Fişiere eliminate: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>În working tree:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Data ultimei revizii: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Data primei revizii: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Vârsta branch-ului în zile: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Număr autori: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Merge - Olive"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Istorie branch:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Stocare revizii:</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "Dimensiune repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revizii în repository: "
+
+#~ msgid "Merge from:"
+#~ msgstr "Sursa merge:"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Deschide director favorite în Nautilus"
+
+#~ msgid "_Get..."
+#~ msgstr "Creează _branch local"
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Subdosare versionate: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Adi Roiban https://launchpad.net/~adiroiban\n"
+#~ "  Sabin Iacob https://launchpad.net/~iacobs"

=== modified file 'po/ru.po'
--- po/ru.po	2008-03-11 17:01:27 +0000
+++ po/ru.po	2011-03-08 04:41:48 +0000
@@ -7,367 +7,496 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2007-06-17 20:24+0000\n"
-"Last-Translator: Pavel A. Bragin <balintrue@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-02-18 06:41+0000\n"
+"Last-Translator: Sergey Basalaev <SBasalaev@gmail.com>\n"
 "Language-Team: Russian <ru@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
-msgstr "Ветка"
-
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Выберите папку"
-
-#: branch.py:57 checkout.py:55
+msgstr "В_етка"
+
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
-msgstr "Дислокация ветки:"
+msgstr "Расположение ветки:"
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Назначение:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
-msgstr ""
+msgstr "Условное обозначение ветки:"
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
-msgstr ""
-
-#: branch.py:162 checkout.py:163
+msgstr "Версия:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Выберите папку"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr ""
+msgstr "Отсутствует расположение ветки"
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr ""
+msgstr "Вы должны указать расположение ветви"
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
-msgstr ""
+msgstr "Ветвь успешно создана"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
-msgstr ""
+msgstr "%d версия ветки"
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
-msgstr ""
+msgstr "Н/Д"
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
+msgstr "_Проверка"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
-msgstr ""
+msgstr "_Облегченная проверка"
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr ""
+msgstr "У каталога нет рабочего дерева"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
-msgstr ""
-
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-#, fuzzy
-msgid "Directory is not a branch"
-msgstr "Каталог не является ветвью"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-#, fuzzy
-msgid "You can perform this action only in a branch."
-msgstr "Вы можете применить это действи етолько к ветви."
-
-#: commit.py:88
+msgstr "Операция прервана."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "Есть локальные изменения в ветви"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "Пожалуйста закрепите или откатите изменения перед обьединением."
+
+#: ../commit.py:182
+msgid "added"
+msgstr "добавлен"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "удален"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "переименован"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "переименован и изменен"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "изменён"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "_Публиковать только локально?"
+
+#: ../commit.py:364
 msgid "Comm_it"
-msgstr ""
-
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
+msgstr "О_публиковать"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
-msgstr "Зафиксировать"
+msgstr "Публиковать"
 
-#: commit.py:325 conflicts.py:108
-#, fuzzy
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Путь"
 
-#: commit.py:327 conflicts.py:110
-#, fuzzy
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Тип"
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr ""
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-#, fuzzy
-msgid "removed"
-msgstr "удален"
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-#, fuzzy
-msgid "renamed"
-msgstr "переименован"
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr ""
-
-#: commit.py:395
-#, fuzzy
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr "Дата"
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
-msgstr ""
+msgstr "Опубликовал"
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
-msgstr ""
-
-#: conflicts.py:48
+msgstr "Сводка"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Публиковать с пустым сообщением?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "Вы можете описать вашу публикацию в сообщении"
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr "Публиковать с неизвестными?"
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr "Неизвестные файлы в рабочем дереве. Продолжить публикацию?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "Публиковать без внесения изменений?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr ""
+msgstr "Внешняя утилита:"
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
-msgstr ""
+msgstr "Конфликты"
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
-msgstr ""
+msgstr "В рабочем дереве конфликтов нет."
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
-msgstr ""
+msgstr "конфликт путей"
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
-msgstr ""
+msgstr "конфликт содержания"
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
-msgstr ""
+msgstr "текстовый конфликт"
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
-msgstr ""
+msgstr "совпадающий id"
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
-msgstr ""
+msgstr "дубликат"
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
-msgstr ""
+msgstr "начальный контур"
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
-msgstr ""
+msgstr "вне версионный предок"
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
-msgstr ""
+msgstr "отсутствует предок"
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
-msgstr ""
+msgstr "удален предок"
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
-msgstr ""
+msgstr "неизвестный тип конфликта"
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
-#, fuzzy
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Файл не был выбран"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
-msgstr ""
+msgstr "Пожалуйста, выберите файл из списка."
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
-msgstr ""
+msgstr "Вызов внешнего приложения неудачен"
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
-msgstr ""
+msgstr "Невозможно разрешить конфликт"
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
-
-#: errors.py:29
+"В настоящее время, при помощи Olive можно разрешить только конфликты текста "
+"в файлах. Конфликты содержимого, структуры дерева должны разрешаться "
+"используя командную строку."
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Просмотр"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Объединение прошло успешно"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Все изменения применены успешно ."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "Обнаружены конфликты"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "Пожалуйста, разрешите конфликты вручную перед публикацией."
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Каталог не является ветвью"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "Вы можете применить это действие только к ветви."
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
-msgstr ""
+msgstr "Каталог не проверен"
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
-msgstr ""
+msgstr "Вы можете выполнить локальную публикацию только после проверки."
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
-msgstr ""
+msgstr "Нет изменений для публикации"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
-msgstr ""
-
-#: errors.py:35
-#, fuzzy
+msgstr "Попытаться опубликовать если вы хотите опубликовать в любом случае."
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Конфликты в дереве"
 
-#: errors.py:36
-#, fuzzy
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
-msgstr "Вам необходимо устранить все конфликты перед фиксацией."
+msgstr "Вам необходимо устранить все конфликты перед публикацией."
 
-#: errors.py:38
-#, fuzzy
+#: ../errors.py:43
 msgid "Strict commit failed"
-msgstr "Ошибка точной фиксации"
+msgstr "Ошибка точной публикации"
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
+"В рабочем дереве содержаться неизвестные файлы.\n"
+"Пожалуйста добавьте или удалите их."
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
-msgstr ""
+msgstr "Связанная ветвь устарела"
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
-msgstr ""
+msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
-msgstr ""
+msgstr "Файл без версии"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
-msgstr ""
+msgstr "Выбранный файл без версии"
 
-#: errors.py:47 push.py:105
-#, fuzzy
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Ветви не совпадают"
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
+"Вы не можете передать если ветви расходятся. Используйте\n"
+"опцию перезаписи если вы ходите передать в любом случае."
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
-msgstr ""
+msgstr "Нет результатов сравнения"
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
-msgstr ""
+msgstr "Выбранный файл не изменился."
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
-msgstr ""
+msgstr "Нет такой ревизии"
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
-msgstr ""
+msgstr "Указанная вами ревизия не существует"
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
-msgstr ""
+msgstr "Цель уже существует."
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
+"Указанный каталог уже существует. Пожалуйста, укажите другое значение."
 
-#: errors.py:59
-#, fuzzy
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Каталог уже является ветвью"
 
-#: errors.py:60
-#, fuzzy, python-format
+#: ../errors.py:66
+#, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 "Текущий каталог (%s) уже является ветвью.\n"
-"Вы не можете использовать его, или инициализировать другой каталог."
+"Используйте его  или инициализируйте другой каталог."
 
-#: errors.py:62
-#, fuzzy
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Ветвь находится вне рабочего дерева"
 
-#: errors.py:63
-#, fuzzy, python-format
+#: ../errors.py:69
+#, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
@@ -375,995 +504,787 @@
 "Текущий каталог (%s)\n"
 "является ветвью вне рабочего дерева."
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
-msgstr ""
+msgstr "Неизвестная ошибка bzr"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
-msgstr ""
+msgstr "В доступе отказано"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
-msgstr ""
+msgstr "доступ запрещен."
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
-msgstr ""
+msgstr "Неизвестная ошибка"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
-msgstr "Инициализировать"
+msgstr "_Инициализировать"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
-msgstr ""
+msgstr "Какой каталог вы хотите инициализировать?"
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
-msgstr ""
+msgstr "Текущий каталог"
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
-msgstr ""
+msgstr "Создайте новый каталог с именем:"
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
-msgstr ""
+msgstr "Не указано имя каталога"
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
-msgstr ""
-
-#: merge.py:66
+msgstr "вы должны указать имя нового каталога."
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Объединить"
+
+#: ../merge.py:132
 msgid "Branch not given"
-msgstr ""
+msgstr "Ветвь не выбрана"
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
-msgstr ""
+msgstr "Пожалуйста, укажите ветку для объединения"
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
-msgstr ""
-
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+msgstr "Ошибка комманды Bazaar"
+
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
-msgstr ""
+msgstr "Местоположение:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
-msgstr ""
-
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+msgstr "_Разместить"
+
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
+"Вы не можете передать если ветви расходятся.\n"
+"Перезаписать?"
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
-msgstr ""
+msgstr "Успешное размещение"
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
-msgstr ""
+msgstr "%d ревизия(и) передана(ы)."
 
-#: push.py:146
-#, fuzzy
+#: ../push.py:142
 msgid "Non existing parent directory"
-msgstr "Несуществующий родительский каталог"
+msgstr "Отсутствует родительский каталог"
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
-
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+"Родительский каталог (%s)\n"
+"не существует. Создать?"
+
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
-msgstr ""
-
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+msgstr "В_ыделить"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
-msgstr ""
+msgstr "Добавлено"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
-msgstr ""
+msgstr "Удалено"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
-msgstr ""
+msgstr "Переименовано"
 
-#: status.py:97
-#, fuzzy
+#: ../status.py:113
 msgid "Modified"
 msgstr "Изменено"
 
-#: status.py:105
-#, fuzzy
+#: ../status.py:121
 msgid "Unknown"
-msgstr "Неизвестно"
+msgstr "Неизвестный"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
-msgstr ""
+msgstr "Без изменений."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
-msgstr ""
+msgstr "Метки"
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
-msgstr ""
+msgstr "Название метки"
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
-msgstr ""
+msgstr "Идентификатор ревизии"
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
-msgstr ""
+msgstr "Метки не поддерживаются текущим форматом ветви. Пожалуйста обновите."
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
-msgstr ""
+msgstr "Нет помеченной ревизии в ветви."
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
-msgstr ""
+msgstr "_Удалить метку"
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
-msgstr ""
+msgstr "<b><big>Удалить метку?</big></b>"
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
-msgstr ""
+msgstr "Вы уверены, что хотите удалить метку: <b>%s</b>?"
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
-msgstr ""
+msgstr "_Добавить метку"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
-msgstr ""
+msgstr "Название метки:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
-msgstr ""
+msgstr "Идентификатор ревизии:"
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
-msgstr ""
+msgstr "Не указано название метки"
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
-msgstr ""
-
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-#, fuzzy
-msgid "Local branch up to date"
-msgstr "Локальная ветьвь обновлена"
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-#, fuzzy
-msgid "Bookmarks"
-msgstr "Закладки"
-
-#: __init__.py:842 menu.py:99
-#, fuzzy
-msgid "Bookmark"
-msgstr "Закладка"
-
-#: __init__.py:944 __init__.py:1231
-#, fuzzy
-msgid "unchanged"
-msgstr "неизмененный"
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr "неизвестный"
-
-#: __init__.py:964
-#, fuzzy
-msgid "Filename"
-msgstr "Имя файла"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "Состояние"
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-#, fuzzy
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-"Пожалуйста, выберите файл из этого списка,\n"
-"или выберите другие опции."
-
-#: bookmark.py:46
-#, fuzzy
-msgid "Title:"
-msgstr "Заголовок:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-#, fuzzy
-msgid "Please specify a title to continue."
-msgstr "Для продолжения укажите, пожалуйста, название."
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-#, fuzzy
-msgid "Add"
-msgstr "Добавить"
-
-#: menu.py:64
-#, fuzzy
-msgid "Add the selected file"
-msgstr "Добавить выбранный файл"
-
-#: menu.py:67 menu.py:107
-#, fuzzy
-msgid "Remove"
-msgstr "Удалить"
-
-#: menu.py:68
-#, fuzzy
-msgid "Remove the selected file"
-msgstr "Удалить выбранный файл"
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-#, fuzzy
-msgid "Commit the changes"
-msgstr "Фиксировать изменения"
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Различия"
-
-#: menu.py:96
-#, fuzzy
-msgid "Show the diff of the file"
-msgstr "Показать изменения в этом файле"
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-#, fuzzy
-msgid "Edit"
-msgstr "Редактировать"
-
-#: menu.py:104
-#, fuzzy
-msgid "Edit the selected bookmark"
-msgstr "Редактировать выбранную закладку"
-
-#: menu.py:108
-#, fuzzy
-msgid "Remove the selected bookmark"
-msgstr "Удалить выбранную закладку"
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-#, fuzzy
-msgid "Selected..."
-msgstr "Выбрать..."
-
-#: menu.py:116
-#, fuzzy
-msgid "Show the differences of the selected file"
-msgstr "Показать изменения в выбранном файле"
-
-#: menu.py:119
-#, fuzzy
-msgid "All..."
-msgstr "Все..."
-
-#: menu.py:120
-#, fuzzy
-msgid "Show the differences of all files"
-msgstr "Показать изменения во всех файлах"
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-#, fuzzy
-msgid "Bookmark successfully added"
-msgstr "Закладка успешно добавлена"
-
-#: menu.py:316
-#, fuzzy
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-"Текущий каталог добавлен в закладки. Вы можете\n"
-"выбрать его на левой панели."
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-#, fuzzy
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-"Текущий каталог уже добавлен в закладки.\n"
-"Смотрите ссылку в левой панели."
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-#, fuzzy
-msgid "Please specify a desired name for the new directory."
-msgstr "Укажите имя нового каталога."
-
-#: mkdir.py:79 mkdir.py:89
-#, fuzzy
-msgid "Directory already exists"
-msgstr "Каталог уже существует"
-
-#: mkdir.py:80 mkdir.py:90
-#, fuzzy
-msgid "Please specify another name to continue."
-msgstr "Выберите другое имя."
-
-#: move.py:80 rename.py:71
-#, fuzzy
-msgid "Please select a file from the list to proceed."
-msgstr "ДЛя продолжения выберите файл из списка."
-
-#: move.py:89 rename.py:87
-#, fuzzy
-msgid "Not the same branch"
-msgstr "Это другая ветвь"
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-#, fuzzy
-msgid "No matching files"
-msgstr "Нет подходящих файлов"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "Какие файлы вы хотите удалить?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Только отмеченные"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr "Все файлы со статусом \"добавлен\""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "Удалить"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-#, fuzzy
-msgid "Please specify a new name for the file."
-msgstr "Выберите новое имя для этого файла."
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:21
-msgid "_File"
-msgstr ""
-
-#: olive.glade:28
-#, fuzzy
-msgid "_Add file(s)..."
-msgstr "Добавить файл(ы)..."
-
-#: olive.glade:43
-#, fuzzy
-msgid "Remove file(s)..."
-msgstr "Удалить файл(ы)..."
-
-#: olive.glade:63
-#, fuzzy
-msgid "Make _directory..."
-msgstr "Создать каталог..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Переименовать..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Переместить..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr ""
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Показывать скрытые файлы"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "Обновить"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-#, fuzzy
-msgid "_Get..."
-msgstr "Получить..."
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr "Зафиксировать"
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "Статус"
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "Статистика"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "Различия..."
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "Журнал..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "Справка"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Alexander Belchenko https://launchpad.net/~bialix\n"
-"  Pavel A. Bragin https://launchpad.net/~balintrue"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Добавить файл(ы)"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Какие файлы вы хотите добавить?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr "Все неизвестные рекурсивно"
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "Добавить"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Удалить файл(ы)"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - Создать каталог"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "Создать каталог"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Переместить"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Переместить в"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Выберите директорию"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "Переместить"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Переименовать"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-#, fuzzy
-msgid "Branch root: "
-msgstr "Корень ветви: "
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-#, fuzzy
-msgid "Repository branch: "
-msgstr "Ветвь репозитория: "
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520
-#, fuzzy
-msgid "Parent branch: "
-msgstr "Родительская ветвь: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-#, fuzzy
-msgid "Repository format: "
-msgstr "Тип репозитория: "
-
-#: olive.glade:1626
-#, fuzzy
-msgid "Branch format: "
-msgstr "Тип ветви: "
-
-#: olive.glade:1638
-#, fuzzy
-msgid "Working tree format: "
-msgstr "Тип рабоего дерева: "
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-#, fuzzy
-msgid "Repository lock status: "
-msgstr "Состояние блокировки репозитория: "
-
-#: olive.glade:1743
-#, fuzzy
-msgid "Branch lock status: "
-msgstr "Состояние блокировки ветви: "
-
-#: olive.glade:1755
-#, fuzzy
-msgid "Working tree lock status: "
-msgstr "Состояние блокировки рабочего дерева: "
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "Игнорируемые файлы: "
-
-#: olive.glade:2005
-#, fuzzy
-msgid "Unknown files: "
-msgstr "Неизвестные файлы: "
-
-#: olive.glade:2017
-#, fuzzy
-msgid "Renamed files: "
-msgstr "Переименованные файлы: "
-
-#: olive.glade:2029
-#, fuzzy
-msgid "Removed files: "
-msgstr "Удаленные файлы: "
-
-#: olive.glade:2041
-#, fuzzy
-msgid "Added files: "
-msgstr "Добавленные файлы: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Измененные файлы: "
-
-#: olive.glade:2065
-#, fuzzy
-msgid "Unchanged files: "
-msgstr "Неизмененные файлы: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:2196
-#, fuzzy
-msgid "Age of branch in days: "
-msgstr "Возраст ветви в днях: "
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-#, fuzzy
-msgid "Size of repository: "
-msgstr "Размер репозитория: "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+msgstr "Вы должны указать желаемое имя метки."
+
+#~ msgid "_Rename..."
+#~ msgstr "_Переименовать..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Переместить..."
+
+#~ msgid "_Refresh"
+#~ msgstr "Обновить"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Показывать скрытые файлы"
+
+#~ msgid "_Commit..."
+#~ msgstr "Зафиксировать"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Статус"
+
+#~ msgid "_Log..."
+#~ msgstr "Журнал..."
+
+#~ msgid "_Differences..."
+#~ msgstr "Различия..."
+
+#~ msgid "_Statistics"
+#~ msgstr "Статистика"
+
+#~ msgid "_Help"
+#~ msgstr "Справка"
+
+#~ msgid "Diff"
+#~ msgstr "Различия"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Какие файлы вы хотите добавить?"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Добавить файл(ы)"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Все файлы со статусом \"добавлен\""
+
+#~ msgid "_Remove"
+#~ msgstr "Удалить"
+
+#~ msgid "Selected only"
+#~ msgstr "Только отмеченные"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Удалить файл(ы)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Какие файлы вы хотите удалить?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Все неизвестные рекурсивно"
+
+#~ msgid "_Add"
+#~ msgstr "Добавить"
+
+#~ msgid "_Make directory"
+#~ msgstr "Создать каталог"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Переместить"
+
+#~ msgid "Move to"
+#~ msgstr "Переместить в"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Создать каталог"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Переименовать"
+
+#~ msgid "_Move"
+#~ msgstr "Переместить"
+
+#~ msgid "Select a directory"
+#~ msgstr "Выберите директорию"
+
+#~ msgid "Branch root: "
+#~ msgstr "Корень ветви: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Ветвь репозитория: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Родительская ветвь: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Тип рабоего дерева: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Тип репозитория: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Тип ветви: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Неизмененные файлы: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Измененные файлы: "
+
+#~ msgid "Added files: "
+#~ msgstr "Добавленные файлы: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Состояние блокировки репозитория: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Состояние блокировки ветви: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Состояние блокировки рабочего дерева: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Переименованные файлы: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Неизвестные файлы: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Игнорируемые файлы: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Возраст ветви в днях: "
+
+#~ msgid "Title:"
+#~ msgstr "Заголовок:"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Пожалуйста, выберите файл из этого списка,\n"
+#~ "или выберите другие опции."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Размер репозитория: "
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Локальная ветьвь обновлена"
+
+#~ msgid "Bookmark"
+#~ msgstr "Закладка"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Закладки"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Добавить выбранный файл"
+
+#~ msgid "Add"
+#~ msgstr "Добавить"
+
+#~ msgid "Status"
+#~ msgstr "Состояние"
+
+#~ msgid "Filename"
+#~ msgstr "Имя файла"
+
+#~ msgid "unknown"
+#~ msgstr "неизвестный"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Показать изменения во всех файлах"
+
+#~ msgid "All..."
+#~ msgstr "Все..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Показать изменения в выбранном файле"
+
+#~ msgid "Edit"
+#~ msgstr "Редактировать"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Редактировать выбранную закладку"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Текущий каталог добавлен в закладки. Вы можете\n"
+#~ "выбрать его на левой панели."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Закладка успешно добавлена"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Текущий каталог уже добавлен в закладки.\n"
+#~ "Смотрите ссылку в левой панели."
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Укажите имя нового каталога."
+
+#~ msgid "Directory already exists"
+#~ msgstr "Каталог уже существует"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Выберите другое имя."
+
+#~ msgid "Not the same branch"
+#~ msgstr "Это другая ветвь"
+
+#~ msgid "No matching files"
+#~ msgstr "Нет подходящих файлов"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Выберите новое имя для этого файла."
+
+#~ msgid "Time"
+#~ msgstr "Время"
+
+#~ msgid "ignored"
+#~ msgstr "игнорируется"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Переименовать выбранный файл"
+
+#~ msgid "Last modified"
+#~ msgstr "Последняя модификация"
+
+#~ msgid "Size"
+#~ msgstr "Размер"
+
+#~ msgid "Rename"
+#~ msgstr "Переименовать"
+
+#~ msgid "Open"
+#~ msgstr "Открыть"
+
+#~ msgid "Revert"
+#~ msgstr "Восстановить"
+
+#~ msgid "Open Folder"
+#~ msgstr "Открыть папку"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Открыть выбранный файл"
+
+#~ msgid "No directory name given"
+#~ msgstr "Не указано название папки"
+
+#~ msgid "Show differences"
+#~ msgstr "Показать изменения"
+
+#~ msgid "_Merge..."
+#~ msgstr "_Объединить..."
+
+#~ msgid "_File"
+#~ msgstr "_Файл"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "_Метки..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "_Конфликты..."
+
+#~ msgid "_Rename"
+#~ msgstr "_Переименовать"
+
+#~ msgid "Rename to"
+#~ msgstr "Переименовать в"
+
+#~ msgid "_Information..."
+#~ msgstr "_Информация..."
+
+#~ msgid "(none)"
+#~ msgstr "(нет)"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Местоположение:</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Формат:</b>"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Отсутствуют изменения в рабочем дереве."
+
+#~ msgid "Set default push location"
+#~ msgstr "Указать место размещения по-умолчанию"
+
+#~ msgid "Revno"
+#~ msgstr "Рев.№"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Место размещения по-умолчанию не установлено.\n"
+#~ "Установить %r по-умолчанию?"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Файл(ы) для публикации"
+
+#~ msgid "Commit message:"
+#~ msgstr "Сообщение публикации:"
+
+#~ msgid "Pending merges"
+#~ msgstr "Ожидающие слияния"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Пожалуйста подождите, версии загружаются..."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Обнаружены конфликты"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Откзаться от изменений"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Добавить текущее положение в закладки"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Опубликовать изменения"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Открыть папку с закладками в Наутилусе"
+
+#~ msgid "View contents"
+#~ msgstr "Просмотреть содержимое"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Вернуться к этой версии"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Местоположение уже есть в закладках"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Вернуться к указанной версии выделенного файла"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Удалить каталог и все его подкаталоги?"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Не найдены добавленные файлы в рабочем дереве"
+
+#~ msgid "Filename not given"
+#~ msgstr "Не указано имя файла"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Статус блокировки:</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>В рабочем дереве:</b>"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Местонахождение предка неизвестно"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Нельзя определить отсутствующие ревизии если местоположение предка не "
+#~ "известно."
+
+#~ msgid "Pull successful"
+#~ msgstr "Получение выполненно"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d ревизия(й) получена(о)."
+
+#~ msgid "Revert successful"
+#~ msgstr "Откат выполнен"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Все файлы возвращены к последней ревизии."
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Получить не возможно пока здесь расположен предок."
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Открываемый файл не наден."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Файл описания идентификатора пользователя не найден."
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Пожалуйста укажите заголовок для продолжения."
+
+#~ msgid "No title given"
+#~ msgstr "Заголовок не указан"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Убрать выбранный файл/каталог и удалить с диска."
+
+#~ msgid "Remove and delete"
+#~ msgstr "Убрать и удалить"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Просмотреть содержимое файла во встроенном просмоторщике"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Для продолжения выберите файл из списка."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Создать _каталог..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Добавить файл(ы)..."
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "Место назначения в другой ветви."
+
+#~ msgid "_Get..."
+#~ msgstr "_Забрать"
+
+#~ msgid "C_heckout..."
+#~ msgstr "_Проверить..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Пол_учить"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Режим и_стории"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Инициализация"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "О_ткатить все изменения"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Отсутствующие _ревизии"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Проверяемый корень: "
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Отслеживаемые _каталоги"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Проверка репозитория: "
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Информация"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Проверка ветви: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Доступный репозитоий: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Облегченная проверка корня: "
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Пкбликуемая ветвь: "
+
+#~ msgid "Control format: "
+#~ msgstr "Формат контроля: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Связанные ветви:</b>"
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Отслеживаемые подкаталолги: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Ревизий в ветви: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>История ветви:</b>"
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Колличество публикаций: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Ревизий в репозитории: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Merge - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Обьеденить из:"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Есть отсутствующие ревизии"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d ревизия(-ий) отсутствует(-ют)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Нет отсутсвующих ревизий."
+
+#~ msgid "unchanged"
+#~ msgstr "неизменённый"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Пожалуйста укажите рабочее дерево перед продолжением."
+
+#~ msgid "Remove"
+#~ msgstr "Убрать"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Добавить аннотацию к выбранному файлу"
+
+#~ msgid "Annotate"
+#~ msgstr "Аннотация"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Убрать выбранный файл"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Показать изменения в файле"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Показать изменения между двумя ревизиями файла"
+
+#~ msgid "Selected..."
+#~ msgstr "Выбранное..."
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Убрать выбранную закладку"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Убрать файл(ы)..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Аннотация..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "П_ередать..."
+
+#~ msgid "Removed files: "
+#~ msgstr "Убранные файлы: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Отсутсвующие ревизии:</b>"
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Отсутсвующие ревизии в рабочем дереве: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Отсутсвующие ревизии в ветке: "
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Время последней ревизии: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Время первой ревизии: "
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Ревизий хранится:</b>"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Alexander Belchenko https://launchpad.net/~bialix\n"
+#~ "  Mikhail Pitertsev https://launchpad.net/~platiferro\n"
+#~ "  Oleg Koptev https://launchpad.net/~koptev-oleg\n"
+#~ "  Pavel A. Bragin https://launchpad.net/~balintrue\n"
+#~ "  Petr E. Antonov https://launchpad.net/~antpeter\n"
+#~ "  Rail Aliev https://launchpad.net/~rail\n"
+#~ "  Sergey Basalaev https://launchpad.net/~sbasalaev\n"
+#~ "  Sergey Sedov https://launchpad.net/~serg-sedov\n"
+#~ "  XPEH https://launchpad.net/~akidyarov"

=== modified file 'po/sr.po'
--- po/sr.po	2008-03-11 17:01:27 +0000
+++ po/sr.po	2011-03-08 04:41:48 +0000
@@ -7,1282 +7,697 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2008-01-18 15:46+0000\n"
-"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-12-11 18:52+0000\n"
+"Last-Translator: Данило Шеган <Unknown>\n"
 "Language-Team: Serbian <sr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
-msgstr ""
-
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr ""
-
-#: branch.py:57 checkout.py:55
+msgstr "_Грана"
+
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: branch.py:162 checkout.py:163
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr ""
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr ""
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: commit.py:88
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr ""
+
+#: ../commit.py:183
+msgid "removed"
+msgstr ""
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr ""
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: commit.py:325 conflicts.py:108
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: commit.py:327 conflicts.py:110
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
-msgid "added"
-msgstr ""
-
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
-msgid "removed"
-msgstr ""
-
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
-msgid "renamed"
-msgstr ""
-
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
-msgid "modified"
-msgstr ""
-
-#: commit.py:395
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr ""
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr ""
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr ""
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr ""
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr ""
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr ""
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:964
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:965
-msgid "Status"
-msgstr ""
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr ""
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr ""
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr ""
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr ""
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:103
-msgid "Edit"
-msgstr ""
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr ""
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr ""
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr ""
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:21
-msgid "_File"
-msgstr ""
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr ""
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr ""
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr ""
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr ""
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr ""
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr ""
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  bilbija https://launchpad.net/~bilbija\n"
+#~ "  Данило Шеган https://launchpad.net/~danilo"

=== modified file 'po/sv.po'
--- po/sv.po	2008-03-11 17:01:27 +0000
+++ po/sv.po	2011-03-08 04:41:48 +0000
@@ -7,1285 +7,979 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
-"PO-Revision-Date: 2007-12-21 21:00+0000\n"
-"Last-Translator: Zirro <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:27+0000\n"
+"Last-Translator: Daniel Nylander <yeager@ubuntu.com>\n"
 "Language-Team: Swedish <sv@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2008-03-11 16:44+0000\n"
-"X-Generator: Launchpad (build Unknown)\n"
-
-#: branch.py:52 olive.glade:151
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Gren"
 
-#: branch.py:55 checkout.py:53
-msgid "Please select a folder"
-msgstr "Välj en mapp"
-
-#: branch.py:57 checkout.py:55
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: branch.py:58 checkout.py:56
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Mål:"
 
-#: branch.py:59 checkout.py:57
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: branch.py:60 checkout.py:58
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
-msgstr ""
-
-#: branch.py:162 checkout.py:163
+msgstr "Revision:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Välj en mapp"
+
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:205
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Grening lyckades"
 
-#: branch.py:206
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d revision(er) grenade."
 
-#: branch.py:214 checkout.py:195
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
-#: checkout.py:50
+#. Create the widgets
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr ""
+msgstr "Katalogen innehåller inte ett arbetsträd"
 
-#: commit.py:69
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Åtgärden avbruten."
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
-msgid "Directory is not a branch"
-msgstr "Katalogen är inte en gren"
-
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: commit.py:88
-msgid "Comm_it"
-msgstr ""
-
-#: commit.py:89
-msgid "File(s) to commit"
-msgstr ""
-
-#: commit.py:95
-msgid "Commit message:"
-msgstr ""
-
-#: commit.py:99
-msgid "Pending merges"
-msgstr ""
-
-#: commit.py:147
-msgid "_Only commit locally"
-msgstr ""
-
-#: commit.py:215
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: commit.py:216
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: commit.py:228
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: commit.py:229
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: commit.py:240
-msgid "Commit with no changes?"
-msgstr ""
-
-#: commit.py:241
-msgid "There are no changes in the working tree."
-msgstr ""
-
-#: commit.py:323 menu.py:87
-msgid "Commit"
-msgstr "Verkställ"
-
-#: commit.py:325 conflicts.py:108
-msgid "Path"
-msgstr "Sökväg"
-
-#: commit.py:327 conflicts.py:110
-msgid "Type"
-msgstr "Typ"
-
-#: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
 msgid "added"
 msgstr "lades till"
 
-#: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
+#: ../commit.py:183
 msgid "removed"
 msgstr "togs bort"
 
-#: commit.py:353
-msgid "renamed and modified"
-msgstr ""
-
-#: commit.py:355 __init__.py:936 __init__.py:1223
+#: ../commit.py:184
 msgid "renamed"
 msgstr "bytte namn"
 
-#: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
 msgid "modified"
 msgstr "ändrades"
 
-#: commit.py:395
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr ""
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Verkställ"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Sökväg"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Typ"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
 msgid "Date"
 msgstr "Datum"
 
-#: commit.py:397 revbrowser.py:68
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Verkställd av"
 
-#: commit.py:399 revbrowser.py:66
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Sammanfattning"
 
-#: conflicts.py:48
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: conflicts.py:99
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: conflicts.py:102
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: conflicts.py:115
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: conflicts.py:117
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: conflicts.py:119
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: conflicts.py:121
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: conflicts.py:125
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
-#: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Ingen fil valdes"
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: conflicts.py:173
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: conflicts.py:176
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Visa"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "Katalogen är inte en gren"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Inga ändringar att verkställa"
 
-#: errors.py:33
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Konflikter i träd"
 
-#: errors.py:36
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Strikt verkställning misslyckades"
 
-#: errors.py:39
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: errors.py:44
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Filen inte versionskontrollerad"
 
-#: errors.py:45
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Den valda filen har inte ändrats."
 
-#: errors.py:53
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "Revisionen du angav finns inte."
 
-#: errors.py:56
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Mål finns redan"
 
-#: errors.py:57
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: errors.py:59
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Katalogen är redan en gren"
 
-#: errors.py:60
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: errors.py:63
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Åtkomst nekas"
 
-#: errors.py:67
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: errors.py:69
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Okänt fel"
 
-#: initialize.py:47
+#. Create the widgets
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initiera"
 
-#: initialize.py:48
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
-#: initialize.py:50
+#: ../initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr ""
 
-#: initialize.py:85
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
-msgid "Merge successful"
-msgstr ""
-
-#: merge.py:82
-msgid "All changes applied successfully."
-msgstr ""
-
-#: merge.py:85
-msgid "Conflicts encountered"
-msgstr ""
-
-#: merge.py:86
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: push.py:52 bookmark.py:45
+#. Create the widgets
+#: ../push.py:51
 msgid "Location:"
 msgstr "Plats:"
 
-#: push.py:54
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Skjut ut"
 
-#: push.py:97
-msgid "Set default push location"
-msgstr ""
-
-#: push.py:98
-#, python-format
-msgid ""
-"There is no default push location set.\n"
-"Set %r as default now?"
-msgstr ""
-
-#: push.py:106
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: ../push.py:108
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
 
-#: revbrowser.py:45
-msgid "Please wait, revisions are being loaded..."
-msgstr ""
-
-#: revbrowser.py:48
+#. Create the widgets
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Markera"
 
-#: revbrowser.py:64
-msgid "Revno"
-msgstr ""
-
-#: revbrowser.py:70
-msgid "Time"
-msgstr "Tid"
-
-#: status.py:78
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
 msgid "Added"
 msgstr "Lades till"
 
-#: status.py:84
+#: ../status.py:100
 msgid "Removed"
 msgstr "Togs bort"
 
-#: status.py:90
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Bytte namn"
 
-#: status.py:97
+#: ../status.py:113
 msgid "Modified"
 msgstr "Ändrades"
 
-#: status.py:105
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Okänd"
 
-#: status.py:110
+#: ../status.py:126
 msgid "No changes."
 msgstr "Inga ändringar."
 
-#: tags.py:67
+#. Set properties
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: ../tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: ../tags.py:115
 msgid "Revision ID"
 msgstr ""
 
-#: tags.py:151
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#. Create the widgets
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Lägg till tagg"
 
-#: tags.py:291
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Taggnamn:"
 
-#: tags.py:292
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: __init__.py:513
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: __init__.py:525 __init__.py:550
-msgid "Parent location is unknown"
-msgstr ""
-
-#: __init__.py:526
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: __init__.py:537
-msgid "There are missing revisions"
-msgstr "Det finns saknade revisioner"
-
-#: __init__.py:538
-#, python-format
-msgid "%d revision(s) missing."
-msgstr "%d revision(er) saknas."
-
-#: __init__.py:540
-msgid "Local branch up to date"
-msgstr "Lokal gren uppdaterad"
-
-#: __init__.py:541
-msgid "There are no missing revisions."
-msgstr "Det finns inga saknade revisioner."
-
-#: __init__.py:551
-msgid "Pulling is not possible until there is a parent location."
-msgstr ""
-
-#: __init__.py:561
-msgid "Pull successful"
-msgstr ""
-
-#: __init__.py:561
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: __init__.py:575 menu.py:275
-msgid "Conflicts detected"
-msgstr ""
-
-#: __init__.py:576 menu.py:276
-msgid "Please have a look at the working tree before continuing."
-msgstr ""
-
-#: __init__.py:578 menu.py:278
-msgid "Revert successful"
-msgstr ""
-
-#: __init__.py:579 menu.py:279
-msgid "All files reverted to last revision."
-msgstr ""
-
-#: __init__.py:835 __init__.py:1117
-msgid "Bookmarks"
-msgstr "Bokmärken"
-
-#: __init__.py:842 menu.py:99
-msgid "Bookmark"
-msgstr "Bokmärke"
-
-#: __init__.py:944 __init__.py:1231
-msgid "unchanged"
-msgstr "oförändrad"
-
-#: __init__.py:946 __init__.py:1233
-msgid "ignored"
-msgstr ""
-
-#: __init__.py:948 __init__.py:1235
-msgid "unknown"
-msgstr "okänd"
-
-#: __init__.py:964
-msgid "Filename"
-msgstr "Filnamn"
-
-#: __init__.py:965
-msgid "Status"
-msgstr "Status"
-
-#: __init__.py:966
-msgid "Size"
-msgstr ""
-
-#: __init__.py:967
-msgid "Last modified"
-msgstr ""
-
-#: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: bookmark.py:46
-msgid "Title:"
-msgstr "Titel:"
-
-#: bookmark.py:81
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:82
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: guifiles.py:45
-msgid "Glade file cannot be found."
-msgstr "Glade-filen kunde inte hittas."
-
-#: guifiles.py:55
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:63
-msgid "Add"
-msgstr "Lägg till"
-
-#: menu.py:64
-msgid "Add the selected file"
-msgstr "Lägg till den markerade filen"
-
-#: menu.py:67 menu.py:107
-msgid "Remove"
-msgstr "Ta bort"
-
-#: menu.py:68
-msgid "Remove the selected file"
-msgstr "Ta bort den markerade filen"
-
-#: menu.py:71
-msgid "Remove and delete"
-msgstr ""
-
-#: menu.py:72
-msgid "Remove the selected file/dir and delete from disk"
-msgstr ""
-
-#: menu.py:75
-msgid "Rename"
-msgstr ""
-
-#: menu.py:76
-msgid "Rename the selected file"
-msgstr ""
-
-#: menu.py:79
-msgid "Open"
-msgstr ""
-
-#: menu.py:80
-msgid "Open the selected file"
-msgstr ""
-
-#: menu.py:83
-msgid "Revert"
-msgstr ""
-
-#: menu.py:84
-msgid "Revert the changes"
-msgstr ""
-
-#: menu.py:88
-msgid "Commit the changes"
-msgstr "Verkställ ändringarna"
-
-#: menu.py:91
-msgid "Annotate"
-msgstr ""
-
-#: menu.py:92
-msgid "Annotate the selected file"
-msgstr ""
-
-#: menu.py:95
-msgid "Diff"
-msgstr "Diff"
-
-#: menu.py:96
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:100
-msgid "Bookmark current location"
-msgstr "Bokmärk aktuell plats"
-
-#: menu.py:103
-msgid "Edit"
-msgstr "Redigera"
-
-#: menu.py:104
-msgid "Edit the selected bookmark"
-msgstr "Redigera det markerade bokmärket"
-
-#: menu.py:108
-msgid "Remove the selected bookmark"
-msgstr "Ta bort det markerade bokmärket"
-
-#: menu.py:111
-msgid "Open Folder"
-msgstr ""
-
-#: menu.py:112
-msgid "Open bookmark folder in Nautilus"
-msgstr ""
-
-#: menu.py:115
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:116
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:119
-msgid "All..."
-msgstr "Alla..."
-
-#: menu.py:120
-msgid "Show the differences of all files"
-msgstr "Visa skillnaderna för alla filer"
-
-#: menu.py:123
-msgid "View contents"
-msgstr ""
-
-#: menu.py:124
-msgid "View the contents of the file in a builtin viewer"
-msgstr ""
-
-#: menu.py:127
-msgid "Show differences"
-msgstr ""
-
-#: menu.py:128
-msgid "Show the differences between two revisions of the file"
-msgstr ""
-
-#: menu.py:131
-msgid "Revert to this revision"
-msgstr ""
-
-#: menu.py:132
-msgid "Revert the selected file to the selected revision"
-msgstr ""
-
-#: menu.py:228
-msgid "Delete directory with all directories below ?"
-msgstr ""
-
-#: menu.py:315
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:316
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:319
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:320
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr "Inget katalognamn angavs"
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:89
-msgid "Directory already exists"
-msgstr "Katalogen finns redan"
-
-#: mkdir.py:80 mkdir.py:90
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: move.py:80 rename.py:71
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:89 rename.py:87
-msgid "Not the same branch"
-msgstr "Inte i samma gren"
-
-#: move.py:90 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: remove.py:79 remove.py:139
-msgid "No matching files"
-msgstr "Inga filer matchades"
-
-#: remove.py:80 remove.py:140
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: remove.py:105 olive.glade:825
-msgid "Which file(s) do you want to remove?"
-msgstr "Vilka fil(er) vill du ta bort?"
-
-#: remove.py:106 olive.glade:717 olive.glade:837
-msgid "Selected only"
-msgstr "Endast markerade"
-
-#: remove.py:107 olive.glade:851
-msgid "All files with status 'added'"
-msgstr ""
-
-#: remove.py:108 olive.glade:905
-msgid "_Remove"
-msgstr "_Ta bort"
-
-#: rename.py:75
-msgid "Filename not given"
-msgstr "Filnamn angavs inte"
-
-#: rename.py:76
-msgid "Please specify a new name for the file."
-msgstr "Ange ett nytt namn för filen."
-
-#: olive.glade:8
-msgid "Olive - Bazaar GUI"
-msgstr "Olive - Användargränssnitt för Bazaar"
-
-#: olive.glade:21
-msgid "_File"
-msgstr "_Arkiv"
-
-#: olive.glade:28
-msgid "_Add file(s)..."
-msgstr "_Lägg till fil(er)..."
-
-#: olive.glade:43
-msgid "Remove file(s)..."
-msgstr "Ta bort fil(er)..."
-
-#: olive.glade:63
-msgid "Make _directory..."
-msgstr "Skapa _katalog..."
-
-#: olive.glade:76
-msgid "_Rename..."
-msgstr "_Byt namn..."
-
-#: olive.glade:84
-msgid "_Move..."
-msgstr "_Flytta..."
-
-#: olive.glade:92
-msgid "_Annotate..."
-msgstr ""
-
-#: olive.glade:118
-msgid "_View"
-msgstr "_Visa"
-
-#: olive.glade:126
-msgid "Show _hidden files"
-msgstr "Visa _dolda filer"
-
-#: olive.glade:139
-msgid "_Refresh"
-msgstr "_Uppdatera"
-
-#: olive.glade:158
-msgid "_Initialize..."
-msgstr ""
-
-#: olive.glade:166
-msgid "_Get..."
-msgstr "_Hämta..."
-
-#: olive.glade:174
-msgid "C_heckout..."
-msgstr "C_hecka ut..."
-
-#: olive.glade:187
-msgid "Pu_ll"
-msgstr "Dra _in"
-
-#: olive.glade:201
-msgid "Pu_sh..."
-msgstr "Skjut _ut..."
-
-#: olive.glade:220
-msgid "_Revert all changes"
-msgstr ""
-
-#: olive.glade:228
-msgid "_Merge..."
-msgstr ""
-
-#: olive.glade:236
-msgid "_Commit..."
-msgstr "_Verkställ..."
-
-#: olive.glade:255
-msgid "Ta_gs..."
-msgstr ""
-
-#: olive.glade:263
-msgid "S_tatus..."
-msgstr "S_tatus..."
-
-#: olive.glade:271
-msgid "Missing _revisions"
-msgstr ""
-
-#: olive.glade:279
-msgid "Con_flicts..."
-msgstr ""
-
-#: olive.glade:291
-msgid "_Statistics"
-msgstr "_Statistik"
-
-#: olive.glade:298
-msgid "_Differences..."
-msgstr "_Skillnader"
-
-#: olive.glade:312
-msgid "_Log..."
-msgstr "_Logg..."
-
-#: olive.glade:326
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:338
-msgid "_Help"
-msgstr "_Hjälp"
-
-#: olive.glade:548
-msgid "gtk-jump-to"
-msgstr ""
-
-#: olive.glade:575
-msgid "H_istory Mode"
-msgstr ""
-
-#: olive.glade:673
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-
-#: olive.glade:675
-msgid "https://launchpad.net/products/olive"
-msgstr "https://launchpad.net/products/olive"
-
-#: olive.glade:677
-msgid "translator-credits"
-msgstr ""
-"Launchpad Contributions:\n"
-"  Daniel Nylander https://launchpad.net/~yeager\n"
-"  Zirro https://launchpad.net/~magne-andersson"
-
-#: olive.glade:694
-msgid "Olive - Add file(s)"
-msgstr "Olive - Lägg till fil(er)"
-
-#: olive.glade:705
-msgid "Which file(s) do you want to add?"
-msgstr "Vilka fil(er) vill du lägga till?"
-
-#: olive.glade:731
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:785
-msgid "_Add"
-msgstr "_Lägg till"
-
-#: olive.glade:814
-msgid "Olive - Remove file(s)"
-msgstr "Olive - Ta bort fil(er)"
-
-#: olive.glade:934
-msgid "Olive - Make directory"
-msgstr "Olive - Skapa katalog"
-
-#: olive.glade:957
-msgid "_Versioned directory"
-msgstr "_Versionshanterad katalog"
-
-#: olive.glade:1011
-msgid "_Make directory"
-msgstr "_Skapa katalog"
-
-#: olive.glade:1041
-msgid "Olive - Move"
-msgstr "Olive - Flytta"
-
-#: olive.glade:1055
-msgid "Move to"
-msgstr "Flytta till"
-
-#: olive.glade:1066
-msgid "Select a directory"
-msgstr "Välj en katalog"
-
-#: olive.glade:1120
-msgid "_Move"
-msgstr "_Flytta"
-
-#: olive.glade:1148
-msgid "Olive - Rename"
-msgstr "Olive - Byt namn"
-
-#: olive.glade:1162
-msgid "Rename to"
-msgstr "Byt namn till"
-
-#: olive.glade:1227
-msgid "_Rename"
-msgstr "_Byt namn"
-
-#: olive.glade:1255
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:1279 olive.glade:1292 olive.glade:1305 olive.glade:1318
-#: olive.glade:1331 olive.glade:1344 olive.glade:1357 olive.glade:1484
-#: olive.glade:1495 olive.glade:1564 olive.glade:1575 olive.glade:1588
-#: olive.glade:1601 olive.glade:1694 olive.glade:1705 olive.glade:1718
-#: olive.glade:1799 olive.glade:1810 olive.glade:1879 olive.glade:1890
-#: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
-#: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
-#: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
-msgid "(none)"
-msgstr "(ingen)"
-
-#: olive.glade:1368
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:1380
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:1392
-msgid "Repository checkout: "
-msgstr "Förrådsutcheckning: "
-
-#: olive.glade:1404
-msgid "Checkout of branch: "
-msgstr "Checka ut gren: "
-
-#: olive.glade:1416
-msgid "Repository branch: "
-msgstr "Förrådsgren: "
-
-#: olive.glade:1428
-msgid "Shared repository: "
-msgstr "Delat förråd: "
-
-#: olive.glade:1440
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:1454
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Publish to branch: "
-msgstr "Publicera till gren: "
-
-#: olive.glade:1520
-msgid "Parent branch: "
-msgstr "Föräldergren: "
-
-#: olive.glade:1534
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:1614
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:1626
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:1638
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:1650
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:1664
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:1731
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:1743
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:1755
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:1769
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:1823
-msgid "Missing revisions in branch: "
-msgstr "Saknade revisioner i gren: "
-
-#: olive.glade:1835
-msgid "Missing revisions in working tree: "
-msgstr "Saknade revisioner i arbetsträd: "
-
-#: olive.glade:1849
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:1981
-msgid "Versioned subdirectories: "
-msgstr "Versionshanterade underkataloger: "
-
-#: olive.glade:1993
-msgid "Ignored files: "
-msgstr "Ignorerade filer: "
-
-#: olive.glade:2005
-msgid "Unknown files: "
-msgstr "Okända filer: "
-
-#: olive.glade:2017
-msgid "Renamed files: "
-msgstr "Filer som bytt namn: "
-
-#: olive.glade:2029
-msgid "Removed files: "
-msgstr "Borttagna filer: "
-
-#: olive.glade:2041
-msgid "Added files: "
-msgstr "Tillagda filer: "
-
-#: olive.glade:2053
-msgid "Modified files: "
-msgstr "Ändrade filer: "
-
-#: olive.glade:2065
-msgid "Unchanged files: "
-msgstr "Oförändrade filer: "
-
-#: olive.glade:2079
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:2172
-msgid "Time of last revision: "
-msgstr "Tid för sista revision: "
-
-#: olive.glade:2184
-msgid "Time of first revision: "
-msgstr "Tid för första revision: "
-
-#: olive.glade:2196
-msgid "Age of branch in days: "
-msgstr "Ålder för gren (i dagar): "
-
-#: olive.glade:2208
-msgid "Number of commiters: "
-msgstr "Antal insändare: "
-
-#: olive.glade:2220
-msgid "Revisions in branch: "
-msgstr "Revisioner i gren: "
-
-#: olive.glade:2234
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:2288
-msgid "Size of repository: "
-msgstr "Storlek på förråd: "
-
-#: olive.glade:2300
-msgid "Revisions in repository: "
-msgstr "Revisioner i förråd: "
-
-#: olive.glade:2314
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:2356
-msgid "Merge - Olive"
-msgstr ""
-
-#: olive.glade:2370
-msgid "Merge from:"
-msgstr ""
-
-#: olive.glade:2454
-msgid "_Merge"
-msgstr ""
+#~ msgid "_Rename..."
+#~ msgstr "_Byt namn..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Flytta..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Skapa _katalog..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Ta bort fil(er)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Användargränssnitt för Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Lägg till fil(er)..."
+
+#~ msgid "_File"
+#~ msgstr "_Arkiv"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Uppdatera"
+
+#~ msgid "_Get..."
+#~ msgstr "_Hämta..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Visa _dolda filer"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_hecka ut..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Dra _in"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Verkställ..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Skjut _ut..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Logg..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Skillnader"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistik"
+
+#~ msgid "_Help"
+#~ msgstr "_Hjälp"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Vilka fil(er) vill du lägga till?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Lägg till fil(er)"
+
+#~ msgid "_Remove"
+#~ msgstr "_Ta bort"
+
+#~ msgid "Selected only"
+#~ msgstr "Endast markerade"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Ta bort fil(er)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Vilka fil(er) vill du ta bort?"
+
+#~ msgid "_Add"
+#~ msgstr "_Lägg till"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Skapa katalog"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Versionshanterad katalog"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Flytta"
+
+#~ msgid "Move to"
+#~ msgstr "Flytta till"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Skapa katalog"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Byt namn"
+
+#~ msgid "_Move"
+#~ msgstr "_Flytta"
+
+#~ msgid "Select a directory"
+#~ msgstr "Välj en katalog"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Förrådsutcheckning: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checka ut gren: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Förrådsgren: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Delat förråd: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Byt namn"
+
+#~ msgid "Rename to"
+#~ msgstr "Byt namn till"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publicera till gren: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Föräldergren: "
+
+#~ msgid "(none)"
+#~ msgstr "(ingen)"
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Oförändrade filer: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Ändrade filer: "
+
+#~ msgid "Added files: "
+#~ msgstr "Tillagda filer: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Saknade revisioner i arbetsträd: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Saknade revisioner i gren: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisioner i gren: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Filer som bytt namn: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Okända filer: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ignorerade filer: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Versionshanterade underkataloger: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Tid för första revision: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Ålder för gren (i dagar): "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Antal insändare: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Borttagna filer: "
+
+#~ msgid "Title:"
+#~ msgstr "Titel:"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Tid för sista revision: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Storlek på förråd: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisioner i förråd: "
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Det finns saknade revisioner"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Lokal gren uppdaterad"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revision(er) saknas."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Det finns inga saknade revisioner."
+
+#~ msgid "Bookmark"
+#~ msgstr "Bokmärke"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Bokmärken"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade-filen kunde inte hittas."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Lägg till den markerade filen"
+
+#~ msgid "Add"
+#~ msgstr "Lägg till"
+
+#~ msgid "unchanged"
+#~ msgstr "oförändrad"
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Filnamn"
+
+#~ msgid "unknown"
+#~ msgstr "okänd"
+
+#~ msgid "Remove"
+#~ msgstr "Ta bort"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Ta bort den markerade filen"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Verkställ ändringarna"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Visa skillnaderna för alla filer"
+
+#~ msgid "All..."
+#~ msgstr "Alla..."
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Bokmärk aktuell plats"
+
+#~ msgid "Edit"
+#~ msgstr "Redigera"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Redigera det markerade bokmärket"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Ta bort det markerade bokmärket"
+
+#~ msgid "No directory name given"
+#~ msgstr "Inget katalognamn angavs"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Katalogen finns redan"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Inte i samma gren"
+
+#~ msgid "No matching files"
+#~ msgstr "Inga filer matchades"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Ange ett nytt namn för filen."
+
+#~ msgid "Filename not given"
+#~ msgstr "Filnamn angavs inte"
+
+#~ msgid "Time"
+#~ msgstr "Tid"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Carl-Uno Olsson https://launchpad.net/~carl-uno\n"
+#~ "  Daniel Nylander https://launchpad.net/~yeager\n"
+#~ "  Fredrik Portström https://launchpad.net/~rheo\n"
+#~ "  Zirro https://launchpad.net/~magne-andersson"

=== added file 'po/th.po'
--- po/th.po	1970-01-01 00:00:00 +0000
+++ po/th.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,1207 @@
+# Thai translation for olive
+# Copyright (c) 2006 Rosetta Contributors and Canonical Ltd 2006
+# This file is distributed under the same license as the olive package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2006.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: olive\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-03-18 03:18+0000\n"
+"Last-Translator: SiraNokyoongtong <gumaraa@gmail.com>\n"
+"Language-Team: Thai <th@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr "_สาขา"
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr "ตำแหน่งสาขา:"
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "ปลายทาง:"
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr "ชื่อเรียกสาขา:"
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr "รุ่น:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "โปรดเลือกโฟลเดอร์"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr "ไม่พบตำแหน่งสาขา"
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr "คุณต้องระบุตำแหน่งสาขา"
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr "แตกสาขาสำเร็จ"
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr "รุ่นที่ %d ของสาขา"
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr "N/A"
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr ""
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr "ไดเรกทอรีไม่มีสายงาน"
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "ยกเลิกปฏิบัติการ"
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr "นั่นคือการเปลี่ยนแปลงในสาขา"
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr "โปรดยืนยันหรือย้อนกลับการเปลี่ยนแปลงก่อนจะรวม"
+
+#: ../commit.py:182
+msgid "added"
+msgstr "เพิ่มแล้ว"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "ลบแล้ว"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "เปลี่ยนชื่อแล้ว"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "เปลี่ยนชื่อและเปลี่ยนแปลงแล้ว"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "เปลี่ยนแปลงแล้ว"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr "<b>ข้อความยืนยัน</b>"
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr "ยืนยัน_อยู่ภายในเท่านั้น"
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "_ยืนยัน"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr "แฟ้ม"
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr "ยืนยันการเปลี่ยนแปลงทั้งหมด"
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr "ยืนยันการเปลี่ยนแปลงทั้งหมด*"
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr "ยืนยัน*"
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "ยืนยัน"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "พาธ"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "รูปแบบ"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr "<i>* ไม่สามารถเลือกแฟ้มขณะกำลังผสาน</i>"
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr "กำลังรอรุ่น"
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "วันที่"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr "ผู้ยืนยัน"
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "ภาพรวม"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr "เปรียบเทียบทั้งสายงาน"
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr "แฟ้มข้อความยืนยัน"
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr "ข้อความยืนยันโดยรวม"
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr "<b>ข้อความยืนยันโดยรวม</b>"
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr "เปรียบเทียบกับ "
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr "ข้อความยืนยันสำหรับ "
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "ยืนยันโดยไม่กำหนดข้อความ?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr "คุณสามารถระบุเหตุผลของการยืนยัน"
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr "มีแฟ้มที่ไม่รู้จักในสายงาน ยืนยันหรือไม่?"
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "ยืนยันแม้ไม่เปลี่ยนแปลง?"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr "ไม่มีการเปลี่ยนแปลงในสายงาน คุณต้องการยืนยันหรือไม่?"
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr "เครื่องมืออำนวยความสะดวกภายนอก:"
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "ขัดแย้ง"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr "ไม่มีความขัดแย้งในสายงานนนี้"
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr "ขัดแย้งที่พาธ"
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr "ขัดแย้งที่เนื้อหา"
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr "ขัดแย้งที่อักขระ"
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr "id ซ้ำซ้อน"
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr "ซ้ำซ้อน"
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr "ไม่ทราบรูปแบบของความผิดพลาด"
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr "ไม่มีแฟ้มถูกเลือก"
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr "โปรดเลือกแฟ้มจากรายการ"
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr "การเรียกเครื่องมืออำนวยความสะดวกภายนอกล้มเหลว"
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr "ไม่สามารถแก้ไขความขัดแย้ง"
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "มุม_มอง"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "รวมสำเร็จ"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "การเปลี่ยนแปลงทั้งหมดปรับใช้เรียบร้อย"
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr "พบความขัดแย้ง"
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr "โปรดแก้ไขความขัดแย้งด้วยตัวเองก่อนจะยืนยัน"
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr "ไดเรกทอรีไม่ใช่สาขา"
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr "การกระทำนี้คุณสามารถทำได้ในสาขาเท่านั้น"
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr ""
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr "ไม่มีการเปลี่ยนแปลงที่จะยืนยัน"
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr "ขัดแย้งในสายงาน"
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr "คุณต้องแก้ไขความขัดแย้งก่อนการยืนยัน"
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr "ส่วนขอบของสาขาล้าสมัย"
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr "%s"
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr "แฟ้มยังไม่ได้ระบุรุ่น"
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr "แฟ้มที่เลือกยังไม่ได้ระบุรุ่น"
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr "ไม่มีผลลัพธ์การเปรียบเทียบ"
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr "แฟ้มที่เลือกไม่มีการเปลี่ยนแปลง"
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr "ไม่มีรุ่นที่คุณระบุ"
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr ""
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr "ไดเรกทอรี่เป็นสาขาแล้ว"
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr "สาขาไม่มีสายงาน"
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+"ไดเรกทอรีปัจจุบัน (%s)\n"
+"คือสาขาโดยไม่มีสายงาน"
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr "bzr ผิดพลาดไม่ทราบสาเหตุ"
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr "ไม่ได้รับอนุญาต"
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr "ไม่ได้รับอนุญาต"
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr "ผิดพลาดไม่ทราบสาเหตุ"
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr "ไดเรกทอรีใดที่คุณต้องการเริ่ม?"
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr "ไดเรกทอรีปัจจุบัน"
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr "สร้างไดเรกทอรีใหม่ด้วยชื่อ:"
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr "ไม่ได้ระบุชื่อไดเรกทอรี"
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr "คุณควรระบุชื่อไดเรกทอรี"
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_ผสาน"
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr "โปรดระบุสาขาที่จะรวมเข้ามา"
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr "คำสั่ง Bazaar ผิดพลาด"
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr "ตำแหน่ง:"
+
+#: ../push.py:53
+msgid "_Push"
+msgstr "_ส่ง"
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr "ส่งเรียบร้อย"
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr "รุ่นที่ %d ได้ส่งแล้ว"
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr "เ_ลือก"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr "เพิ่มแล้ว"
+
+#: ../status.py:100
+msgid "Removed"
+msgstr "ลบแล้ว"
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr "เปลี่ยนชื่อแล้ว"
+
+#: ../status.py:113
+msgid "Modified"
+msgstr "แก้ไขแล้ว"
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr "ไม่ทราบ"
+
+#: ../status.py:126
+msgid "No changes."
+msgstr "ไม่มีการเปลี่ยนแปลง"
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr "ป้าย"
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr "ชื่อป้าย"
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr "หมายเลขประจำรุ่น"
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr "_ลบป้าย"
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr "<b><big>ลบป้าย?</big></b>"
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr "คุณแน่ใจหรือไม่ที่ป้าย: <b>%s</b>?"
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr "เ_พิ่มป้าย"
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr "ชื่อป้าย:"
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr "หมายเลขประจำรุ่น:"
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr "ไม่มีชื่อป้ายถูกระบุ"
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "File(s) to commit"
+#~ msgstr "แฟ้มที่จะยืนยัน"
+
+#~ msgid "Commit message:"
+#~ msgstr "ข้อความการยืนยัน:"
+
+#~ msgid "Pending merges"
+#~ msgstr "กำลังรอผสาน"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "ไม่มีการเปลี่ยนแปลงในสายงานนี้"
+
+#~ msgid "Set default push location"
+#~ msgstr "กำหนดตำแหน่งส่งปริยาย"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "นั่นไม่ใช่ตำแหน่งส่งปริยาย\n"
+#~ "ตั้ง %r เป็นปริยายเดี๋ยวนี้?"
+
+#~ msgid "Revno"
+#~ msgstr "ลำดับรุ่น"
+
+#~ msgid "Time"
+#~ msgstr "เวลา"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "สาขาภายในเป็นปัจจุบันแล้ว"
+
+#~ msgid "Pull successful"
+#~ msgstr "ดึงสำเร็จ"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "รุ่นที่ %d ได้ดึงลงมาแล้ว"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "ตรวจพบความขัดแย้ง"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "โปรดดูที่สายงานก่อนดำเนินการต่อ"
+
+#~ msgid "Revert successful"
+#~ msgstr "ย้อนกลับเรียบร้อย"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "แฟ้มทั้งหมดย้อนกลับไปรุ่นก่อนหน้าเรียบร้อยแล้ว"
+
+#~ msgid "Bookmarks"
+#~ msgstr "ที่คั่นหน้า"
+
+#~ msgid "Bookmark"
+#~ msgstr "ที่คั่นหน้า"
+
+#~ msgid "unchanged"
+#~ msgstr "ไม่เปลี่ยนแปลง"
+
+#~ msgid "ignored"
+#~ msgstr "ละเลย"
+
+#~ msgid "unknown"
+#~ msgstr "ไม่ทราบ"
+
+#~ msgid "Filename"
+#~ msgstr "ชื่อแฟ้ม"
+
+#~ msgid "Status"
+#~ msgstr "สถานะ"
+
+#~ msgid "Size"
+#~ msgstr "ขนาด"
+
+#~ msgid "Last modified"
+#~ msgstr "แก้ไขล่าสุด"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "โปรดเลือกแฟ้มจากรายการ\n"
+#~ "หรือเลือกตัวเลือกอื่น"
+
+#~ msgid "Title:"
+#~ msgstr "หัวข้อ:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "โปรดระบุหัวข้อที่จะดำเนินการต่อ"
+
+#~ msgid "Add"
+#~ msgstr "เพิ่ม"
+
+#~ msgid "Add the selected file"
+#~ msgstr "เพิ่มแฟ้มที่เลือก"
+
+#~ msgid "Remove"
+#~ msgstr "ลบ"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "ลบแฟ้มที่เลือก"
+
+#~ msgid "Remove and delete"
+#~ msgstr "เอาออกและลบ"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "เอาแฟ้ม/ไดเรกทอรีออกและลบจากดิสก์"
+
+#~ msgid "Rename"
+#~ msgstr "เปลี่ยนชื่อ"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "เปลี่ยนชื่อแฟ้มที่เลือก"
+
+#~ msgid "Open"
+#~ msgstr "เปิด"
+
+#~ msgid "Open the selected file"
+#~ msgstr "เปิดแฟ้มที่เลือก"
+
+#~ msgid "Revert"
+#~ msgstr "ย้อนกลับ"
+
+#~ msgid "Revert the changes"
+#~ msgstr "ย้อนกลับการเปลี่ยนแปลง"
+
+#~ msgid "Commit the changes"
+#~ msgstr "ยืนยันการเปลี่ยนแปลง"
+
+#~ msgid "Annotate"
+#~ msgstr "หมายเหตุ"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "ใส่หมายเหตุแฟ้มที่เลือก"
+
+#~ msgid "Diff"
+#~ msgstr "เปรียบเทียบ"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "แสดงการเปรียบเทียบของแฟ้ม"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "คั่นหน้าตำแหน่งปัจจุบัน"
+
+#~ msgid "Edit"
+#~ msgstr "แก้ไข"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "แก้ไขที่คั่นหน้าที่เลือก"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "ลบที่คั่นหน้าที่เลือก"
+
+#~ msgid "Open Folder"
+#~ msgstr "เปิดโฟลเดอร์"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "เปิดโฟลเดอร์ที่คั่นหน้าใน Nautilus"
+
+#~ msgid "Selected..."
+#~ msgstr "เลือกแล้ว..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "แสดงความแตกต่างของแฟ้มที่เลือก"
+
+#~ msgid "All..."
+#~ msgstr "ทั้งหมด..."
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "แสดงความแตกต่างของแฟ้มทั้งหมด"
+
+#~ msgid "View contents"
+#~ msgstr "แสดงเนื้อหา"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "แสดงเนื้อหาของแฟ้มในตัวดูที่มีให้"
+
+#~ msgid "Show differences"
+#~ msgstr "แสดงความแตกต่าง"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "แสดงความแตกต่างของแฟ้มระหว่างสองรุ่น"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "ย้อนกลับมาเป็นรุ่นนี้"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "ย้อนกลับแฟ้มที่เลือกมาเป็นรุ่นที่เลือก"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "ลบไดเรกทอรีรวมทั้งไดเรกทอรีทั้งหมดข้างล่าง ?"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "เพิ่มที่คั่นหน้าสำเร็จแล้ว"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "ไดเรกทอรีปัจจุบันได้คั่นหน้าไว้แล้ว คุณสามารถเข้าถึง\n"
+#~ "มันโดยการเลือกจากพาเนลซ้าย"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "คั่นหน้าตำแหน่งนี้แล้ว"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "ไดเรกทอรีนี้เป็นที่คั่นหน้าแล้ว\n"
+#~ "ดูพาเนลซ้ายเพื่ออ้างถึง"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "โปรดระบุชื่อที่ต้องการสำหรับไดเรกทอรีใหม่"
+
+#~ msgid "Directory already exists"
+#~ msgstr "ไดเรกทอรีมีแล้ว"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "โปรดระบุชื่ออื่นเพื่อทำต่อ"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "โปรดเลือกแฟ้มจากรายการเพื่อดำเนินการ"
+
+#~ msgid "Not the same branch"
+#~ msgstr "ไม่ใช่สาขาเดียวกัน"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "ปลายทางไม่ใช่สาขาเดียวกัน"
+
+#~ msgid "No matching files"
+#~ msgstr "ไม่มีแฟ้มที่ตรงกัน"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "ไม่พบแฟ้มที่เพิ่มในสายงาน"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "แฟ้มใดที่คุณต้องการลบ?"
+
+#~ msgid "Selected only"
+#~ msgstr "เฉพาะที่เลือกแล้ว"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "แฟ้มทั้งหมดเป็นสถานะ 'เพิ่มแล้ว'"
+
+#~ msgid "_Remove"
+#~ msgstr "_ถอดถอน"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "โปรดระบุชื่อใหม่สำหรับแฟ้ม"
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_File"
+#~ msgstr "แ_ฟ้ม"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "เ_พิ่มแฟ้ม..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "ลบแฟ้ม..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "สร้างไ_ดเรกทอรี..."
+
+#~ msgid "_Rename..."
+#~ msgstr "เ_ปลี่ยนชื่อ..."
+
+#~ msgid "_Move..."
+#~ msgstr "_ย้าย"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_หมายเหตุ..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "แสดงแฟ้ม_ซ่อน"
+
+#~ msgid "_Refresh"
+#~ msgstr "เ_รียกใหม่"
+
+#~ msgid "Pu_ll"
+#~ msgstr "_ดึง"
+
+#~ msgid "Pu_sh..."
+#~ msgstr "_ส่ง..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_ย้อนกลับการเปลี่ยนแปลงทั้งหมด"
+
+#~ msgid "_Merge..."
+#~ msgstr "_รวม..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_ยืนยัน..."
+
+#~ msgid "Ta_gs..."
+#~ msgstr "_ป้าย..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "_สถานะ..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "_ขัดแย้ง..."
+
+#~ msgid "_Statistics"
+#~ msgstr "ส_ถิติ"
+
+#~ msgid "_Differences..."
+#~ msgstr "ความแ_ตกต่าง..."
+
+#~ msgid "_Log..."
+#~ msgstr "_ปูม..."
+
+#~ msgid "_Information..."
+#~ msgstr "_ข้อมูล..."
+
+#~ msgid "_Help"
+#~ msgstr "_วิธีใช้"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "ลิขสิทธิ์ (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Sira Nokyoongtong (http://launchpad.net/~gumara)\n"
+#~ "\n"
+#~ "Launchpad Contributions:\n"
+#~ "  SiraNokyoongtong https://launchpad.net/~gumara"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - เพิ่มแฟ้ม"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "แฟ้มใดที่คุณต้องการจะเพิ่ม?"
+
+#~ msgid "_Add"
+#~ msgstr "เ_พิ่ม"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - ถอดถอนแฟ้ม"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - สร้างไดเรกทอรี"
+
+#~ msgid "_Make directory"
+#~ msgstr "สร้างไ_ดเรกทอรี"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - ย้าย"
+
+#~ msgid "Move to"
+#~ msgstr "ย้ายไปยัง"
+
+#~ msgid "Select a directory"
+#~ msgstr "เลือกไดเรกทอรี"
+
+#~ msgid "_Move"
+#~ msgstr "_ย้าย"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - เปลี่ยนชื่อ"
+
+#~ msgid "Rename to"
+#~ msgstr "เปลี่ยนชื่อเป็น"
+
+#~ msgid "_Rename"
+#~ msgstr "เ_ปลี่ยนชื่อ"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - ข้อมูล"
+
+#~ msgid "(none)"
+#~ msgstr "(ไม่มี)"
+
+#~ msgid "Branch root: "
+#~ msgstr "รากสาขา: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "สาขาคลัง: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "คลังที่แบ่งปัน: "
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>ตำแหน่ง:</b>"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "เผยแพร่สาขา: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>สาขาที่เกี่ยวข้อง:</b>"
+
+#~ msgid "Repository format: "
+#~ msgstr "รูปแบบคลัง: "
+
+#~ msgid "Branch format: "
+#~ msgstr "รูปแบบสาขา: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "รูปแบบสายงาน: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>รูปแบบ:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "สถานะการล็อคคลัง: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "สถานะการล็อคสาขา: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "สถานะการล็อคสายงาน: "
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>สถานะการล็อค:</b>"
+
+#~ msgid "Ignored files: "
+#~ msgstr "แฟ้มที่เพิกเฉยแล้ว: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "แฟ้มที่ไม่รู้จัก: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "แฟ้มที่เปลี่ยนชื่อแล้ว: "
+
+#~ msgid "Removed files: "
+#~ msgstr "แฟ้มที่ถอดถอนแล้ว: "
+
+#~ msgid "Added files: "
+#~ msgstr "แฟ้มที่เพิ่มแล้ว: "
+
+#~ msgid "Modified files: "
+#~ msgstr "แฟ้มที่แก้ไขแล้ว: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "แฟ้มที่ยังไม่เปลี่ยนแปลง: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>ในสายงาน:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "เวลาของรุ่นล่าสุด: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "เวลาของรุ่นแรก: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "อายุของสาขา: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "จำนวนของผู้ยืนยัน: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "รุ่นในสาขา: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>ประวัติสาขา:</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "ขนาดของคลัง: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "รุ่นในคลัง: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "ผสาน - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "ผสานจาก:"
+
+#~ msgid "_Bookmark current directory"
+#~ msgstr "_คั่นหน้าไดเรกทอรีปัจจุบัน"
+
+#~ msgid "Show _ignored files"
+#~ msgstr "แสดงแฟ้มที่เ_พิกเฉยแล้ว"
+
+#~ msgid "Update"
+#~ msgstr "อัปเดท"
+
+#~ msgid "Please wait, loading ancestral graph..."
+#~ msgstr "โปรดรอ กำลังโหลดกราฟ"
+
+#~ msgid "Lead Developer:"
+#~ msgstr "หัวหน้านักพัฒนา:"
+
+#~ msgid "Contributors:"
+#~ msgstr "ผู้ร่วมสนับสนุน:"
+
+#~ msgid "Update successful but conflicts generated"
+#~ msgstr "อัปเดทเรียบร้อยแต่มีความขัดแย้ง"
+
+#~ msgid "Number of conflicts generated: %d."
+#~ msgstr "จำนวนของความขัดแย้ง: %d"
+
+#~ msgid "Update successful"
+#~ msgstr "อัปเดทเรียบร้อย"
+
+#~ msgid "No conflicts generated."
+#~ msgstr "ไม่มีความขัดแย้ง"

=== added file 'po/tr.po'
--- po/tr.po	1970-01-01 00:00:00 +0000
+++ po/tr.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,813 @@
+# Turkish translation for bzr-gtk
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-18 06:34+0000\n"
+"Last-Translator: Rail Aliev <rail@iqchoice.com>\n"
+"Language-Team: Turkish <tr@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr ""
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr ""
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "Hedef:"
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr ""
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Lütfen bir dizin seçin"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr ""
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr ""
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr ""
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr ""
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr ""
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr ""
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr ""
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "İşlem iptal edildi."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr "eklendi"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "silindi"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr ""
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr ""
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "değiştirildi"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr ""
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr ""
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr ""
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr ""
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "Tarih"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr ""
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "Özet"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr ""
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "Çelişenler"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr ""
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr ""
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr ""
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr ""
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr ""
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr "kopya"
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr ""
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr ""
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr ""
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr ""
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr ""
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Görünüm"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr ""
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr ""
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr ""
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr ""
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr "%s"
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr ""
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr ""
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr ""
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr "Hedef zaten mevcut"
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr ""
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr ""
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr ""
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr "İzin verilmedi"
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr ""
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr "Bilinmeyen hata"
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr ""
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr ""
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr ""
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr ""
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Birleştir"
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr ""
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr "Konum:"
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr "_Seç"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr ""
+
+#: ../status.py:100
+msgid "Removed"
+msgstr ""
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr ""
+
+#: ../status.py:113
+msgid "Modified"
+msgstr ""
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr ""
+
+#: ../status.py:126
+msgid "No changes."
+msgstr ""
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr ""
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr "Etiket Adı"
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr ""
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr ""
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr ""
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr ""
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr ""
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr "Etiket İsmi"
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr ""
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr ""
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "Time"
+#~ msgstr "Zaman"
+
+#~ msgid "unchanged"
+#~ msgstr "değiştirilmemiş"
+
+#~ msgid "Bookmark"
+#~ msgstr "Yer imi"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Yer İmleri"
+
+#~ msgid "ignored"
+#~ msgstr "yoksayıldı"
+
+#~ msgid "unknown"
+#~ msgstr "bilinmiyor"
+
+#~ msgid "Status"
+#~ msgstr "Durum"
+
+#~ msgid "Filename"
+#~ msgstr "Dosya ismi"
+
+#~ msgid "Size"
+#~ msgstr "Boyut"
+
+#~ msgid "Title:"
+#~ msgstr "Başlık:"
+
+#~ msgid "Last modified"
+#~ msgstr "Değiştirilme zamanı"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Seçilen dosyanın adını değiştir"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Seçili dosyaları aç"
+
+#~ msgid "Add"
+#~ msgstr "Ekle"
+
+#~ msgid "Rename"
+#~ msgstr "Yeniden adlandır"
+
+#~ msgid "Open"
+#~ msgstr "Aç"
+
+#~ msgid "Remove"
+#~ msgstr "Kaldır"
+
+#~ msgid "Annotate"
+#~ msgstr "Notlar"
+
+#~ msgid "Edit"
+#~ msgstr "Düzenle"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Seçili yer imini sil"
+
+#~ msgid "Open Folder"
+#~ msgstr "Dizin aç"
+
+#~ msgid "_Move..."
+#~ msgstr "_Taşı..."
+
+#~ msgid "_Remove"
+#~ msgstr "_Sil"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Yeniden Adlandır..."
+
+#~ msgid "_File"
+#~ msgstr "_Dosya"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "_Gizli dosyaları göster"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Tazele"
+
+#~ msgid "_Statistics"
+#~ msgstr "_İstatistikler"
+
+#~ msgid "_Help"
+#~ msgstr "_Yardım"
+
+#~ msgid "_Add"
+#~ msgstr "_Ekle"
+
+#~ msgid "Rename to"
+#~ msgstr "Yeniden adlandır"
+
+#~ msgid "_Move"
+#~ msgstr "_Taşı"
+
+#~ msgid "Select a directory"
+#~ msgstr "Bir dizin seçin"
+
+#~ msgid "(none)"
+#~ msgstr "(hiçbiri)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Yeniden Adlandır"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Biçim:</b>"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Konum:</b>"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Rail Aliev https://launchpad.net/~rail"

=== added file 'po/uk.po'
--- po/uk.po	1970-01-01 00:00:00 +0000
+++ po/uk.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,1008 @@
+# Ukrainian translation for bzr-gtk
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-18 06:36+0000\n"
+"Last-Translator: kosha <Unknown>\n"
+"Language-Team: Ukrainian <uk@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr ""
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr ""
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "Призначення:"
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr "Модифікація:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "Будь ласка, виберіть теку"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr ""
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr ""
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr ""
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr ""
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr "ВІДСУТНЬО"
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr "Прийняти зміни"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr "Легко прийняти зміни"
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr "Директорія не має робочого дерева"
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "Дію перервано."
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr "додано"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "видалено"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "змінена назва"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "змінена назва та внесені зміни"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "змінено"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "Підтвердити"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "Фіксація"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "Шлях"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "Тип"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "Дата"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr ""
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "Підсумок"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr "Підтвердити з пустим повідомленням?"
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr ""
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr "Зовнішні утиліти."
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "Конфлікти"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr "Не має конфліктів у робочому дереві."
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr "шлях конфлікту"
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr "зміст конфлікту"
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr "текст конфлікту"
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr "повторення мітки"
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr "повторення"
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr "конфлікт невідомого типу"
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr "Не вибрано файлу"
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr "Виберіть файл з переліку."
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr "Помилка під час виклику зовнішньої утиліти."
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr "Не можливо розвязати конфлікт"
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+"Тільки конфлікти у текстових файлай можуть бути розвязані за допомогою Олів "
+"на даний час. Зміст конфлікту, у структурі дерева, потрібно розвязувати його "
+"за допомогою командної строки."
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr "_Погляд"
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr "Обєднано вдало"
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr "Всі зміни вдало прийняті."
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr "Директорія не звірена"
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr "Відсутні зміни для фіксації"
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr "Конфлікт у дереві"
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr ""
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr "%s"
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr ""
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr ""
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr "Обраний файл не змінено."
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr ""
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr ""
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr ""
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr "Невідома помилка bzr"
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr "Доступ заборонено"
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr "доступ заборонено"
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr "Невідома помилка"
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr ""
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr "Поточна директорія"
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr "Створити нову директорію під назвою:"
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr "Назва директорії не унікальна"
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr "Ви повинні вказати назву нової директорії"
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr "_Об'єднати"
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr "Помилка Bazaar"
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr "Розташування:"
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr "Не існує батьківської директорії"
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr "_Вибрати"
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr "Додано"
+
+#: ../status.py:100
+msgid "Removed"
+msgstr "Видалено"
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr "Назва змінена"
+
+#: ../status.py:113
+msgid "Modified"
+msgstr "Змінено"
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr "Невідомо"
+
+#: ../status.py:126
+msgid "No changes."
+msgstr "Без змін."
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr "Мітки"
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr "Назва мітки"
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr "Версія ID"
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr "Видалення мітки"
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr "<b><big>Видалити мітку?</big></b>"
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr "Ви впевнені, що хочете видалити мітку: <b>%s</b>?"
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr "Додати мітку"
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr "Назва мітки:"
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr "Версія ID:"
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr "Не вказана назва мітки"
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "Time"
+#~ msgstr "Час"
+
+#~ msgid "unchanged"
+#~ msgstr "без змін"
+
+#~ msgid "Bookmark"
+#~ msgstr "Закладка"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Закладки"
+
+#~ msgid "ignored"
+#~ msgstr "ігнорується"
+
+#~ msgid "unknown"
+#~ msgstr "невідомо"
+
+#~ msgid "Last modified"
+#~ msgstr "Востаннє змінено"
+
+#~ msgid "Status"
+#~ msgstr "Стан"
+
+#~ msgid "Filename"
+#~ msgstr "Назва файлу"
+
+#~ msgid "Size"
+#~ msgstr "Розмір"
+
+#~ msgid "Title:"
+#~ msgstr "Назва:"
+
+#~ msgid "Add"
+#~ msgstr "Додати"
+
+#~ msgid "Open"
+#~ msgstr "Відкрити"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Відкрити вибраний файл"
+
+#~ msgid "Remove"
+#~ msgstr "Видалити"
+
+#~ msgid "Revert"
+#~ msgstr "Повернути"
+
+#~ msgid "Open Folder"
+#~ msgstr "Відкрити теку"
+
+#~ msgid "_Move..."
+#~ msgstr "П_еремістити..."
+
+#~ msgid "_Remove"
+#~ msgstr "_Видалити"
+
+#~ msgid "_File"
+#~ msgstr "_Файл"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Оновити"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Показувати при_ховані файли"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Статистика"
+
+#~ msgid "_Help"
+#~ msgstr "_Допомога"
+
+#~ msgid "_Add"
+#~ msgstr "_Додати"
+
+#~ msgid "(none)"
+#~ msgstr "(жоден)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Перейменувати"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Формат:</b>"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Додати обрані файли"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Перемістити та видалити"
+
+#~ msgid "Diff"
+#~ msgstr "Відмінність"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Показати відмінність файлу"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Перемістити обрані файли"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Прийняти зміни"
+
+#~ msgid "Show differences"
+#~ msgstr "Показати відмінності"
+
+#~ msgid "All..."
+#~ msgstr "Все..."
+
+#~ msgid "View contents"
+#~ msgstr "Перегляд змісту"
+
+#~ msgid "Selected..."
+#~ msgstr "Обираємо..."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Закладка додана"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Всі файли зі статусом 'додати'"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Директорія існує"
+
+#~ msgid "Selected only"
+#~ msgstr "Тільки обрати"
+
+#~ msgid "_Initialize..."
+#~ msgstr "Запуск..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Перемістити файл(и)"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "Додати файл(и)"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Стан"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "_Information..."
+#~ msgstr "Інформація"
+
+#~ msgid "Move to"
+#~ msgstr "Перемістити до"
+
+#~ msgid "Repository format: "
+#~ msgstr "Формат сховища: "
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Стан блокування:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Стан блокування сховища: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Невідомі файли: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Незмінені файли: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Змінені файли: "
+
+#~ msgid "Added files: "
+#~ msgstr "Додані файли: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Розмір сховища: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Версія у сховищі: "
+
+#~ msgid "Commit message:"
+#~ msgstr "Підтвердження:"
+
+#~ msgid "Pending merges"
+#~ msgstr "До обєднання"
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Визначено конфлікт"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Будь ласка, вкажіть назву для продовження."
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Змінити назву обраним файлам"
+
+#~ msgid "Rename"
+#~ msgstr "Змінити назву"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Аннотація обраного файлу"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Повернути зміни"
+
+#~ msgid "Annotate"
+#~ msgstr "Аннотація"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Закладка поточної позиції"
+
+#~ msgid "Edit"
+#~ msgstr "Редагувати"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Редагувати обрану закладку"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Відкрити закладку теки у Наутілусі"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Показати різницю у всіх файлах"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Показати різницю у обраних файлах"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Видалити обрану закладку"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Позиція закладена"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Повернути попередню версію обраного файлу"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Видалити директорію зі всіма підпорядкованими директоріями?"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Будь ласка, оберіть іншу назву для продовження."
+
+#~ msgid "_Rename..."
+#~ msgstr "Зміна назви..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Створення директорії..."
+
+#~ msgid "_Get..."
+#~ msgstr "Взяти..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "Аннотація"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Повернути зміни"
+
+#~ msgid "C_heckout..."
+#~ msgstr "Звірити..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Обєднати"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Конфлікти..."
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Які файл(и) Ви хочете додати?"
+
+#~ msgid "Rename to"
+#~ msgstr "Змінити назву на"
+
+#~ msgid "_Move"
+#~ msgstr "Перем_істити"
+
+#~ msgid "Select a directory"
+#~ msgstr "Вибрати директорію"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Позиція:</b>"
+
+#~ msgid "Renamed files: "
+#~ msgstr "Змінити назву файлів: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ігнорувати файли: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Перемістити файли: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>В робоче дерево:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Час останньої версії: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Час першої версії: "
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Історія версій:</b>"
+
+#~ msgid "Merge from:"
+#~ msgstr "Обєднати из:"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  kosha https://launchpad.net/~o-kornyeyev"

=== added file 'po/zh_CN.po'
--- po/zh_CN.po	1970-01-01 00:00:00 +0000
+++ po/zh_CN.po	2011-03-08 04:41:48 +0000
@@ -0,0 +1,709 @@
+# Simplified Chinese translation for bzr-gtk
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the bzr-gtk package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: bzr-gtk\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-03-17 09:03+0000\n"
+"Last-Translator: Eleanor Chen <chenyueg@gmail.com>\n"
+"Language-Team: Simplified Chinese <zh_CN@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
+
+#: ../bazaar-properties.desktop.in.h:1
+msgid "Bazaar Preferences"
+msgstr ""
+
+#: ../bazaar-properties.desktop.in.h:2
+msgid "Configure Bazaar settings"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:1
+msgid "Apply Bazaar Bundle"
+msgstr ""
+
+#: ../bzr-handle-patch.desktop.in.h:2
+msgid "Bazaar"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:1
+msgid "Bazaar Notification"
+msgstr ""
+
+#: ../bzr-notify.desktop.in.h:2
+msgid "Notification Area Icon for Bazaar"
+msgstr ""
+
+#. Create the widgets
+#: ../branch.py:52
+msgid "_Branch"
+msgstr "分支(_B)"
+
+#: ../branch.py:55 ../checkout.py:55
+msgid "Branch location:"
+msgstr "分支位置："
+
+#: ../branch.py:57 ../checkout.py:56
+msgid "Destination:"
+msgstr "目标："
+
+#: ../branch.py:58
+msgid "Branck nick:"
+msgstr ""
+
+#: ../branch.py:59 ../checkout.py:58
+msgid "Revision:"
+msgstr "修订版本:"
+
+#: ../branch.py:60 ../checkout.py:53
+msgid "Please select a folder"
+msgstr "请选择一个文件夹"
+
+#: ../branch.py:140 ../checkout.py:159
+msgid "Missing branch location"
+msgstr "缺少分支地址"
+
+#: ../branch.py:141 ../checkout.py:160
+msgid "You must specify a branch location."
+msgstr "你必须指定一个分支地址"
+
+#: ../branch.py:182
+msgid "Branching successful"
+msgstr "创建分支成功"
+
+#: ../branch.py:183
+#, python-format
+msgid "%d revision(s) branched."
+msgstr ""
+
+#: ../branch.py:191 ../checkout.py:191
+msgid "N/A"
+msgstr "N/A"
+
+#. Create the widgets
+#: ../checkout.py:50
+msgid "Check_out"
+msgstr "签出(_O)"
+
+#: ../checkout.py:57
+msgid "Branch nick:"
+msgstr ""
+
+#: ../checkout.py:62
+msgid "_Lightweight checkout"
+msgstr "轻量级签出(_L)"
+
+#: ../commands.py:307
+msgid "Directory does not have a working tree"
+msgstr ""
+
+#: ../commands.py:308
+msgid "Operation aborted."
+msgstr "操作中止。"
+
+#: ../commands.py:412
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: ../commands.py:413
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: ../commit.py:182
+msgid "added"
+msgstr "已添加"
+
+#: ../commit.py:183
+msgid "removed"
+msgstr "已移除"
+
+#: ../commit.py:184
+msgid "renamed"
+msgstr "已重命名"
+
+#: ../commit.py:185
+msgid "renamed and modified"
+msgstr "已重命名并且已修改"
+
+#: ../commit.py:186
+msgid "modified"
+msgstr "已修改"
+
+#: ../commit.py:187
+msgid "kind changed"
+msgstr ""
+
+#: ../commit.py:280
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:333
+msgid "_Only commit locally"
+msgstr ""
+
+#: ../commit.py:364
+msgid "Comm_it"
+msgstr "提交(_I)"
+
+#: ../commit.py:390
+msgid "Files"
+msgstr ""
+
+#: ../commit.py:395
+msgid "Commit all changes"
+msgstr ""
+
+#: ../commit.py:401
+msgid "Only commit selected changes"
+msgstr ""
+
+#: ../commit.py:407
+msgid "Commit all changes*"
+msgstr ""
+
+#: ../commit.py:440
+msgid "Commit*"
+msgstr ""
+
+#: ../commit.py:442
+msgid "Commit"
+msgstr "提交"
+
+#: ../commit.py:446 ../conflicts.py:111
+msgid "Path"
+msgstr "路径"
+
+#: ../commit.py:448 ../conflicts.py:113
+msgid "Type"
+msgstr "类型"
+
+#: ../commit.py:481
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: ../commit.py:485
+msgid "Pending Revisions"
+msgstr ""
+
+#: ../commit.py:507
+msgid "Date"
+msgstr "日期"
+
+#: ../commit.py:509
+msgid "Committer"
+msgstr "提交者"
+
+#: ../commit.py:511 ../search.py:59
+msgid "Summary"
+msgstr "概要"
+
+#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
+#. decide that we really don't ever want to display it, we should
+#. actually remove it, and other references to it, along with the
+#. tests that it is set properly.
+#: ../commit.py:521
+msgid "Diff for whole tree"
+msgstr ""
+
+#. Whole tree
+#: ../commit.py:545 ../commit.py:628
+msgid "File commit message"
+msgstr ""
+
+#: ../commit.py:552
+msgid "Global Commit Message"
+msgstr ""
+
+#: ../commit.py:554
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: ../commit.py:581
+msgid "Diff for "
+msgstr ""
+
+#: ../commit.py:634
+msgid "Commit message for "
+msgstr ""
+
+#: ../commit.py:689
+msgid "Commit cancelled"
+msgstr ""
+
+#: ../commit.py:690
+msgid "Do you want to save your commit messages ?"
+msgstr ""
+
+#: ../commit.py:708
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: ../commit.py:709
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: ../commit.py:729
+msgid "Commit with unknowns?"
+msgstr ""
+
+#: ../commit.py:730
+msgid "Unknown files exist in the working tree. Commit anyway?"
+msgstr ""
+
+#: ../commit.py:750
+msgid "Commit with no changes?"
+msgstr "没有更改仍然要提交吗？"
+
+#: ../commit.py:751
+msgid ""
+"There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: ../conflicts.py:50
+msgid "External utility:"
+msgstr ""
+
+#: ../conflicts.py:101
+msgid "Conflicts"
+msgstr "冲突"
+
+#: ../conflicts.py:104
+msgid "No conflicts in working tree."
+msgstr "工作树中没有冲突。"
+
+#: ../conflicts.py:118
+msgid "path conflict"
+msgstr "路径冲突"
+
+#: ../conflicts.py:120
+msgid "contents conflict"
+msgstr "内容冲突"
+
+#: ../conflicts.py:122
+msgid "text conflict"
+msgstr "文本冲突"
+
+#: ../conflicts.py:124
+msgid "duplicate id"
+msgstr ""
+
+#: ../conflicts.py:126
+msgid "duplicate"
+msgstr "复制"
+
+#: ../conflicts.py:128
+msgid "parent loop"
+msgstr ""
+
+#: ../conflicts.py:130
+msgid "unversioned parent"
+msgstr ""
+
+#: ../conflicts.py:132
+msgid "missing parent"
+msgstr ""
+
+#: ../conflicts.py:134
+msgid "deleting parent"
+msgstr ""
+
+#: ../conflicts.py:136
+msgid "unknown type of conflict"
+msgstr ""
+
+#: ../conflicts.py:165
+msgid "No file was selected"
+msgstr ""
+
+#: ../conflicts.py:166
+msgid "Please select a file from the list."
+msgstr ""
+
+#: ../conflicts.py:176
+msgid "Call to external utility failed"
+msgstr ""
+
+#: ../conflicts.py:178
+msgid "Cannot resolve conflict"
+msgstr ""
+
+#: ../conflicts.py:179
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#. View menu
+#: ../diff.py:445
+msgid "_View"
+msgstr ""
+
+#: ../diff.py:447
+msgid "Wrap _Long Lines"
+msgstr ""
+
+#. No conflicts found.
+#: ../diff.py:492 ../merge.py:146
+msgid "Merge successful"
+msgstr ""
+
+#: ../diff.py:493 ../merge.py:147
+msgid "All changes applied successfully."
+msgstr ""
+
+#. There are conflicts to be resolved.
+#: ../diff.py:496 ../merge.py:150
+msgid "Conflicts encountered"
+msgstr ""
+
+#: ../diff.py:497 ../merge.py:151
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: ../errors.py:28
+msgid "Directory is not a branch"
+msgstr ""
+
+#: ../errors.py:29
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: ../errors.py:31
+msgid "Directory is not a checkout"
+msgstr ""
+
+#: ../errors.py:32
+msgid "You can perform local commit only on checkouts."
+msgstr ""
+
+#: ../errors.py:34
+msgid "No changes to commit"
+msgstr ""
+
+#: ../errors.py:35
+msgid "Try force commit if you want to commit anyway."
+msgstr ""
+
+#: ../errors.py:37
+msgid "No changes to merge"
+msgstr ""
+
+#: ../errors.py:38
+msgid "Merge location is already fully merged in working tree."
+msgstr ""
+
+#: ../errors.py:40
+msgid "Conflicts in tree"
+msgstr ""
+
+#: ../errors.py:41
+msgid "You need to resolve the conflicts before committing."
+msgstr ""
+
+#: ../errors.py:43
+msgid "Strict commit failed"
+msgstr ""
+
+#: ../errors.py:44
+msgid ""
+"There are unknown files in the working tree.\n"
+"Please add or delete them."
+msgstr ""
+
+#: ../errors.py:46
+msgid "Bound branch is out of date"
+msgstr ""
+
+#. FIXME: Really ? Internationalizing %s ?? --vila080505
+#: ../errors.py:48
+#, python-format
+msgid "%s"
+msgstr ""
+
+#: ../errors.py:50
+msgid "File not versioned"
+msgstr ""
+
+#: ../errors.py:51
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: ../errors.py:53 ../push.py:99
+msgid "Branches have been diverged"
+msgstr ""
+
+#: ../errors.py:54
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: ../errors.py:56
+msgid "No diff output"
+msgstr ""
+
+#: ../errors.py:57
+msgid "The selected file hasn't changed."
+msgstr ""
+
+#: ../errors.py:59
+msgid "No such revision"
+msgstr ""
+
+#: ../errors.py:60
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: ../errors.py:62
+msgid "Target already exists"
+msgstr ""
+
+#: ../errors.py:63
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: ../errors.py:65
+msgid "Directory is already a branch"
+msgstr ""
+
+#: ../errors.py:66
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: ../errors.py:68
+msgid "Branch without a working tree"
+msgstr ""
+
+#: ../errors.py:69
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: ../errors.py:71
+msgid "Unknown bzr error"
+msgstr ""
+
+#: ../errors.py:73
+msgid "Permission denied"
+msgstr ""
+
+#: ../errors.py:73
+msgid "permission denied."
+msgstr ""
+
+#: ../errors.py:75
+msgid "Unknown error"
+msgstr ""
+
+#. Create the widgets
+#: ../initialize.py:48
+msgid "_Initialize"
+msgstr ""
+
+#: ../initialize.py:49
+msgid "Which directory do you want to initialize?"
+msgstr ""
+
+#: ../initialize.py:50
+msgid "Current directory"
+msgstr ""
+
+#: ../initialize.py:51
+msgid "Create a new directory with the name:"
+msgstr ""
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
+#: ../initialize.py:87
+msgid "You should specify a new directory name."
+msgstr ""
+
+#: ../loom.py:53
+msgid "Upgrade to Loom branch?"
+msgstr ""
+
+#: ../loom.py:54
+msgid "Branch is not a loom branch. Upgrade to Loom format?"
+msgstr ""
+
+#: ../merge.py:54
+msgid "Merge from"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Folder"
+msgstr ""
+
+#: ../merge.py:56
+msgid "Custom Location"
+msgstr ""
+
+#: ../merge.py:59
+msgid "_Merge"
+msgstr ""
+
+#: ../merge.py:132
+msgid "Branch not given"
+msgstr ""
+
+#: ../merge.py:133
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: ../merge.py:141
+msgid "Bazaar command error"
+msgstr ""
+
+#. Create the widgets
+#: ../push.py:51
+msgid "Location:"
+msgstr ""
+
+#: ../push.py:53
+msgid "_Push"
+msgstr ""
+
+#: ../push.py:100
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
+#: ../push.py:109
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: ../push.py:142
+msgid "Non existing parent directory"
+msgstr ""
+
+#: ../push.py:143
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist. Create?"
+msgstr ""
+
+#. Create the widgets
+#: ../revbrowser.py:45
+msgid "_Select"
+msgstr ""
+
+#: ../search.py:44
+msgid "Search for:"
+msgstr ""
+
+#: ../search.py:56
+msgid "Document"
+msgstr ""
+
+#: ../status.py:94
+msgid "Added"
+msgstr ""
+
+#: ../status.py:100
+msgid "Removed"
+msgstr ""
+
+#: ../status.py:106
+msgid "Renamed"
+msgstr ""
+
+#: ../status.py:113
+msgid "Modified"
+msgstr ""
+
+#: ../status.py:121
+msgid "Unknown"
+msgstr ""
+
+#: ../status.py:126
+msgid "No changes."
+msgstr ""
+
+#. Set properties
+#: ../tags.py:66
+msgid "Tags"
+msgstr ""
+
+#: ../tags.py:110
+msgid "Tag Name"
+msgstr ""
+
+#: ../tags.py:115
+msgid "Revision ID"
+msgstr ""
+
+#: ../tags.py:150
+msgid "Tags are not supported by this branch format. Please upgrade."
+msgstr ""
+
+#: ../tags.py:156
+msgid "No tagged revisions in the branch."
+msgstr ""
+
+#: ../tags.py:231
+msgid "_Remove tag"
+msgstr ""
+
+#: ../tags.py:241
+msgid "<b><big>Remove tag?</big></b>"
+msgstr ""
+
+#: ../tags.py:243
+#, python-format
+msgid "Are you sure you want to remove the tag: <b>%s</b>?"
+msgstr ""
+
+#. Create the widgets
+#: ../tags.py:288
+msgid "_Add tag"
+msgstr ""
+
+#: ../tags.py:290
+msgid "Tag Name:"
+msgstr ""
+
+#: ../tags.py:291
+msgid "Revision ID:"
+msgstr ""
+
+#: ../tags.py:322
+msgid "No tag name specified"
+msgstr ""
+
+#: ../tags.py:323
+msgid "You have to specify the tag's desired name."
+msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Aron Xu https://launchpad.net/~happyaron\n"
+#~ "  Chen Tao https://launchpad.net/~pro711"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "准备提交的文件"
+
+#~ msgid "Commit message:"
+#~ msgstr "提交说明："

=== modified file 'preferences/__init__.py'
--- preferences/__init__.py	2011-02-18 13:01:03 +0000
+++ preferences/__init__.py	2011-03-14 20:12:19 +0000
@@ -29,9 +29,9 @@
 
 class PreferencesWindow(gtk.Dialog):
     """Displays global preferences windows."""
-    # Note that we don't allow configuration of aliases or 
-    # default log formats. This is because doing so wouldn't make 
-    # a lot of sense to pure GUI users. Users that need these settings 
+    # Note that we don't allow configuration of aliases or
+    # default log formats. This is because doing so wouldn't make
+    # a lot of sense to pure GUI users. Users that need these settings
     # will already be familiar with the configuration file.
 
     def __init__(self, config=None):
@@ -60,7 +60,7 @@
         self.action_area.set_border_width(12)
 
     def _create_pages(self):
-        return [("Identity", IdentityPage(self.config)), 
+        return [("Identity", IdentityPage(self.config)),
                 ("Plugins", PluginsPage()),
                 ("Notifications", NotificationsPage(self.config))]
 

=== modified file 'preferences/identity.py'
--- preferences/identity.py	2011-02-18 13:01:03 +0000
+++ preferences/identity.py	2011-03-14 20:12:19 +0000
@@ -22,6 +22,7 @@
 
 import gtk
 
+
 class IdentityPage(gtk.Table):
 
     def __init__(self, config):
@@ -58,10 +59,10 @@
         self.attach(align, 0, 1, 2, 3, gtk.FILL, gtk.FILL)
 
         sigvals = gtk.VBox()
-        self.check_sigs_if_possible = gtk.RadioButton(None, 
+        self.check_sigs_if_possible = gtk.RadioButton(None,
                                                       "_Check if possible")
         sigvals.pack_start(self.check_sigs_if_possible)
-        self.check_sigs_always = gtk.RadioButton(self.check_sigs_if_possible, 
+        self.check_sigs_always = gtk.RadioButton(self.check_sigs_if_possible,
                                                  "Check _always")
         sigvals.pack_start(self.check_sigs_always)
         self.check_sigs_never = gtk.RadioButton(self.check_sigs_if_possible,
@@ -77,7 +78,7 @@
         self.attach(align, 0, 1, 3, 4, gtk.FILL, gtk.FILL)
 
         create_sigs = gtk.VBox()
-        self.create_sigs_when_required = gtk.RadioButton(None, 
+        self.create_sigs_when_required = gtk.RadioButton(None,
                                                          "Sign When _Required")
         create_sigs.pack_start(self.create_sigs_when_required)
         self.create_sigs_always = gtk.RadioButton(

=== modified file 'preferences/notifications.py'
--- preferences/notifications.py	2011-02-18 13:01:03 +0000
+++ preferences/notifications.py	2011-03-14 20:12:19 +0000
@@ -23,7 +23,11 @@
 import gtk
 
 import bzrlib.plugins.gtk
-from bzrlib.plugins.gtk.notify import has_avahi, has_dbus
+from bzrlib.plugins.gtk.notify import (
+    has_avahi,
+    has_dbus,
+    )
+
 
 def has_email():
     return (getattr(bzrlib.plugins, "email", None) is not None)

=== modified file 'preferences/plugins.py'
--- preferences/plugins.py	2011-02-18 13:01:03 +0000
+++ preferences/plugins.py	2011-03-14 20:12:19 +0000
@@ -22,6 +22,7 @@
 
 import gtk
 
+
 class PluginsPage(gtk.VPaned):
 
     def __init__(self):

=== modified file 'push.py'
--- push.py	2009-05-06 11:51:38 +0000
+++ push.py	2011-03-14 20:12:19 +0000
@@ -20,60 +20,63 @@
     pygtk.require("2.0")
 except:
     pass
-    
+
 import gtk
 
 from errors import show_bzr_error
 
-from bzrlib.config import LocationConfig
 import bzrlib.errors as errors
 
 from bzrlib.plugins.gtk import _i18n
-from dialog import error_dialog, info_dialog, question_dialog
+from bzrlib.plugins.gtk.dialog import (
+    info_dialog,
+    question_dialog,
+    )
 
-from history import UrlHistory
+from bzrlib.plugins.gtk.history import UrlHistory
 
 class PushDialog(gtk.Dialog):
     """ New implementation of the Push dialog. """
+
     def __init__(self, repository, revid, branch=None, parent=None):
         """ Initialize the Push dialog. """
         gtk.Dialog.__init__(self, title="Push - Olive",
                                   parent=parent,
                                   flags=0,
                                   buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
-        
+
         # Get arguments
         self.repository = repository
         self.revid = revid
         self.branch = branch
-        
+
         # Create the widgets
         self._label_location = gtk.Label(_i18n("Location:"))
         self._combo = gtk.ComboBoxEntry()
         self._button_push = gtk.Button(_i18n("_Push"), use_underline=True)
         self._hbox_location = gtk.HBox()
-        
+
         # Set callbacks
         self._button_push.connect('clicked', self._on_push_clicked)
-        
+
         # Set properties
         self._label_location.set_alignment(0, 0.5)
         self._hbox_location.set_spacing(3)
         self.vbox.set_spacing(3)
-        
+
         # Pack widgets
         self._hbox_location.pack_start(self._label_location, False, False)
         self._hbox_location.pack_start(self._combo, True, True)
         self.vbox.pack_start(self._hbox_location)
         self.action_area.pack_end(self._button_push)
-        
+
         # Show the dialog
         self.vbox.show_all()
-        
+
         # Build location history
         self._history = UrlHistory(self.branch.get_config(), 'push_history')
         self._build_history()
-        
+
     def _build_history(self):
         """ Build up the location history. """
         self._combo_model = gtk.ListStore(str)
@@ -81,18 +84,18 @@
             self._combo_model.append([ item ])
         self._combo.set_model(self._combo_model)
         self._combo.set_text_column(0)
-        
+
         if self.branch is not None:
             location = self.branch.get_push_location()
             if location is not None:
                 self._combo.get_child().set_text(location)
-    
+
     @show_bzr_error
     def _on_push_clicked(self, widget):
         """ Push button clicked handler. """
         location = self._combo.get_child().get_text()
         revs = 0
-        
+
         try:
             revs = do_push(self.branch, location=location, overwrite=False)
         except errors.DivergedBranches:
@@ -100,30 +103,28 @@
                                        _i18n('You cannot push if branches have diverged.\nOverwrite?'))
             if response == gtk.RESPONSE_YES:
                 revs = do_push(self.branch, location=location, overwrite=True)
-        
+
         if self.branch is not None and self.branch.get_push_location() is None:
             self.branch.set_push_location(location)
-        
+
         self._history.add_entry(location)
         info_dialog(_i18n('Push successful'),
                     _i18n("%d revision(s) pushed.") % revs)
-        
+
         self.response(gtk.RESPONSE_OK)
 
+
 def do_push(br_from, location, overwrite):
     """ Update a mirror of a branch.
-    
+
     :param br_from: the source branch
-    
     :param location: the location of the branch that you'd like to update
-    
     :param overwrite: overwrite target location if it diverged
-    
     :return: number of revisions pushed
     """
     from bzrlib.bzrdir import BzrDir
     from bzrlib.transport import get_transport
-        
+
     transport = get_transport(location)
     location_url = transport.base
 

=== modified file 'revbrowser.py'
--- revbrowser.py	2008-05-05 18:16:46 +0000
+++ revbrowser.py	2011-03-14 20:12:19 +0000
@@ -14,8 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import time
-
 try:
     import pygtk
     pygtk.require("2.0")
@@ -25,7 +23,6 @@
 import gobject
 import gtk
 
-from bzrlib.osutils import format_date
 from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.branchview.treeview import TreeView
 
@@ -37,43 +34,43 @@
                                   parent=parent,
                                   flags=gtk.DIALOG_MODAL,
                                   buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
-    
+
         # Get arguments
         self.branch = branch
-        
+
         # Create the widgets
         self._button_select = gtk.Button(_i18n("_Select"), use_underline=True)
         start_revs = [branch.last_revision(),]
         self.treeview = TreeView(branch, start_revs, None)
-        
+
         # Set callbacks
         self._button_select.connect('clicked', self._on_select_clicked)
         self.treeview.connect('revision-activated',
                                self._on_treeview_revision_activated)
-        
+
         # Set properties
         self.set_default_size(600, 400)
         self.vbox.set_spacing(3)
         self.treeview.set_property('graph-column-visible', False)
         self.treeview.set_property('date-column-visible', True)
         self.treeview.set_property('mainline-only', True)
-        
+
         # Construct the dialog
         self.action_area.pack_end(self._button_select)
-        
+
         self.vbox.pack_start(self.treeview, True, True)
 
         # Show the dialog
         self.show_all()
 
-    
+
     def _on_treeview_revision_activated(self, treeview, path, column):
         """ Double-click on a row should also select a revision. """
         self._on_select_clicked(treeview)
-    
+
     def _on_select_clicked(self, widget):
         """ Select button clicked handler. """
-        
+
         self.selected_revno = self.treeview.get_property('revision-number')
         self.selected_revid = \
                     self.treeview.get_property('revision').revision_id

=== modified file 'revidbox.py'
--- revidbox.py	2007-07-15 18:12:57 +0000
+++ revidbox.py	2011-03-14 20:12:19 +0000
@@ -24,6 +24,7 @@
 import gtk
 
 class RevisionSelectionBox(gtk.HBox):
+
     def __init__(self, branch):
         super(RevisionSelectionBox, self).__init__()
         self._branch = branch
@@ -32,25 +33,25 @@
         self._button_revid.set_image(gtk.image_new_from_stock(
             gtk.STOCK_OPEN, gtk.ICON_SIZE_BUTTON))
         self.pack_start(self._entry_revid, True, True)
-        self.pack_start(self._button_revid, False, False) 
+        self.pack_start(self._button_revid, False, False)
 
         self._button_revid.connect('clicked', self._on_revid_clicked)
 
     def _on_revid_clicked(self, widget):
         """ Browse for revision button clicked handler. """
         from revbrowser import RevisionBrowser
-        
+
         # FIXME: Should specific parent window here - how to get to it?
         # JRV 20070715
         revb = RevisionBrowser(self._branch)
         response = revb.run()
         if response != gtk.RESPONSE_NONE:
             revb.hide()
-        
+
             if response == gtk.RESPONSE_OK:
                 if revb.selected_revno is not None:
                     self._entry_revid.set_text(revb.selected_revid)
-            
+
             revb.destroy()
 
     def get_revision_id(self):

=== modified file 'revisionmenu.py'
--- revisionmenu.py	2008-07-01 21:54:21 +0000
+++ revisionmenu.py	2011-03-14 20:12:19 +0000
@@ -21,10 +21,9 @@
 except:
     pass
 
-import bzrlib
 import gtk
 import gobject
-from bzrlib import (errors, ui)
+from bzrlib import ui
 from bzrlib.revision import NULL_REVISION
 
 class RevisionMenu(gtk.Menu):
@@ -73,7 +72,7 @@
             item = gtk.MenuItem("_Send Merge Directive")
             item.connect('activate', self.send_merge_directive)
             self.append(item)
-            
+
             if self.wt:
                 item = gtk.MenuItem("_Revert to this revision")
                 item.connect('activate', self.revert)
@@ -126,12 +125,12 @@
 
         if response != gtk.RESPONSE_NONE:
             dialog.hide()
-        
+
             if response == gtk.RESPONSE_OK:
                 self.emit('tag-added', dialog.tagname, dialog._revid)
-            
+
             dialog.destroy()
-    
+
     def revert(self, item):
         pb = ui.ui_factory.nested_progress_bar()
         revision_tree = self.branch.repository.revision_tree(self.revids[0])

=== modified file 'revisionview.py'
--- revisionview.py	2009-12-09 13:27:53 +0000
+++ revisionview.py	2011-03-14 20:12:19 +0000
@@ -32,6 +32,8 @@
 
 from bzrlib.plugins.gtk import icon_path
 
+from bzrlib.plugins.gtk.avatarsbox import AvatarsBox
+
 try:
     from bzrlib.plugins.gtk import seahorse
 except ImportError:
@@ -93,7 +95,7 @@
                 (url, status) = bugline.split(" ")
                 if status == "fixed":
                     self.add_bug(url, status)
-        
+
         if self.num_bugs == 0:
             return
         elif self.num_bugs == 1:
@@ -402,13 +404,18 @@
 
     def _set_revision(self, revision):
         if revision is None: return
-
+        
+        self.avatarsbox.reset()
+        
         self._revision = revision
         if revision.committer is not None:
             self.committer.set_text(revision.committer)
+            self.avatarsbox.add(revision.committer, "committer")
         else:
             self.committer.set_text("")
+            self.avatarsbox.hide()
         author = revision.properties.get('author', '')
+        self.avatarsbox.merge(revision.get_apparent_authors(), "author")
         if author != '':
             self.author.set_text(author)
             self.author.show()
@@ -579,10 +586,15 @@
         self.connect_after('notify::revision', self._update_signature)
 
     def _create_headers(self):
+        self.avatarsbox = AvatarsBox()
+        
         self.table = gtk.Table(rows=5, columns=2)
         self.table.set_row_spacings(6)
         self.table.set_col_spacings(6)
         self.table.show()
+        
+        self.avatarsbox.pack_start(self.table)
+        self.avatarsbox.show()
 
         row = 0
 
@@ -673,7 +685,8 @@
 
         self.connect('notify::revision', self._add_tags)
 
-        return self.table
+        self.avatarsbox.show()
+        return self.avatarsbox
     
     def _create_parents(self):
         hbox = gtk.HBox(True, 3)

=== modified file 'seahorse.py'
--- seahorse.py	2008-08-05 13:56:46 +0000
+++ seahorse.py	2011-03-14 20:12:19 +0000
@@ -40,12 +40,12 @@
         name = get_name()
     else:
         name = getattr(e, '_dbus_error_name', None)
-        
+
     if name is None:
         args = getattr(e, 'args', None) # This is case for old python-dbus-0.62
         if args == ("Unable to determine the address of the message bus (try 'man dbus-launch' and 'man dbus-daemon' for help)",):
             raise ImportError
-        
+
     # DBus sometimes fails like this, just treat it as if seahorse is not
     # available rather than crashing.
     if name in ("org.freedesktop.DBus.Error.Spawn.ExecFailed", 

=== added file 'setup.cfg'
--- setup.cfg	1970-01-01 00:00:00 +0000
+++ setup.cfg	2010-08-21 09:38:06 +0000
@@ -0,0 +1,7 @@
+[build_i18n]
+domain=bzr-gtk
+desktop_files=[
+	('share/applications', ['bazaar-properties.desktop.in',
+				'bzr-handle-patch.desktop.in',
+				'bzr-notify.desktop.in'])]
+

=== modified file 'setup.py'
--- setup.py	2010-10-20 00:42:32 +0000
+++ setup.py	2011-03-06 10:43:25 +0000
@@ -6,6 +6,18 @@
 from distutils.core import setup, Command
 from distutils.command.install_data import install_data
 from distutils.command.build import build
+from distutils.command.sdist import sdist
+try:
+    from DistUtilsExtra.command import *
+except ImportError:
+   # Python distutils extra is not available.
+    class cmd_build_i18n(Command):
+        def run(self):
+            print >> sys.stderr, "For internationalization support you'll need to install https://launchpad.net/python-distutils-extra"
+else:
+    # Use build_i18n from DistUtilsExtra
+    cmd_build_i18n = build_i18n.build_i18n
+
 import os
 import sys
 
@@ -25,11 +37,13 @@
 
     def run(self):
         from bzrlib.tests import TestLoader, TestSuite, TextTestRunner
-        import __init__ as bzrgtk
+        from bzrlib.plugin import PluginImporter
+        PluginImporter.specific_paths["bzrlib.plugins.gtk"] = os.path.dirname(__file__)
+        from bzrlib.plugins.gtk.tests import load_tests
+        suite = TestSuite()
+        loader = TestLoader()
+        load_tests(suite, None, loader)
         runner = TextTestRunner()
-        loader = TestLoader()
-        suite = TestSuite()
-        suite.addTest(bzrgtk.test_suite())
         result = runner.run(suite)
         return result.wasSuccessful()
 
@@ -77,6 +91,11 @@
     sub_commands.append(('build_credits', is_versioned))
 
 
+class SourceDist(sdist):
+    sub_commands = sdist.sub_commands[:]
+    sub_commands.append(('build_credits', is_versioned))
+
+
 class InstallData(install_data):
 
     def run(self):
@@ -150,6 +169,8 @@
                                              'icons/tag-16.png',
                                              'icons/bug.png',
                                              'icons/bzr-icon-64.png']),
+                    # In case Python distutils extra is not available,
+                    # install the .desktop files
                     ('share/applications', ['bazaar-properties.desktop',
                                             'bzr-handle-patch.desktop',
                                             'bzr-notify.desktop']),
@@ -167,5 +188,7 @@
         cmdclass={'install_data': InstallData,
                   'build_credits': CreateCredits,
                   'build': BuildData,
+                  'build_i18n': cmd_build_i18n,
+                  'sdist': SourceDist,
                   'check': Check}
         )

=== modified file 'status.py'
--- status.py	2008-11-06 15:45:24 +0000
+++ status.py	2011-03-14 20:12:19 +0000
@@ -29,6 +29,7 @@
 
 class StatusWindow(window.Window):
     """ Display Status window and perform the needed actions. """
+
     def __init__(self, wt, wtpath, revision=None):
         """ Initialize the Status window. """
         super(StatusWindow, self).__init__()

=== modified file 'tags.py'
--- tags.py	2008-05-23 13:14:58 +0000
+++ tags.py	2011-03-14 20:12:19 +0000
@@ -24,12 +24,11 @@
 import gtk
 
 from bzrlib.plugins.gtk import _i18n
+from bzrlib.plugins.gtk.dialog import error_dialog
+from bzrlib.plugins.gtk.revidbox import RevisionSelectionBox
 from bzrlib.plugins.gtk.revisionview import RevisionView
 from bzrlib.plugins.gtk.window import Window
 
-from dialog import error_dialog
-from revidbox import RevisionSelectionBox
-
 
 class TagsWindow(Window):
     """ Tags window. Allows the user to view/add/remove tags. """
@@ -54,76 +53,76 @@
         self._vbox_buttons_top = gtk.VBox()
         self._vbox_buttons_bottom = gtk.VBox()
         self._vpaned = gtk.VPaned()
-        
+
         # Set callbacks
         self._button_add.connect('clicked', self._on_add_clicked)
         self._button_close.connect('clicked', self._on_close_clicked)
         self._button_refresh.connect('clicked', self._on_refresh_clicked)
         self._button_remove.connect('clicked', self._on_remove_clicked)
         self._treeview_tags.connect('cursor-changed', self._on_treeview_changed)
-        
+
         # Set properties
         self.set_title(_i18n("Tags"))
         self.set_default_size(600, 400)
-        
+
         self._scrolledwindow_tags.set_policy(gtk.POLICY_AUTOMATIC,
                                              gtk.POLICY_AUTOMATIC)
-        
+
         self._hbox.set_border_width(5)
         self._hbox.set_spacing(5)
         self._vbox_buttons.set_size_request(100, -1)
-        
+
         self._vbox_buttons_top.set_spacing(3)
-        
+
         self._vpaned.set_position(200)
-        
+
         # Construct the dialog
         self._scrolledwindow_tags.add(self._treeview_tags)
-        
+
         self._vbox_buttons_top.pack_start(self._button_add, False, False)
         self._vbox_buttons_top.pack_start(self._button_remove, False, False)
         self._vbox_buttons_top.pack_start(self._button_refresh, False, False)
         self._vbox_buttons_bottom.pack_start(self._button_close, False, False)
-        
+
         self._vbox_buttons.pack_start(self._vbox_buttons_top, True, True)
         self._vbox_buttons.pack_start(self._vbox_buttons_bottom, False, False)
-        
+
         self._vpaned.add1(self._scrolledwindow_tags)
         self._vpaned.add2(self._revisionview)
-        
+
         self._hbox.pack_start(self._vpaned, True, True)
         self._hbox.pack_start(self._vbox_buttons, False, True)
-        
+
         self.add(self._hbox)
-        
+
         # Default to no tags
         self._no_tags = True
-        
+
         # Load the tags
         self._load_tags()
-        
+
         # Display everything
         self._hbox.show_all()
-    
+
     def _load_tags(self):
         """ Load the tags into the TreeView. """
         tvcol_name = gtk.TreeViewColumn(_i18n("Tag Name"),
                                         gtk.CellRendererText(),
                                         text=0)
         tvcol_name.set_resizable(True)
-        
+
         tvcol_revid = gtk.TreeViewColumn(_i18n("Revision ID"),
                                          gtk.CellRendererText(),
                                          text=1)
         tvcol_revid.set_resizable(True)
-        
+
         self._treeview_tags.append_column(tvcol_name)
         self._treeview_tags.append_column(tvcol_revid)
-        
+
         self._treeview_tags.set_search_column(0)
-        
+
         self._refresh_tags()
-    
+
     def _refresh_tags(self):
         """ Refresh the list of tags. """
         self._model.clear()
@@ -133,7 +132,6 @@
                 self._no_tags = False
                 for name, target in tags.items():
                     self._model.append([name, target])
-                
                 self._button_add.set_sensitive(True)
                 self._button_remove.set_sensitive(True)
             else:
@@ -142,21 +140,20 @@
         else:
             self._no_tags = True
             self._tags_not_supported()
-        
         self._treeview_tags.set_model(self._model)
-    
+
     def _tags_not_supported(self):
         """ Tags are not supported. """
         self._model.append([_i18n("Tags are not supported by this branch format. Please upgrade."), ""])
         self._button_add.set_sensitive(False)
         self._button_remove.set_sensitive(False)
-    
+
     def _no_tags_available(self):
         """ No tags in the branch. """
         self._model.append([_i18n("No tagged revisions in the branch."), ""])
         self._button_add.set_sensitive(True)
         self._button_remove.set_sensitive(False)
-    
+
     def _on_add_clicked(self, widget):
         """ Add button event handler. """
         dialog = AddTagDialog(self.branch.repository, None,
@@ -164,13 +161,11 @@
         response = dialog.run()
         if response != gtk.RESPONSE_NONE:
             dialog.hide()
-        
             if response == gtk.RESPONSE_OK:
                 self.branch.tags.set_tag(dialog.tagname, dialog._revid)
                 self._refresh_tags()
-            
             dialog.destroy()
-    
+
     def _on_close_clicked(self, widget):
         """ Close button event handler. """
         self.destroy()
@@ -180,33 +175,29 @@
     def _on_refresh_clicked(self, widget):
         """ Refresh button event handler. """
         self._refresh_tags()
-    
+
     def _on_remove_clicked(self, widget):
         """ Remove button event handler. """
         (path, col) = self._treeview_tags.get_cursor()
         if path is None:
             return
-        
+
         tag = self._model[path][0]
-        
         dialog = RemoveTagDialog(tag, self)
         response = dialog.run()
         if response != gtk.RESPONSE_NONE:
             dialog.hide()
-        
             if response == gtk.RESPONSE_OK:
                 self.branch.tags.delete_tag(tag)
                 self._refresh_tags()
-            
             dialog.destroy()
-    
+
     def _on_treeview_changed(self, *args):
         """ When a user clicks on a tag. """
         # Refresh RevisionView only if there are tags available
         if not self._no_tags:
             (path, col) = self._treeview_tags.get_cursor()
             revision = self._model[path][1]
-            
             self._revisionview.set_revision(self.branch.repository.get_revision(revision))
 
 
@@ -217,10 +208,10 @@
                                   parent=parent,
                                   flags=0,
                                   buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
-        
+
         # Get the arguments
         self.tag = tagname
-        
+
         # Create the widgets
         self._hbox = gtk.HBox()
         self._vbox_question = gtk.VBox()
@@ -229,41 +220,41 @@
         self._label_title = gtk.Label()
         self._label_question = gtk.Label()
         self._button_remove = gtk.Button(_i18n("_Remove tag"), use_underline=True)
-        
+
         # Set callbacks
         self._button_remove.connect('clicked', self._on_remove_clicked)
-        
+
         # Set properties
         self._hbox.set_border_width(5)
         self._hbox.set_spacing(5)
         self._vbox_question.set_spacing(3)
-        
+
         self._label_title.set_markup(_i18n("<b><big>Remove tag?</big></b>"))
         self._label_title.set_alignment(0.0, 0.5)
         self._label_question.set_markup(_i18n("Are you sure you want to remove the tag: <b>%s</b>?") % self.tag)
         self._label_question.set_alignment(0.0, 0.5)
-        
+
         self._button_remove.set_image(gtk.image_new_from_stock(gtk.STOCK_REMOVE,
                                                                gtk.ICON_SIZE_BUTTON))
         self._button_remove.set_flags(gtk.CAN_DEFAULT)
-        
+
         # Construct the dialog
         self._vbox_question.pack_start(self._label_title)
         self._vbox_question.pack_start(self._label_question)
-        
+
         self._hbox.pack_start(self._image_question)
         self._hbox.pack_start(self._vbox_question)
-        
+
         self.vbox.add(self._hbox)
-        
+
         self.action_area.pack_end(self._button_remove)
-        
+
         # Display dialog
         self.vbox.show_all()
-        
+
         # Default to Commit button
         self._button_remove.grab_default()
-    
+
     def _on_remove_clicked(self, widget):
         """ Remove button event handler. """
         self.response(gtk.RESPONSE_OK)
@@ -271,6 +262,7 @@
 
 class AddTagDialog(gtk.Dialog):
     """ Add tag dialog. """
+
     def __init__(self, repository, revid=None, branch=None, parent=None):
         """ Initialize Add tag dialog. """
         gtk.Dialog.__init__(self, title="Add tag",
@@ -278,12 +270,12 @@
                                   flags=0,
                                   buttons=(gtk.STOCK_CANCEL, 
                                            gtk.RESPONSE_CANCEL))
-        
+
         # Get arguments
         self._repository = repository
         self._revid = revid
         self._branch = branch
-        
+
         # Create the widgets
         self._button_add = gtk.Button(_i18n("_Add tag"), use_underline=True)
         self._table = gtk.Table(2, 2)
@@ -294,17 +286,17 @@
             self._hbox_revid = gtk.Label(self._revid)
         else:
             self._hbox_revid = RevisionSelectionBox(self._branch)
-        
+
         # Set callbacks
         self._button_add.connect('clicked', self._on_add_clicked)
-        
+
         # Set properties
         self._label_name.set_alignment(0, 0.5)
         self._label_revid.set_alignment(0, 0.5)
         self._button_add.set_image(gtk.image_new_from_stock(gtk.STOCK_ADD,
                                                             gtk.ICON_SIZE_BUTTON))
         self._button_add.set_flags(gtk.CAN_DEFAULT)
-        
+
         # Construct the dialog
         self._table.attach(self._label_name, 0, 1, 0, 1)
         self._table.attach(self._label_revid, 0, 1, 1, 2)
@@ -312,23 +304,23 @@
         self._table.attach(self._hbox_revid, 1, 2, 1, 2)
         self.vbox.add(self._table)
         self.action_area.pack_end(self._button_add)
-        
+
         # Show the dialog
         self.vbox.show_all()
-    
+
     def _on_add_clicked(self, widget):
         """ Add button clicked handler. """
         if len(self._entry_name.get_text()) == 0:
             error_dialog(_i18n("No tag name specified"),
                          _i18n("You have to specify the tag's desired name."))
             return
-        
+
         if self._revid is None:
             if self._hbox_revid.get_revision_id() is None:
                 self._revid = self._branch.last_revision()
             else:
                 self._revid = self._hbox_revid.get_revision_id()
-            
+
         self.tagname = self._entry_name.get_text()
-        
+
         self.response(gtk.RESPONSE_OK)

=== modified file 'tests/test_linegraph.py'
--- tests/test_linegraph.py	2011-02-18 13:01:03 +0000
+++ tests/test_linegraph.py	2011-03-14 20:12:19 +0000
@@ -31,7 +31,7 @@
 
     def test_simple(self):
         lg = linegraph(self.get_graph({"A": ("B", "C"), "B": ()}), ["A"])
-        self.assertEquals(lg,  
+        self.assertEquals(lg,
             ([
                ['A', (0, 0), [(0, 0, 0)], ['B'], [], (2,)],
                ['B', (0, 0), [], (), ['A'], (1,)]

=== modified file 'ui.py'
--- ui.py	2009-06-15 14:02:08 +0000
+++ ui.py	2011-03-14 20:12:19 +0000
@@ -20,14 +20,13 @@
 """
 
 import gtk
-import sys
 
-from bzrlib import progress
 from bzrlib.ui import UIFactory
 
 
 class PromptDialog(gtk.Dialog):
-    """ Prompt the user for a yes/no answer. """
+    """Prompt the user for a yes/no answer."""
+
     def __init__(self, prompt):
         gtk.Dialog.__init__(self)
 

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2011-02-18 16:58:04 +0000
+++ viz/branchwin.py	2011-04-06 14:00:46 +0000
@@ -20,6 +20,7 @@
 from bzrlib.revision import NULL_REVISION
 from bzrlib.trace import mutter
 
+
 class BranchWindow(Window):
     """Branch window.
 
@@ -431,7 +432,7 @@
                 prev_menu.hide()
 
             if getattr(self.prev_button, 'set_menu', None) is not None:
-		self.prev_button.set_menu(prev_menu)
+                self.prev_button.set_menu(prev_menu)
 
             next_menu = gtk.Menu()
             if len(children) > 0:
@@ -452,7 +453,7 @@
                 next_menu.hide()
 
             if getattr(self.next_button, 'set_menu', None) is not None:
-		self.next_button.set_menu(next_menu)
+                self.next_button.set_menu(next_menu)
 
             self.revisionview.set_revision(revision)
             self.revisionview.set_children(children)

